(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   3488442,     103159]*)
(*NotebookOutlinePosition[   3489092,     103182]*)
(*  CellTagsIndexPosition[   3489048,     103178]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Mechanics: Small Oscillations:", "Title"],

Cell[CellGroupData[{

Cell[TextData[{
  "1 Eigenvalues and eigenvectors for small oscillating systems ",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]],
  " ",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(smallOsc[T_, V_, coord_List, equlib_List, 
        t_:  t] := \[IndentingNewLine]Module[{q, p, dim, equlibRule, Vij, 
          Tij, matrix, \[Omega]2Sol, freq, vector, eqs, 
          vSol}, \[IndentingNewLine]q = coord; \[IndentingNewLine]p = 
          D[coord, t]; 
        dim = Length[q]; \[IndentingNewLine]equlibRule = 
          Thread[coord \[Rule] equlib]; \[IndentingNewLine]Vij = 
          Outer[D[V, #1, #2] &, q, q\ ]; \[IndentingNewLine]Tij = 
          Outer[D[T, #1, #2] &, \ p, p\ ]; \[IndentingNewLine]matrix = 
          Vij - \[Omega]2\ Tij /. 
            equlibRule; \[IndentingNewLine]\[Omega]2Sol = 
          Simplify[
            Solve[Det[matrix] == 
                0, \[Omega]2]]; \[IndentingNewLine]freq = \[Omega]2 /. \
\[Omega]2Sol; 
        vector = Array[a, dim]; \[IndentingNewLine]eqs = 
          Simplify[
            ExpandAll[
              Thread[0 == matrix . vector]]]; \[IndentingNewLine]vSol = 
          Table[\[IndentingNewLine]\(Solve[
                Join[eqs /. \[Omega]2Sol[\([i]\)], {vector . vector == 
                      1}]\[IndentingNewLine], vector]\)[\([2]\)], {i, 1, 
              dim}]; \[IndentingNewLine]{freq, vSol}\ ]\)], "Input"],

Cell["Protect[smallOsc ];", "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", 
        FormBox[
          RowBox[{
            RowBox[{\(1\/2\), " ", "m", " ", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], "2"]}], "+", 
            RowBox[{\(1\/2\), " ", "m", " ", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "(", "t", ")"}], "2"]}]}],
          "TraditionalForm"]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"V", "=", 
        FormBox[\(1\/2\ k1\ \((q2(t) - q1(t))\)\^2\),
          "TraditionalForm"]}], ";"}]}], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(smallOsc[T, V, {q1[t], q2[t]}, {0, 0}, t]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", \(\(2\ k1\)\/m\)},
            {\({a(1) \[Rule] 1\/\@2, 
                a(2) \[Rule] 1\/\@2}\), \({a(1) \[Rule] 1\/\@2, 
                a(2) \[Rule] \(-\(1\/\@2\)\)}\)}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 2: Three Coupled Oscillators along a Line  ",
  StyleBox[" ",
    FontColor->RGBColor[0, 1, 0]]
}], "Subsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["Remarks and outline ", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    FormBox[
      RowBox[{\(Clear::"wrsym"\), \(\(:\)\(\ \)\), "\<\"Symbol \
\\!\\(TraditionalForm\\`diffSeriesOne\\) is Protected.\"\>"}], 
      TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{\(Clear::"wrsym"\), \(\(:\)\(\ \)\), "\<\"Symbol \
\\!\\(TraditionalForm\\`doublePlot\\) is Protected.\"\>"}], 
      TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{\(Clear::"wrsym"\), \(\(:\)\(\ \)\), "\<\"Symbol \
\\!\\(TraditionalForm\\`phasePlot\\) is Protected.\"\>"}], 
      TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(TraditionalForm\\`\\(Clear :: \\\"wrsym\\\"\\)\\) will be suppressed \
during this calculation.\"\>"}], TraditionalForm]], "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{
          RowBox[{\(1\/2\), " ", "m", " ", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox[\(x[1]\), "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
                SuperscriptBox[
                  RowBox[{
                    SuperscriptBox[\(x[3]\), "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}], "2"]}], 
              ")"}]}], "+", 
          RowBox[{\(1\/2\), " ", "M", " ", 
            SuperscriptBox[
              RowBox[{
                SuperscriptBox[\(x[2]\), "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}], " ", 
      ";", "\n", \(V = 
        1\/2\ k\ \((\((\(x[2]\)[t] - \(x[1]\)[t])\)\^2 + \((\(x[3]\)[t] - \
\(x[2]\)[t])\)\^2)\)\), " ", ";"}]], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(solution\)\(=\)\(smallOsc[T, 
        V, {\(x[1]\)[t], \(x[2]\)[t], \(x[3]\)[t]}, {0, 0, 0}, 
        t]\)\(\ \)\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", \(k\/m\), \(k\ \((2\/M + 1\/m)\)\)},
            {\({a(1) \[Rule] 1\/\@3, a(3) \[Rule] 1\/\@3, 
                a(2) \[Rule] 1\/\@3}\), \({a(1) \[Rule] 1\/\@2, 
                a(3) \[Rule] \(-\(1\/\@2\)\), 
                a(2) \[Rule] 0}\), \({a(1) \[Rule] 
                  M\/\(\@2\ \@\(2\ m\^2 + M\^2\)\), 
                a(3) \[Rule] M\/\(\@2\ \@\(2\ m\^2 + M\^2\)\), 
                a(2) \[Rule] \(-\(\(\@2\ m\)\/\@\(2\ m\^2 + M\^2\)\)\)}\)}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(eigenmatrix = \(\(Array[a, 
          3]\)\(/.\)\(solution[\([2]\)]\)\(\ \)\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/\@3\), \(1\/\@3\), \(1\/\@3\)},
            {\(1\/\@2\), "0", \(-\(1\/\@2\)\)},
            {\(M\/\(\@2\ \@\(2\ m\^2 + M\^2\)\)\), \(-\(\(\@2\ m\)\/\@\(2\ \
m\^2 + M\^2\)\)\), \(M\/\(\@2\ \@\(2\ m\^2 + M\^2\)\)\)}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(xRule = {x1[t], x2[t], x3[t]} \[Rule] 
          Transpose[eigenmatrix] . {c1\ t + \[Phi]1, 
              c2\ Cos[\[Omega]2\ t + \[Phi]2], 
              c3\ Cos[\[Omega]3\ t + \[Phi]3]}\  // Thread\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{x1(
          t) \[Rule] \(c1\ t + \[Phi]1\)\/\@3 + \(c2\ \(cos(\[Phi]2 + t\ \
\[Omega]2)\)\)\/\@2 + \(c3\ M\ \(cos(\[Phi]3 + t\ \[Omega]3)\)\)\/\(\@2\ \
\@\(2\ m\^2 + M\^2\)\), 
      x2(t) \[Rule] \(c1\ t + \[Phi]1\)\/\@3 - \(\@2\ c3\ m\ \(cos(\[Phi]3 + \
t\ \[Omega]3)\)\)\/\@\(2\ m\^2 + M\^2\), 
      x3(t) \[Rule] \(c1\ t + \[Phi]1\)\/\@3 - \(c2\ \(cos(\[Phi]2 + t\ \
\[Omega]2)\)\)\/\@2 + \(c3\ M\ \(cos(\[Phi]3 + t\ \[Omega]3)\)\)\/\(\@2\ \
\@\(2\ m\^2 + M\^2\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(freqrule = {\[Omega]1, \[Omega]2, \[Omega]3} \[Rule] \
\@solution[\([1]\)]\  // Thread\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm\`{\[Omega]1 \[Rule] 
        0, \[Omega]2 \[Rule] \@\(k\/m\), \[Omega]3 \[Rule] \@\(k\ \((2\/M + 1\
\/m)\)\)}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(values = {k \[Rule] 1, m \[Rule] 1, 
          M \[Rule] 3, \[Phi]1 \[Rule] 0, \[Phi]2 \[Rule] 0, \[Phi]3 \[Rule] 
            0};\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(allRules = Join[xRule, freqrule, values];\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(xPlot[C1_, C2_, C3_] := 
        Plot[\({x1[t] + 2, x2[t], x3[t] - 2} //. 
                allRules\) //. {c1 \[Rule] C1, c2 \[Rule] C2, 
                c3 \[Rule] C3}\  // Evaluate, \[IndentingNewLine]{t, 0, 
            20}, \[IndentingNewLine]PlotStyle \[Rule] \
{\[IndentingNewLine]{Thickness[0.010], 
                Hue[ .3]}, \[IndentingNewLine]{Thickness[0.009], 
                Hue[ .6]}, \[IndentingNewLine]{Thickness[0.007], 
                Hue[ .9]}}, \[IndentingNewLine]AxesLabel \[Rule] {t\ , 
              x}, \[IndentingNewLine]DisplayFunction -> 
            Identity];\)\)], "Input"],

Cell[BoxData[
    \(\(xLPlot[C1_, C2_, C3_, opts___] := 
        ParametricPlot3D[\({x1[t], x2[t], x3[t]} //. 
                allRules\) //. {c1 \[Rule] C1, c2 \[Rule] C2, 
                c3 \[Rule] C3}\  // Evaluate, \[IndentingNewLine]{t, 0, 
            20}, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 
              1}, \[IndentingNewLine]AxesLabel \[Rule] {x1, x2, 
              x3}, \[IndentingNewLine]opts, \
\[IndentingNewLine]DisplayFunction -> Identity];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{xPlot[1, 0, 0], \ 
            xLPlot[1, 0, 0\ \ , Ticks \[Rule] None\ ]}]];\)\)], "Input",
  Hyphenation->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0904343 0.0378596 [
[.2619 .07793 -3 -9 ]
[.2619 .07793 3 0 ]
[.5 .07793 -6 -9 ]
[.5 .07793 6 0 ]
[.7381 .07793 -6 -9 ]
[.7381 .07793 6 0 ]
[.97619 .07793 -6 -9 ]
[.97619 .07793 6 0 ]
[1.025 .09043 0 -4.90625 ]
[1.025 .09043 10 4.90625 ]
[.01131 .18508 -18 -4.5 ]
[.01131 .18508 0 4.5 ]
[.01131 .27973 -6 -4.5 ]
[.01131 .27973 0 4.5 ]
[.01131 .37438 -18 -4.5 ]
[.01131 .37438 0 4.5 ]
[.01131 .46903 -12 -4.5 ]
[.01131 .46903 0 4.5 ]
[.01131 .56368 -24 -4.5 ]
[.01131 .56368 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .09043 m
.2619 .09668 L
s
[(5)] .2619 .07793 0 1 Mshowa
.5 .09043 m
.5 .09668 L
s
[(10)] .5 .07793 0 1 Mshowa
.7381 .09043 m
.7381 .09668 L
s
[(15)] .7381 .07793 0 1 Mshowa
.97619 .09043 m
.97619 .09668 L
s
[(20)] .97619 .07793 0 1 Mshowa
.125 Mabswid
.07143 .09043 m
.07143 .09418 L
s
.11905 .09043 m
.11905 .09418 L
s
.16667 .09043 m
.16667 .09418 L
s
.21429 .09043 m
.21429 .09418 L
s
.30952 .09043 m
.30952 .09418 L
s
.35714 .09043 m
.35714 .09418 L
s
.40476 .09043 m
.40476 .09418 L
s
.45238 .09043 m
.45238 .09418 L
s
.54762 .09043 m
.54762 .09418 L
s
.59524 .09043 m
.59524 .09418 L
s
.64286 .09043 m
.64286 .09418 L
s
.69048 .09043 m
.69048 .09418 L
s
.78571 .09043 m
.78571 .09418 L
s
.83333 .09043 m
.83333 .09418 L
s
.88095 .09043 m
.88095 .09418 L
s
.92857 .09043 m
.92857 .09418 L
s
.25 Mabswid
0 .09043 m
1 .09043 L
s
gsave
1.025 .09043 -61 -8.90625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.02381 .18508 m
.03006 .18508 L
s
[(2.5)] .01131 .18508 1 0 Mshowa
.02381 .27973 m
.03006 .27973 L
s
[(5)] .01131 .27973 1 0 Mshowa
.02381 .37438 m
.03006 .37438 L
s
[(7.5)] .01131 .37438 1 0 Mshowa
.02381 .46903 m
.03006 .46903 L
s
[(10)] .01131 .46903 1 0 Mshowa
.02381 .56368 m
.03006 .56368 L
s
[(12.5)] .01131 .56368 1 0 Mshowa
.125 Mabswid
.02381 .01472 m
.02756 .01472 L
s
.02381 .03364 m
.02756 .03364 L
s
.02381 .05257 m
.02756 .05257 L
s
.02381 .0715 m
.02756 .0715 L
s
.02381 .10936 m
.02756 .10936 L
s
.02381 .12829 m
.02756 .12829 L
s
.02381 .14722 m
.02756 .14722 L
s
.02381 .16615 m
.02756 .16615 L
s
.02381 .20401 m
.02756 .20401 L
s
.02381 .22294 m
.02756 .22294 L
s
.02381 .24187 m
.02756 .24187 L
s
.02381 .2608 m
.02756 .2608 L
s
.02381 .29866 m
.02756 .29866 L
s
.02381 .31759 m
.02756 .31759 L
s
.02381 .33652 m
.02756 .33652 L
s
.02381 .35545 m
.02756 .35545 L
s
.02381 .39331 m
.02756 .39331 L
s
.02381 .41224 m
.02756 .41224 L
s
.02381 .43117 m
.02756 .43117 L
s
.02381 .4501 m
.02756 .4501 L
s
.02381 .48796 m
.02756 .48796 L
s
.02381 .50689 m
.02756 .50689 L
s
.02381 .52582 m
.02756 .52582 L
s
.02381 .54475 m
.02756 .54475 L
s
.02381 .58261 m
.02756 .58261 L
s
.02381 .60154 m
.02756 .60154 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.2 1 0 r
.01 w
.02381 .16615 m
.06244 .18389 L
.10458 .20323 L
.14415 .22139 L
.18221 .23886 L
.22272 .25746 L
.26171 .27536 L
.30316 .29438 L
.34309 .31271 L
.3815 .33034 L
.42237 .3491 L
.46172 .36716 L
.49955 .38453 L
.53984 .40302 L
.57861 .42082 L
.61984 .43974 L
.65954 .45797 L
.69774 .4755 L
.73838 .49416 L
.77751 .51212 L
.81909 .53121 L
.85916 .5496 L
.89771 .5673 L
.93871 .58612 L
.97619 .60332 L
s
0 .4 1 r
.009 w
.02381 .09043 m
.06244 .10817 L
.10458 .12751 L
.14415 .14567 L
.18221 .16314 L
.22272 .18174 L
.26171 .19964 L
.30316 .21866 L
.34309 .23699 L
.3815 .25462 L
.42237 .27338 L
.46172 .29144 L
.49955 .30881 L
.53984 .3273 L
.57861 .3451 L
.61984 .36402 L
.65954 .38225 L
.69774 .39978 L
.73838 .41844 L
.77751 .4364 L
.81909 .45549 L
.85916 .47388 L
.89771 .49158 L
.93871 .5104 L
.97619 .5276 L
s
1 0 .6 r
.007 w
.02381 .01472 m
.06244 .03245 L
.10458 .05179 L
.14415 .06996 L
.18221 .08742 L
.22272 .10602 L
.26171 .12392 L
.30316 .14294 L
.34309 .16127 L
.3815 .1789 L
.42237 .19766 L
.46172 .21572 L
.49955 .23309 L
.53984 .25158 L
.57861 .26938 L
.61984 .28831 L
.65954 .30653 L
.69774 .32406 L
.73838 .34272 L
.77751 .36068 L
.81909 .37977 L
.85916 .39816 L
.89771 .41586 L
.93871 .43468 L
.97619 .45188 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 7.96346e-17 1.16608 [
[.30907 .06148 -14.3775 -9.8125 ]
[.30907 .06148 1.62253 0 ]
[.2142 1.04697 -8.70051 0 ]
[.2142 1.04697 7.29949 9.8125 ]
[-0.03373 .52941 -16 -3.08918 ]
[-0.03373 .52941 0 6.72332 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
gsave
.30907 .06148 -75.3775 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
1.000 setlinewidth
grestore
0 .80374 m
.40037 1.0855 L
s
gsave
.2142 1.04697 -69.7005 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
1.000 setlinewidth
grestore
.08846 .24555 m
0 .80374 L
s
gsave
-0.03373 .52941 -77 -7.08918 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x3) show
1.000 setlinewidth
grestore
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.10855 .26104 m
.11945 .26944 L
s
.11945 .26944 m
.13036 .27785 L
s
.13036 .27785 m
.1413 .28628 L
s
.1413 .28628 m
.15226 .29473 L
s
.15226 .29473 m
.16324 .30319 L
s
.16324 .30319 m
.17424 .31167 L
s
.17424 .31167 m
.18526 .32017 L
s
.18526 .32017 m
.19631 .32868 L
s
.19631 .32868 m
.20737 .33721 L
s
.20737 .33721 m
.21846 .34576 L
s
.21846 .34576 m
.22957 .35432 L
s
.22957 .35432 m
.2407 .3629 L
s
.2407 .3629 m
.25186 .3715 L
s
.25186 .3715 m
.26303 .38011 L
s
.26303 .38011 m
.27423 .38874 L
s
.27423 .38874 m
.28545 .39739 L
s
.28545 .39739 m
.29669 .40605 L
s
.29669 .40605 m
.30796 .41474 L
s
.30796 .41474 m
.31924 .42344 L
s
.31924 .42344 m
.33055 .43215 L
s
.33055 .43215 m
.34189 .44089 L
s
.34189 .44089 m
.35324 .44964 L
s
.35324 .44964 m
.36462 .45841 L
s
.36462 .45841 m
.37602 .46719 L
s
.37602 .46719 m
.38744 .476 L
s
.38744 .476 m
.39889 .48482 L
s
.39889 .48482 m
.41035 .49366 L
s
.41035 .49366 m
.42185 .50252 L
s
.42185 .50252 m
.43336 .51139 L
s
.43336 .51139 m
.4449 .52029 L
s
.4449 .52029 m
.45646 .5292 L
s
.45646 .5292 m
.46804 .53812 L
s
.46804 .53812 m
.47965 .54707 L
s
.47965 .54707 m
.49128 .55604 L
s
.49128 .55604 m
.50294 .56502 L
s
.50294 .56502 m
.51461 .57402 L
s
.51461 .57402 m
.52632 .58304 L
s
.52632 .58304 m
.53804 .59208 L
s
.53804 .59208 m
.54979 .60113 L
s
.54979 .60113 m
.56156 .61021 L
s
.56156 .61021 m
.57336 .6193 L
s
.57336 .6193 m
.58518 .62841 L
s
.58518 .62841 m
.59703 .63754 L
s
.59703 .63754 m
.60889 .64669 L
s
.60889 .64669 m
.62079 .65586 L
s
.62079 .65586 m
.63271 .66504 L
s
.63271 .66504 m
.64465 .67425 L
s
.64465 .67425 m
.65661 .68347 L
s
.65661 .68347 m
.6686 .69271 L
s
.6686 .69271 m
.68062 .70197 L
s
.68062 .70197 m
.69266 .71125 L
s
.69266 .71125 m
.70472 .72055 L
s
.70472 .72055 m
.71681 .72987 L
s
.71681 .72987 m
.72893 .73921 L
s
.72893 .73921 m
.74107 .74856 L
s
.74107 .74856 m
.75323 .75794 L
s
.75323 .75794 m
.76542 .76733 L
s
.76542 .76733 m
.77764 .77675 L
s
.77764 .77675 m
.78988 .78618 L
s
.78988 .78618 m
.80214 .79564 L
s
.80214 .79564 m
.81443 .80511 L
s
.81443 .80511 m
.82675 .8146 L
s
.82675 .8146 m
.83909 .82412 L
s
.83909 .82412 m
.85146 .83365 L
s
.85146 .83365 m
.86385 .8432 L
s
.86385 .8432 m
.87627 .85277 L
s
.87627 .85277 m
.88872 .86237 L
s
.88872 .86237 m
.90119 .87198 L
s
.90119 .87198 m
.91369 .88161 L
s
.91369 .88161 m
.92621 .89126 L
s
.92621 .89126 m
.93876 .90094 L
s
.93876 .90094 m
.95134 .91063 L
s
.95134 .91063 m
.96394 .92034 L
s
.96394 .92034 m
.97657 .93008 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
gsave
.30907 .06148 -75.3775 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
1.000 setlinewidth
grestore
0 .80374 m
.40037 1.0855 L
s
gsave
.2142 1.04697 -69.7005 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{647, 190.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:70000_R000`400?l00000o`00003oo`3ooooo
0?ooohT0oooo003o0?ooool0ooooR@3oool00?l0ooooo`3ooon90?ooo`00o`3ooooo0?ooohT0oooo
003o0?ooool0ooooR@3oool00?l0ooooo`3oool;0?ooo`800000O03oool00?l0ooooo`3oool90?oo
o`80000000<0oooo000000000000N`3oool00?l0ooooo`3oool70?ooo`8000000`3oool2000007/0
oooo000[0?ooo`030000003oool0oooo0?l0ooooU@3oool2000000030?ooo`00000000000080oooo
1000000e0?ooo`<000001@3oool00`000000oooo0000001j0?ooo`00:`3oool00`000000oooo0?oo
o`3o0?oooiH0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0b0?ooo`800000203o
ool00`000000oooo0000001j0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooiL0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0_0?ooo`<000002P3oool010000000oooo0?ooo`00
001i0?ooo`00:`3oool00`000000oooo0?ooo`3o0?oooiH0oooo00<000000?ooo`0000001@3oool0
0`000000oooo0?ooo`0]0?ooo`8000003@3oool01@000000oooo0?ooo`3oool0000007P0oooo000[
0?ooo`80o`2Io`3ooonF0?ooo`80000000<0oooo000000000000103oool00`000000oooo0?ooo`0[
0?ooo`8000003`3oool01@000000oooo0?ooo`3oool0000007P0oooo000[0?ooo`040000003oool0
o`2I0?l0VOl0ooooV`3oool3000002X0oooo0`00000A0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0M@3oool002/0oooo00@000000?ooo`3oool0oooo0`3o09Wo0?oooiX0oooo00<0
00000?ooo`3oool09P3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1d0?ooo`00:`3oool00`000000oooo0?ooo`040?ooo`80o`2Io`3ooono0?ooo`8000005`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo07@0oooo000[0?ooo`030000003oool0oooo
00H0oooo0`3o09Wo0?oookT0oooo0`00000I0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0L`3oool002/0oooo0P0000090?ooo`<0o`2Io`3ooone0?ooo`800000703oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo07<0oooo000[0?ooo`030000003oool0oooo00/0oooo
0P3o09Wo0?oook00oooo0`00000N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
LP3oool002/0oooo00<000000?ooo`3oool03@3oool20?l0VOl0oooo[03oool200000240oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`00:`3oool00`000000oooo0?ooo`0?
0?ooo`<0o`2Io`3ooonW0?ooo`8000008`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0740oooo000[0?ooo`030000003oool0oooo0140oooo0`3o09TT0?ooo`<00000=P3oool40000
00<0oooo0P00000d0?ooo`@000000P3oool3000003<0oooo100000030?ooo`800000`P3oool30000
02D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1`0?ooo`00:`3oool2000001@0
oooo0`3o09TU0?ooo`030000003oool0oooo03D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000_`3oool2000002P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`1`0?ooo`00:`3oool00`000000oooo0?ooo`0E0?oo
o`<0o`2I8`3oool00`000000oooo0?ooo`0e0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000;d0oooo0P00000Z0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0K`3oool002/0oooo00<000000?ooo`3oool05`3oool3
0?l0VAh0oooo0`00000h0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0c0?ooo`040000003oool0oooo0?ooo`<00000=@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0^03oool3000002`0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`1^0?ooo`00:`3oool00`000000oooo0?ooo`0I0?ooo`<0o`2I703oool00`000000oooo
0?ooo`0h0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0c0?ooo`05
0000003oool0oooo0?ooo`000000>03oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0;H0oooo0P00000_0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0KP3oool0
02/0oooo0P00000L0?ooo`<0o`2I6P3oool00`000000oooo0?ooo`0f0?ooo`<000000`3oool01000
0000oooo0?ooo`00000c0?ooo`<000000`3oool00`000000oooo0?ooo`0c0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000]@3oool300000340oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`1]0?ooo`00:`3oool00`000000oooo0?ooo`0N0?ooo`80o`2I603o
ool4000003L0oooo00<000000?ooo`3oool00P3oool2000003H0oooo00@000000?ooo`3oool0oooo
1000000c0?ooo`800000103oool200000;@0oooo0P00000d0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0K@3oool002/0oooo00<000000?ooo`3oool0803oool30?l0VOl0ooooP`3o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00:`3oool0
0`000000oooo0?ooo`0S0?ooo`80o`2Io`3ooomn0?ooo`<00000>03oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo06/0oooo000[0?ooo`03001Vo`3oool0oooo02D0oooo0`3o09WI0?oo
o`800000W@3oool2000003/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?oo
o`009@3oool5000000@006Ko9`0000030?l0VLd000002@3oool010000000oooo0?ooo`00002J0?oo
o`800000?@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo06X0oooo000[0?ooo`D0
06Ko1`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0103oool30?l0V@80oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo09P0oooo0`00000o0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0J@3oool002/0oooo00<000000?ooo`00I_l01000I_lW0?ooo`<0o`2I303oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo09H0oooo0P0000120?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0J@3oool002/0oooo00@000000?ooo`3oool0oooo1@00I_lW0?ooo`<0o`2I
c`3oool4000009<0oooo0`0000150?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
J03oool002/0oooo00<000000?ooo`3oool00`3oool5001VobL0oooo0`3o09W>0?ooo`030000003o
ool0oooo0940oooo0P0000180?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0J03o
ool002/0oooo0P0000060?ooo`D006Ko9`3oool30?l0VL`0oooo00<000000?ooo`3oool0S`3oool2
000004X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1W0?ooo`00:`3oool00`00
0000oooo0?ooo`070?ooo`D006Ko9`3oool30?l0VOl0ooooFP3oool3000004`0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`1V0?ooo`00:`3oool00`000000oooo0?ooo`090?ooo`D0
06Ko9`3oool30?l0VOl0ooooEP3oool2000004l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`1V0?ooo`00:`3oool00`000000oooo0?ooo`0<0?ooo`D006Ko9P3oool30?l0VOl0oooo
DP3oool200000540oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1U0?ooo`00:`3o
ool00`000000oooo0?ooo`0>0?ooo`D006Ko9P3oool30?l0VOl0ooooC@3oool3000005<0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`1U0?ooo`00:`3oool200000140oooo1@00I_lV
0?ooo`<0o`2Io`3ooom90?ooo`800000EP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo06@0oooo000[0?ooo`030000003oool0oooo0180oooo1P00I_lU0?ooo`<0o`2Io`3ooom40?oo
o`<00000F03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo06<0oooo000[0?ooo`03
0000003oool0oooo01D0oooo1@00I_lU0?ooo`<0o`2Io`3ooom00?ooo`800000F`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo06<0oooo000[0?ooo`030000003oool0oooo01L0oooo
1P00I_lT0?ooo`<0o`2Io`3oooll0?ooo`800000G@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo0680oooo000[0?ooo`030000003oool0oooo01X0oooo1@00I_lT0?ooo`<0o`2Io`3o
oolh0?ooo`800000G`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0680oooo000[
0?ooo`8000007@3oool5001VobD0oooo0P3o09Wo0?ooocH0oooo0P00001O0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0H@3oool002/0oooo00<000000?ooo`3oool07P3oool5001V
obD0oooo0`3o09Wo0?oooc<0oooo00@000000?ooo`0000000000G@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo0600oooo000[0?ooo`030000003oool0oooo0200oooo1@00I_lV0?oo
o`80o`2Io`3ooola0?ooo`030000003oool0oooo00800000G03oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo0600oooo000[0?ooo`0303?o003oool0oooo0280oooo1@00I_lV0?ooo`<0
o`2Io`3oool]0?ooo`030000003oool0oooo0080oooo0P00001K0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0G`3oool002X0oooo100co`0T0?ooo`D006Ko9P3oool30?l0VOl0oooo
:`3oool00`000000oooo0?ooo`030?ooo`<00000F@3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo05h0oooo000[0?ooo`D0<ol0903oool6001VobD0oooo0`3o09Wo0?ooobT0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0000001H0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0GP3oool002/0oooo00<000000?ooo`0co`00100co`0U0?ooo`D006Ko9@3oool3
0?l0VOl0oooo9`3oool00`000000oooo0?ooo`050?ooo`030000003oool0000005L0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`1M0?ooo`005`3oool4000000<0oooo00<000000?oo
o`3oool00P3oool3000000D0oooo00@000000?ooo`3oool0oooo1@0co`0U0?ooo`H006Ko903oool3
0?l0VOl0oooo9@3oool00`000000oooo0?ooo`060?ooo`030000003oool0000005L0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`1M0?ooo`005`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool503?o02H0oooo1@00I_lT0?oo
o`<0o`2Io`3ooolS0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`0000000000E@3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05`0oooo000H0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00P3oool3000000D0oooo1@0co`0V0?ooo`D006Ko9@3oool30?l0
VOl0oooo7`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00800000D`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo05/0oooo000I0?ooo`030000003oool0oooo00L0
oooo0`0000050?ooo`030000003oool0oooo00L0oooo1@0co`0V0?ooo`D006Ko9P3oool20?l0VOl0
oooo7@3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000005<0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`006P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool503?o02H0oooo1@00I_lV0?ooo`<0
o`2Io`3ooolJ0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool00000DP3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo05X0oooo000G0?ooo`040000003oool0oooo0000
00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`D0<ol09@3oool5001V
obL0oooo0`3o09Wo0?oooaL0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020000
0500oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00603oool2000000T0
oooo100000040?ooo`030000003oool0oooo00h0oooo1@0co`0U0?ooo`D006Ko9`3oool30?l0VOl0
oooo5@3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000C`3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo05T0oooo000[0?ooo`8000004@3oool503?o02D0
oooo1@00I_lW0?ooo`<0o`2Io`3ooolC0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3o
ool0oooo0000001>0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0F03oool002/0
oooo00<000000?ooo`3oool04P3oool603?o02@0oooo1@00I_lW0?ooo`<0o`2Io`3oool@0?ooo`03
0000003oool0oooo0100oooo00@000000?ooo`3oool0oooo0P00001<0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0F03oool002/0oooo00<000000?ooo`3oool05@3oool503?o02@0
oooo1@00I_lW0?ooo`<0o`2Io`3oool>0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool00P3oool2000004X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00
:`3oool00`000000oooo0?ooo`0G0?ooo`H0<ol08`3oool5001VobL0oooo0`3o09Wo0?ooo``0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00:`3oool00`000000oooo0?oo
o`0J0?ooo`D0<ol08`3oool5001VobP0oooo0P3o09Wo0?ooo`X0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`1F0?ooo`00:`3oool2000001d0oooo1@0co`0S0?ooo`H006Ko9`3oool2
0?l0VOl0oooo203oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo0P000017
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool002/0oooo00<000000?oo
o`3oool07P3oool503?o02@0oooo1@00I_lW0?ooo`80o`2Io`3oool60?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0E@3oool002/0oooo00<000000?ooo`3oool0803oool503?o02@0
oooo1P00I_lV0?ooo`<0o`2Io`3oool20?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0E03oool002/0oooo00<000000?ooo`3oool08P3oool503?o02D0oooo1@00I_lV0?ooo`<0o`2I
o`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00<0oooo0P0000130?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0D`3oool002/0oooo00<000000?ooo`3oool0903o
ool503?o02D0oooo1@00I_lV0?ooo`<0o`2Io@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00@0oooo0P0000110?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0D`3o
ool002/0oooo0P00000W0?ooo`D0<ol09@3oool5001VobH0oooo0`3o09Wk0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0DP3oool002/0oooo00<000000?ooo`3oool0:03oool503?o
02D0oooo1@00I_lV0?ooo`<0o`2In@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
0580oooo000[0?ooo`030000003oool0oooo02X0oooo1@0co`0U0?ooo`D006Ko9P3oool30?l0VOL0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool08@3oool2000005<0oooo000[0?ooo`030000003oool0oooo02`0oooo
1@0co`0U0?ooo`D006Ko9P3oool30?l0VO@0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool07P3oool3000000030?oo
o`000000oooo0580oooo000[0?ooo`800000;`3oool503?o02D0oooo1@00I_lV0?ooo`<0o`2IlP3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0K0?ooo`<00000103oool00`000000oooo0?ooo`1A0?ooo`00:`3oool0
0`000000oooo0?ooo`0`0?ooo`H0<ol0903oool5001VobH0oooo0`3o09W`0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool01P3oool2000003/0oooo00<000000?ooo`3oool0603oool3
000000L0oooo00<000000?ooo`3oool0D@3oool002/0oooo00<000000?ooo`3oool0<`3oool503?o
02D0oooo1@00I_lU0?ooo`<0o`2IkP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
00L0oooo0P00000i0?ooo`030000003oool0oooo01D0oooo0`00000;0?ooo`030000003oool0oooo
0500oooo000S0?ooo`<000001@3oool00`000000oooo0?ooo`0e0?ooo`H0<ol0903oool5001VobD0
oooo0`3o09W/0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo0180oooo0`00000>0?ooo`030000003oool0oooo0500
oooo000V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>03oool503?o02@0oooo
1@00I_lV0?ooo`<0o`2Ij@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0?0?ooo`<000004@3oool00`000000oooo
0?ooo`1@0?ooo`009P3oool00`000000oooo0?ooo`020?ooo`<00000>P3oool503?o02@0oooo1P00
I_lV0?ooo`80o`2IiP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo0P00
000e0?ooo`030000003oool0oooo00/0oooo1000000D0?ooo`030000003oool0oooo0500oooo000S
0?ooo`<000001@3oool00`000000oooo0?ooo`0l0?ooo`D0<ol09@3oool5001VobH0oooo0`3o09WS
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo00P0oooo0`00000H0?ooo`030000003oool0oooo0500oooo000S0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0?P3oool503?o02D0oooo1P00I_lV0?oo
o`<0o`2Ih03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`050?ooo`<000006`3oool00`000000oooo0?ooo`1@0?oo
o`008`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0400oooo1@0co`0V0?ooo`D0
06Ko9P3oool30?l0VMh0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool00P3oool3000001h0oooo00<000000?ooo`3o
ool0D03oool002<0oooo100000040?ooo`030000003oool0oooo0480oooo1@0co`0V0?ooo`@006Ko
9`3oool30?l0VM`0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`0000000P00000R0?ooo`030000003oool0oooo04l0oooo
000[0?ooo`800000A@3oool503?o02H0oooo1000I_lW0?ooo`<0o`2IfP3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<0
00000?ooo`3oool0C`3oool002/0oooo00<000000?ooo`3oool0AP3oool503?o02H0oooo1000I_lW
0?ooo`<0o`2Ie`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo0P00000Z
0?ooo`<0000000<0oooo0000003oool09@3oool00`000000oooo0?ooo`1?0?ooo`00:`3oool00`00
0000oooo0?ooo`180?ooo`D0<ol09P3oool4001VobL0oooo0`3o09WE0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0T0?ooo`<00000103oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo000[0?ooo`030000003oool0oooo04X0
oooo1@0co`0U0?ooo`D006Ko9`3oool30?l0VM<0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0200oooo0`0000070?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0C`3oool002/0oooo00<000000?ooo`3oool0C03oool503?o02D0oooo
1P00I_lV0?ooo`<0o`2Id@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo
0P00000M0?ooo`<000002P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo
000[0?ooo`800000C`3oool603?o02D0oooo1@00I_lV0?ooo`<0o`2Ic`3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo00/0oooo0P00000H0?ooo`<000003@3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo04l0oooo000[0?ooo`030000003oool0oooo0540oooo1@0co`0U
0?ooo`H006Ko9@3oool30?l0VLd0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0180oooo0`00000@0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0C`3oool002/0oooo00<000000?ooo`3oool0D`3oool603?o02D0oooo1@00I_lU0?oo
o`<0o`2I/03oool2000000030?ooo`000000000000<0oooo0P00000@0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`<00000503oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo04h0oooo000[0?ooo`030000003oool0oooo05H0
oooo1@0co`0U0?ooo`D006Ko9P3oool20?l0VJl0oooo00<000000?ooo`0000000`3oool010000000
oooo0?ooo`00000?0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0303oool20000
00X0oooo1000000G0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0CP3oool002/0
oooo00<000000?ooo`3oool0F03oool503?o02D0oooo1@00I_lV0?ooo`<0o`2I[@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo0`00000K0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0CP3oool002/0oooo0P00001K0?ooo`D0<ol09@3oool5001VobL0oooo
0P3o09VZ0?ooo`030000003oool0000000@0oooo0P00000@0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0303oool010000000oooo0?ooo`3oool3000001h0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`1>0?ooo`00:`3oool00`000000oooo0?ooo`1M0?ooo`D0<ol0
903oool5001VobL0oooo0`3o09VV0?ooo`80000000<0oooo0000000000001@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool300000240oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1>0?ooo`00:`3oool00`000000oooo0?oo
o`1O0?ooo`D0<ol0903oool5001VobL0oooo0`3o09V[0?ooo`040000003oool0oooo000000l0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`080?ooo`<000000P3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0CP3oool002/0oooo00<0
00000?ooo`3oool0H@3oool503?o02@0oooo1@00I_lW0?ooo`<0o`2IZP3oool2000000l0oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`040?ooo`<000001P3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0CP3oool002/0oooo00<00000
0?ooo`3oool0H`3oool503?o02@0oooo1@00I_lW0?ooo`<0o`2I^@3oool00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo00<000002P3oool2000001h0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`1=0?ooo`00:`3oool2000006H0oooo1@0co`0U0?ooo`D006Ko9P3oool30?l0
VKL0oooo00<000000?ooo`3oool0>`3oool2000000l0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04d0oooo000[0?ooo`030000003oool0oooo06L0
oooo1@0co`0U0?ooo`D006Ko9P3oool30?l0VKD0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo01T0oooo0P00000W0?ooo`030000003oool0oooo04d0
oooo000H0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool3000000D0oooo
00<000000?ooo`3oool0J@3oool503?o02D0oooo1@00I_lV0?ooo`<0o`2I/`3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo0100oooo0P00000F0?ooo`<000000P3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo04d0oooo000H0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1[0?ooo`D0<ol09@3oool6001VobH0oooo0P3o
09Va0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0@0?ooo`<000001P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo04d0oooo000I
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool3000006d0oooo1@0co`0V
0?ooo`D006Ko9P3oool20?l0VJh0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00/0oooo100000090?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0C@3oool001T0oooo00<000000?ooo`3oool01`3oool3000000D0oooo00<000000?oo
o`3oool0L03oool403?o02H0oooo1P00I_lU0?ooo`<0o`2IZ`3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo01@0oooo0P0000080?ooo`<000003P3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo04d0oooo000J0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1b0?ooo`D0<ol09P3oool5001VobD0oooo0`3o09VY0?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`<0
00004P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo04`0oooo000G0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1d0?ooo`D0
<ol09P3oool5001VobH0oooo0P3o09VW0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool05`3oool4000001H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1<0?ooo`00
5`3oool4000000P0oooo100000040?ooo`030000003oool0oooo07H0oooo1@0co`0V0?ooo`D006Ko
9P3oool30?l0VJ@0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0E0?ooo`D00000
603oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo04`0oooo000[0?ooo`800000N@3o
ool503?o02H0oooo1@00I_lW0?ooo`80o`2IXP3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0140oooo100000050?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`1<0?ooo`00:`3oool00`000000oooo0?ooo`1j0?ooo`D0<ol09P3oool5
001VobL0oooo0`3o09VN0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03P3oool3
000000X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo04`0oooo000[0?ooo`030000003oool0oooo07`0oooo1@0co`0V0?ooo`D006Ko9`3oool30?l0
VI`0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0;0?ooo`<000003P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0C03oool002/0
oooo00<000000?ooo`3oool0OP3oool503?o02H0oooo1@00I_lW0?ooo`<0o`2IVP3oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo00P0oooo0`00000B0?ooo`8000005P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo04`0oooo000[0?ooo`030000003oool0oooo0800oooo
1P0co`0U0?ooo`D006Ko9`3oool30?l0VIP0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`050?ooo`<000005`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0B`3oool002/0oooo0P0000240?ooo`D0<ol09@3oool5001VobL0oooo0`3o
09VF0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool00P3oool4000001/0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo04/0oooo000[
0?ooo`030000003oool0oooo08D0oooo1P0co`0T0?ooo`D006Ko9`3oool30?l0VI@0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0000000200000200oooo0P00000D0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0B`3oool002/0oooo00<000000?ooo`3oool0R03oool503?o
02@0oooo1@00I_lW0?ooo`<0o`2IT@3oool00`000000oooo0?ooo`0l0?ooo`<000009@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0B`3oool002/0
oooo00<000000?ooo`3oool0RP3oool503?o02@0oooo1P00I_lV0?ooo`<0o`2IS`3oool00`000000
oooo0?ooo`0i0?ooo`<0000000<0oooo0000003oool09P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0B`3oool002/0oooo00<000000?ooo`3oool0
S03oool503?o02D0oooo1@00I_lV0?ooo`<0o`2IS@3oool00`000000oooo0?ooo`0f0?ooo`<00000
103oool00`000000oooo0?ooo`0V0?ooo`8000004`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo04/0oooo000[0?ooo`800000T03oool503?o02@0oooo1P00I_lU0?ooo`<0o`2IR`3o
ool00`000000oooo0?ooo`0b0?ooo`@000001`3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1;0?ooo`00:`3oool0
0`000000oooo0?ooo`2A0?ooo`D0<ol09@3oool5001VobD0oooo0`3o09V90?ooo`030000003oool0
oooo02l0oooo0`00000;0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04/0oooo000[0?ooo`030000003oool0oooo
09<0oooo1@0co`0U0?ooo`D006Ko9P3oool20?l0VHL0oooo00<000000?ooo`3oool0;03oool30000
00h0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0BP3oool002/0oooo00<000000?ooo`3oool0U@3oool503?o02D0
oooo1@00I_lV0?ooo`80o`2IQ03oool00`000000oooo0?ooo`0Z0?ooo`<000004@3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`1:0?ooo`00:`3oool00`000000oooo0?ooo`2G0?ooo`D0<ol09P3oool5001VobD0oooo
0P3o09V20?ooo`030000003oool0oooo02L0oooo0`00000D0?ooo`030000003oool0oooo02`0oooo
0P00000A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0BP3oool002/0oooo0P00
002J0?ooo`D0<ol09P3oool5001VobD0oooo0P3o09V00?ooo`030000003oool0oooo02<0oooo1000
000G0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo04X0oooo000[0?ooo`030000003oool0oooo09/0oooo1@0co`0V
0?ooo`D006KoY@3oool00`000000oooo0?ooo`0P0?ooo`<000006`3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1:
0?ooo`007@3oool4000000<0oooo0P0000050?ooo`030000003oool0oooo09d0oooo1@0co`0V0?oo
o`D006KoX`3oool00`000000oooo0?ooo`0M0?ooo`<000007P3oool00`000000oooo0?ooo`0`0?oo
o`8000003`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04X0oooo000O0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
09l0oooo1P0co`0U0?ooo`D006KoX@3oool00`000000oooo0?ooo`0J0?ooo`<000008@3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`1:0?ooo`007`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool00P3oool300000:80oooo1@0co`0U0?ooo`D006KoWP3oool00`000000oooo0?ooo`0H0?oo
o`<00000903oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`190?ooo`007`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2T0?ooo`H0<ol0903oool5001V
oi`0oooo00<000000?ooo`3oool0503oool4000002L0oooo00<000000?ooo`3oool0=03oool20000
00h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`190?ooo`007`3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2W0?oo
o`D0<ol0903oool5001VoiX0oooo00<000000?ooo`3oool04@3oool3000002/0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0B@3oool001d0oooo0`0000030?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0Z@3oool503?o02@0oooo1P00I_nG0?ooo`030000003oool0oooo00h0oooo0`00000^0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo04T0oooo000O0?ooo`030000003oool0oooo0080oooo0P0000050?ooo`03
0000003oool0oooo0:/0oooo1@0co`0U0?ooo`D006KoU@3oool00`000000oooo0?ooo`0;0?ooo`<0
0000<@3oool00`000000oooo0?ooo`0h0?ooo`800000303oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo04T0oooo000[0?ooo`800000[P3oool503?o02D0oooo1P00I_nB0?ooo`030000
003oool0oooo00P0oooo0`00000d0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04T0oooo000[0?ooo`030000003o
ool0oooo0:l0oooo1@0co`0V0?ooo`D006KoS`3oool00`000000oooo0?ooo`050?ooo`@00000=`3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`190?ooo`00:`3oool00`000000oooo0?ooo`2a0?ooo`D0<ol09P3oool5
001Vohd0oooo00<000000?ooo`3oool00P3oool3000003/0oooo00<000000?ooo`3oool0?03oool2
000000/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`180?ooo`00:`3oool00`00
0000oooo0?ooo`2c0?ooo`H0<ol09@3oool5001Voh/0oooo00<000000?ooo`0000000P00000n0?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo04P0oooo000[0?ooo`030000003oool0oooo0;H0oooo1@0co`0U0?ooo`D0
06KoR@3oool200000440oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0B03oool002/0oooo0P00002i0?ooo`H0<ol0
903oool5001VohP0oooo0P0000100?ooo`030000003oool0oooo0400oooo0P0000090?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0B03oool002/0oooo00<000000?ooo`3oool0^`3o
ool503?o02@0oooo1@00I_n80?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0B03o
ool002/0oooo00<000000?ooo`3oool0_@3oool503?o02@0oooo1@00I_n70?ooo`800000?@3oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`180?ooo`00:`3oool00`000000oooo0?ooo`2o0?ooo`D0<ol09@3oool4001V
ohL0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`140?ooo`800000203oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo04P0oooo000[0?ooo`030000003oool0oooo0<80
oooo1@0co`0T0?ooo`D006KoQ@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04L0
oooo000[0?ooo`800000a@3oool503?o02@0oooo1000I_n50?ooo`800000>03oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`170?ooo`00:`3oool00`000000oooo0?ooo`360?ooo`D0<ol0903oool00`00I_l0oooo0?oo
o`260?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0A`3oool002/0oooo00<00000
0?ooo`3oool0b03oool503?o0:`0oooo0P00000e0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04L0oooo000[0?oo
o`030000003oool0oooo0<X0oooo1@0co`2/0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0B`3oool2000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`170?oo
o`00:`3oool00`000000oooo0?ooo`3<0?ooo`D0<ol0Z`3oool200000380oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0A`3oool002/0oooo0P00003?0?ooo`D0<ol0Z`3oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo04h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo04L0oooo000[0?ooo`030000003oool0oooo0=00oooo1@0co`2Z0?ooo`800000;`3o
ool00`000000oooo0?ooo`1?0?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo04L0oooo000[0?ooo`030000003oool0oooo0=80oooo1P0co`2Y0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0AP3oool00140oooo100000020?ooo`@000000`3oool00`00
0000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`3E0?ooo`D0<ol0Z03oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo04H0oooo000C0?ooo`050000003oool0oooo0?oo
o`0000003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0=L0oooo1P0co`2V0?oo
o`800000:`3oool00`000000oooo0?ooo`1C0?ooo`8000000P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo04H0oooo000C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`020?ooo`<00000fP3oool503?o0:H0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`1E0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0AP3oool001<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`<0
00001@3oool00`000000oooo0?ooo`3L0?ooo`D0<ol0Y@3oool2000002P0oooo00<000000?ooo`3o
ool0EP3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo04H0oooo000C0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0=h0oooo1@0co`2U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0E`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo04H0oooo000A0?ooo`<0
00000`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0h03oool503?o0:@0oooo0P00000U0?ooo`030000003oool0oooo05P0oooo00H000000?oo
o`3oool000000?ooo`0000180?ooo`004`3oool00`000000oooo0?ooo`020?ooo`8000002@3oool4
000000@0oooo0P00003S0?ooo`D0<ol0Y03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo05T0oooo0P000000103oool000000?ooo`0000170?ooo`00:`3oool00`000000oooo0?ooo`3T
0?ooo`D0<ol0X`3oool200000280oooo00<000000?ooo`3oool0G03oool00`000000oooo00000017
0?ooo`00:`3oool00`000000oooo0?ooo`3V0?ooo`@0<ol0Y03oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo05d0oooo0P0000170?ooo`00:`3oool00`000000oooo0?ooo`3X0?ooo`@0
<ol0X`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05`0oooo0`0000170?ooo`00
:`3oool00`000000oooo0?ooo`3Z0?ooo`@0<ol0XP3oool2000001h0oooo00<000000?ooo`3oool0
F03oool4000004X0oooo000[0?ooo`800000k@3oool403?o0:80oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`1C0?ooo`D00000CP3oool002/0oooo00<000000?ooo`3oool0k@3oool4
03?o0:80oooo0P00000K0?ooo`030000003oool0oooo04l0oooo1000001C0?ooo`00:`3oool00`00
0000oooo0?ooo`3_0?ooo`0303?o003oool0oooo0:<0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`1:0?ooo`D00000E`3oool002/0oooo00<000000?ooo`3oool0o`3ooonG0?ooo`80
0000603oool00`000000oooo0?ooo`160?ooo`@00000G03oool002/0oooo00<000000?ooo`3oool0
o`3ooonI0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0@P3oool400000600oooo
003o0?ooolP0oooo0P00000E0?ooo`030000003oool0oooo03d0oooo1@00001T0?ooo`00o`3oooo:
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0>@3oool4000006T0oooo003o0?oo
ol/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0e0?ooo`D00000K@3oool00?l0
ooooc03oool200000100oooo00<000000?ooo`3oool0<@3oool400000780oooo003o0?ooolh0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0/0?ooo`D00000MP3oool00?l0ooooc`3o
ool2000000d0oooo00<000000?ooo`3oool0:03oool4000007/0oooo003o0?ooom40oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0S0?ooo`D00000O`3oool00?l0oooodP3oool20000
00X0oooo00<000000?ooo`3oool07`3oool4000008@0oooo003o0?ooom@0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0J0?ooo`D00000R03oool002P0oooo0P0000000`3oool00000
0000003o0?ooojP0oooo0P0000070?ooo`030000003oool0oooo01H0oooo1000002=0?ooo`00:@3o
ool00`000000oooo0000003o0?oooj/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0B0?ooo`@00000T@3oool002X0oooo00<000000?ooo`3oool0o`3ooon[0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool03@3oool5000009D0oooo000Y0?ooo`030000003oool00000
0?l0oooo[@3oool2000000<0oooo00<000000?ooo`3oool02@3oool4000009X0oooo000X0?ooo`80
000000<0oooo000000000000o`3ooon<0?ooo`80000000<0oooo0000000000000P3oool4000001L0
oooo00@000000?ooo`3oool000001P3oool5000009h0oooo003o0?oookX0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`0I0?ooo`<000000P3oool400000:<0oooo003o0?oook/0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`<00000Y`3oool00?l0oooo^P3o
ool00`000000oooo000000050?ooo`030000003oool0oooo0<<0oooo003o0?oookT0oooo0P000000
0`3oool00000000000050?ooo`030000003oool0oooo0<80oooo003o0?oool00oooo00@000000?oo
o`3oool00000a03oool00?l0oooo`@3oool200000<D0oooo003o0?ooool0ooooR@3oool00?l0oooo
o`3ooon90?ooo`00o`3ooooo0?ooohT0oooo003o0?ooool0ooooR@3oool00001\
\>"],
  ImageRangeCache->{{{0, 646}, {189.375, 0}} -> {-0.054129, -0.0147182, \
0.00326356, 0.00326356}, {{16.5625, 308.375}, {184.812, 4.5}} -> {-3.61186, \
-3.2239, 0.0825706, 0.103856}, {{337.562, 629.375}, {184.812, 4.5}} -> \
{-2.12514, -0.0240309, 0.00526606, 0.00526606}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{xPlot[0, 1, 0], \ 
            xLPlot[0, 1, 0\ , Ticks \[Rule] None, 
              ViewPoint \[Rule] {1, 1, 
                  1}]}\[IndentingNewLine]]\[IndentingNewLine]];\)\)], "Input",\

  Hyphenation->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.309017 0.108715 [
[.2619 .29652 -3 -9 ]
[.2619 .29652 3 0 ]
[.5 .29652 -6 -9 ]
[.5 .29652 6 0 ]
[.7381 .29652 -6 -9 ]
[.7381 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -4.90625 ]
[1.025 .30902 10 4.90625 ]
[.01131 .09159 -12 -4.5 ]
[.01131 .09159 0 4.5 ]
[.01131 .2003 -12 -4.5 ]
[.01131 .2003 0 4.5 ]
[.01131 .41773 -6 -4.5 ]
[.01131 .41773 0 4.5 ]
[.01131 .52645 -6 -4.5 ]
[.01131 .52645 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(10)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(15)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -8.90625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.02381 .09159 m
.03006 .09159 L
s
[(-2)] .01131 .09159 1 0 Mshowa
.02381 .2003 m
.03006 .2003 L
s
[(-1)] .01131 .2003 1 0 Mshowa
.02381 .41773 m
.03006 .41773 L
s
[(1)] .01131 .41773 1 0 Mshowa
.02381 .52645 m
.03006 .52645 L
s
[(2)] .01131 .52645 1 0 Mshowa
.125 Mabswid
.02381 .11333 m
.02756 .11333 L
s
.02381 .13507 m
.02756 .13507 L
s
.02381 .15682 m
.02756 .15682 L
s
.02381 .17856 m
.02756 .17856 L
s
.02381 .22205 m
.02756 .22205 L
s
.02381 .24379 m
.02756 .24379 L
s
.02381 .26553 m
.02756 .26553 L
s
.02381 .28727 m
.02756 .28727 L
s
.02381 .33076 m
.02756 .33076 L
s
.02381 .3525 m
.02756 .3525 L
s
.02381 .37425 m
.02756 .37425 L
s
.02381 .39599 m
.02756 .39599 L
s
.02381 .43947 m
.02756 .43947 L
s
.02381 .46122 m
.02756 .46122 L
s
.02381 .48296 m
.02756 .48296 L
s
.02381 .5047 m
.02756 .5047 L
s
.02381 .06984 m
.02756 .06984 L
s
.02381 .0481 m
.02756 .0481 L
s
.02381 .02636 m
.02756 .02636 L
s
.02381 .00462 m
.02756 .00462 L
s
.02381 .54819 m
.02756 .54819 L
s
.02381 .56993 m
.02756 .56993 L
s
.02381 .59167 m
.02756 .59167 L
s
.02381 .61342 m
.02756 .61342 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.2 1 0 r
.01 w
.02381 .60332 m
.02499 .6033 L
.02605 .60323 L
.02729 .60311 L
.02846 .60295 L
.03053 .60255 L
.03279 .60196 L
.03527 .6011 L
.0379 .59998 L
.04262 .5974 L
.05205 .59019 L
.06244 .57938 L
.0842 .54935 L
.10458 .51683 L
.12312 .48861 L
.13291 .47574 L
.14335 .46439 L
.1491 .45937 L
.15431 .45567 L
.15683 .45419 L
.15955 .45281 L
.1621 .45173 L
.16449 .45092 L
.16691 .45029 L
.1682 .45003 L
.16957 .44982 L
.17027 .44974 L
.17102 .44967 L
.17173 .44962 L
.17239 .44959 L
.17363 .44957 L
.17495 .44961 L
.17609 .44969 L
.17731 .44983 L
.17847 .45001 L
.17953 .45021 L
.18199 .45082 L
.18458 .45168 L
.18958 .45396 L
.19412 .45673 L
.20432 .46521 L
.21377 .47557 L
.22268 .48719 L
.26115 .54708 L
.28064 .57484 L
.29171 .5873 L
.29702 .59215 L
.30207 .59601 L
.30682 .59892 L
.30933 .60017 L
Mistroke
.312 .60127 L
.31447 .60209 L
.3167 .60265 L
.31778 .60286 L
.31895 .60304 L
.32005 .60317 L
.32107 .60325 L
.32225 .60331 L
.32352 .60331 L
.32471 .60327 L
.3258 .60319 L
.32708 .60304 L
.32847 .60281 L
.331 .60224 L
.33364 .60141 L
.33644 .60028 L
.34147 .59761 L
.35087 .59053 L
.36098 .58014 L
.37928 .55562 L
.39896 .52459 L
.42047 .49123 L
.43042 .47782 L
.44103 .46586 L
.44619 .4611 L
.45105 .45732 L
.45575 .45434 L
.46014 .45219 L
.46238 .45134 L
.46479 .45061 L
.46616 .45028 L
.46746 .45002 L
.46862 .44984 L
.46989 .4497 L
.47112 .44961 L
.47183 .44958 L
.47248 .44957 L
.47318 .44958 L
.47381 .4496 L
.47451 .44963 L
.47524 .44969 L
.47647 .44983 L
.47761 .45 L
.4802 .45055 L
.4826 .45126 L
.48487 .45211 L
.48912 .45415 L
.4937 .45699 L
.49866 .4608 L
.50811 .46997 L
Mistroke
.51851 .48261 L
.53955 .51382 L
.5606 .54748 L
.57986 .57487 L
.58937 .58575 L
.59439 .59057 L
.59975 .59493 L
.60489 .59829 L
.60955 .60062 L
.6118 .60149 L
.61424 .60224 L
.61535 .60252 L
.61653 .60277 L
.61763 .60296 L
.61865 .6031 L
.61987 .60323 L
.62051 .60327 L
.6212 .6033 L
.62235 .60332 L
.62361 .60329 L
.62474 .60321 L
.62595 .60308 L
.62709 .60292 L
.62814 .60272 L
.6305 .60216 L
.63309 .60132 L
.6383 .59897 L
.6429 .59618 L
.6478 .59248 L
.65664 .58408 L
.678 .55632 L
.69816 .52459 L
.71649 .49587 L
.7269 .48129 L
.73664 .4696 L
.74624 .46039 L
.75162 .45638 L
.75653 .45349 L
.75904 .45232 L
.7617 .4513 L
.76324 .45082 L
.76463 .45045 L
.76604 .45014 L
.76733 .44991 L
.76857 .44975 L
.76987 .44964 L
.77118 .44958 L
.77192 .44957 L
.77262 .44958 L
.77387 .44965 L
Mistroke
.77502 .44975 L
.77633 .44992 L
.77758 .45014 L
.77996 .4507 L
.78219 .45139 L
.78727 .45359 L
.79222 .45653 L
.79755 .46053 L
.80717 .46982 L
.81598 .48035 L
.85568 .541 L
.8757 .57055 L
.88442 .58128 L
.89386 .59081 L
.89913 .59506 L
.90398 .59823 L
.90862 .60057 L
.91096 .60148 L
.91353 .60227 L
.91493 .60261 L
.91626 .60287 L
.91746 .60305 L
.91876 .6032 L
.91943 .60325 L
.92017 .60329 L
.92094 .60332 L
.92167 .60332 L
.92297 .60328 L
.9237 .60323 L
.92437 .60317 L
.92559 .60302 L
.92672 .60284 L
.9293 .60227 L
.93181 .60149 L
.93449 .60043 L
.93982 .59764 L
.94473 .59428 L
.95583 .58409 L
.97598 .55813 L
.97619 .55782 L
Mfstroke
0 .4 1 r
.009 w
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.30316 .30902 L
.34309 .30902 L
.3815 .30902 L
.42237 .30902 L
.46172 .30902 L
.49955 .30902 L
.53984 .30902 L
.57861 .30902 L
.61984 .30902 L
.65954 .30902 L
.69774 .30902 L
.73838 .30902 L
.77751 .30902 L
.81909 .30902 L
.85916 .30902 L
.89771 .30902 L
.93871 .30902 L
.97619 .30902 L
s
1 0 .6 r
.007 w
.02381 .01472 m
.02499 .01474 L
.02605 .0148 L
.02729 .01492 L
.02846 .01508 L
.03053 .01548 L
.03279 .01608 L
.03527 .01693 L
.0379 .01805 L
.04262 .02063 L
.05205 .02784 L
.06244 .03866 L
.0842 .06868 L
.10458 .1012 L
.12312 .12943 L
.13291 .1423 L
.14335 .15365 L
.1491 .15866 L
.15431 .16236 L
.15683 .16385 L
.15955 .16523 L
.1621 .1663 L
.16449 .16711 L
.16691 .16775 L
.1682 .168 L
.16957 .16821 L
.17027 .16829 L
.17102 .16836 L
.17173 .16841 L
.17239 .16844 L
.17363 .16846 L
.17495 .16842 L
.17609 .16834 L
.17731 .1682 L
.17847 .16803 L
.17953 .16783 L
.18199 .16722 L
.18458 .16636 L
.18958 .16407 L
.19412 .1613 L
.20432 .15283 L
.21377 .14247 L
.22268 .13085 L
.26115 .07095 L
.28064 .04319 L
.29171 .03073 L
.29702 .02588 L
.30207 .02203 L
.30682 .01912 L
.30933 .01787 L
Mistroke
.312 .01676 L
.31447 .01595 L
.3167 .01539 L
.31778 .01518 L
.31895 .01499 L
.32005 .01486 L
.32107 .01478 L
.32225 .01472 L
.32352 .01472 L
.32471 .01476 L
.3258 .01485 L
.32708 .015 L
.32847 .01522 L
.331 .01579 L
.33364 .01662 L
.33644 .01775 L
.34147 .02042 L
.35087 .0275 L
.36098 .03789 L
.37928 .06242 L
.39896 .09345 L
.42047 .1268 L
.43042 .14021 L
.44103 .15217 L
.44619 .15693 L
.45105 .16072 L
.45575 .16369 L
.46014 .16584 L
.46238 .1667 L
.46479 .16743 L
.46616 .16776 L
.46746 .16801 L
.46862 .16819 L
.46989 .16834 L
.47112 .16842 L
.47183 .16845 L
.47248 .16846 L
.47318 .16846 L
.47381 .16844 L
.47451 .1684 L
.47524 .16834 L
.47647 .16821 L
.47761 .16804 L
.4802 .16749 L
.4826 .16677 L
.48487 .16593 L
.48912 .16389 L
.4937 .16104 L
.49866 .15724 L
.50811 .14807 L
Mistroke
.51851 .13542 L
.53955 .10422 L
.5606 .07056 L
.57986 .04317 L
.58937 .03228 L
.59439 .02746 L
.59975 .02311 L
.60489 .01974 L
.60955 .01741 L
.6118 .01654 L
.61424 .01579 L
.61535 .01551 L
.61653 .01526 L
.61763 .01507 L
.61865 .01493 L
.61987 .01481 L
.62051 .01476 L
.6212 .01473 L
.62235 .01472 L
.62361 .01475 L
.62474 .01482 L
.62595 .01495 L
.62709 .01512 L
.62814 .01531 L
.6305 .01588 L
.63309 .01671 L
.6383 .01906 L
.6429 .02186 L
.6478 .02555 L
.65664 .03395 L
.678 .06171 L
.69816 .09344 L
.71649 .12217 L
.7269 .13674 L
.73664 .14844 L
.74624 .15764 L
.75162 .16165 L
.75653 .16454 L
.75904 .16571 L
.7617 .16674 L
.76324 .16722 L
.76463 .16759 L
.76604 .1679 L
.76733 .16812 L
.76857 .16828 L
.76987 .1684 L
.77118 .16845 L
.77192 .16846 L
.77262 .16845 L
.77387 .16839 L
Mistroke
.77502 .16829 L
.77633 .16811 L
.77758 .1679 L
.77996 .16734 L
.78219 .16664 L
.78727 .16444 L
.79222 .1615 L
.79755 .1575 L
.80717 .14822 L
.81598 .13769 L
.85568 .07703 L
.8757 .04749 L
.88442 .03676 L
.89386 .02722 L
.89913 .02297 L
.90398 .0198 L
.90862 .01747 L
.91096 .01656 L
.91353 .01577 L
.91493 .01543 L
.91626 .01516 L
.91746 .01498 L
.91876 .01483 L
.91943 .01478 L
.92017 .01474 L
.92094 .01472 L
.92167 .01472 L
.92297 .01476 L
.9237 .0148 L
.92437 .01486 L
.92559 .01501 L
.92672 .01519 L
.9293 .01577 L
.93181 .01654 L
.93449 .0176 L
.93982 .02039 L
.94473 .02375 L
.95583 .03394 L
.97598 .05991 L
.97619 .06022 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0773503 1.1547 -2.1413e-17 1.1547 [
[.28173 1.02423 -8.92376 0 ]
[.28173 1.02423 7.07624 9.8125 ]
[.22213 .16489 -16 -8.5482 ]
[.22213 .16489 0 1.2643 ]
[.99614 .54294 0 -7.03072 ]
[.99614 .54294 16 2.78178 ]
[ 0 0 0 0 ]
[ 1 .98974 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.5 .98974 m
0 .86603 L
s
gsave
.28173 1.02423 -69.9238 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
1.000 setlinewidth
grestore
.14286 .37115 m
.5 0 L
s
gsave
.22213 .16489 -77 -12.5482 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
1.000 setlinewidth
grestore
.85714 .37115 m
1 .86603 L
s
gsave
.99614 .54294 -61 -11.0307 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x3) show
1.000 setlinewidth
grestore
.5 .57735 m
.5 .98974 L
s
.5 .98974 m
1 .86603 L
s
1 .86603 m
.85714 .37115 L
s
.85714 .37115 m
.5 .57735 L
s
.14286 .37115 m
.5 0 L
s
.5 0 m
.5 .57735 L
s
.5 .57735 m
0 .86603 L
s
0 .86603 m
.14286 .37115 L
s
.5 .57735 m
.5 .98974 L
s
.5 .98974 m
0 .86603 L
s
0 .86603 m
.14286 .37115 L
s
.14286 .37115 m
.5 .57735 L
s
.85714 .37115 m
.5 0 L
s
.5 0 m
.5 .57735 L
s
.5 .57735 m
1 .86603 L
s
1 .86603 m
.85714 .37115 L
s
0 0 m
1 0 L
1 .98974 L
0 .98974 L
closepath
clip
newpath
.5 Mabswid
.31292 .25333 m
.33737 .29567 L
s
.30206 .23452 m
.31292 .25333 L
s
.30159 .23369 m
.30879 .24617 L
s
.30343 .23688 m
.31777 .26172 L
s
.30336 .23677 m
.30343 .23688 L
s
.30558 .2406 m
.30206 .23452 L
s
.32321 .27115 m
.30558 .2406 L
s
.31777 .26172 m
.34534 .30947 L
s
.31758 .26139 m
.30336 .23677 L
s
.34504 .30896 m
.31758 .26139 L
s
.32988 .2827 m
.36333 .34063 L
s
.30879 .24617 m
.32988 .2827 L
s
.30567 .24077 m
.32343 .27152 L
s
.30203 .23446 m
.30567 .24077 L
s
.31277 .25305 m
.30203 .23446 L
s
.3371 .2952 m
.31277 .25305 L
s
.33737 .29567 m
.37363 .35846 L
s
.37326 .35783 m
.3371 .2952 L
s
.35369 .32393 m
.32321 .27115 L
s
.39479 .39511 m
.35369 .32393 L
s
.34534 .30947 m
.38415 .37669 L
s
.32343 .27152 m
.35401 .32448 L
s
.38376 .37602 m
.34504 .30896 L
s
.35401 .32448 m
.39519 .39581 L
s
.44353 .47954 m
.39479 .39511 L
s
.36333 .34063 m
.4067 .41575 L
s
.43092 .45771 m
.38376 .37602 L
s
.41863 .43641 m
.37326 .35783 L
s
.37363 .35846 m
.41906 .43716 L
s
.39519 .39581 m
.44398 .48033 L
s
.38415 .37669 m
.43137 .45848 L
s
.4067 .41575 m
.45685 .50261 L
s
.46991 .52523 m
.41863 .43641 L
s
.4831 .54808 m
.43092 .45771 L
s
.43137 .45848 m
.48358 .5489 L
s
.44398 .48033 m
.49685 .57189 L
s
.49637 .57107 m
.44353 .47954 L
s
.45685 .50261 m
.51013 .5949 L
s
.52338 .61784 m
.46991 .52523 L
s
.53651 .64059 m
.4831 .54808 L
s
.48358 .5489 m
.53698 .6414 L
s
.54949 .66306 m
.49637 .57107 L
s
.49685 .57189 m
.54995 .66386 L
s
.51013 .5949 m
.56269 .68593 L
s
.57515 .70751 m
.52338 .61784 L
s
.58728 .72852 m
.53651 .64059 L
s
.53698 .6414 m
.5877 .72925 L
s
.54995 .66386 m
.59942 .74955 L
s
.59901 .74884 m
.54949 .66306 L
s
.56269 .68593 m
.61069 .76908 L
s
.62147 .78775 m
.57515 .70751 L
s
.5877 .72925 m
.63206 .80609 L
s
.63171 .80547 m
.58728 .72852 L
s
.64135 .82217 m
.59901 .74884 L
s
.65898 .85271 m
.62147 .78775 L
s
.61069 .76908 m
.65067 .83832 L
s
.59942 .74955 m
.64168 .82275 L
s
.63206 .80609 m
.66684 .86632 L
s
.68495 .89769 m
.65898 .85271 L
s
.69749 .91942 m
.68495 .89769 L
s
.66658 .86587 m
.63171 .80547 L
s
.65067 .83832 m
.67971 .88861 L
s
.64168 .82275 m
.67366 .87814 L
s
.67343 .87774 m
.64135 .82217 L
s
.69292 .9115 m
.67343 .87774 L
s
.66684 .86632 m
.6895 .90558 L
s
.68936 .90533 m
.66658 .86587 L
s
.67971 .88861 m
.6957 .91632 L
s
.69841 .92101 m
.69292 .9115 L
s
.6895 .90558 m
.69841 .92101 L
s
.67366 .87814 m
.69303 .91169 L
s
.6957 .91632 m
.69749 .91942 L
s
.6984 .92098 m
.68936 .90533 L
s
.69303 .91169 m
.6984 .92098 L
s
.25 Mabswid
.14286 .37115 m
.5 0 L
s
.5 0 m
.5 .57735 L
s
.5 .57735 m
0 .86603 L
s
0 .86603 m
.14286 .37115 L
s
.85714 .37115 m
.5 0 L
s
.5 0 m
.5 .57735 L
s
.5 .57735 m
1 .86603 L
s
1 .86603 m
.85714 .37115 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{653, 192.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:=0000`2000`400?l00000o`00003oo`3ooooo
0?ooohl0oooo003o0?ooool0ooooS`3oool00?l0ooooo`3ooon?0?ooo`00o`3ooooo0?ooohl0oooo
003o0?ooool0ooooS`3oool00200oooo00<000000?ooo`3oool0o`3ooonn0?ooo`030000003oool0
oooo0:X0oooo000P0?ooo`800000o`3ooonn0?ooo`<00000Z`3oool00200oooo00<000000?ooo`3o
ool0o`3ooonl0?ooo`050000003oool000000?ooo`000000ZP3oool00200oooo00<000000?ooo`3o
ool0o`3ooonk0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0Y`3oool00200
oooo103o09U90?ooo`L0o`2IBP3oool70?l0VDT0oooo1P3o09W80?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`2V0?ooo`00803oool010000000oooo0?ooo`3oool20?l0
VDH0oooo0P3o09T60?ooo`80o`2IA@3oool30?l0V@H0oooo0P3o09U60?ooo`80o`2I1P3oool30?l0
VL@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0:D0oooo000P0?ooo`030000003oool0oooo00<0oooo0P3o09U20?ooo`80o`2I2P3oool20?l0VD80
oooo0P3o09T:0?ooo`030?l0V@3oool0oooo0440oooo0P3o09T:0?ooo`80o`2I`P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0Y03oool00200oooo
0P0000060?ooo`030?l0V@3oool0oooo03h0oooo0P3o09T=0?ooo`030?l0V@3oool0oooo03h0oooo
00<0o`2I0?ooo`3oool02`3oool00`3o09T0oooo0?ooo`0o0?ooo`80o`2I3@3oool00`3o09T0oooo
0?ooo`2n0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2S0?ooo`00803oool00`000000oooo0?ooo`060?ooo`030?l0V@3oool0oooo03`0oooo00<0
o`2I0?ooo`3oool03P3oool00`3o09T0oooo0?ooo`0l0?ooo`80o`2I3P3oool20?l0VCh0oooo00<0
o`2I0?ooo`3oool03P3oool00`3o09T0oooo0?ooo`2l0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`2R0?ooo`00803oool00`000000oooo0?ooo`06
0?ooo`030?l0V@3oool0oooo03/0oooo00<0o`2I0?ooo`3oool03`3oool00`3o09T0oooo0?ooo`0l
0?ooo`030?l0V@3oool0oooo00l0oooo00<0o`2I0?ooo`3oool0>`3oool00`3o09T0oooo0?ooo`0?
0?ooo`030?l0V@3oool0oooo0;X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0:40oooo000P0?ooo`030000003oool0oooo00L0oooo00<0o`2I0?oo
o`3oool0>@3oool20?l0VA80oooo00<0o`2I0?ooo`3oool0>P3oool00`3o09T0oooo0?ooo`0A0?oo
o`030?l0V@3oool0oooo03T0oooo00<0o`2I0?ooo`3oool04@3oool00`3o09T0oooo0?ooo`2h0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2P0?oo
o`00803oool00`000000oooo0?ooo`080?ooo`030?l0V@3oool0oooo03P0oooo00<0o`2I0?ooo`3o
ool04P3oool00`3o09T0oooo0?ooo`0h0?ooo`030?l0V@3oool0oooo0180oooo0P3o09Ti0?ooo`03
0?l0V@3oool0oooo0180oooo0P3o09Vh0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`2O0?ooo`00803oool00`000000oooo0?ooo`080?ooo`80o`2I
>03oool00`3o09T0oooo0?ooo`0C0?ooo`80o`2I>03oool00`3o09T0oooo0?ooo`0D0?ooo`030?l0
V@3oool0oooo03H0oooo00<0o`2I0?ooo`3oool0503oool00`3o09T0oooo0?ooo`2e0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2N0?ooo`00803o
ool2000000X0oooo00<0o`2I0?ooo`3oool0=@3oool00`3o09T0oooo0?ooo`0E0?ooo`030?l0V@3o
ool0oooo03D0oooo00<0o`2I0?ooo`3oool05P3oool00`3o09T0oooo0?ooo`0d0?ooo`030?l0V@3o
ool0oooo01H0oooo00<0o`2I0?ooo`3oool0/`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0W@3oool00200oooo00<000000?ooo`3oool02P3oool0
0`3o09T0oooo0?ooo`0c0?ooo`80o`2I603oool00`3o09T0oooo0?ooo`0c0?ooo`80o`2I603oool2
0?l0VC@0oooo00<0o`2I0?ooo`3oool05`3oool20?l0VK<0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo09`0oooo000P0?ooo`030000003oool0oooo
00/0oooo00<0o`2I0?ooo`3oool0<P3oool00`3o09T0oooo0?ooo`0G0?ooo`80o`2I=03oool00`3o
09T0oooo0?ooo`0H0?ooo`030?l0V@3oool0oooo0380oooo00<0o`2I0?ooo`3oool0603oool00`3o
09T0oooo0?ooo`2`0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`2K0?ooo`00803oool00`000000oooo0?ooo`0;0?ooo`80o`2I<P3oool00`3o09T0
oooo0?ooo`0I0?ooo`030?l0V@3oool0oooo0340oooo00<0o`2I0?ooo`3oool06P3oool00`3o09T0
oooo0?ooo`0`0?ooo`030?l0V@3oool0oooo0<`0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo09/0oooo000P0?ooo`030000003oool0oooo00`0oooo
00<0o`2I0?ooo`3oool0;`3oool20?l0VA`0oooo00<0o`2I0?ooo`3oool0;`3oool20?l0VAd0oooo
00<0o`2I0?ooo`3oool0;P3oool20?l0VLd0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo09X0oooo000P0?ooo`030000003oool0oooo00d0oooo00<0
o`2I0?ooo`3oool0;P3oool00`3o09T0oooo0?ooo`0L0?ooo`030?l0V@3oool0oooo02h0oooo00<0
o`2I0?ooo`3oool0703oool00`3o09T0oooo0?ooo`0^0?ooo`030?l0V@3oool0oooo0</0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo09T0oooo000P
0?ooo`8000003`3oool00`3o09T0oooo0?ooo`0/0?ooo`030?l0V@3oool0oooo01d0oooo0P3o09T^
0?ooo`030?l0V@3oool0oooo01h0oooo00<0o`2I0?ooo`3oool0;03oool00`3o09T0oooo0?ooo`3;
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2H
0?ooo`00803oool00`000000oooo0?ooo`0>0?ooo`030?l0V@3oool0oooo02/0oooo00<0o`2I0?oo
o`3oool07`3oool00`3o09T0oooo0?ooo`0[0?ooo`030?l0V@3oool0oooo0200oooo00<0o`2I0?oo
o`3oool0:`3oool00`3o09T0oooo0?ooo`3:0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`2G0?ooo`00803oool00`000000oooo0?ooo`0?0?ooo`03
0?l0V@3oool0oooo02X0oooo00<0o`2I0?ooo`3oool0803oool00`3o09T0oooo0?ooo`0Z0?ooo`03
0?l0V@3oool0oooo0200oooo00<0o`2I0?ooo`3oool0:P3oool00`3o09T0oooo0?ooo`3:0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`2F0?ooo`00
603oool4000000@0oooo00<000000?ooo`3oool0403oool00`3o09T0oooo0?ooo`0X0?ooo`030?l0
V@3oool0oooo0280oooo00<0o`2I0?ooo`3oool0:03oool00`3o09T0oooo0?ooo`0R0?ooo`030?l0
V@3oool0oooo02P0oooo00<0o`2I0?ooo`3oool0bP3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0U@3oool001P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0@0?ooo`030?l0V@3oool0oooo02L0oooo00<0o`2I0?ooo`3oool08`3o
ool20?l0VBP0oooo00<0o`2I0?ooo`3oool0903oool00`3o09T0oooo0?ooo`0W0?ooo`030?l0V@3o
ool0oooo0:80oooo0P0000000`3oool00000000000020?ooo`@00000703oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0U03oool001T0oooo00<00000
0?ooo`3oool0103oool300000140oooo00<0o`2I0?ooo`3oool09@3oool20?l0VBH0oooo00<0o`2I
0?ooo`3oool09P3oool00`3o09T0oooo0?ooo`0T0?ooo`030?l0V@3oool0oooo02H0oooo00<0o`2I
0?ooo`3oool0Y03oool00`000000oooo000000030?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo09<0oooo000B0?oo
o`@00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0180oooo00<0o`2I0?oo
o`3oool0903oool00`3o09T0oooo0?ooo`0V0?ooo`030?l0V@3oool0oooo02@0oooo00<0o`2I0?oo
o`3oool09P3oool00`3o09T0oooo0?ooo`0T0?ooo`030?l0V@3oool0oooo0:H0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`2B0?ooo`006`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0180oooo00<0o`2I0?ooo`3oool08`3oool00`3o09T0oooo0?ooo`0W0?ooo`80
o`2I903oool00`3o09T0oooo0?ooo`0X0?ooo`030?l0V@3oool0oooo0280oooo0P3o09VW0?ooo`03
0000003oool0000000D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0T@3oool001P0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0C0?ooo`030?l0V@3oool0oooo0240oooo0P3o09TZ0?ooo`03
0?l0V@3oool0oooo0280oooo00<0o`2I0?ooo`3oool0:03oool00`3o09T0oooo0?ooo`0R0?ooo`03
0?l0V@3oool0oooo0:D0oooo0P0000000`3oool00000000000050?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0900
oooo000I0?ooo`8000001@3oool00`000000oooo0?ooo`0D0?ooo`030?l0V@3oool0oooo0200oooo
00<0o`2I0?ooo`3oool0:P3oool00`3o09T0oooo0?ooo`0P0?ooo`030?l0V@3oool0oooo02X0oooo
00<0o`2I0?ooo`3oool0803oool00`3o09T0oooo0?ooo`2]0?ooo`040000003oool0oooo000001L0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo08l0
oooo000P0?ooo`030000003oool0oooo01@0oooo00<0o`2I0?ooo`3oool07`3oool00`3o09T0oooo
0?ooo`0[0?ooo`030?l0V@3oool0oooo01l0oooo00<0o`2I0?ooo`3oool0:`3oool20?l0VB00oooo
0P3o09V`0?ooo`8000005`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0SP3oool00200oooo0P00000F0?ooo`030?l0V@3oool0oooo01d0oooo0P3o
09T^0?ooo`030?l0V@3oool0oooo01h0oooo00<0o`2I0?ooo`3oool0;03oool00`3o09T0oooo0?oo
o`0N0?ooo`030?l0V@3oool0oooo0<L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo08d0oooo000P0?ooo`030000003oool0oooo01D0oooo0P3o09TN
0?ooo`030?l0V@3oool0oooo02d0oooo00<0o`2I0?ooo`3oool07@3oool00`3o09T0oooo0?ooo`0^
0?ooo`030?l0V@3oool0oooo01`0oooo00<0o`2I0?ooo`3oool0a`3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0S03oool00200oooo00<000000?oo
o`3oool05P3oool00`3o09T0oooo0?ooo`0K0?ooo`030?l0V@3oool0oooo02l0oooo00<0o`2I0?oo
o`3oool06`3oool20?l0VC00oooo00<0o`2I0?ooo`3oool06`3oool20?l0VLP0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo08/0oooo000P0?ooo`03
0000003oool0oooo01L0oooo00<0o`2I0?ooo`3oool06@3oool00`3o09T0oooo0?ooo`0`0?ooo`80
o`2I703oool00`3o09T0oooo0?ooo`0`0?ooo`030?l0V@3oool0oooo01X0oooo00<0o`2I0?ooo`3o
ool0aP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0RP3oool00200oooo00<000000?ooo`3oool05`3oool00`3o09T0oooo0?ooo`0I0?ooo`030?l0
V@3oool0oooo0340oooo00<0o`2I0?ooo`3oool06@3oool00`3o09T0oooo0?ooo`0a0?ooo`80o`2I
6P3oool00`3o09T0oooo0?ooo`360?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`290?ooo`00803oool00`000000oooo0?ooo`0H0?ooo`030?l0V@3o
ool0oooo01L0oooo00<0o`2I0?ooo`3oool0<`3oool00`3o09T0oooo0?ooo`0H0?ooo`030?l0V@3o
ool0oooo0380oooo00<0o`2I0?ooo`3oool05`3oool00`3o09T0oooo0?ooo`360?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`280?ooo`00803oool2
000001X0oooo00<0o`2I0?ooo`3oool05@3oool00`3o09T0oooo0?ooo`0e0?ooo`030?l0V@3oool0
oooo01H0oooo00<0o`2I0?ooo`3oool0<`3oool20?l0VAP0oooo00<0o`2I0?ooo`3oool0a@3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0Q`3oool0
0200oooo00<000000?ooo`3oool06@3oool00`3o09T0oooo0?ooo`0E0?ooo`030?l0V@3oool0oooo
03H0oooo00<0o`2I0?ooo`3oool0503oool00`3o09T0oooo0?ooo`0e0?ooo`030?l0V@3oool0oooo
01D0oooo00<0o`2I0?ooo`3oool0a@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0QP3oool00200oooo00<000000?ooo`3oool06P3oool00`3o09T0
oooo0?ooo`0C0?ooo`030?l0V@3oool0oooo03P0oooo00<0o`2I0?ooo`3oool04P3oool20?l0VCP0
oooo00<0o`2I0?ooo`3oool04`3oool00`3o09T0oooo0?ooo`350?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`250?ooo`00803oool00`000000oooo
0?ooo`0K0?ooo`030?l0V@3oool0oooo0140oooo00<0o`2I0?ooo`3oool0>@3oool20?l0VA<0oooo
00<0o`2I0?ooo`3oool0>03oool00`3o09T0oooo0?ooo`0B0?ooo`030?l0V@3oool0oooo0<@0oooo
00D000000?ooo`3oool0oooo0000000Q0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0Q03oool00200oooo00<000000?ooo`3oool0703oool00`3o09T0oooo0?ooo`0?0?ooo`030?l0
V@3oool0oooo03/0oooo00<0o`2I0?ooo`3oool0403oool00`3o09T0oooo0?ooo`0j0?ooo`030?l0
V@3oool0oooo0100oooo00<0o`2I0?ooo`3oool0a03oool00`000000oooo0?ooo`020?ooo`800000
803oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo08<0oooo000P0?ooo`030000003o
ool0oooo01d0oooo0P3o09T>0?ooo`030?l0V@3oool0oooo03d0oooo00<0o`2I0?ooo`3oool03@3o
ool20?l0VCh0oooo0P3o09T>0?ooo`80o`2IaP3oool00`000000oooo0?ooo`040?ooo`8000007`3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0880oooo000P0?ooo`8000007`3oool2
0?l0V@`0oooo00<0o`2I0?ooo`3oool0?`3oool20?l0V@`0oooo00<0o`2I0?ooo`3oool0@03oool0
0`3o09T0oooo0?ooo`0:0?ooo`030?l0V@3oool0oooo0<D0oooo00<000000?ooo`3oool01@3oool2
000001l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`210?ooo`00803oool00`00
0000oooo0?ooo`0P0?ooo`030?l0V@3oool0oooo00L0oooo0P3o09U30?ooo`80o`2I2P3oool00`3o
09T0oooo0?ooo`120?ooo`030?l0V@3oool0oooo00P0oooo00<0o`2I0?ooo`3oool0a@3oool00`00
0000oooo0?ooo`070?ooo`8000007P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
0800oooo000P0?ooo`030000003oool0oooo0240oooo0P3o09T50?ooo`<0o`2IAP3oool20?l0V@H0
oooo0P3o09U60?ooo`80o`2I1P3oool20?l0VLL0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0O`3oool00200oooo
00<000000?ooo`3oool08`3oool50?l0VD/0oooo1P3o09U:0?ooo`L0o`2Ia`3oool00`000000oooo
0?ooo`0:0?ooo`8000007@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo07h0oooo
000P0?ooo`030000003oool0oooo0?l0ooooT@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`1m0?ooo`00803oool0
0`000000oooo0?ooo`3o0?oooi40oooo00<000000?ooo`3oool0303oool2000001`0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`1m0?ooo`00803oool200000?l0ooooT@3oool00`00
0000oooo0?ooo`0>0?ooo`8000006`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
07`0oooo000P0?ooo`030000003oool0oooo0?l0ooooS`3oool00`000000oooo0?ooo`0?0?ooo`80
00006`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo07/0oooo000P0?ooo`030000
003oool0oooo0?l0ooooSP3oool00`000000oooo0?ooo`0A0?ooo`8000006P3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo07X0oooo000P0?ooo`030000003oool0oooo0?l0ooooS@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`1i0?ooo`00603oool4000000@0oooo00<000000?ooo`3oool0o`3ooon<
0?ooo`030000003oool0oooo01@0oooo0P00000I0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0N03oool001X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oo
oh/0oooo00<000000?ooo`3oool05P3oool2000001P0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`1g0?ooo`006P3oool00`000000oooo0?ooo`030?ooo`<00000o`3ooon:0?ooo`03
0000003oool0oooo01L0oooo0P00000H0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0MP3oool00180oooo100000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
o`3ooon90?ooo`030000003oool0oooo01T0oooo0P00000G0?ooo`030000003oool0oooo0380oooo
00<000000?ooo`3oool0M@3oool001X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3o0?ooohP0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool0M03oool001P0oooo0`0000050?ooo`030000003oool0
oooo0?l0ooooQ`3oool00`000000oooo0?ooo`0L0?ooo`8000005P3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo07<0oooo000J0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0o`3ooon60?ooo`030000003oool0oooo01h0oooo0P00000E0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool0LP3oool00200oooo0P00003o0?ooohH0oooo00<000000?ooo`3o
ool07`3oool2000001D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1a0?ooo`00
803oool00`000000oooo0?ooo`3o0?oooh@0oooo00<000000?ooo`3oool08@3oool2000001@0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1`0?ooo`00803oool00`000000oooo0?oo
o`3o0?oooh<0oooo00<000000?ooo`3oool08P3oool3000001<0oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`1_0?ooo`00803oool00`000000oooo0?ooo`3o0?oooh80oooo00<00000
0?ooo`3oool0903oool2000001<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1^
0?ooo`00803oool00`000000oooo0?ooo`3o0?oooh80oooo0`00000U0?ooo`8000004P3oool00`00
0000oooo0?ooo`0g0?ooo`<00000L03oool00200oooo00<000000?ooo`3oool0o`3ooon10?ooo`04
0000003oool0oooo0?ooo`8000008`3oool200000180oooo00<000000?ooo`3oool0=@3oool20000
00<0oooo00<000000?ooo`3oool0K@3oool00200oooo0P00003o0?oooh80oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0Q0?ooo`8000004@3oool00`000000oooo0?ooo`0c0?ooo`80
00001@3oool00`000000oooo0?ooo`1]0?ooo`00803oool00`000000oooo0?ooo`3o0?oooh40oooo
00<000000?ooo`3oool0103oool200000240oooo0P00000A0?ooo`030000003oool0oooo0380oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`00803oool00`000000oooo0?oo
o`3o0?oooh40oooo00<000000?ooo`3oool01P3oool200000200oooo0P00000@0?ooo`030000003o
ool0oooo0300oooo0P0000080?ooo`030000003oool0oooo06d0oooo000P0?ooo`030000003oool0
oooo0?l0ooooP03oool00`000000oooo0?ooo`090?ooo`8000007`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo02h0oooo0P00000;0?ooo`030000003oool0oooo06`0oooo000P0?oo
o`030000003oool0oooo0?l0ooooP03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
01`0oooo0P00000?0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1/0?ooo`00803oool00`000000oooo0?ooo`3o0?oooh00oooo00<000000?ooo`3o
ool0303oool2000001d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0[0?ooo`80
00003P3oool00`000000oooo0?ooo`1/0?ooo`00803oool200000?l0ooooP03oool00`000000oooo
0?ooo`0?0?ooo`8000006`3oool2000000h0oooo00<000000?ooo`3oool0:@3oool200000140oooo
00<000000?ooo`3oool0J`3oool00200oooo00<000000?ooo`3oool0>`3oool3000003X0oooo1000
00030?ooo`800000=P3oool400000080oooo0`00000g0?ooo`@000000`3oool2000007h0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool09`3oool2000001<0oooo00<000000?ooo`3oool0J`3oool00200oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0i0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000007d0oooo00<000000?ooo`3oool0
4P3oool2000001T0oooo0P00000=0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`1[0?ooo`00803oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo03T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000O@3oool00`000000oooo0?ooo`0D0?ooo`800000603oool2000000`0
oooo00<000000?ooo`3oool0903oool2000001H0oooo00<000000?ooo`3oool0J`3oool00200oooo
00<000000?ooo`3oool0>`3oool3000003`0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo03D0oooo00@000000?ooo`3oool0oooo0`00000i0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo01L0oooo0P00000G
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08P3oool2000001T0oooo00<00000
0?ooo`3oool0JP3oool00200oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0l0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0e0?ooo`050000003oool0
oooo0?ooo`000000?03oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo07X0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0D0?ooo`8000002`3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0JP3oool00200oooo0P00
000l0?ooo`030000003oool0oooo03X0oooo0`0000030?ooo`040000003oool0oooo000003D0oooo
0`0000030?ooo`030000003oool0oooo03L0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`00001l0?ooo`030000003oool0oooo01X0oooo0P00000E0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool07`3oool2000001`0oooo00<000000?ooo`3oool0JP3oool00200
oooo00<000000?ooo`3oool0>`3oool4000003/0oooo00<000000?ooo`3oool00P3oool2000003P0
oooo00@000000?ooo`3oool0oooo1000000g0?ooo`800000103oool2000007`0oooo00<000000?oo
o`3oool07@3oool2000001<0oooo0P00000:0?ooo`030000003oool0oooo01d0oooo0P00000O0?oo
o`030000003oool0oooo06T0oooo000P0?ooo`030000003oool0oooo0?l0ooooO@3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo0140oooo0P0000090?ooo`030000003oool0oooo01/0
oooo0P00000Q0?ooo`030000003oool0oooo06T0oooo000P0?ooo`030000003oool0oooo0?l0oooo
O@3oool00`000000oooo0?ooo`0P0?ooo`8000004@3oool2000000T0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06T0oooo000P0?ooo`030000003o
ool0oooo0?l0oooo3`3oool2000006`0oooo00<000000?ooo`3oool08P3oool200000100oooo0P00
00080?ooo`030000003oool0oooo01P0oooo0P00000T0?ooo`030000003oool0oooo06T0oooo000P
0?ooo`030000003oool0oooo0?l0oooo3P3oool010000000oooo0?ooo`00001Z0?ooo`030000003o
ool0oooo02D0oooo0P00000?0?ooo`8000001`3oool00`000000oooo0?ooo`0F0?ooo`8000009`3o
ool00`000000oooo0?ooo`1X0?ooo`006P3oool500000?l006Ko0P00I_l7000000T0oooo00<00000
0?ooo`3oool0J`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00`0oooo0P000007
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`1X
0?ooo`007`3ooooo001Vo`8006Ko403oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo
02P0oooo0P00000=0?ooo`8000001P3oool00`000000oooo0?ooo`0C0?ooo`800000:P3oool00`00
0000oooo0?ooo`1X0?ooo`00803oool00`000000oooo0?ooo`3o0?ooo`d0oooo1000001Z0?ooo`03
0000003oool0oooo02/0oooo0P00000;0?ooo`8000001P3oool00`000000oooo0?ooo`0A0?ooo`80
0000;@3oool00`000000oooo0?ooo`1W0?ooo`00803oool00`000000oooo0?ooo`3o0?ooo`h0oooo
00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo
0P0000050?ooo`030000003oool0oooo00l0oooo0P00000_0?ooo`030000003oool0oooo06L0oooo
000P0?ooo`030000003oool0oooo0?l0oooo3P3oool00`000000oooo0?ooo`1Z0?ooo`030000003o
ool0oooo02h0oooo0P00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo06L0oooo000P0?ooo`030000003oool0
oooo0?l0ooooN`3oool00`000000oooo0?ooo`0`0?ooo`800000203oool2000000@0oooo00<00000
0?ooo`3oool0303oool200000380oooo00<000000?ooo`3oool03`3oool2000000030?ooo`000000
000000<0oooo0P00001>0?ooo`00803oool200000?l0ooooN`3oool00`000000oooo0?ooo`0c0?oo
o`8000001`3oool2000000<0oooo00<000000?ooo`3oool02P3oool2000003D0oooo00<000000?oo
o`3oool03`3oool00`000000oooo000000030?ooo`040000003oool0oooo000004d0oooo000P0?oo
o`030000003oool0oooo0?l0ooooNP3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
00@0oooo0P0000030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0B`3oool00200
oooo00<000000?ooo`3oool0o`3ooomj0?ooo`030000003oool0oooo03H0oooo0P0000050?ooo`80
00000P3oool00`000000oooo0?ooo`070?ooo`800000>03oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0000000@0oooo0P00001>0?ooo`00803oool00`000000oooo0?ooo`3o0?ooogT0oooo
00<000000?ooo`3oool0>@3oool2000000@0oooo00@000000?ooo`3oool000001`3oool2000003/0
oooo00<000000?ooo`3oool03@3oool2000000030?ooo`000000000000D0oooo00<000000?ooo`3o
ool0B`3oool00200oooo00<000000?ooo`3oool0o`3ooomi0?ooo`030000003oool0oooo03/0oooo
00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`040?ooo`800000?@3oool00`000000
oooo0?ooo`0D0?ooo`040000003oool0oooo000004d0oooo000P0?ooo`800000o`3ooomj0?ooo`03
0000003oool0oooo03`0oooo0P0000020?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0E0?ooo`800000CP3oool00200oooo00<000000?ooo`3oool0
o`3ooomi0?ooo`030000003oool0oooo03h0oooo1@0000020?ooo`800000@03oool00`000000oooo
0?ooo`1U0?ooo`00803oool00`000000oooo0?ooo`3o0?ooogP0oooo00<000000?ooo`3oool0@@3o
ool5000004<0oooo00<000000?ooo`3oool0I03oool00200oooo00<000000?ooo`3oool0o`3ooomh
0?ooo`030000003oool0oooo0480oooo0P0000150?ooo`030000003oool0oooo06@0oooo000P0?oo
o`030000003oool0oooo0?l0ooooN03oool00`000000oooo0?ooo`110?ooo`D00000@`3oool00`00
0000oooo0?ooo`1T0?ooo`00803oool00`000000oooo0?ooo`3o0?ooogL0oooo00<000000?ooo`3o
ool0@03oool200000080oooo0P0000000`3oool00000000000120?ooo`030000003oool0oooo06<0
oooo000P0?ooo`800000o`3ooomh0?ooo`030000003oool0oooo03h0oooo0P0000040?ooo`<00000
0P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo06<0oooo000P0?ooo`030000003o
ool0oooo0?l0ooooM`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`0000000`3oool2000003l0oooo00<000000?ooo`3oool0H`3oool00200oooo00<00000
0?ooo`3oool0o`3ooomg0?ooo`030000003oool0oooo03/0oooo0P0000070?ooo`040000003oool0
0000000000@0oooo0P00000m0?ooo`030000003oool0oooo06<0oooo000P0?ooo`030000003oool0
oooo0?l0ooooMP3oool00`000000oooo0?ooo`0j0?ooo`8000002@3oool010000000oooo0?ooo`00
00060?ooo`800000?03oool00`000000oooo0?ooo`1R0?ooo`00803oool00`000000oooo0?ooo`3o
0?ooogH0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo008000001`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0680oooo000P0?oo
o`030000003oool0oooo0?l0ooooMP3oool00`000000oooo0?ooo`0g0?ooo`800000303oool01000
0000oooo0?ooo`3oool2000000L0oooo0P00000i0?ooo`030000003oool0oooo0680oooo000P0?oo
o`800000o`3ooomf0?ooo`030000003oool0oooo03H0oooo0P00000>0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01`3oool2000003P0oooo00<000000?ooo`3oool0H@3oool00200
oooo00<000000?ooo`3oool0o`3ooome0?ooo`030000003oool0oooo03@0oooo0P00000@0?ooo`03
0000003oool0oooo0080oooo0P00000:0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool0H@3oool00200oooo00<000000?ooo`3oool0o`3ooome0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
0P00000e0?ooo`030000003oool0oooo0640oooo000P0?ooo`030000003oool0oooo0?l0ooooM@3o
ool00`000000oooo0?ooo`0a0?ooo`8000004`3oool00`000000oooo0?ooo`030?ooo`800000303o
ool2000003<0oooo00<000000?ooo`3oool0H@3oool001P0oooo100000040?ooo`030000003oool0
oooo0?l0ooooM03oool00`000000oooo0?ooo`0`0?ooo`8000005@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00`0oooo0P00000b0?ooo`030000003oool0oooo0600oooo000J0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooomd0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`8000003`3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo0600oooo000J0?ooo`030000003oool0oooo00<0
oooo0`00003o0?ooog@0oooo00<000000?ooo`3oool0;@3oool2000001P0oooo00<000000?ooo`3o
ool01@3oool2000000l0oooo0P00000_0?ooo`030000003oool0oooo0600oooo000J0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`030000003oool0oooo02`0oooo
0P00000J0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03`3oool2000002h0oooo
00<000000?ooo`3oool0G`3oool001X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3o0?ooog<0oooo00<000000?ooo`3oool0:P3oool2000001`0oooo00<000000?ooo`3oool01P3o
ool200000180oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1O0?ooo`00603oool3
000000D0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo0P00000[
0?ooo`030000003oool0oooo05l0oooo000J0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0o`3ooomc0?ooo`030000003oool0oooo02L0oooo0P00000O0?ooo`030000003oool0oooo
00L0oooo0P00000D0?ooo`800000:@3oool00`000000oooo0?ooo`1O0?ooo`00803oool00`000000
oooo0?ooo`3o0?ooog80oooo00<000000?ooo`3oool09P3oool200000240oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0D0?ooo`800000:03oool00`000000oooo0?ooo`1N0?ooo`00
803oool200000?l0ooooL`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0203oool2000001L0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`1N0?ooo`00803oool00`000000oooo0?ooo`3o0?ooog80oooo00<000000?ooo`3oool08`3o
ool2000002@0oooo00<000000?ooo`3oool02@3oool2000001L0oooo0P00000U0?ooo`030000003o
ool0oooo05h0oooo000P0?ooo`030000003oool0oooo02<0oooo1@0co`1;0?ooo`D0<ol0B`3oool5
03?o0:P0oooo00<000000?ooo`3oool08P3oool2000002H0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0G0?ooo`800000903oool00`000000oooo0?ooo`1M0?ooo`00803oool00`00
0000oooo0?ooo`0P0?ooo`X0<ol0A`3oool:03?o04D0oooo300co`2T0?ooo`030000003oool0oooo
0200oooo0P00000X0?ooo`030000003oool0oooo00X0oooo0P00000J0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0G@3oool00200oooo00<000000?ooo`3oool07`3oool503?o00<0
oooo1P0co`110?ooo`L0<ol00P3oool603?o0480oooo1P0co`020?ooo`H0<ol0X`3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0I0?ooo`8000008@3oool00`000000oooo0?ooo`1M0?ooo`00803oool2000001h0oooo
1@0co`070?ooo`@0<ol0@03oool503?o00P0oooo100co`100?ooo`<0<ol02P3oool303?o0:80oooo
00<000000?ooo`3oool07@3oool2000002/0oooo00<000000?ooo`3oool02`3oool2000001`0oooo
0P00000O0?ooo`030000003oool0oooo05d0oooo000P0?ooo`030000003oool0oooo01`0oooo100c
o`0<0?ooo`80<ol0?`3oool203?o00d0oooo0`0co`0n0?ooo`<0<ol0303oool303?o0:00oooo00<0
00000?ooo`3oool0703oool2000002d0oooo00<000000?ooo`3oool0303oool2000001d0oooo0P00
000N0?ooo`030000003oool0oooo05`0oooo000P0?ooo`030000003oool0oooo01/0oooo0`0co`0>
0?ooo`<0<ol0?@3oool303?o00h0oooo0`0co`0l0?ooo`<0<ol03P3oool303?o09l0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00`0oooo0P00000O
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0G03oool00200oooo00<000000?oo
o`3oool06P3oool303?o0100oooo100co`0j0?ooo`<0<ol0403oool303?o03X0oooo0`0co`0@0?oo
o`<0<ol0WP3oool00`000000oooo0?ooo`0I0?ooo`800000<03oool00`000000oooo0?ooo`0=0?oo
o`8000007`3oool2000001/0oooo00<000000?ooo`3oool0G03oool00200oooo00<000000?ooo`3o
ool06@3oool303?o01<0oooo0`0co`0h0?ooo`<0<ol04P3oool303?o03P0oooo0`0co`0B0?ooo`80
<ol0W@3oool00`000000oooo0?ooo`0H0?ooo`800000<P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo01l0oooo0P00000J0?ooo`030000003oool0oooo05/0oooo000P0?ooo`030000
003oool0oooo01T0oooo0P0co`0E0?ooo`80<ol0=`3oool303?o01@0oooo0`0co`0f0?ooo`<0<ol0
503oool203?o09`0oooo00<000000?ooo`3oool05P3oool2000003@0oooo00<000000?ooo`3oool0
3P3oool200000280oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1K0?ooo`00803o
ool2000001T0oooo0`0co`0F0?ooo`80<ol0=@3oool303?o01H0oooo0`0co`0d0?ooo`<0<ol05@3o
ool303?o09/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool08@3oool2000001L0oooo00<000000?ooo`3oool0F`3o
ool00200oooo00<000000?ooo`3oool0603oool203?o01L0oooo0`0co`0d0?ooo`80<ol0603oool2
03?o03@0oooo0P0co`0G0?ooo`80<ol0V`3oool00`000000oooo0?ooo`0C0?ooo`800000=`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0280oooo0P00000E0?ooo`030000003oool0
oooo05/0oooo000P0?ooo`030000003oool0oooo01L0oooo0`0co`0H0?ooo`80<ol0<`3oool203?o
01T0oooo0`0co`0b0?ooo`<0<ol0603oool203?o09T0oooo00<000000?ooo`3oool04P3oool20000
03T0oooo00<000000?ooo`3oool0403oool2000002D0oooo0P00000D0?ooo`030000003oool0oooo
05X0oooo000P0?ooo`030000003oool0oooo01L0oooo0P0co`0J0?ooo`80<ol0<@3oool303?o01X0
oooo0P0co`0b0?ooo`80<ol06@3oool303?o09P0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo05X0oooo000P0?ooo`030000003oool0oooo01H0oooo
0P0co`0K0?ooo`<0<ol0<03oool203?o01`0oooo0P0co`0`0?ooo`<0<ol06P3oool203?o09P0oooo
00<000000?ooo`3oool03`3oool2000003`0oooo00<000000?ooo`3oool04@3oool2000002L0oooo
0P00000A0?ooo`030000003oool0oooo05X0oooo000P0?ooo`030000003oool0oooo01D0oooo0`0c
o`0L0?ooo`80<ol0;`3oool203?o01d0oooo0P0co`0`0?ooo`80<ol0703oool203?o09H0oooo00<0
00000?ooo`3oool03P3oool2000003h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0W0?ooo`800000403oool00`000000oooo0?ooo`1I0?ooo`00803oool2000001D0oooo0`0co`0N
0?ooo`80<ol0;@3oool303?o01h0oooo0P0co`0^0?ooo`80<ol07@3oool303?o09D0oooo00<00000
0?ooo`3oool0303oool200000400oooo00<000000?ooo`3oool04P3oool2000002X0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`1I0?ooo`00803oool00`000000oooo0?ooo`0D0?oo
o`80<ol07`3oool303?o02`0oooo0P0co`0O0?ooo`<0<ol0;03oool303?o01h0oooo0`0co`2D0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0C0?oo
o`800000:P3oool2000000d0oooo00<000000?ooo`3oool0F@3oool00200oooo00<000000?ooo`3o
ool04`3oool203?o0240oooo0`0co`0Z0?ooo`<0<ol0803oool203?o02/0oooo0`0co`0P0?ooo`80
<ol0U03oool00`000000oooo0?ooo`090?ooo`800000@`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo02X0oooo0P00000;0?ooo`030000003oool0oooo05T0oooo000P0?ooo`030000
003oool0oooo0180oooo0`0co`0R0?ooo`80<ol0:P3oool203?o0240oooo0`0co`0Z0?ooo`80<ol0
8@3oool303?o0980oooo00<000000?ooo`3oool0203oool2000004D0oooo00<000000?ooo`3oool0
503oool2000002d0oooo0P00000:0?ooo`030000003oool0oooo05P0oooo000H0?ooo`@00000103o
ool00`000000oooo0?ooo`0B0?ooo`80<ol08`3oool303?o02P0oooo0P0co`0S0?ooo`80<ol0:@3o
ool203?o02<0oooo0`0co`2A0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`1H0?ooo`00603oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0140oooo0P0co`0U0?ooo`<0<ol09P3oool303?o02@0oooo0P0co`0W0?ooo`<0<ol0903oool2
03?o0940oooo00<000000?ooo`3oool01@3oool2000004P0oooo00<000000?ooo`3oool05@3oool2
000002l0oooo0P0000070?ooo`030000003oool0oooo05P0oooo000I0?ooo`030000003oool0oooo
00@0oooo0`00000@0?ooo`<0<ol09P3oool203?o02H0oooo0P0co`0U0?ooo`<0<ol09P3oool203?o
02H0oooo0P0co`2?0?ooo`030000003oool0oooo00@0oooo0P00001:0?ooo`030000003oool0oooo
01H0oooo0P00000`0?ooo`8000001P3oool00`000000oooo0?ooo`1G0?ooo`006P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0100oooo0P0co`0X0?ooo`80<ol0903oool203?o02L0
oooo0P0co`0U0?ooo`80<ol09`3oool303?o08h0oooo00<000000?ooo`3oool00P3oool2000004`0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0E`3oool001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0?0?ooo`80<ol0:@3oool303?o0280oooo0`0co`0X0?ooo`80<ol08`3oool303?o02P0oooo
0P0co`2>0?ooo`050000003oool0oooo0?ooo`000000CP3oool00`000000oooo0?ooo`0G0?ooo`80
0000<P3oool2000000<0oooo00<000000?ooo`3oool0E`3oool001P0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0>0?ooo`<0<ol0:P3oool203?o0280oooo0P0co`0Y0?ooo`<0
<ol08P3oool203?o02X0oooo0P0co`2=0?ooo`040000003oool00000000004l0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0b0?ooo`80000000<0oooo0000003oool0F03oool001T0
oooo0P0000050?ooo`030000003oool0oooo00h0oooo0P0co`0/0?ooo`80<ol0803oool203?o02/0
oooo0P0co`0Q0?ooo`80<ol0:`3oool303?o08/0oooo0`00001A0?ooo`030000003oool0oooo01P0
oooo0P00000e0?ooo`<00000F03oool00200oooo00<000000?ooo`3oool03@3oool203?o02d0oooo
0`0co`0N0?ooo`<0<ol0;03oool203?o01l0oooo0`0co`0/0?ooo`80<ol0R`3oool300000540oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0c0?ooo`<00000F03oool00200oooo0P00
000=0?ooo`<0<ol0;P3oool203?o01h0oooo0P0co`0]0?ooo`<0<ol07P3oool203?o02h0oooo0P0c
o`2=0?ooo`@00000C@3oool00`000000oooo0?ooo`0I0?ooo`800000<03oool4000005/0oooo000P
0?ooo`030000003oool0oooo00/0oooo0`0co`0`0?ooo`80<ol0703oool203?o02l0oooo0P0co`0M
0?ooo`80<ol0;`3oool303?o0900oooo100000190?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0:P3oool4000005l0oooo000P0?ooo`030000003oool0oooo00/0oooo0P0co`0a0?oo
o`<0<ol06P3oool303?o0300oooo0P0co`0K0?ooo`<0<ol0<03oool203?o01/0oooo00<0<ol00?oo
o`3oool0MP3oool4000004D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0U0?oo
o`@00000H`3oool00200oooo00<000000?ooo`3oool02P3oool203?o03<0oooo0P0co`0I0?ooo`<0
<ol0<@3oool303?o01X0oooo0P0co`0a0?ooo`<0<ol06P3oool203?o07/0oooo100000110?ooo`03
0000003oool0oooo01/0oooo0P00000R0?ooo`@00000I`3oool00200oooo00<000000?ooo`3oool0
2@3oool303?o03<0oooo0`0co`0H0?ooo`80<ol0<`3oool303?o01P0oooo0P0co`0c0?ooo`80<ol0
6@3oool203?o0800oooo1@00000l0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
6`3oool5000006/0oooo000P0?ooo`030000003oool0oooo00P0oooo0`0co`0e0?ooo`80<ol05`3o
ool203?o03D0oooo0P0co`0G0?ooo`<0<ol0=03oool203?o01L0oooo0`0co`250?ooo`@00000>03o
ool00`000000oooo0?ooo`0L0?ooo`800000603oool400000700oooo000P0?ooo`8000002@3oool2
03?o03L0oooo0P0co`0E0?ooo`80<ol0=`3oool203?o01D0oooo0`0co`0e0?ooo`<0<ol05@3oool3
03?o08X0oooo1000000d0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool04P3oool4
000007@0oooo000P0?ooo`030000003oool0oooo00L0oooo0P0co`0h0?ooo`<0<ol04`3oool303?o
03L0oooo0`0co`0D0?ooo`80<ol0=`3oool303?o01@0oooo0P0co`2?0?ooo`@00000<03oool00`00
0000oooo0?ooo`0M0?ooo`8000003`3oool4000007P0oooo000P0?ooo`030000003oool0oooo00H0
oooo0`0co`0i0?ooo`<0<ol04@3oool303?o03T0oooo0`0co`0B0?ooo`80<ol0>@3oool303?o0180
oooo0P0co`2D0?ooo`@00000;03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00T0
oooo1000001l0?ooo`00803oool00`000000oooo0?ooo`060?ooo`80<ol0>`3oool303?o0100oooo
0P0co`0k0?ooo`<0<ol0403oool303?o03X0oooo0`0co`0@0?ooo`<0<ol0V03oool5000002L0oooo
00<000000?ooo`3oool09@3oool500000800oooo000P0?ooo`030000003oool0oooo00D0oooo0P0c
o`0m0?ooo`<0<ol03P3oool203?o03d0oooo0`0co`0>0?ooo`<0<ol0?03oool303?o00h0oooo0`0c
o`2N0?ooo`@000008`3oool00`000000oooo0?ooo`0Q0?ooo`@00000Q@3oool00200oooo0P000005
0?ooo`<0<ol0?P3oool203?o00d0oooo0`0co`0n0?ooo`<0<ol0303oool303?o03h0oooo100co`0;
0?ooo`<0<ol0X`3oool4000001l0oooo00<000000?ooo`3oool07@3oool4000008T0oooo000P0?oo
o`030000003oool0oooo0080oooo100co`0o0?ooo`@0<ol02@3oool403?o0400oooo100co`090?oo
o`<0<ol0@03oool403?o00P0oooo100co`2X0?ooo`@000006`3oool00`000000oooo0?ooo`0I0?oo
o`@00000S@3oool00200oooo00@000000?ooo`3oool0oooo0`0co`120?ooo`D0<ol01P3oool303?o
04<0oooo100co`050?ooo`D0<ol0@`3oool303?o00H0oooo100co`2]0?ooo`@000005`3oool00`00
0000oooo0?ooo`0E0?ooo`@00000T@3oool00200oooo1P0co`150?ooo`/0<ol0AP3oool;03?o04D0
oooo2P0co`2c0?ooo`D000004P3oool00`000000oooo0?ooo`0@0?ooo`D00000U@3oool001l0oooo
1P0co`170?ooo`T0<ol0B03oool703?o04T0oooo200co`2i0?ooo`@000003P3oool00`000000oooo
0?ooo`0<0?ooo`@00000VP3oool001l0oooo0`0co`1=0?ooo`<0<ol0CP3oool203?o04h0oooo0P0c
o`300?ooo`@000002P3oool00`000000oooo0?ooo`080?ooo`@00000WP3oool00200oooo0P00003o
0?oookD0oooo100000060?ooo`030000003oool0oooo00@0oooo1000002R0?ooo`00803oool00`00
0000oooo0?ooo`3o0?oookP0oooo100000020?ooo`030000003oool0oooo00@00000YP3oool00?l0
oooog`3oool500000:X0oooo003o0?ooool0ooooS`3oool00?l0ooooo`3ooon?0?ooo`00o`3ooooo
0?ooohl0oooo003o0?ooool0ooooS`3oool00?l0ooooo`3ooon?0?ooo`00o`3ooooo0?ooohl0oooo
003o0?ooool0ooooS`3oool00?l0ooooo`3ooon?0?ooo`00o`3ooooo0?ooohl0oooo000M0?ooo`80
000000<0oooo000000000000o`3ooonC0?ooo`80000000<0oooo0000000000000P3oool400000<h0
oooo000N0?ooo`030000003oool000000?l0ooooU@3oool00`000000oooo000000050?ooo`030000
003oool0oooo0<d0oooo000O0?ooo`030000003oool0oooo0?l0ooooU@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0<d0oooo000N0?ooo`030000003oool000000?l0ooooU@3oool0
0`000000oooo000000050?ooo`030000003oool0oooo0<d0oooo000M0?ooo`80000000<0oooo0000
00000000o`3ooonC0?ooo`80000000<0oooo000000000000103oool00`000000oooo0?ooo`3=0?oo
o`00o`3ooonl0?ooo`<00000c`3oool00?l0oooo_P3oool00`000000oooo0?ooo`3=0?ooo`00o`3o
oooo0?ooohl0oooo003o0?ooool0ooooS`3oool00?l0ooooo`3ooon?0?ooo`00o`3ooooo0?ooohl0
oooo0000\
\>"],
  ImageRangeCache->{{{0, 652}, {191.125, 0}} -> {-0.0541781, -0.0147182, \
0.00323368, 0.00323368}, {{16.75, 311.25}, {186.562, 4.5}} -> {-2.55414, \
-2.99915, 0.0783964, 0.0343389}, {{340.688, 635.188}, {186.562, 4.5}} -> \
{-1.97316, -0.0234995, 0.0051496, 0.0051496}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{xPlot[0, 0, 1], 
            xLPlot[0, 0, 1\ , Ticks \[Rule] None\ ]}]];\)\)], "Input",
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.309017 0.111495 [
[.2619 .29652 -3 -9 ]
[.2619 .29652 3 0 ]
[.5 .29652 -6 -9 ]
[.5 .29652 6 0 ]
[.7381 .29652 -6 -9 ]
[.7381 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -4.90625 ]
[1.025 .30902 10 4.90625 ]
[.01131 .08603 -12 -4.5 ]
[.01131 .08603 0 4.5 ]
[.01131 .19752 -12 -4.5 ]
[.01131 .19752 0 4.5 ]
[.01131 .42051 -6 -4.5 ]
[.01131 .42051 0 4.5 ]
[.01131 .53201 -6 -4.5 ]
[.01131 .53201 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(5)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(10)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(15)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -8.90625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.02381 .08603 m
.03006 .08603 L
s
[(-2)] .01131 .08603 1 0 Mshowa
.02381 .19752 m
.03006 .19752 L
s
[(-1)] .01131 .19752 1 0 Mshowa
.02381 .42051 m
.03006 .42051 L
s
[(1)] .01131 .42051 1 0 Mshowa
.02381 .53201 m
.03006 .53201 L
s
[(2)] .01131 .53201 1 0 Mshowa
.125 Mabswid
.02381 .10833 m
.02756 .10833 L
s
.02381 .13063 m
.02756 .13063 L
s
.02381 .15292 m
.02756 .15292 L
s
.02381 .17522 m
.02756 .17522 L
s
.02381 .21982 m
.02756 .21982 L
s
.02381 .24212 m
.02756 .24212 L
s
.02381 .26442 m
.02756 .26442 L
s
.02381 .28672 m
.02756 .28672 L
s
.02381 .33132 m
.02756 .33132 L
s
.02381 .35361 m
.02756 .35361 L
s
.02381 .37591 m
.02756 .37591 L
s
.02381 .39821 m
.02756 .39821 L
s
.02381 .44281 m
.02756 .44281 L
s
.02381 .46511 m
.02756 .46511 L
s
.02381 .48741 m
.02756 .48741 L
s
.02381 .50971 m
.02756 .50971 L
s
.02381 .06373 m
.02756 .06373 L
s
.02381 .04143 m
.02756 .04143 L
s
.02381 .01913 m
.02756 .01913 L
s
.02381 .55431 m
.02756 .55431 L
s
.02381 .5766 m
.02756 .5766 L
s
.02381 .5989 m
.02756 .5989 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.2 1 0 r
.01 w
.02381 .60332 m
.02499 .60328 L
.02605 .60319 L
.02729 .603 L
.02846 .60275 L
.03053 .60214 L
.03279 .60122 L
.03527 .59991 L
.0379 .59818 L
.04262 .59425 L
.05205 .58342 L
.06244 .56765 L
.08274 .53008 L
.09394 .50887 L
.10458 .49063 L
.11464 .47652 L
.12033 .47029 L
.12562 .46582 L
.12813 .46416 L
.1305 .46289 L
.13263 .46199 L
.13494 .46129 L
.13613 .46103 L
.13745 .46083 L
.13811 .46076 L
.13883 .46071 L
.14011 .4607 L
.14139 .46077 L
.1426 .46092 L
.14368 .46111 L
.14487 .4614 L
.1472 .46217 L
.14972 .46331 L
.15427 .46619 L
.15968 .47091 L
.16464 .4764 L
.18565 .50925 L
.20618 .54838 L
.21618 .56638 L
.22527 .58059 L
.22982 .58664 L
.23475 .59226 L
.23901 .59625 L
.2437 .59966 L
.24627 .60106 L
.24867 .60208 L
.25 .60251 L
.25121 .60282 L
.25188 .60296 L
.25261 .60309 L
Mistroke
.2533 .60318 L
.25394 .60325 L
.25518 .60331 L
.25634 .6033 L
.25738 .60323 L
.25851 .60309 L
.25975 .60286 L
.26105 .60253 L
.26338 .60172 L
.26594 .60052 L
.26836 .59908 L
.27289 .5956 L
.27776 .5908 L
.28306 .58441 L
.30141 .55499 L
.32083 .51794 L
.33114 .4992 L
.34224 .48191 L
.3474 .47532 L
.35283 .46958 L
.35747 .46575 L
.36012 .46403 L
.36253 .46277 L
.36371 .46226 L
.36499 .46178 L
.36609 .46144 L
.3673 .46114 L
.36859 .46091 L
.3693 .46082 L
.36995 .46075 L
.37113 .4607 L
.3724 .46072 L
.37357 .46081 L
.37485 .461 L
.37607 .46125 L
.37719 .46156 L
.37931 .46231 L
.38156 .46336 L
.38644 .4665 L
.39091 .4704 L
.40101 .48239 L
.41928 .5127 L
.43978 .55183 L
.44978 .56945 L
.45887 .58313 L
.46341 .58884 L
.46833 .59407 L
.47298 .59799 L
.47727 .60068 L
.47962 .60177 L
Mistroke
.48182 .60252 L
.48308 .60285 L
.48423 .60307 L
.48487 .60316 L
.48556 .60324 L
.48682 .60331 L
.48751 .60332 L
.48816 .6033 L
.48937 .60321 L
.49067 .60303 L
.4914 .60288 L
.49207 .60273 L
.49444 .602 L
.49695 .60091 L
.4995 .59947 L
.50191 .59782 L
.50643 .59396 L
.5166 .58202 L
.53494 .55172 L
.55317 .51684 L
.56355 .49809 L
.57329 .4829 L
.58281 .47132 L
.58817 .46654 L
.59071 .46475 L
.59308 .46337 L
.59544 .46227 L
.59665 .46182 L
.59797 .46141 L
.59872 .46122 L
.59941 .46107 L
.60006 .46095 L
.60077 .46085 L
.60201 .46073 L
.60331 .46069 L
.60403 .46071 L
.60472 .46075 L
.606 .4609 L
.60672 .46102 L
.60738 .46115 L
.60888 .46154 L
.6114 .46245 L
.61409 .46378 L
.61947 .46751 L
.62441 .47216 L
.63556 .48641 L
.65574 .5216 L
.67622 .56035 L
.68621 .57682 L
.6953 .589 L
Mistroke
.69983 .59382 L
.70475 .598 L
.707 .59953 L
.70939 .60087 L
.71143 .60179 L
.71368 .60255 L
.71499 .60288 L
.71623 .60311 L
.71735 .60324 L
.71857 .60331 L
.71989 .6033 L
.72063 .60326 L
.7213 .60319 L
.7226 .60299 L
.72383 .60273 L
.72499 .60241 L
.72621 .60199 L
.7284 .60106 L
.73335 .59806 L
.7383 .59386 L
.74282 .58906 L
.75298 .57528 L
.77131 .54302 L
.79199 .50386 L
.80109 .48871 L
.80593 .48168 L
.81114 .47506 L
.81614 .46979 L
.82072 .46595 L
.8251 .46323 L
.8273 .46223 L
.82972 .46142 L
.83105 .4611 L
.8323 .46088 L
.83343 .46076 L
.83466 .4607 L
.83529 .4607 L
.83599 .46072 L
.83672 .46078 L
.83741 .46085 L
.83863 .46105 L
.83994 .46134 L
.84116 .4617 L
.84249 .46217 L
.84491 .46327 L
.84946 .46613 L
.85478 .47074 L
.85979 .47625 L
.86916 .4892 L
.89014 .52667 L
Mistroke
.90855 .56135 L
.91899 .57834 L
.92409 .58537 L
.92873 .59088 L
.93335 .59545 L
.93837 .59928 L
.94113 .60086 L
.94368 .60198 L
.94494 .60241 L
.94612 .60273 L
.94734 .603 L
.948 .60311 L
.9487 .6032 L
.94934 .60326 L
.95003 .6033 L
.95126 .60331 L
.95202 .60328 L
.95273 .60323 L
.95337 .60315 L
.95406 .60305 L
.95549 .60275 L
.957 .60233 L
.9597 .60127 L
.96218 .59998 L
.9645 .59849 L
.96978 .59413 L
.97619 .58714 L
Mfstroke
0 .4 1 r
.009 w
.02381 .26148 m
.02499 .2615 L
.02605 .26156 L
.02729 .26169 L
.02846 .26185 L
.03053 .26226 L
.03279 .26288 L
.03527 .26375 L
.0379 .2649 L
.04262 .26752 L
.05205 .27474 L
.06244 .28526 L
.08274 .3103 L
.09394 .32444 L
.10458 .3366 L
.11464 .34601 L
.12033 .35016 L
.12562 .35314 L
.12813 .35424 L
.1305 .35509 L
.13263 .35569 L
.13494 .35616 L
.13613 .35634 L
.13745 .35647 L
.13811 .35652 L
.13883 .35655 L
.14011 .35656 L
.14139 .35651 L
.1426 .35641 L
.14368 .35628 L
.14487 .35609 L
.1472 .35558 L
.14972 .35481 L
.15427 .35289 L
.15968 .34975 L
.16464 .34609 L
.18565 .32419 L
.20618 .2981 L
.21618 .2861 L
.22527 .27663 L
.22982 .27259 L
.23475 .26885 L
.23901 .26618 L
.2437 .26392 L
.24627 .26298 L
.24867 .2623 L
.25 .26202 L
.25121 .26181 L
.25188 .26171 L
.25261 .26163 L
Mistroke
.2533 .26157 L
.25394 .26152 L
.25518 .26148 L
.25634 .26149 L
.25738 .26153 L
.25851 .26163 L
.25975 .26178 L
.26105 .262 L
.26338 .26254 L
.26594 .26334 L
.26836 .2643 L
.27289 .26662 L
.27776 .26982 L
.28306 .27408 L
.30141 .2937 L
.32083 .31839 L
.33114 .33089 L
.34224 .34242 L
.3474 .34681 L
.35283 .35063 L
.35747 .35319 L
.36012 .35434 L
.36253 .35518 L
.36371 .35552 L
.36499 .35583 L
.36609 .35606 L
.3673 .35626 L
.36859 .35642 L
.3693 .35648 L
.36995 .35652 L
.37113 .35656 L
.3724 .35654 L
.37357 .35648 L
.37485 .35636 L
.37607 .35619 L
.37719 .35598 L
.37931 .35548 L
.38156 .35478 L
.38644 .35269 L
.39091 .35009 L
.40101 .34209 L
.41928 .32189 L
.43978 .2958 L
.44978 .28405 L
.45887 .27494 L
.46341 .27113 L
.46833 .26764 L
.47298 .26503 L
.47727 .26323 L
.47962 .26251 L
Mistroke
.48182 .262 L
.48308 .26179 L
.48423 .26164 L
.48487 .26158 L
.48556 .26153 L
.48682 .26148 L
.48751 .26148 L
.48816 .26149 L
.48937 .26155 L
.49067 .26167 L
.4914 .26176 L
.49207 .26187 L
.49444 .26236 L
.49695 .26308 L
.4995 .26404 L
.50191 .26514 L
.50643 .26771 L
.5166 .27568 L
.53494 .29588 L
.55317 .31913 L
.56355 .33163 L
.57329 .34176 L
.58281 .34947 L
.58817 .35266 L
.59071 .35386 L
.59308 .35478 L
.59544 .35551 L
.59665 .35581 L
.59797 .35608 L
.59872 .35621 L
.59941 .35631 L
.60006 .35639 L
.60077 .35645 L
.60201 .35653 L
.60331 .35656 L
.60403 .35655 L
.60472 .35652 L
.606 .35642 L
.60672 .35634 L
.60738 .35625 L
.60888 .356 L
.6114 .35539 L
.61409 .3545 L
.61947 .35201 L
.62441 .34892 L
.63556 .33942 L
.65574 .31596 L
.67622 .29012 L
.68621 .27914 L
.6953 .27102 L
Mistroke
.69983 .26781 L
.70475 .26502 L
.707 .264 L
.70939 .26311 L
.71143 .26249 L
.71368 .26198 L
.71499 .26177 L
.71623 .26162 L
.71735 .26153 L
.71857 .26148 L
.71989 .26149 L
.72063 .26152 L
.7213 .26156 L
.7226 .26169 L
.72383 .26187 L
.72499 .26208 L
.72621 .26236 L
.7284 .26298 L
.73335 .26498 L
.7383 .26778 L
.74282 .27098 L
.75298 .28017 L
.77131 .30167 L
.79199 .32778 L
.80109 .33788 L
.80593 .34257 L
.81114 .34698 L
.81614 .3505 L
.82072 .35306 L
.8251 .35487 L
.8273 .35554 L
.82972 .35608 L
.83105 .35629 L
.8323 .35643 L
.83343 .35652 L
.83466 .35656 L
.83529 .35656 L
.83599 .35654 L
.83672 .3565 L
.83741 .35645 L
.83863 .35632 L
.83994 .35613 L
.84116 .35589 L
.84249 .35557 L
.84491 .35484 L
.84946 .35294 L
.85478 .34986 L
.85979 .34619 L
.86916 .33755 L
.89014 .31258 L
Mistroke
.90855 .28945 L
.91899 .27813 L
.92409 .27344 L
.92873 .26977 L
.93335 .26672 L
.93837 .26417 L
.94113 .26311 L
.94368 .26237 L
.94494 .26208 L
.94612 .26187 L
.94734 .26169 L
.948 .26162 L
.9487 .26156 L
.94934 .26151 L
.95003 .26149 L
.95126 .26148 L
.95202 .2615 L
.95273 .26154 L
.95337 .26159 L
.95406 .26166 L
.95549 .26185 L
.957 .26213 L
.9597 .26284 L
.96218 .2637 L
.9645 .2647 L
.96978 .2676 L
.97619 .27226 L
Mfstroke
1 0 .6 r
.007 w
.02381 .15734 m
.02499 .1573 L
.02605 .15721 L
.02729 .15702 L
.02846 .15677 L
.03053 .15616 L
.03279 .15524 L
.03527 .15393 L
.0379 .1522 L
.04262 .14827 L
.05205 .13744 L
.06244 .12167 L
.08274 .0841 L
.09394 .06289 L
.10458 .04465 L
.11464 .03054 L
.12033 .02431 L
.12562 .01984 L
.12813 .01818 L
.1305 .01691 L
.13263 .01602 L
.13494 .01531 L
.13613 .01505 L
.13745 .01485 L
.13811 .01478 L
.13883 .01473 L
.14011 .01472 L
.14139 .01479 L
.1426 .01494 L
.14368 .01513 L
.14487 .01542 L
.1472 .01619 L
.14972 .01733 L
.15427 .02021 L
.15968 .02493 L
.16464 .03042 L
.18565 .06327 L
.20618 .1024 L
.21618 .1204 L
.22527 .13461 L
.22982 .14066 L
.23475 .14628 L
.23901 .15028 L
.2437 .15368 L
.24627 .15508 L
.24867 .1561 L
.25 .15653 L
.25121 .15684 L
.25188 .15698 L
.25261 .15711 L
Mistroke
.2533 .1572 L
.25394 .15727 L
.25518 .15734 L
.25634 .15732 L
.25738 .15725 L
.25851 .15711 L
.25975 .15688 L
.26105 .15655 L
.26338 .15575 L
.26594 .15454 L
.26836 .1531 L
.27289 .14962 L
.27776 .14482 L
.28306 .13843 L
.30141 .10901 L
.32083 .07197 L
.33114 .05322 L
.34224 .03593 L
.3474 .02934 L
.35283 .0236 L
.35747 .01977 L
.36012 .01805 L
.36253 .01679 L
.36371 .01628 L
.36499 .01581 L
.36609 .01547 L
.3673 .01516 L
.36859 .01493 L
.3693 .01484 L
.36995 .01477 L
.37113 .01472 L
.3724 .01474 L
.37357 .01483 L
.37485 .01502 L
.37607 .01527 L
.37719 .01558 L
.37931 .01633 L
.38156 .01738 L
.38644 .02052 L
.39091 .02442 L
.40101 .03641 L
.41928 .06672 L
.43978 .10585 L
.44978 .12347 L
.45887 .13715 L
.46341 .14286 L
.46833 .14809 L
.47298 .15201 L
.47727 .15471 L
.47962 .15579 L
Mistroke
.48182 .15655 L
.48308 .15687 L
.48423 .15709 L
.48487 .15718 L
.48556 .15726 L
.48682 .15733 L
.48751 .15734 L
.48816 .15732 L
.48937 .15723 L
.49067 .15705 L
.4914 .15691 L
.49207 .15675 L
.49444 .15602 L
.49695 .15493 L
.4995 .15349 L
.50191 .15184 L
.50643 .14798 L
.5166 .13604 L
.53494 .10574 L
.55317 .07086 L
.56355 .05211 L
.57329 .03692 L
.58281 .02534 L
.58817 .02056 L
.59071 .01877 L
.59308 .01739 L
.59544 .01629 L
.59665 .01584 L
.59797 .01543 L
.59872 .01524 L
.59941 .01509 L
.60006 .01497 L
.60077 .01487 L
.60201 .01475 L
.60331 .01472 L
.60403 .01473 L
.60472 .01477 L
.606 .01492 L
.60672 .01504 L
.60738 .01517 L
.60888 .01556 L
.6114 .01647 L
.61409 .0178 L
.61947 .02153 L
.62441 .02618 L
.63556 .04043 L
.65574 .07562 L
.67622 .11437 L
.68621 .13084 L
.6953 .14302 L
Mistroke
.69983 .14784 L
.70475 .15202 L
.707 .15355 L
.70939 .15489 L
.71143 .15581 L
.71368 .15658 L
.71499 .1569 L
.71623 .15713 L
.71735 .15726 L
.71857 .15733 L
.71989 .15732 L
.72063 .15728 L
.7213 .15721 L
.7226 .15702 L
.72383 .15675 L
.72499 .15643 L
.72621 .15601 L
.7284 .15508 L
.73335 .15208 L
.7383 .14788 L
.74282 .14308 L
.75298 .1293 L
.77131 .09704 L
.79199 .05788 L
.80109 .04273 L
.80593 .0357 L
.81114 .02908 L
.81614 .02381 L
.82072 .01997 L
.8251 .01725 L
.8273 .01625 L
.82972 .01544 L
.83105 .01512 L
.8323 .0149 L
.83343 .01478 L
.83466 .01472 L
.83529 .01472 L
.83599 .01474 L
.83672 .0148 L
.83741 .01487 L
.83863 .01507 L
.83994 .01536 L
.84116 .01572 L
.84249 .01619 L
.84491 .01729 L
.84946 .02015 L
.85478 .02476 L
.85979 .03027 L
.86916 .04322 L
.89014 .08069 L
Mistroke
.90855 .11537 L
.91899 .13236 L
.92409 .13939 L
.92873 .1449 L
.93335 .14947 L
.93837 .1533 L
.94113 .15488 L
.94368 .156 L
.94494 .15643 L
.94612 .15675 L
.94734 .15702 L
.948 .15713 L
.9487 .15722 L
.94934 .15728 L
.95003 .15732 L
.95126 .15733 L
.95202 .1573 L
.95273 .15725 L
.95337 .15717 L
.95406 .15707 L
.95549 .15678 L
.957 .15635 L
.9597 .15529 L
.96218 .154 L
.9645 .15251 L
.96978 .14815 L
.97619 .14116 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 5.12828e-17 1.16608 [
[.30907 .06148 -14.3775 -9.8125 ]
[.30907 .06148 1.62253 0 ]
[.2142 1.04697 -8.70051 0 ]
[.2142 1.04697 7.29949 9.8125 ]
[-0.03373 .52941 -16 -3.08918 ]
[-0.03373 .52941 0 6.72332 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
gsave
.30907 .06148 -75.3775 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
1.000 setlinewidth
grestore
0 .80374 m
.40037 1.0855 L
s
gsave
.2142 1.04697 -69.7005 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
1.000 setlinewidth
grestore
.08846 .24555 m
0 .80374 L
s
gsave
-0.03373 .52941 -77 -7.08918 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x3) show
1.000 setlinewidth
grestore
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.42216 .58164 m
.42725 .58171 L
s
.42733 .58171 m
.42216 .58164 L
s
.42216 .58164 m
.42717 .58171 L
s
.42741 .58171 m
.42216 .58164 L
s
.42216 .58164 m
.4271 .58171 L
s
.42749 .58171 m
.42216 .58164 L
s
.42216 .58164 m
.42702 .58171 L
s
.42757 .58171 m
.42216 .58164 L
s
.42702 .58171 m
.44221 .58191 L
s
.4271 .58171 m
.44237 .58191 L
s
.42717 .58171 m
.44253 .58191 L
s
.42725 .58171 m
.44269 .58192 L
s
.44284 .58192 m
.42733 .58171 L
s
.443 .58192 m
.42741 .58171 L
s
.44316 .58192 m
.42749 .58171 L
s
.44332 .58192 m
.42757 .58171 L
s
.44221 .58191 m
.46785 .58225 L
s
.44237 .58191 m
.46809 .58226 L
s
.44253 .58191 m
.46832 .58226 L
s
.44269 .58192 m
.46856 .58226 L
s
.4688 .58227 m
.44284 .58192 L
s
.46904 .58227 m
.443 .58192 L
s
.46928 .58227 m
.44316 .58192 L
s
.46952 .58228 m
.44332 .58192 L
s
.46785 .58225 m
.50367 .58273 L
s
.46809 .58226 m
.50398 .58274 L
s
.46832 .58226 m
.50429 .58274 L
s
.46856 .58226 m
.5046 .58275 L
s
.50491 .58275 m
.4688 .58227 L
s
.50523 .58276 m
.46904 .58227 L
s
.50554 .58276 m
.46928 .58227 L
s
.50585 .58276 m
.46952 .58228 L
s
.50367 .58273 m
.54826 .58333 L
s
.50398 .58274 m
.54863 .58334 L
s
.50429 .58274 m
.549 .58334 L
s
.5046 .58275 m
.54936 .58335 L
s
.54973 .58335 m
.50491 .58275 L
s
.5501 .58336 m
.50523 .58276 L
s
.55047 .58336 m
.50554 .58276 L
s
.55084 .58337 m
.50585 .58276 L
s
.54826 .58333 m
.59793 .584 L
s
.54863 .58334 m
.59831 .58401 L
s
.549 .58334 m
.5987 .58401 L
s
.54936 .58335 m
.59908 .58402 L
s
.59947 .58402 m
.54973 .58335 L
s
.59985 .58403 m
.5501 .58336 L
s
.60023 .58403 m
.55047 .58336 L
s
.60062 .58404 m
.55084 .58337 L
s
.59793 .584 m
.64563 .58464 L
s
.59831 .58401 m
.64596 .58465 L
s
.5987 .58401 m
.64629 .58465 L
s
.59908 .58402 m
.64663 .58466 L
s
.64696 .58466 m
.59947 .58402 L
s
.64729 .58466 m
.59985 .58403 L
s
.64762 .58467 m
.60023 .58403 L
s
.64794 .58467 m
.60062 .58404 L
s
.64563 .58464 m
.68132 .58512 L
s
.64596 .58465 m
.68151 .58512 L
s
.64629 .58465 m
.68171 .58513 L
s
.64663 .58466 m
.68191 .58513 L
s
.68211 .58513 m
.64696 .58466 L
s
.6823 .58513 m
.64729 .58466 L
s
.68249 .58514 m
.64762 .58467 L
s
.68268 .58514 m
.64794 .58467 L
s
.68287 .58514 m
.64827 .58468 L
s
.68132 .58512 m
.69519 .58531 L
s
.68151 .58512 m
.69519 .58531 L
s
.68171 .58513 m
.6952 .58531 L
s
.68191 .58513 m
.6952 .58531 L
s
.6952 .58531 m
.68211 .58513 L
s
.6952 .58531 m
.6823 .58513 L
s
.6952 .58531 m
.68249 .58514 L
s
.69519 .58531 m
.68268 .58514 L
s
.69519 .58531 m
.68287 .58514 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
gsave
.30907 .06148 -75.3775 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
1.000 setlinewidth
grestore
0 .80374 m
.40037 1.0855 L
s
gsave
.2142 1.04697 -69.7005 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{670, 197.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:N0000aB000`400?l00000o`00003oo`3ooooo
0?oooj00oooo003o0?ooool0ooooX03oool00?l0ooooo`3ooonP0?ooo`00o`3ooooo0?oooj00oooo
003o0?ooool0ooooX03oool00240oooo00<000000?ooo`3oool0o`3ooooh0?ooo`800000P@3oool0
0240oooo00<000000?ooo`3oool0o`3oooof0?ooo`80000000<0oooo000000000000P03oool00240
oooo00<000000?ooo`3oool0o`3ooood0?ooo`8000000`3oool200000800oooo000Q0?ooo`030000
003oool0oooo0?l0ooool@3oool3000000D0oooo00<000000?ooo`000000O`3oool00240oooo00<0
00000?ooo`3oool06`3oool40?l0VC`0oooo103o09Tk0?ooo`D0o`2I?03oool40?l0VLl0oooo0P00
00000`3oool00000000000020?ooo`@00000=@3oool2000000P0oooo00<000000?ooo`000000O`3o
ool00240oooo0P00000J0?ooo`80o`2I103oool20?l0VCP0oooo0P3o09T40?ooo`030?l0V@3oool0
oooo03L0oooo0P3o09T30?ooo`<0o`2I>03oool20?l0V@<0oooo0P3o09W?0?ooo`030000003oool0
000000D0oooo00<000000?ooo`3oool0<P3oool2000000X0oooo00@000000?ooo`3oool00000OP3o
ool00240oooo00<000000?ooo`3oool0603oool20?l0V@H0oooo0P3o09Tf0?ooo`80o`2I1P3oool2
0?l0VCH0oooo00<0o`2I0?ooo`3oool01@3oool20?l0VCH0oooo00<0o`2I0?ooo`3oool01@3oool0
0`3o09T0oooo0?ooo`3=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;`3oool3
000000`0oooo00D000000?ooo`3oool0oooo0000001m0?ooo`008@3oool00`000000oooo0?ooo`0G
0?ooo`80o`2I2@3oool00`3o09T0oooo0?ooo`0b0?ooo`80o`2I203oool20?l0VC@0oooo00<0o`2I
0?ooo`3oool0203oool00`3o09T0oooo0?ooo`0a0?ooo`80o`2I2@3oool20?l0VL`0oooo00<00000
0?ooo`0000001@3oool00`000000oooo0?ooo`0]0?ooo`8000003`3oool01@000000oooo0?ooo`3o
ool0000007d0oooo000Q0?ooo`030000003oool0oooo01H0oooo00<0o`2I0?ooo`3oool02P3oool0
0`3o09T0oooo0?ooo`0`0?ooo`030?l0V@3oool0oooo00X0oooo00<0o`2I0?ooo`3oool0<03oool0
0`3o09T0oooo0?ooo`0:0?ooo`030?l0V@3oool0oooo02l0oooo0P3o09T;0?ooo`80o`2IbP3oool2
000000030?ooo`000000000000@0oooo00<000000?ooo`3oool0:P3oool300000140oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`1j0?ooo`008@3oool00`000000oooo0?ooo`0E0?oo
o`030?l0V@3oool0oooo00`0oooo00<0o`2I0?ooo`3oool0;P3oool00`3o09T0oooo0?ooo`0<0?oo
o`030?l0V@3oool0oooo02h0oooo00<0o`2I0?ooo`3oool02`3oool20?l0VBl0oooo0P3o09T=0?oo
o`80o`2Id03oool3000002X0oooo0P00000E0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0N@3oool00240oooo00<000000?ooo`3oool0503oool20?l0V@h0oooo00<0o`2I0?ooo`3o
ool0;@3oool00`3o09T0oooo0?ooo`0>0?ooo`030?l0V@3oool0oooo02`0oooo00<0o`2I0?ooo`3o
ool03@3oool00`3o09T0oooo0?ooo`0]0?ooo`030?l0V@3oool0oooo00d0oooo00<0o`2I0?ooo`3o
ool0d03oool00`000000oooo0?ooo`0V0?ooo`8000005`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo07T0oooo000Q0?ooo`8000005@3oool00`3o09T0oooo0?ooo`0>0?ooo`030?l0
V@3oool0oooo02/0oooo00<0o`2I0?ooo`3oool0403oool00`3o09T0oooo0?ooo`0Z0?ooo`030?l0
V@3oool0oooo00l0oooo00<0o`2I0?ooo`3oool0:`3oool20?l0V@l0oooo0P3o09Wg0?ooo`<00000
6@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07P0oooo000Q0?ooo`030000003o
ool0oooo01<0oooo00<0o`2I0?ooo`3oool0403oool00`3o09T0oooo0?ooo`0Z0?ooo`030?l0V@3o
ool0oooo0100oooo00<0o`2I0?ooo`3oool0:@3oool20?l0VA80oooo00<0o`2I0?ooo`3oool0:P3o
ool00`3o09T0oooo0?ooo`0?0?ooo`030?l0V@3oool0oooo0?<0oooo0P00000L0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0N03oool00240oooo00<000000?ooo`3oool04P3oool0
0`3o09T0oooo0?ooo`0A0?ooo`030?l0V@3oool0oooo02T0oooo00<0o`2I0?ooo`3oool04P3oool0
0`3o09T0oooo0?ooo`0X0?ooo`030?l0V@3oool0oooo0140oooo00<0o`2I0?ooo`3oool0:@3oool0
0`3o09T0oooo0?ooo`0A0?ooo`030?l0V@3oool0oooo0?00oooo0P00000N0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0M`3oool00240oooo00<000000?ooo`3oool04P3oool00`3o
09T0oooo0?ooo`0B0?ooo`030?l0V@3oool0oooo02P0oooo00<0o`2I0?ooo`3oool04P3oool20?l0
VBP0oooo00<0o`2I0?ooo`3oool04`3oool00`3o09T0oooo0?ooo`0W0?ooo`80o`2I4`3oool00`3o
09T0oooo0?ooo`3]0?ooo`<00000803oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
07H0oooo000Q0?ooo`030000003oool0oooo0140oooo00<0o`2I0?ooo`3oool0503oool00`3o09T0
oooo0?ooo`0V0?ooo`030?l0V@3oool0oooo01@0oooo00<0o`2I0?ooo`3oool09@3oool20?l0VAD0
oooo00<0o`2I0?ooo`3oool09`3oool00`3o09T0oooo0?ooo`0C0?ooo`030?l0V@3oool0oooo0>X0
oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0MP3oool00240oooo
00<000000?ooo`3oool04@3oool00`3o09T0oooo0?ooo`0D0?ooo`030?l0V@3oool0oooo02D0oooo
00<0o`2I0?ooo`3oool05P3oool00`3o09T0oooo0?ooo`0T0?ooo`030?l0V@3oool0oooo01D0oooo
00<0o`2I0?ooo`3oool09@3oool00`3o09T0oooo0?ooo`0D0?ooo`030?l0V@3oool0oooo0>P0oooo
0P00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0M@3oool00240oooo00<0
00000?ooo`3oool0403oool00`3o09T0oooo0?ooo`0F0?ooo`030?l0V@3oool0oooo02@0oooo00<0
o`2I0?ooo`3oool05P3oool00`3o09T0oooo0?ooo`0S0?ooo`80o`2I603oool00`3o09T0oooo0?oo
o`0S0?ooo`80o`2I5`3oool00`3o09T0oooo0?ooo`3T0?ooo`<000009`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo07D0oooo000Q0?ooo`800000403oool20?l0VAP0oooo0P3o09TT
0?ooo`030?l0V@3oool0oooo01P0oooo00<0o`2I0?ooo`3oool08P3oool00`3o09T0oooo0?ooo`0G
0?ooo`030?l0V@3oool0oooo02<0oooo00<0o`2I0?ooo`3oool05`3oool00`3o09T0oooo0?ooo`3Q
0?ooo`800000:P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07@0oooo000Q0?oo
o`030000003oool0oooo00l0oooo00<0o`2I0?ooo`3oool0603oool00`3o09T0oooo0?ooo`0R0?oo
o`030?l0V@3oool0oooo01P0oooo0P3o09TR0?ooo`80o`2I6P3oool00`3o09T0oooo0?ooo`0Q0?oo
o`030?l0V@3oool0oooo01P0oooo00<0o`2I0?ooo`3oool0g`3oool2000002`0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`1c0?ooo`008@3oool00`000000oooo0?ooo`0>0?ooo`80
o`2I6`3oool00`3o09T0oooo0?ooo`0P0?ooo`030?l0V@3oool0oooo01X0oooo00<0o`2I0?ooo`3o
ool0803oool00`3o09T0oooo0?ooo`0I0?ooo`030?l0V@3oool0oooo0240oooo00<0o`2I0?ooo`3o
ool06@3oool00`3o09T0oooo0?ooo`3K0?ooo`<00000;P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo07<0oooo000Q0?ooo`030000003oool0oooo00h0oooo00<0o`2I0?ooo`3oool0
6P3oool00`3o09T0oooo0?ooo`0O0?ooo`80o`2I703oool00`3o09T0oooo0?ooo`0O0?ooo`80o`2I
703oool00`3o09T0oooo0?ooo`0O0?ooo`030?l0V@3oool0oooo01X0oooo00<0o`2I0?ooo`3oool0
f@3oool200000340oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1b0?ooo`00603o
ool4000000D0oooo00<000000?ooo`3oool03@3oool20?l0VAd0oooo00<0o`2I0?ooo`3oool07P3o
ool00`3o09T0oooo0?ooo`0L0?ooo`030?l0V@3oool0oooo01h0oooo00<0o`2I0?ooo`3oool06`3o
ool20?l0VB00oooo00<0o`2I0?ooo`3oool06`3oool00`3o09T0oooo0?ooo`3E0?ooo`<00000<`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0740oooo000H0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool03@3oool00`3o09T0oooo0?ooo`0L0?ooo`030?l0V@3oool0
oooo01d0oooo0P3o09TN0?ooo`030?l0V@3oool0oooo01d0oooo00<0o`2I0?ooo`3oool07@3oool0
0`3o09T0oooo0?ooo`0M0?ooo`030?l0V@3oool0oooo01`0oooo0P3o09WD0?ooo`800000=P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0740oooo000I0?ooo`030000003oool0oooo
00D0oooo0P00000=0?ooo`80o`2I7`3oool00`3o09T0oooo0?ooo`0L0?ooo`030?l0V@3oool0oooo
01h0oooo00<0o`2I0?ooo`3oool0703oool00`3o09T0oooo0?ooo`0M0?ooo`030?l0V@3oool0oooo
01d0oooo00<0o`2I0?ooo`3oool07@3oool00`3o09T0oooo0?ooo`3@0?ooo`800000>03oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0700oooo000B0?ooo`@00000103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<0o`2I0?ooo`3oool07P3oool00`3o09T0
oooo0?ooo`0K0?ooo`80o`2I803oool00`3o09T0oooo0?ooo`0K0?ooo`030?l0V@3oool0oooo01l0
oooo00<0o`2I0?ooo`3oool06`3oool00`3o09T0oooo0?ooo`0N0?ooo`80o`2IcP3oool3000003/0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1`0?ooo`006`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00/0oooo00<0o`2I0?ooo`3oool0803oool00`3o09T0oooo
0?ooo`0J0?ooo`030?l0V@3oool0oooo0200oooo00<0o`2I0?ooo`3oool06P3oool00`3o09T0oooo
0?ooo`0O0?ooo`030?l0V@3oool0oooo01X0oooo0P3o09TQ0?ooo`030?l0V@3oool0oooo0<X0oooo
0P00000n0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0K`3oool001P0oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`0;0?ooo`030?l0V@3oool0oooo0200oooo
0P3o09TJ0?ooo`80o`2I8P3oool00`3o09T0oooo0?ooo`0I0?ooo`030?l0V@3oool0oooo0240oooo
00<0o`2I0?ooo`3oool06@3oool00`3o09T0oooo0?ooo`0P0?ooo`80o`2Ib@3oool200000400oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1^0?ooo`006@3oool2000000H0oooo00<0
00000?ooo`3oool02P3oool00`3o09T0oooo0?ooo`0R0?ooo`030?l0V@3oool0oooo01P0oooo00<0
o`2I0?ooo`3oool08@3oool20?l0VAT0oooo0P3o09TS0?ooo`030?l0V@3oool0oooo01P0oooo0P3o
09TS0?ooo`030?l0V@3oool0oooo0<@0oooo0`0000120?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0KP3oool00240oooo00<000000?ooo`3oool02P3oool00`3o09T0oooo0?ooo`0S
0?ooo`030?l0V@3oool0oooo01H0oooo0P3o09TT0?ooo`030?l0V@3oool0oooo01L0oooo00<0o`2I
0?ooo`3oool08`3oool00`3o09T0oooo0?ooo`0G0?ooo`030?l0V@3oool0oooo0280oooo0P3o09W3
0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo06d0oooo000Q0?oo
o`8000002P3oool00`3o09T0oooo0?ooo`0T0?ooo`030?l0V@3oool0oooo01H0oooo00<0o`2I0?oo
o`3oool0903oool00`3o09T0oooo0?ooo`0E0?ooo`80o`2I9@3oool00`3o09T0oooo0?ooo`0F0?oo
o`030?l0V@3oool0oooo02@0oooo00<0o`2I0?ooo`3oool0_`3oool2000004L0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`1]0?ooo`008@3oool00`000000oooo0?ooo`090?ooo`03
0?l0V@3oool0oooo02D0oooo00<0o`2I0?ooo`3oool0503oool00`3o09T0oooo0?ooo`0U0?ooo`03
0?l0V@3oool0oooo01D0oooo00<0o`2I0?ooo`3oool0903oool20?l0VAL0oooo00<0o`2I0?ooo`3o
ool0903oool20?l0VKd0oooo0`0000190?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0K03oool00240oooo00<000000?ooo`3oool0203oool00`3o09T0oooo0?ooo`0V0?ooo`030?l0
V@3oool0oooo01@0oooo00<0o`2I0?ooo`3oool09P3oool00`3o09T0oooo0?ooo`0C0?ooo`030?l0
V@3oool0oooo02H0oooo00<0o`2I0?ooo`3oool0503oool00`3o09T0oooo0?ooo`0V0?ooo`030?l0
V@3oool0oooo0;T0oooo0P00001<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
J`3oool00240oooo00<000000?ooo`3oool01`3oool20?l0VBT0oooo00<0o`2I0?ooo`3oool04P3o
ool00`3o09T0oooo0?ooo`0W0?ooo`030?l0V@3oool0oooo01<0oooo00<0o`2I0?ooo`3oool09`3o
ool00`3o09T0oooo0?ooo`0C0?ooo`030?l0V@3oool0oooo02L0oooo00<0o`2I0?ooo`3oool0]P3o
ool2000004h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1[0?ooo`008@3oool0
0`000000oooo0?ooo`070?ooo`030?l0V@3oool0oooo02P0oooo0P3o09TB0?ooo`80o`2I:P3oool0
0`3o09T0oooo0?ooo`0A0?ooo`030?l0V@3oool0oooo02P0oooo0P3o09TC0?ooo`030?l0V@3oool0
oooo02P0oooo0P3o09Vd0?ooo`<00000D03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo06X0oooo000Q0?ooo`030000003oool0oooo00H0oooo00<0o`2I0?ooo`3oool0:P3oool00`3o
09T0oooo0?ooo`0@0?ooo`030?l0V@3oool0oooo02T0oooo0P3o09TB0?ooo`030?l0V@3oool0oooo
02T0oooo00<0o`2I0?ooo`3oool0403oool20?l0VB/0oooo00<0o`2I0?ooo`3oool0/03oool20000
05<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1Z0?ooo`008@3oool2000000H0
oooo0P3o09T/0?ooo`80o`2I403oool00`3o09T0oooo0?ooo`0[0?ooo`030?l0V@3oool0oooo00l0
oooo00<0o`2I0?ooo`3oool0:`3oool00`3o09T0oooo0?ooo`0?0?ooo`030?l0V@3oool0oooo02/0
oooo00<0o`2I0?ooo`3oool0[03oool3000005D0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`1Y0?ooo`008@3oool00`000000oooo0?ooo`050?ooo`030?l0V@3oool0oooo02`0oooo
00<0o`2I0?ooo`3oool03P3oool00`3o09T0oooo0?ooo`0[0?ooo`80o`2I3`3oool20?l0VBh0oooo
00<0o`2I0?ooo`3oool03@3oool00`3o09T0oooo0?ooo`0/0?ooo`80o`2IZ`3oool2000005P0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1X0?ooo`008@3oool00`000000oooo0?oo
o`040?ooo`030?l0V@3oool0oooo02d0oooo0P3o09T>0?ooo`030?l0V@3oool0oooo02d0oooo0P3o
09T>0?ooo`030?l0V@3oool0oooo02h0oooo00<0o`2I0?ooo`3oool0303oool00`3o09T0oooo0?oo
o`0]0?ooo`030?l0V@3oool0oooo0:L0oooo0P00001J0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0J03oool00240oooo00<000000?ooo`3oool00`3oool00`3o09T0oooo0?ooo`0_
0?ooo`80o`2I303oool20?l0VC00oooo0P3o09T<0?ooo`030?l0V@3oool0oooo0300oooo00<0o`2I
0?ooo`3oool02P3oool00`3o09T0oooo0?ooo`0_0?ooo`030?l0V@3oool0oooo00/0oooo00<0o`2I
0?ooo`3oool0U@3oool3000005`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1W
0?ooo`008@3oool00`000000oooo0?ooo`030?ooo`030?l0V@3oool0oooo0300oooo0P3o09T:0?oo
o`80o`2I<P3oool20?l0V@/0oooo00<0o`2I0?ooo`3oool0<03oool20?l0V@X0oooo00<0o`2I0?oo
o`3oool0<@3oool00`3o09T0oooo0?ooo`090?ooo`030?l0V@3oool0oooo09@0oooo0P00001O0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0IP3oool00240oooo00<000000?ooo`3o
ool00P3oool00`3o09T0oooo0?ooo`0c0?ooo`030?l0V@3oool0oooo00H0oooo0P3o09Td0?ooo`03
0?l0V@3oool0oooo00L0oooo0P3o09Td0?ooo`030?l0V@3oool0oooo00L0oooo00<0o`2I0?ooo`3o
ool0<`3oool00`3o09T0oooo0?ooo`070?ooo`030?l0V@3oool0oooo09<0oooo0P00001Q0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0IP3oool00240oooo0P0000000`3oool0o`2I
0?l0V@0g0?ooo`030?l0V@3oool0oooo00@0oooo00<0o`2I0?ooo`3oool0=@3oool00`3o09T0oooo
0?ooo`050?ooo`80o`2I=P3oool20?l0V@H0oooo00<0o`2I0?ooo`3oool0=@3oool00`3o09T0oooo
0?ooo`040?ooo`80o`2IU03oool2000006@0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`1U0?ooo`008@3oool30?l0VCX0oooo1P3o09Ti0?ooo`L0o`2I>@3oool70?l0VCT0oooo1P3o
09VF0?ooo`800000I03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo06D0oooo000Q
0?ooo`030000003oool0oooo0?l0ooooUP3oool00`000000oooo0000001S0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0I03oool00240oooo00<000000?ooo`3oool0o`3ooonF0?oo
o`040000003oool0oooo00000680oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1S
0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooiD0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0H`3oool00240
oooo00<000000?ooo`3oool0o`3ooonE0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0680oooo000Q0?ooo`800000
o`3ooonF0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0G@3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0680oooo000Q0?ooo`030000003oool0oooo0?l0ooooU@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`1Q0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooiD0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0H03oool00240oooo00<000000?ooo`3oool0o`3ooonE0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
0600oooo000H0?ooo`@000001@3oool00`000000oooo0?ooo`3o0?oooiD0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0G`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooi@0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0GP3oool001X0oooo00<000000?ooo`3oool0103oool200000?l0ooooU@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`1N0?ooo`004P3oool4000000@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`3o0?oooi@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0G@3oool001X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`3o0?oooi@0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0G@3oool001P0
oooo0`0000060?ooo`030000003oool0oooo0?l0ooooU03oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1L0?ooo`00
6P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooU03oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`1K0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooi<0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3o
ool00240oooo00<000000?ooo`3oool0o`3ooonC0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0DP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05X0oooo000Q0?oo
o`800000o`3ooonD0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo05X0oooo000Q0?ooo`030000003oool0oooo0?l0
ooooT`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`1I0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooi<0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0F03oool00240oooo00<000000?ooo`3oool0o`3ooonC0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo05P0oooo000Q0?ooo`030000003oool0oooo0?l0ooooT`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1G
0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooi80oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`1<0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0EP3oool00240
oooo0P00003o0?oooi<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0EP3oool00240oooo00<000000?ooo`3oool0
o`3ooonB0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo05D0oooo000Q0?ooo`030000003oool0oooo0?l0ooooTP3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`1E0?ooo`008@3oool00`000000oooo0?ooo`3o0?oooi80oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02<0oooo0P00001F
0?ooo`008@3oool00`000000oooo0?ooo`1j0?ooo`03001Vo`3oool0oooo0?l0oooo5@3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0803oool30000
00030?ooo`000000oooo05D0oooo000P0?ooo`D006Ko>03oool7001VocT0oooo2000I_lg0?ooo`T0
06Ko=`3oool8001Voi40oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo01d0oooo0`0000040?ooo`030000003oool0oooo05@0oooo000P0?ooo`L006Ko
=03oool=001Voc<0oooo3000I_ld0?ooo`/006Ko=03oool<001Vohh0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo01X0oooo0`0000070?ooo`030000
003oool0oooo05@0oooo000Q0?ooo`030000003oool0oooo00@006Ko<@3oool5001Vo`D0oooo1P00
I_la0?ooo`@006Ko1P3oool4001Voc80oooo1000I_l60?ooo`@006Ko<03oool5001Vo`H0oooo1@00
I_n<0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0A03oool00`000000oooo0?oo
o`0G0?ooo`<000002`3oool00`000000oooo0?ooo`1C0?ooo`008@3oool00`000000oooo0?ooo`02
0?ooo`<006Ko;`3oool4001Vo`@0oooo0`0000040?ooo`8006Ko;`3oool4001Vo`<0oooo10000003
0?ooo`<006Ko<03oool3001Vo`@0oooo100000000`3oool006Ko001Vo`02001Vobh0oooo1000I_l7
0?ooo`<000001000I_l2000008T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo01<0oooo0`00000>0?ooo`030000003oool0oooo05<0oooo000Q0?oo
o`030000003oool0oooo00<0oooo0`00I_l]0?ooo`<006Ko2@3oool010000000oooo0?ooo`3oool3
001Vobd0oooo1000I_l60?ooo`060000003oool0oooo0?ooo`000000oooo0`00I_l]0?ooo`@006Ko
1`3oool00`000000oooo0?ooo`020?ooo`<006Ko;@3oool2001Vo`T0oooo00<000000?ooo`3oool0
0P3oool01@00I_l000000?ooo`3oool0000008P0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo0100oooo0`00000A0?ooo`030000003oool0oooo05<0
oooo000Q0?ooo`030000003oool0oooo00@0oooo0`00I_l/0?ooo`8006Ko2P3oool00`000000oooo
0?ooo`020?ooo`<006Ko:`3oool3001Vo`P0oooo00D000000?ooo`3oool0oooo000000020?ooo`<0
06Ko:`3oool3001Vo`T0oooo00<000000?ooo`3oool00`3oool3001Vob/0oooo0`00I_l:0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000R03oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool0303oool4000001@0oooo00<000000?oo
o`3oool0D`3oool00240oooo00<000000?ooo`3oool01@3oool3001VobX0oooo0P00I_l80?ooo`<0
00001P3oool3001VobT0oooo0`00I_l90?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
000006Ko001Vo`0Z0?ooo`<006Ko2P3oool010000000oooo0?ooo`3oool3000000<006Ko:@3oool3
001Vo``0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00T0oooo0`00
000H0?ooo`030000003oool0oooo05<0oooo000Q0?ooo`8000001`3oool3001VobP0oooo0`00I_l8
0?ooo`030000003oool0oooo00L0oooo0`00I_lW0?ooo`<006Ko2P3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`00I_l006Ko:03oool3001Vo`/0oooo00D000000?ooo`3oool0
oooo000000030?ooo`8006Ko:03oool3001Vo`h0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`250?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`060?ooo`<000006`3oool00`000000oooo0?ooo`1C0?ooo`008@3oool00`000000
oooo0?ooo`070?ooo`<006Ko9P3oool3001Vo`T0oooo00<000000?ooo`3oool0203oool3001VobD0
oooo0`00I_l90?ooo`<000000`3oool010000000oooo0?ooo`0000020?ooo`8006Ko9P3oool3001V
o`X0oooo0`0000030?ooo`030000003oool0oooo0080oooo0P00I_lV0?ooo`<006Ko303oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000008L0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00<0oooo0`00000N0?ooo`030000003o
ool0oooo05<0oooo000Q0?ooo`030000003oool0oooo00P0oooo0`00I_lT0?ooo`<006Ko2P3oool4
000000P0oooo0`00I_lS0?ooo`<006Ko303oool00`000000oooo0?ooo`020?ooo`8000000`3oool3
001VobD0oooo0P00I_l=0?ooo`040000003oool0oooo0?ooo`@000000P3oool2001Vob@0oooo0`00
I_l>0?ooo`800000103oool2000008P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00<000008P3oool00`000000oooo0?ooo`1B0?ooo`008@3oool0
0`000000oooo0?ooo`090?ooo`<006Ko8P3oool3001VoaP0oooo0P00I_lS0?ooo`8006Ko603oool3
001Vob<0oooo0P00I_lH0?ooo`<006Ko8`3oool2001Voil0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`0m0?ooo`<000009@3oool00`000000oooo0?ooo`1B0?ooo`008@3oool00`00
0000oooo0?ooo`0:0?ooo`<006Ko803oool3001VoaX0oooo0P00I_lQ0?ooo`8006Ko6P3oool3001V
ob40oooo0`00I_lI0?ooo`<006Ko8@3oool2001Voj00oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0i0?ooo`@000009`3oool00`000000oooo0?ooo`1B0?ooo`008@3oool00`000000
oooo0?ooo`0;0?ooo`<006Ko7P3oool3001Voa/0oooo0`00I_lO0?ooo`<006Ko6`3oool2001Vob00
oooo0`00I_lK0?ooo`<006Ko7`3oool2001VobL0oooo0P00001h0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0=@3oool3000000<0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`1B0?ooo`006P3ooolF000000<006Ko7@000002001Voad000000`00I_lN0000008006Ko
7@000002001Voal000000P00I_lM000000<006Ko7@000003001Voa`000002P3oool010000000oooo
0?ooo`00001g0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0<@3oool3000000H0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1B0?ooo`008@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo008006Ko203oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00@0oooo0P00I_l40?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`00000006Ko001Vo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
0P3oool3001Vo`D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`8006Ko
303oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo0?ooo`8006Ko1`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo0P00I_l00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00X0oooo00@00000001Vo`00I_l006Ko2@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo02d0oooo0`0000090?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0DP3oool00240oooo00<000000?ooo`3oool03P3oool2001VoaX0oooo0`00I_lA0?ooo`03
0000003oool0oooo00`0oooo0P00I_lL0?ooo`8006Ko4`3oool00`000000oooo0?ooo`090?ooo`<0
06Ko6`3oool3001Voa@0oooo00<000000?ooo`3oool02@3oool2001VoaX0oooo0`00I_lG0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo02T0oooo0`00000<0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0DP3oool00240oooo00<000000?ooo`3oool03P3oool3001VoaP0oooo0`00I_lQ0?ooo`<006Ko
6P3oool2001Vob40oooo0`00I_lI0?ooo`<006Ko8@3oool3001VoaP0oooo0`00I_lX0?ooo`@00000
M`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02D0oooo0`00000?0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0D@3oool00240oooo00<000000?ooo`3oool03`3o
ool3001VoaH0oooo0`00I_lS0?ooo`<006Ko603oool3001Vob80oooo0`00I_lG0?ooo`<006Ko8`3o
ool3001VoaL0oooo0P00I_lZ0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0Q0?ooo`<000004P3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo0540oooo000Q0?ooo`030000003oool0oooo0100oooo0P00I_lE0?ooo`<006Ko9@3oool3
001VoaH0oooo0`00I_lT0?ooo`<006Ko5@3oool3001VobD0oooo0`00I_lE0?ooo`8006Ko:`3oool0
0`000000oooo0?ooo`1L0?ooo`80000000<0oooo0000000000000`3oool200000140oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0M0?ooo`<000005@3oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo0540oooo000Q0?ooo`8000004P3oool2001Voa<0oooo0`00I_lW0?oo
o`<006Ko503oool3001VobH0oooo0`00I_lC0?ooo`<006Ko9`3oool3001Voa<0oooo0`00I_n;0?oo
o`030000003oool0000000<0oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo01P0oooo1000000I0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0D@3oool00240oooo00<000000?ooo`3oool04@3oool3001Voa40oooo0`00I_lY0?oo
o`<006Ko4P3oool3001VobP0oooo0`00I_lA0?ooo`<006Ko:@3oool3001Voa40oooo0`00I_n=0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo01@0oooo0`00000M0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0D@3oool00240oooo00<000000?ooo`3oool04P3oool3001Vo`l0oooo0`00I_l[0?ooo`<0
06Ko403oool3001VobX0oooo0`00I_l?0?ooo`<006Ko:`3oool3001Vo`l0oooo0`00I_n=0?ooo`03
0000003oool0000000@0oooo0P00000@0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0403oool300000200oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1A0?ooo`00
8@3oool00`000000oooo0?ooo`0C0?ooo`@006Ko303oool3001Vobd0oooo0`00I_l>0?ooo`<006Ko
;03oool3001Vo`d0oooo0`00I_l]0?ooo`<006Ko3@3oool3001Vohd0oooo0P0000000`3oool00000
000000050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0<0?ooo`<000008`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0540oooo
000Q0?ooo`030000003oool0oooo01D0oooo0`00I_l:0?ooo`<006Ko;`3oool3001Vo`/0oooo1000
I_l^0?ooo`@006Ko2P3oool3001Vobl0oooo0P00I_l;0?ooo`@006KoU@3oool010000000oooo0?oo
o`00000?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0203oool3000002H0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1@0?ooo`008@3oool00`000000oooo0?oo
o`0F0?ooo`@006Ko1`3oool3001Voc40oooo0`00I_l80?ooo`@006Ko<P3oool3001Vo`P0oooo0`00
I_l`0?ooo`@006Ko203oool4001VoiL0oooo0P00000@0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0103oool3000002T0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`1@0?ooo`008@3oool2000001P0oooo0`00I_l50?ooo`@006Ko<`3oool4001Vo`D0oooo1000I_ld
0?ooo`<006Ko1@3oool4001Voc80oooo1@00I_l50?ooo`<006KoZ`3oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo00<00000;03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo0500oooo000Q0?ooo`030000003oool0oooo01P0oooo2P00I_le0?ooo`X006Ko=`3oool:001V
ocD0oooo2P00I_n/0?ooo`030000003oool0oooo03d0oooo3000000U0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0D03oool00240oooo00<000000?ooo`3oool06@3oool7001VocT0
oooo1`00I_li0?ooo`L006Ko>@3oool7001Vojd0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`040?ooob/00000:03oool00`000000oooo0?ooo`1@0?ooo`008@3oool00`000000oooo
0?ooo`3o0?ooohd0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0Z0?ooo`<00000
0P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0500oooo000Q0?ooo`030000003o
ool0oooo0?l0ooooS@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo02H0oooo1000
00060?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0D03oool00240oooo00<00000
0?ooo`3oool0o`3ooon=0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool08`3oool3
000000X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1?0?ooo`008@3oool00`00
0000oooo0?ooo`3o0?ooohd0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0P0?oo
o`<000003P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo000Q0?ooo`80
0000o`3ooon>0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool07@3oool300000180
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1?0?ooo`008@3oool00`000000oooo
0?ooo`3o0?ooohd0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0J0?ooo`<00000
5P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo04l0oooo000Q0?ooo`030000003o
ool0oooo0?l0ooooS03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo01H0oooo1000
000J0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0C`3oool00240oooo00<00000
0?ooo`3oool0o`3ooon<0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool04`3oool3
000001l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1?0?ooo`008@3oool00`00
0000oooo0?ooo`3o0?oooh`0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0@0?oo
o`<000008P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo04l0oooo000Q0?ooo`03
0000003oool0oooo0?l0ooooS03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0
oooo0`00000V0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0CP3oool00240oooo
0P00003o0?ooohd0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0:0?ooo`<00000
:P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo04h0oooo000Q0?ooo`030000003o
ool0oooo0?l0ooooS03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00H0oooo1000
000^0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0CP3oool00240oooo00<00000
0?ooo`3oool0o`3ooon<0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool00`3oool3
000003<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1>0?ooo`008@3oool00`00
0000oooo0?ooo`3o0?oooh/0oooo00<000000?ooo`3oool0?`3oool010000000oooo0?ooo`3oool3
000003H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1>0?ooo`00603oool40000
00D0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`030000003oool0oooo03l0oooo1000000j0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0CP3oool001X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`3o0?oooh/0oooo00<000000?ooo`3oool0?03oool4000003h0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1>0?ooo`006P3oool00`000000oooo
0?ooo`040?ooo`800000o`3ooon<0?ooo`030000003oool0oooo03T0oooo0`0000030?ooo`030000
003oool0oooo03d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1=0?ooo`006P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooR`3oool00`000000oooo0?oo
o`0f0?ooo`<000001P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0C@3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o
0?oooh/0oooo00<000000?ooo`3oool0<`3oool3000000T0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04d0oooo000H0?ooo`<000001P3oool00`00
0000oooo0?ooo`3o0?oooh/0oooo00<000000?ooo`3oool0<03oool3000000`0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04d0oooo000J0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`030000003oool0oooo02d0
oooo1000000?0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`1=0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooohX0oooo00<000000?ooo`3oool0
:P3oool3000001<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo04d0oooo000Q0?ooo`800000o`3ooon;0?ooo`030000003oool0oooo02L0oooo0`00
000F0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`1<0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooohX0oooo00<000000?ooo`3oool0903oool3
000001T0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo04`0oooo000Q0?ooo`030000003oool0oooo0?l0ooooRP3oool00`000000oooo0?ooo`0P0?oo
o`@00000703oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0C03oool00240oooo00<000000?ooo`3oool0o`3ooon:0?ooo`030000003oool0oooo01d0
oooo0`00000P0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`1<0?ooo`008@3oool00`000000oooo0?ooo`3o0?ooohT0oooo00<000000?ooo`3oool0
6`3oool3000002<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo04`0oooo000Q0?ooo`030000003oool0oooo01T0oooo1`0co`0i0?ooo`L0<ol0>@3o
ool703?o03T0oooo1`0co`2X0?ooo`030000003oool0oooo01P0oooo0`00000V0?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1<0?ooo`008@3oool2
000001T0oooo2`0co`0d0?ooo`/0<ol0=@3oool;03?o03D0oooo2`0co`2V0?ooo`030000003oool0
oooo01D0oooo0`00000Y0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`1<0?ooo`008@3oool00`000000oooo0?ooo`0G0?ooo`<0<ol01@3oool403?o
03<0oooo100co`050?ooo`@0<ol0=03oool303?o00D0oooo100co`0c0?ooo`@0<ol01@3oool303?o
0:H0oooo00<000000?ooo`3oool04@3oool4000002`0oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo04/0oooo000Q0?ooo`030000003oool0oooo01H0
oooo0`0co`080?ooo`<0<ol0<P3oool203?o00T0oooo0`0co`0b0?ooo`<0<ol0203oool303?o0340
oooo0`0co`080?ooo`@0<ol0Y03oool00`000000oooo0?ooo`0>0?ooo`<00000<03oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0B`3oool00240oooo
00<000000?ooo`3oool05@3oool303?o00X0oooo0`0co`0`0?ooo`<0<ol02P3oool303?o0300oooo
0`0co`0:0?ooo`80<ol0<03oool303?o00X0oooo100co`2S0?ooo`030000003oool0oooo00/0oooo
0`00000c0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`1;0?ooo`008@3oool00`000000oooo0?ooo`0D0?ooo`<0<ol0303oool203?o02l0oooo0`0c
o`0<0?ooo`<0<ol0;P3oool303?o00`0oooo0P0co`0_0?ooo`80<ol03@3oool203?o0:<0oooo00<0
00000?ooo`3oool0203oool3000003H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo04/0oooo000Q0?ooo`030000003oool0oooo01@0oooo0P0co`0>
0?ooo`80<ol0;@3oool303?o00h0oooo0`0co`0/0?ooo`<0<ol03@3oool303?o02d0oooo0`0co`0=
0?ooo`<0<ol0X@3oool00`000000oooo0?ooo`060?ooo`<00000>@3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0B`3oool00240oooo0P00000D0?oo
o`80<ol03`3oool303?o02/0oooo0`0co`0@0?ooo`80<ol0:`3oool303?o00l0oooo0`0co`0/0?oo
o`80<ol03`3oool203?o0:40oooo00<000000?ooo`3oool00P3oool4000003`0oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04/0oooo000Q0?ooo`03
0000003oool0oooo0180oooo0`0co`0@0?ooo`80<ol0:`3oool203?o0180oooo0P0co`0Z0?ooo`80
<ol04@3oool203?o02/0oooo0`0co`0?0?ooo`<0<ol0X03oool00`000000oooo0000000200000400
oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04/0
oooo000Q0?ooo`030000003oool0oooo0180oooo0P0co`0B0?ooo`80<ol0:@3oool203?o01<0oooo
0`0co`0X0?ooo`80<ol04`3oool203?o02T0oooo0`0co`0A0?ooo`80<ol0X03oool2000004<0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04X0oooo
000Q0?ooo`030000003oool0oooo0140oooo0P0co`0C0?ooo`<0<ol09`3oool303?o01@0oooo0P0c
o`0W0?ooo`<0<ol04`3oool203?o02T0oooo0P0co`0C0?ooo`80<ol0X03oool200000480oooo00<0
00000?ooo`3oool0CP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04X0oooo000Q
0?ooo`030000003oool0oooo0140oooo0P0co`0D0?ooo`80<ol09`3oool203?o01D0oooo0`0co`0V
0?ooo`80<ol05@3oool203?o02L0oooo0P0co`0D0?ooo`80<ol0XP3oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1:
0?ooo`008@3oool00`000000oooo0?ooo`0@0?ooo`80<ol05P3oool203?o02D0oooo0`0co`0F0?oo
o`80<ol09@3oool203?o01H0oooo0`0co`0U0?ooo`<0<ol05@3oool203?o0:80oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0BP3oool00240oooo0P00000@0?ooo`<0<ol05P3oool303?o02@0oooo0P0co`0H0?ooo`80
<ol0903oool203?o01L0oooo0P0co`0U0?ooo`80<ol05P3oool303?o0:80oooo0P00000n0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1:0?ooo`00
8@3oool00`000000oooo0?ooo`0?0?ooo`80<ol0603oool203?o02<0oooo0`0co`0H0?ooo`<0<ol0
8P3oool203?o01T0oooo0P0co`0S0?ooo`<0<ol05`3oool203?o0:@0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
BP3oool00240oooo00<000000?ooo`3oool03P3oool303?o01P0oooo0`0co`0R0?ooo`80<ol06P3o
ool203?o0240oooo0`0co`0I0?ooo`80<ol08`3oool203?o01T0oooo0P0co`2T0?ooo`800000>P3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0BP3o
ool00240oooo00<000000?ooo`3oool03P3oool203?o01X0oooo0P0co`0Q0?ooo`<0<ol06P3oool3
03?o0200oooo0P0co`0K0?ooo`80<ol08@3oool203?o01X0oooo0P0co`2V0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo04T0oooo000Q0?ooo`030000003oool0oooo00d0oooo0`0co`0K0?ooo`80<ol0803oool203?o
01`0oooo0P0co`0O0?ooo`<0<ol06`3oool303?o0200oooo0P0co`0K0?ooo`80<ol0YP3oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`190?ooo`00603oool4000000D0oooo00<000000?ooo`3oool03@3oool203?o01`0
oooo0P0co`0O0?ooo`<0<ol0703oool203?o01l0oooo0P0co`0M0?ooo`80<ol07`3oool203?o01`0
oooo0`0co`2V0?ooo`800000=P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0B@3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0<0?ooo`<0<ol07@3oool203?o01h0oooo0P0co`0N0?ooo`80<ol07@3oool303?o01d0oooo
0`0co`0N0?ooo`80<ol07@3oool203?o0:P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B@3oool001T0oooo00<0
00000?ooo`3oool01@3oool2000000d0oooo0P0co`0N0?ooo`80<ol07@3oool303?o01h0oooo0P0c
o`0M0?ooo`80<ol07`3oool203?o01d0oooo0P0co`0N0?ooo`<0<ol0Z03oool2000003<0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04T0oooo000J
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool203?o0200oooo0P0co`0L
0?ooo`80<ol0803oool203?o01/0oooo0`0co`0O0?ooo`<0<ol06`3oool303?o01l0oooo0P0co`2Z
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo04T0oooo000K0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool02`3oool203?o0200oooo0`0co`0J0?ooo`<0<ol0803oool203?o01/0oooo0P0co`0Q0?oo
o`80<ol06`3oool203?o0200oooo0`0co`2Z0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04T0oooo000H0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool02P3oool203?o0280oooo0P0co`0J0?oo
o`80<ol08@3oool303?o01T0oooo0`0co`0Q0?ooo`<0<ol06@3oool303?o0240oooo0P0co`2[0?oo
o`800000;`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0B03oool001T0oooo0P0000060?ooo`030000003oool0oooo00T0oooo0`0co`0R0?ooo`<0
<ol0603oool303?o0280oooo0P0co`0I0?ooo`80<ol08`3oool203?o01T0oooo0P0co`0R0?ooo`<0
<ol0[03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`180?ooo`008@3oool00`000000oooo0?ooo`090?ooo`80<ol0
903oool203?o01P0oooo0P0co`0S0?ooo`<0<ol05`3oool303?o02<0oooo0`0co`0G0?ooo`80<ol0
903oool203?o0:d0oooo0P00000/0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`180?ooo`008@3oool2000000T0oooo0P0co`0V0?ooo`80<ol05P3o
ool303?o02@0oooo0P0co`0G0?ooo`80<ol09@3oool203?o01H0oooo0`0co`0T0?ooo`<0<ol0[P3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`180?ooo`008@3oool00`000000oooo0?ooo`080?ooo`80<ol09P3oool2
03?o01H0oooo0P0co`0V0?ooo`80<ol05@3oool203?o02H0oooo0`0co`0E0?ooo`80<ol09P3oool2
03?o0:l0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1M0?ooo`050000003oool0
oooo0?ooo`000000BP3oool00240oooo00<000000?ooo`3oool01`3oool203?o02P0oooo0P0co`0D
0?ooo`80<ol09`3oool203?o01@0oooo0`0co`0W0?ooo`80<ol0503oool303?o02H0oooo0`0co`2_
0?ooo`800000:03oool00`000000oooo0?ooo`1N0?ooo`040000003oool0oooo000004X0oooo000Q
0?ooo`030000003oool0oooo00H0oooo0`0co`0X0?ooo`<0<ol04P3oool303?o02P0oooo0P0co`0C
0?ooo`80<ol0:@3oool203?o01<0oooo0P0co`0X0?ooo`80<ol0/@3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`000000BP3oool00240oooo00<000000?oo
o`3oool01P3oool203?o02X0oooo0P0co`0B0?ooo`80<ol0:@3oool303?o0140oooo0`0co`0Y0?oo
o`80<ol04P3oool203?o02X0oooo0P0co`2a0?ooo`8000009@3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0000004T0oooo000Q0?ooo`030000003oool0oooo00D0oooo0P0co`0[0?ooo`<0
<ol0403oool303?o02X0oooo0P0co`0A0?ooo`80<ol0:`3oool203?o0100oooo0`0co`0Z0?ooo`<0
<ol0/P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0600oooo00<000000?ooo`00
0000B@3oool00240oooo0P0000060?ooo`80<ol0;03oool203?o0100oooo0P0co`0[0?ooo`<0<ol0
3`3oool203?o02`0oooo0`0co`0?0?ooo`80<ol0;03oool303?o0;80oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`1Q0?ooo`800000B@3oool00240oooo00<000000?ooo`3oool0103o
ool203?o02d0oooo0`0co`0>0?ooo`80<ol0;@3oool203?o00h0oooo0`0co`0]0?ooo`<0<ol03@3o
ool303?o02d0oooo0P0co`2c0?ooo`8000008@3oool00`000000oooo0?ooo`1P0?ooo`<00000B@3o
ool00240oooo00<000000?ooo`3oool00`3oool303?o02h0oooo0P0co`0=0?ooo`<0<ol0;@3oool4
03?o00`0oooo0P0co`0_0?ooo`<0<ol0303oool203?o02h0oooo0`0co`0=0?ooo`0303?o003oool0
oooo0:@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1L0?ooo`@00000C03oool0
0240oooo00<000000?ooo`3oool00`3oool203?o02l0oooo100co`0;0?ooo`80<ol0;`3oool403?o
00X0oooo0`0co`0`0?ooo`<0<ol02P3oool303?o02l0oooo0`0co`0;0?ooo`<0<ol0YP3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo05P0oooo1000001@0?ooo`008@3oool00`000000
oooo0?ooo`020?ooo`80<ol0<@3oool403?o00P0oooo100co`0a0?ooo`80<ol02P3oool203?o0380
oooo0P0co`090?ooo`<0<ol0<@3oool303?o00T0oooo0`0co`2X0?ooo`8000007@3oool00`000000
oooo0?ooo`1D0?ooo`@00000E03oool00240oooo00@000000?ooo`3oool0oooo0`0co`0c0?ooo`<0
<ol01P3oool403?o0380oooo0`0co`070?ooo`@0<ol0<P3oool303?o00L0oooo0`0co`0c0?ooo`<0
<ol01`3oool303?o0:/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`D0
0000F03oool00240oooo0P00000403?o03D0oooo0`0co`030?ooo`@0<ol0=@3oool403?o00<0oooo
1@0co`0d0?ooo`@0<ol0103oool303?o03D0oooo100co`030?ooo`@0<ol0[@3oool2000001X0oooo
00<000000?ooo`3oool0B`3oool4000005d0oooo000P0?ooo`H0<ol0=`3oool803?o03L0oooo2@0c
o`0g0?ooo`T0<ol0=`3oool903?o0;00oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`170?ooo`@00000H@3oool00200oooo100co`0j0?ooo`H0<ol0>@3oool603?o03/0oooo1P0co`0j
0?ooo`D0<ol0/`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04<0oooo1000001U
0?ooo`008@3oool00`000000oooo0?ooo`3o0?oook@0oooo0P00000F0?ooo`030000003oool0oooo
03h0oooo1@00001Y0?ooo`008@3oool00`000000oooo0?ooo`3o0?oookH0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0j0?ooo`@00000KP3oool00240oooo00<000000?ooo`3oool0
o`3ooong0?ooo`8000004P3oool00`000000oooo0?ooo`0g0?ooo`@00000LP3oool00?l0oooog@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03<0oooo1000001f0?ooo`00o`3ooooN
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0;P3oool5000007X0oooo003o0?oo
oml0oooo0P00000>0?ooo`030000003oool0oooo02X0oooo1000001o0?ooo`00o`3ooooQ0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool09P3oool4000008<0oooo003o0?ooon80oooo
0P00000;0?ooo`030000003oool0oooo0280oooo100000270?ooo`00o`3ooooT0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool07@3oool5000008/0oooo003o0?ooonD0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0I0?ooo`@00000T03oool00?l0ooooiP3oool20000
00L0oooo00<000000?ooo`3oool05@3oool4000009@0oooo003o0?ooonP0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0A0?ooo`@00000V03oool00?l0ooooj@3oool2000000@0oooo
00<000000?ooo`3oool0303oool5000009`0oooo000N0?ooo`80000000<0oooo000000000000o`3o
oonV0?ooo`80000000<0oooo0000000000000P3oool4000001L0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`@00000X@3oool001l0oooo00<000000?ooo`000000o`3ooonX0?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`0000060?ooo`@00000
Y@3oool00200oooo00<000000?ooo`3oool0o`3ooonX0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool06@3oool300000080oooo1000002Y0?ooo`007`3oool00`000000oooo0000003o
0?ooojP0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0J0?ooo`<00000[@3oool0
01h0oooo0P0000000`3oool000000000003o0?ooojH0oooo0P0000000`3oool00000000000050?oo
o`030000003oool0oooo0<T0oooo003o0?ooom00oooo00@000000?ooo`3oool00000b`3oool00?l0
ooood@3oool200000<`0oooo003o0?ooool0ooooX03oool00?l0ooooo`3ooonP0?ooo`00o`3ooooo
0?oooj00oooo003o0?ooool0ooooX03oool00001\
\>"],
  ImageRangeCache->{{{0, 669}, {196.125, 0}} -> {-0.0540885, -0.0147182, \
0.00315124, 0.00315124}, {{17.125, 319.375}, {191.438, 4.625}} -> {-2.53125, \
-2.92434, 0.0762925, 0.0325842}, {{349.562, 651.812}, {191.438, 4.625}} -> \
{-2.11744, -0.0237827, 0.00507267, 0.00507267}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[\ \ xPlot[0, 1, 1]\ , 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  Hyphenation->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.307528 0.0883827 [
[.2619 .29503 -3 -9 ]
[.2619 .29503 3 0 ]
[.5 .29503 -6 -9 ]
[.5 .29503 6 0 ]
[.7381 .29503 -6 -9 ]
[.7381 .29503 6 0 ]
[.97619 .29503 -6 -9 ]
[.97619 .29503 6 0 ]
[1.025 .30753 0 -4.90625 ]
[1.025 .30753 10 4.90625 ]
[.01131 .04238 -12 -4.5 ]
[.01131 .04238 0 4.5 ]
[.01131 .13076 -12 -4.5 ]
[.01131 .13076 0 4.5 ]
[.01131 .21914 -12 -4.5 ]
[.01131 .21914 0 4.5 ]
[.01131 .39591 -6 -4.5 ]
[.01131 .39591 0 4.5 ]
[.01131 .48429 -6 -4.5 ]
[.01131 .48429 0 4.5 ]
[.01131 .57268 -6 -4.5 ]
[.01131 .57268 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30753 m
.2619 .31378 L
s
[(5)] .2619 .29503 0 1 Mshowa
.5 .30753 m
.5 .31378 L
s
[(10)] .5 .29503 0 1 Mshowa
.7381 .30753 m
.7381 .31378 L
s
[(15)] .7381 .29503 0 1 Mshowa
.97619 .30753 m
.97619 .31378 L
s
[(20)] .97619 .29503 0 1 Mshowa
.125 Mabswid
.07143 .30753 m
.07143 .31128 L
s
.11905 .30753 m
.11905 .31128 L
s
.16667 .30753 m
.16667 .31128 L
s
.21429 .30753 m
.21429 .31128 L
s
.30952 .30753 m
.30952 .31128 L
s
.35714 .30753 m
.35714 .31128 L
s
.40476 .30753 m
.40476 .31128 L
s
.45238 .30753 m
.45238 .31128 L
s
.54762 .30753 m
.54762 .31128 L
s
.59524 .30753 m
.59524 .31128 L
s
.64286 .30753 m
.64286 .31128 L
s
.69048 .30753 m
.69048 .31128 L
s
.78571 .30753 m
.78571 .31128 L
s
.83333 .30753 m
.83333 .31128 L
s
.88095 .30753 m
.88095 .31128 L
s
.92857 .30753 m
.92857 .31128 L
s
.25 Mabswid
0 .30753 m
1 .30753 L
s
gsave
1.025 .30753 -61 -8.90625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
1.000 setlinewidth
grestore
.02381 .04238 m
.03006 .04238 L
s
[(-3)] .01131 .04238 1 0 Mshowa
.02381 .13076 m
.03006 .13076 L
s
[(-2)] .01131 .13076 1 0 Mshowa
.02381 .21914 m
.03006 .21914 L
s
[(-1)] .01131 .21914 1 0 Mshowa
.02381 .39591 m
.03006 .39591 L
s
[(1)] .01131 .39591 1 0 Mshowa
.02381 .48429 m
.03006 .48429 L
s
[(2)] .01131 .48429 1 0 Mshowa
.02381 .57268 m
.03006 .57268 L
s
[(3)] .01131 .57268 1 0 Mshowa
.125 Mabswid
.02381 .06006 m
.02756 .06006 L
s
.02381 .07773 m
.02756 .07773 L
s
.02381 .09541 m
.02756 .09541 L
s
.02381 .11309 m
.02756 .11309 L
s
.02381 .14844 m
.02756 .14844 L
s
.02381 .16612 m
.02756 .16612 L
s
.02381 .18379 m
.02756 .18379 L
s
.02381 .20147 m
.02756 .20147 L
s
.02381 .23682 m
.02756 .23682 L
s
.02381 .2545 m
.02756 .2545 L
s
.02381 .27217 m
.02756 .27217 L
s
.02381 .28985 m
.02756 .28985 L
s
.02381 .3252 m
.02756 .3252 L
s
.02381 .34288 m
.02756 .34288 L
s
.02381 .36056 m
.02756 .36056 L
s
.02381 .37823 m
.02756 .37823 L
s
.02381 .41359 m
.02756 .41359 L
s
.02381 .43126 m
.02756 .43126 L
s
.02381 .44894 m
.02756 .44894 L
s
.02381 .46662 m
.02756 .46662 L
s
.02381 .50197 m
.02756 .50197 L
s
.02381 .51965 m
.02756 .51965 L
s
.02381 .53732 m
.02756 .53732 L
s
.02381 .555 m
.02756 .555 L
s
.02381 .0247 m
.02756 .0247 L
s
.02381 .00703 m
.02756 .00703 L
s
.02381 .59035 m
.02756 .59035 L
s
.02381 .60803 m
.02756 .60803 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.2 1 0 r
.01 w
.02381 .60332 m
.02499 .60327 L
.02605 .60314 L
.02729 .6029 L
.02846 .60257 L
.03053 .60176 L
.03279 .60055 L
.03527 .59881 L
.0379 .59653 L
.04262 .59132 L
.05205 .57687 L
.06244 .55558 L
.08274 .50321 L
.10458 .44368 L
.11537 .41807 L
.12562 .39825 L
.13007 .39132 L
.13482 .38518 L
.13755 .38226 L
.14003 .38 L
.14253 .37812 L
.14487 .37672 L
.14719 .37567 L
.14842 .37525 L
.14974 .37492 L
.1504 .37479 L
.15113 .37468 L
.15244 .37457 L
.15371 .37457 L
.15489 .37467 L
.15599 .37483 L
.15702 .37506 L
.15815 .37538 L
.15936 .37582 L
.16184 .37699 L
.16411 .3784 L
.16896 .38242 L
.17426 .38834 L
.18493 .40454 L
.20454 .44522 L
.22549 .49436 L
.23574 .51667 L
.24684 .53745 L
.25193 .54543 L
.25733 .55265 L
.26238 .55818 L
.26699 .56215 L
.26931 .56374 L
.27183 .56516 L
.27422 .56621 L
Mistroke
.27643 .56693 L
.27776 .56724 L
.27901 .56745 L
.28013 .56757 L
.28134 .56763 L
.28197 .56764 L
.28266 .56762 L
.28339 .56758 L
.28406 .56751 L
.28527 .56734 L
.28657 .56708 L
.28779 .56676 L
.28893 .5664 L
.29149 .56537 L
.29615 .56274 L
.30039 .55956 L
.30488 .55542 L
.32439 .53033 L
.34268 .50134 L
.3612 .47339 L
.37168 .46036 L
.37679 .45506 L
.38142 .4509 L
.38609 .44739 L
.39114 .44435 L
.39391 .44303 L
.39647 .44204 L
.39892 .44127 L
.40027 .44093 L
.4015 .44067 L
.4027 .44046 L
.40401 .44028 L
.40473 .4402 L
.40539 .44015 L
.4067 .44007 L
.40782 .44005 L
.40906 .44006 L
.41035 .44013 L
.41156 .44023 L
.41221 .44029 L
.41291 .44038 L
.41433 .4406 L
.41688 .44112 L
.41985 .44193 L
.42261 .44287 L
.43312 .44779 L
.44305 .45392 L
.46163 .46681 L
.47133 .47312 L
.48162 .47877 L
Mistroke
.4904 .48244 L
.49539 .484 L
.50006 .48509 L
.50264 .48555 L
.50503 .48587 L
.50638 .48602 L
.50766 .48613 L
.50836 .48618 L
.50912 .48623 L
.50981 .48627 L
.51045 .48629 L
.51164 .48633 L
.51295 .48634 L
.51423 .48634 L
.51494 .48632 L
.51559 .4863 L
.51676 .48626 L
.51802 .48619 L
.52032 .48601 L
.52254 .48579 L
.52499 .48548 L
.52995 .4847 L
.53885 .48291 L
.54829 .48082 L
.55821 .47892 L
.56073 .47854 L
.56341 .4782 L
.56496 .47804 L
.56636 .47792 L
.56779 .47782 L
.5691 .47775 L
.5703 .47771 L
.57156 .47768 L
.57284 .47768 L
.57356 .47768 L
.57423 .4777 L
.57545 .47774 L
.57657 .4778 L
.57786 .47789 L
.57908 .478 L
.58168 .47831 L
.58413 .47871 L
.5887 .47973 L
.59362 .48123 L
.59894 .48332 L
.60853 .48829 L
.61734 .49403 L
.63782 .51005 L
.64781 .51797 L
.6569 .52443 L
Mistroke
.66143 .5272 L
.66635 .52975 L
.67099 .53167 L
.67306 .53236 L
.67528 .53296 L
.6765 .53324 L
.67762 .53346 L
.67876 .53364 L
.67982 .53378 L
.68105 .53389 L
.68169 .53393 L
.68238 .53397 L
.68366 .53398 L
.68482 .53396 L
.68613 .53387 L
.68733 .53375 L
.68864 .53356 L
.69003 .5333 L
.69237 .53271 L
.69494 .53185 L
.70018 .5294 L
.70514 .52621 L
.71445 .518 L
.72446 .50616 L
.73536 .49035 L
.75473 .4579 L
.76503 .4405 L
.77613 .42343 L
.78669 .41019 L
.79131 .40562 L
.79637 .40162 L
.79869 .40017 L
.80117 .39889 L
.8035 .39795 L
.80563 .39733 L
.80688 .39708 L
.80804 .39691 L
.8093 .3968 L
.80994 .39678 L
.81064 .39677 L
.81182 .39683 L
.81309 .39697 L
.81429 .39718 L
.81538 .39744 L
.81789 .39827 L
.82016 .3993 L
.82278 .40084 L
.82525 .40261 L
.83439 .41192 L
.83959 .41903 L
Mistroke
.84436 .42664 L
.85513 .44713 L
.87558 .49443 L
.89466 .53987 L
.90409 .55958 L
.91301 .57513 L
.91794 .58211 L
.9233 .58822 L
.92566 .5904 L
.92817 .59234 L
.93032 .5937 L
.93267 .59485 L
.93391 .59532 L
.93506 .59567 L
.93627 .59594 L
.93757 .59613 L
.93878 .59621 L
.93992 .59619 L
.94095 .59611 L
.94206 .59594 L
.94328 .59566 L
.94462 .59524 L
.94732 .59403 L
.94983 .59249 L
.95217 .59069 L
.95678 .58612 L
.96099 .58082 L
.97046 .56519 L
.97619 .5535 L
Mfstroke
0 .4 1 r
.009 w
.02381 .26984 m
.02499 .26986 L
.02605 .26991 L
.02729 .27001 L
.02846 .27014 L
.03053 .27047 L
.03279 .27095 L
.03527 .27164 L
.0379 .27256 L
.04262 .27464 L
.05205 .28036 L
.06244 .28869 L
.08274 .30854 L
.09394 .31976 L
.10458 .32939 L
.11464 .33685 L
.12033 .34014 L
.12562 .34251 L
.12813 .34338 L
.1305 .34405 L
.13263 .34453 L
.13494 .3449 L
.13613 .34504 L
.13745 .34514 L
.13811 .34518 L
.13883 .3452 L
.14011 .34521 L
.14139 .34517 L
.1426 .3451 L
.14368 .34499 L
.14487 .34484 L
.1472 .34444 L
.14972 .34383 L
.15427 .34231 L
.15968 .33981 L
.16464 .33691 L
.18565 .31955 L
.20618 .29887 L
.21618 .28936 L
.22527 .28185 L
.22982 .27866 L
.23475 .27569 L
.23901 .27357 L
.2437 .27178 L
.24627 .27103 L
.24867 .2705 L
.25 .27027 L
.25121 .2701 L
.25188 .27003 L
.25261 .26996 L
Mistroke
.2533 .26991 L
.25394 .26988 L
.25518 .26984 L
.25634 .26985 L
.25738 .26989 L
.25851 .26996 L
.25975 .27008 L
.26105 .27026 L
.26338 .27068 L
.26594 .27132 L
.26836 .27208 L
.27289 .27392 L
.27776 .27646 L
.28306 .27983 L
.30141 .29538 L
.32083 .31496 L
.33114 .32486 L
.34224 .334 L
.3474 .33749 L
.35283 .34052 L
.35747 .34254 L
.36012 .34345 L
.36253 .34412 L
.36371 .34439 L
.36499 .34464 L
.36609 .34482 L
.3673 .34498 L
.36859 .3451 L
.3693 .34515 L
.36995 .34518 L
.37113 .34521 L
.3724 .3452 L
.37357 .34515 L
.37485 .34505 L
.37607 .34492 L
.37719 .34476 L
.37931 .34436 L
.38156 .34381 L
.38644 .34215 L
.39091 .34009 L
.40101 .33375 L
.41928 .31773 L
.43978 .29705 L
.44978 .28774 L
.45887 .28051 L
.46341 .27749 L
.46833 .27473 L
.47298 .27266 L
.47727 .27123 L
.47962 .27066 L
Mistroke
.48182 .27026 L
.48308 .27009 L
.48423 .26997 L
.48487 .26993 L
.48556 .26988 L
.48682 .26984 L
.48751 .26984 L
.48816 .26985 L
.48937 .2699 L
.49067 .27 L
.4914 .27007 L
.49207 .27015 L
.49444 .27054 L
.49695 .27112 L
.4995 .27187 L
.50191 .27275 L
.50643 .27478 L
.5166 .2811 L
.53494 .29711 L
.55317 .31554 L
.56355 .32545 L
.57329 .33348 L
.58281 .3396 L
.58817 .34213 L
.59071 .34307 L
.59308 .3438 L
.59544 .34438 L
.59665 .34462 L
.59797 .34483 L
.59872 .34494 L
.59941 .34501 L
.60006 .34508 L
.60077 .34513 L
.60201 .34519 L
.60331 .34521 L
.60403 .3452 L
.60472 .34518 L
.606 .34511 L
.60672 .34504 L
.60738 .34497 L
.60888 .34477 L
.6114 .34429 L
.61409 .34359 L
.61947 .34161 L
.62441 .33916 L
.63556 .33163 L
.65574 .31303 L
.67622 .29255 L
.68621 .28384 L
.6953 .27741 L
Mistroke
.69983 .27486 L
.70475 .27265 L
.707 .27185 L
.70939 .27114 L
.71143 .27065 L
.71368 .27025 L
.71499 .27007 L
.71623 .26995 L
.71735 .26988 L
.71857 .26984 L
.71989 .26985 L
.72063 .26987 L
.7213 .26991 L
.7226 .27001 L
.72383 .27015 L
.72499 .27032 L
.72621 .27054 L
.7284 .27104 L
.73335 .27262 L
.7383 .27484 L
.74282 .27738 L
.75298 .28466 L
.77131 .30171 L
.79199 .3224 L
.80109 .33041 L
.80593 .33413 L
.81114 .33762 L
.81614 .34041 L
.82072 .34244 L
.8251 .34387 L
.8273 .3444 L
.82972 .34483 L
.83105 .345 L
.8323 .34512 L
.83343 .34518 L
.83466 .34521 L
.83529 .34521 L
.83599 .3452 L
.83672 .34517 L
.83741 .34513 L
.83863 .34503 L
.83994 .34487 L
.84116 .34468 L
.84249 .34443 L
.84491 .34385 L
.84946 .34234 L
.85478 .3399 L
.85979 .33699 L
.86916 .33015 L
.89014 .31035 L
Mistroke
.90855 .29202 L
.91899 .28304 L
.92409 .27933 L
.92873 .27641 L
.93335 .274 L
.93837 .27197 L
.94113 .27114 L
.94368 .27055 L
.94494 .27032 L
.94612 .27015 L
.94734 .27001 L
.948 .26995 L
.9487 .2699 L
.94934 .26987 L
.95003 .26985 L
.95126 .26984 L
.95202 .26986 L
.95273 .26989 L
.95337 .26993 L
.95406 .26998 L
.95549 .27014 L
.957 .27036 L
.9597 .27092 L
.96218 .27161 L
.9645 .27239 L
.96978 .2747 L
.97619 .27839 L
Mfstroke
1 0 .6 r
.007 w
.02381 .1248 m
.06244 .11599 L
.07216 .11234 L
.08255 .10885 L
.08852 .1073 L
.09135 .10672 L
.09396 .1063 L
.09658 .10598 L
.09796 .10586 L
.09866 .10581 L
.09942 .10577 L
.10069 .10572 L
.10187 .10571 L
.1026 .10571 L
.10329 .10573 L
.10458 .10578 L
.10586 .10587 L
.10707 .10598 L
.10933 .10627 L
.11176 .10672 L
.11439 .10735 L
.11914 .1089 L
.1235 .11079 L
.13354 .11686 L
.14415 .12571 L
.18212 .16915 L
.19214 .18011 L
.20163 .18872 L
.20687 .19247 L
.20964 .19411 L
.21257 .19557 L
.21504 .19656 L
.21634 .197 L
.21775 .1974 L
.21904 .1977 L
.22023 .19792 L
.22136 .19807 L
.22255 .19818 L
.22378 .19824 L
.22448 .19824 L
.22512 .19823 L
.2263 .19816 L
.22755 .19802 L
.22867 .19785 L
.22971 .19763 L
.23209 .19697 L
.23466 .19599 L
.23701 .19485 L
.24229 .19142 L
.2468 .18755 L
Mistroke
.25171 .18239 L
.26066 .1706 L
.28037 .13592 L
.30135 .09291 L
.31167 .07285 L
.32281 .05417 L
.32792 .04706 L
.33332 .0408 L
.33793 .03655 L
.34056 .03462 L
.34299 .03316 L
.34551 .032 L
.34684 .03152 L
.34825 .03113 L
.34947 .03088 L
.35061 .03073 L
.35187 .03065 L
.35257 .03064 L
.35322 .03066 L
.35434 .03076 L
.35539 .03091 L
.35654 .03115 L
.35776 .0315 L
.36026 .03249 L
.36254 .0337 L
.36771 .0376 L
.37331 .04355 L
.38346 .05866 L
.39295 .07721 L
.40338 .10142 L
.42444 .15635 L
.43528 .18401 L
.44556 .20743 L
.45556 .22613 L
.45996 .23274 L
.46483 .23876 L
.46707 .24105 L
.46948 .24316 L
.47157 .24469 L
.47385 .24603 L
.47628 .24709 L
.47761 .24749 L
.47885 .24777 L
.48001 .24793 L
.48107 .24799 L
.48229 .24797 L
.48344 .24786 L
.48461 .24766 L
.48589 .24733 L
.48724 .24686 L
Mistroke
.4885 .24631 L
.49074 .24507 L
.49316 .24335 L
.49867 .23801 L
.5037 .23145 L
.51356 .21437 L
.5227 .19421 L
.54343 .13878 L
.56224 .0865 L
.57214 .06211 L
.58258 .04076 L
.5879 .03206 L
.59374 .02442 L
.59631 .02174 L
.59905 .01934 L
.60163 .01753 L
.60401 .01626 L
.60527 .01574 L
.60661 .0153 L
.60725 .01513 L
.60795 .01498 L
.60871 .01486 L
.60943 .01478 L
.61074 .01472 L
.61139 .01473 L
.61211 .01478 L
.61338 .01494 L
.61456 .0152 L
.61582 .01557 L
.617 .01602 L
.61922 .0171 L
.6216 .01863 L
.62418 .02069 L
.62908 .02573 L
.63366 .03173 L
.64408 .0495 L
.66512 .09806 L
.68371 .14601 L
.70397 .19171 L
.7093 .20126 L
.71497 .20995 L
.71987 .21614 L
.72516 .22136 L
.72799 .22351 L
.7306 .22508 L
.73309 .22622 L
.73434 .22665 L
.73571 .22703 L
.73696 .22728 L
.7381 .22743 L
Mistroke
.73941 .22751 L
.74066 .22749 L
.7418 .2274 L
.74287 .22725 L
.74403 .22701 L
.74526 .22668 L
.74778 .22574 L
.75017 .22453 L
.75467 .22146 L
.75951 .21704 L
.76479 .21099 L
.78309 .18227 L
.80439 .14099 L
.82372 .10573 L
.83339 .09141 L
.83848 .0851 L
.84386 .07947 L
.84857 .07546 L
.85107 .07369 L
.85374 .07207 L
.8562 .07084 L
.85844 .06993 L
.8607 .06922 L
.86284 .06873 L
.86397 .06854 L
.8652 .0684 L
.86636 .06832 L
.86742 .06829 L
.8686 .0683 L
.86989 .06838 L
.87054 .06844 L
.87123 .06853 L
.87248 .06873 L
.87381 .069 L
.87525 .06936 L
.87786 .0702 L
.88274 .07238 L
.88739 .07513 L
.89232 .07867 L
.90115 .08637 L
.91941 .10554 L
.93903 .12615 L
.94899 .13492 L
.95844 .14157 L
.96693 .14595 L
.97174 .14774 L
.97619 .14896 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003o403IfMT0
0`000000fMWI0=WIf@3o0=WIf@h0fMWI000@0=WIf@030000003IfMT0fMWI0?l0fMWI3P3IfMT00100
fMWI00<000000=WIf@3IfMT0o`3IfMT>0=WIf@00403IfMT00`000000fMWI0=WIf@2D0=WIf@<0o`2I
MP3IfMT00100fMWI00<000000=WIf@3IfMT0T`3IfMT20?l0V@040=WIf@3o09T0o`2I0?l0VG@0fMWI
000@0=WIf@030000003IfMT0fMWI0940fMWI0P3o09T60=WIf@030?l0V@3IfMT0fMWI0740fMWI000@
0=WIf@030000003IfMT0fMWI0940fMWI00<0o`2I0=WIf@3IfMT01P3IfMT00`3o09T0fMWI0=WIf@1`
0=WIf@00403IfMT00`000000fMWI0=WIf@2@0=WIf@030?l0V@3IfMT0fMWI00L0fMWI0P3o09Ua0=WI
f@00403IfMT00`000000fMWI0=WIf@1?0=WIf@L0o`2I>@3IfMT00`3o09T0fMWI0=WIf@090=WIf@03
0?l0V@3IfMT0fMWI06l0fMWI00080=WIf@8000001P3IfMT00`000000fMWI0=WIf@1>0=WIf@80o`2I
1P3IfMT00`3o09T0fMWI0=WIf@0e0=WIf@80o`2I303IfMT00`3o09T0fMWI0=WIf@1^0=WIf@001`3I
fMT010000000fMWI0=WIf@0000050=WIf@030000003IfMT0fMWI04d0fMWI00<0o`2I0=WIf@3IfMT0
1P3IfMT20?l0VCH0fMWI00<0o`2I0=WIf@3IfMT02`3IfMT20?l0VFl0fMWI000:0=WIf@030000003I
fMT0fMWI00<0fMWI0P00001=0=WIf@80o`2I2@3IfMT00`3o09T0fMWI0=WIf@0c0=WIf@80o`2I3P3I
fMT00`3o09T0fMWI0=WIf@1]0=WIf@0000<0fMWI0000000000000P0000030=WIf@8000001P3IfMT0
0`000000fMWI0=WIf@1<0=WIf@030?l0V@3IfMT0fMWI00T0fMWI00<0o`2I0=WIf@3IfMT0<P3IfMT0
0`3o09T0fMWI0=WIf@0>0=WIf@030?l0V@3IfMT0fMWI06`0fMWI000:0=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT0B`3IfMT00`3o09T0fMWI0=WIf@0:0=WIf@80o`2I<P3IfMT20?l0
VA00fMWI00<0o`2I0=WIf@3IfMT0K03IfMT000L0fMWI00@000000=WIf@3IfMT000001@3IfMT00`00
0000fMWI0=WIf@1:0=WIf@030?l0V@3IfMT0fMWI00`0fMWI00<0o`2I0=WIf@3IfMT0<03IfMT00`3o
09T0fMWI0=WIf@0@0=WIf@030?l0V@3IfMT0fMWI06/0fMWI00080=WIf@8000001P3IfMT00`000000
fMWI0=WIf@190=WIf@030?l0V@3IfMT0fMWI00h0fMWI00<0o`2I0=WIf@3IfMT0;P3IfMT20?l0VA80
fMWI00<0o`2I0=WIf@3IfMT0J`3IfMT00100fMWI00<000000=WIf@3IfMT0B03IfMT20?l0VA00fMWI
00<0o`2I0=WIf@3IfMT0;P3IfMT00`3o09T0fMWI0=WIf@0B0=WIf@030?l0V@3IfMT0fMWI06X0fMWI
000@0=WIf@030000003IfMT0fMWI04P0fMWI00<0o`2I0=WIf@3IfMT0403IfMT00`3o09T0fMWI0=WI
f@0/0=WIf@80o`2I503IfMT00`3o09T0fMWI0=WIf@0d0=WIf@<0o`2I<`3IfMT00100fMWI00<00000
0=WIf@3IfMT0A`3IfMT00`3o09T0fMWI0=WIf@0A0=WIf@030?l0V@3IfMT0fMWI02`0fMWI00<0o`2I
0=WIf@3IfMT04`3IfMT00`3o09T0fMWI0=WIf@0a0=WIf@<0o`2I0`3IfMT30?l0VC00fMWI000@0=WI
f@030000003IfMT0fMWI04L0fMWI00<0o`2I0=WIf@3IfMT04P3IfMT00`3o09T0fMWI0=WIf@0Z0=WI
f@80o`2I5P3IfMT00`3o09T0fMWI0=WIf@0_0=WIf@80o`2I203IfMT00`3o09T0fMWI0=WIf@0]0=WI
f@00403IfMT00`000000fMWI0=WIf@160=WIf@030?l0V@3IfMT0fMWI01<0fMWI00<0o`2I0=WIf@3I
fMT0:P3IfMT00`3o09T0fMWI0=WIf@0E0=WIf@030?l0V@3IfMT0fMWI02h0fMWI00<0o`2I0=WIf@3I
fMT02@3IfMT00`3o09T0fMWI0=WIf@0/0=WIf@00403IfMT00`000000fMWI0=WIf@160=WIf@030?l0
V@3IfMT0fMWI01<0fMWI0P3o09TZ0=WIf@80o`2I5`3IfMT00`3o09T0fMWI0=WIf@0]0=WIf@030?l0
V@3IfMT0fMWI00/0fMWI0P3o09T/0=WIf@00403IfMT00`000000fMWI0=WIf@160=WIf@030?l0V@3I
fMT0fMWI01@0fMWI00<0o`2I0=WIf@3IfMT0:03IfMT00`3o09T0fMWI0=WIf@0G0=WIf@030?l0V@3I
fMT0fMWI02/0fMWI00<0o`2I0=WIf@3IfMT03P3IfMT00`3o09T0fMWI0=WIf@0Y0=WIf@00403IfMT0
0`000000fMWI0=WIf@150=WIf@030?l0V@3IfMT0fMWI01D0fMWI0P3o09TY0=WIf@030?l0V@3IfMT0
fMWI01L0fMWI00<0o`2I0=WIf@3IfMT0:P3IfMT00`3o09T0fMWI0=WIf@0@0=WIf@030?l0V@3IfMT0
fMWI02P0fMWI000@0=WIf@030000003IfMT0fMWI04D0fMWI00<0o`2I0=WIf@3IfMT05P3IfMT00`3o
09T0fMWI0=WIf@0V0=WIf@030?l0V@3IfMT0fMWI01T0fMWI00<0o`2I0=WIf@3IfMT0:03IfMT00`3o
09T0fMWI0=WIf@0A0=WIf@80o`2I:@3IfMT00100fMWI00<000000=WIf@3IfMT0A03IfMT20?l0VAP0
fMWI0P3o09TW0=WIf@030?l0V@3IfMT0fMWI01T0fMWI00<0o`2I0=WIf@3IfMT09`3IfMT20?l0VA@0
fMWI0P3o09TX0=WIf@00403IfMT00`000000fMWI0=WIf@140=WIf@030?l0V@3IfMT0fMWI01P0fMWI
00<0o`2I0=WIf@3IfMT09@3IfMT00`3o09T0fMWI0=WIf@0I0=WIf@030?l0V@3IfMT0fMWI02L0fMWI
00<0o`2I0=WIf@3IfMT0503IfMT00`3o09T0fMWI0=WIf@0V0=WIf@00403IfMT00`000000fMWI0=WI
f@0=0=WIf@P0o`2I;P3IfMT00`3o09T0fMWI0=WIf@0I0=WIf@030?l0V@3IfMT0fMWI02D0fMWI00<0
o`2I0=WIf@3IfMT06P3IfMT00`3o09T0fMWI0=WIf@0U0=WIf@030?l0V@3IfMT0fMWI01H0fMWI00<0
o`2I0=WIf@3IfMT09@3IfMT00100fMWI00<000000=WIf@3IfMT02`3IfMT20?l0V@P0fMWI0P3o09T/
0=WIf@030?l0V@3IfMT0fMWI01X0fMWI00<0o`2I0=WIf@3IfMT08`3IfMT00`3o09T0fMWI0=WIf@0K
0=WIf@030?l0V@3IfMT0fMWI02@0fMWI0P3o09TI0=WIf@030?l0V@3IfMT0fMWI02@0fMWI000@0=WI
f@030000003IfMT0fMWI00P0fMWI0`3o09T<0=WIf@80o`2I:@3IfMT00`3o09T0fMWI0=WIf@0K0=WI
f@030?l0V@3IfMT0fMWI02<0fMWI00<0o`2I0=WIf@3IfMT0703IfMT00`3o09T0fMWI0=WIf@0S0=WI
f@030?l0V@3IfMT0fMWI01T0fMWI00<0o`2I0=WIf@3IfMT08`3IfMT00100fMWI00<000000=WIf@3I
fMT01@3IfMT40?l0VA00fMWI00<0o`2I0=WIf@3IfMT09P3IfMT00`3o09T0fMWI0=WIf@0L0=WIf@03
0?l0V@3IfMT0fMWI0280fMWI00<0o`2I0=WIf@3IfMT0703IfMT00`3o09T0fMWI0=WIf@0R0=WIf@03
0?l0V@3IfMT0fMWI01/0fMWI00<0o`2I0=WIf@3IfMT08P3IfMT00100fMWI00<000000=WIf@3IfMT0
1@3o09TE0=WIf@80o`2I9@3IfMT00`3o09T0fMWI0=WIf@0M0=WIf@030?l0V@3IfMT0fMWI0240fMWI
00<0o`2I0=WIf@3IfMT07@3IfMT00`3o09T0fMWI0=WIf@0R0=WIf@030?l0V@3IfMT0fMWI01`0fMWI
00<0o`2I0=WIf@3IfMT08@3IfMT000L0fMWI100000050=WIf@<0o`2I703IfMT00`3o09T0fMWI0=WI
f@0R0=WIf@030?l0V@3IfMT0fMWI01h0fMWI00<0o`2I0=WIf@3IfMT0803IfMT00`3o09T0fMWI0=WI
f@0N0=WIf@030?l0V@3IfMT0fMWI0200fMWI00<0o`2I0=WIf@3IfMT07P3IfMT00`3o09T0fMWI0=WI
f@0P0=WIf@001`3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI01d0fMWI00<0o`2I
0=WIf@3IfMT0803IfMT00`3o09T0fMWI0=WIf@0O0=WIf@030?l0V@3IfMT0fMWI0200fMWI00<0o`2I
0=WIf@3IfMT07P3IfMT00`3o09T0fMWI0=WIf@0P0=WIf@030?l0V@3IfMT0fMWI01l0fMWI00<0o`2I
0=WIf@3IfMT07`3IfMT000P0fMWI00<000000=WIf@3IfMT01@3IfMT2000001l0fMWI00<0o`2I0=WI
f@3IfMT07P3IfMT20?l0VB40fMWI00<0o`2I0=WIf@3IfMT0803IfMT00`3o09T0fMWI0=WIf@0N0=WI
f@030?l0V@3IfMT0fMWI01l0fMWI00<0o`2I0=WIf@3IfMT08@3IfMT00`3o09T0fMWI0=WIf@0N0=WI
f@0000<0fMWI0000000000000P0000040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT07P3IfMT20?l0VAl0fMWI00<0o`2I0=WIf@3IfMT08@3IfMT00`3o09T0fMWI0=WIf@0N0=WIf@03
0?l0V@3IfMT0fMWI0200fMWI00<0o`2I0=WIf@3IfMT07@3IfMT20?l0VB@0fMWI0P3o09TN0=WIf@00
2P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI01l0fMWI00<0o`2I0=WIf@3IfMT0
703IfMT20?l0VB<0fMWI00<0o`2I0=WIf@3IfMT07P3IfMT00`3o09T0fMWI0=WIf@0P0=WIf@030?l0
V@3IfMT0fMWI01d0fMWI00<0o`2I0=WIf@3IfMT0903IfMT30?l0VA`0fMWI00070=WIf@040000003I
fMT0fMWI000000D0fMWI00<000000=WIf@3IfMT0803IfMT00`3o09T0fMWI0=WIf@0K0=WIf@030?l0
V@3IfMT0fMWI02<0fMWI00<0o`2I0=WIf@3IfMT07@3IfMT00`3o09T0fMWI0=WIf@0Q0=WIf@030?l0
V@3IfMT0fMWI01/0fMWI0P3o09TY0=WIf@80o`2I6P3IfMT000P0fMWI0P0000060=WIf@030000003I
fMT0fMWI0240fMWI00<0o`2I0=WIf@3IfMT06@3IfMT00`3o09T0fMWI0=WIf@0T0=WIf@030?l0V@3I
fMT0fMWI01`0fMWI00<0o`2I0=WIf@3IfMT08P3IfMT00`3o09T0fMWI0=WIf@0K0=WIf@030?l0V@3I
fMT0fMWI02X0fMWI0P3o09TH0=WIf@00403IfMT00`000000fMWI0=WIf@0R0=WIf@030?l0V@3IfMT0
fMWI01P0fMWI00<0o`2I0=WIf@3IfMT09@3IfMT00`3o09T0fMWI0=WIf@0K0=WIf@030?l0V@3IfMT0
fMWI0280fMWI0P3o09TL0=WIf@030?l0V@3IfMT0fMWI04@0fMWI000@0=WIf@030000003IfMT0fMWI
02<0fMWI00<0o`2I0=WIf@3IfMT05P3IfMT00`3o09T0fMWI0=WIf@0V0=WIf@030?l0V@3IfMT0fMWI
01X0fMWI00<0o`2I0=WIf@3IfMT0903IfMT00`3o09T0fMWI0=WIf@0I0=WIf@030?l0V@3IfMT0fMWI
04D0fMWI000@0=WIf@030000003IfMT0fMWI02<0fMWI0P3o09TG0=WIf@030?l0V@3IfMT0fMWI02H0
fMWI00<0o`2I0=WIf@3IfMT06P3IfMT00`3o09T0fMWI0=WIf@0T0=WIf@030?l0V@3IfMT0fMWI01T0
fMWI00<0o`2I0=WIf@3IfMT0A@3IfMT00100fMWI00<000000=WIf@3IfMT0903IfMT00`3o09T0fMWI
0=WIf@0D0=WIf@030?l0V@3IfMT0fMWI02P0fMWI00<0o`2I0=WIf@3IfMT0603IfMT00`3o09T0fMWI
0=WIf@0V0=WIf@030?l0V@3IfMT0fMWI01L0fMWI00<0o`2I0=WIf@3IfMT0AP3IfMT00100fMWI00<0
00000=WIf@3IfMT09@3IfMT00`3o09T0fMWI0=WIf@0B0=WIf@80o`2I:P3IfMT00`3o09T0fMWI0=WI
f@0H0=WIf@030?l0V@3IfMT0fMWI02H0fMWI00<0o`2I0=WIf@3IfMT05`3IfMT00`3o09T0fMWI0=WI
f@160=WIf@00403IfMT00`000000fMWI0=WIf@0V0=WIf@030?l0V@3IfMT0fMWI0140fMWI00<0o`2I
0=WIf@3IfMT0:@3IfMT00`3o09T0fMWI0=WIf@0H0=WIf@030?l0V@3IfMT0fMWI02L0fMWI00<0o`2I
0=WIf@3IfMT05@3IfMT00`3o09T0fMWI0=WIf@170=WIf@00403IfMT00`000000fMWI0=WIf@0W0=WI
f@030?l0V@3IfMT0fMWI00l0fMWI00<0o`2I0=WIf@3IfMT0:P3IfMT00`3o09T0fMWI0=WIf@0G0=WI
f@030?l0V@3IfMT0fMWI02P0fMWI00<0o`2I0=WIf@3IfMT05@3IfMT00`3o09T0fMWI0=WIf@170=WI
f@00403IfMT00`000000fMWI0=WIf@0X0=WIf@030?l0V@3IfMT0fMWI00h0fMWI00<0o`2I0=WIf@3I
fMT0:`3IfMT00`3o09T0fMWI0=WIf@0F0=WIf@030?l0V@3IfMT0fMWI02T0fMWI00<0o`2I0=WIf@3I
fMT04`3IfMT20?l0VDT0fMWI000@0=WIf@030000003IfMT0fMWI02T0fMWI00<0o`2I0=WIf@3IfMT0
2`3IfMT20?l0VBh0fMWI00<0o`2I0=WIf@3IfMT05@3IfMT00`3o09T0fMWI0=WIf@0Z0=WIf@030?l0
V@3IfMT0fMWI01<0fMWI00<0o`2I0=WIf@3IfMT0B03IfMT00100fMWI00<000000=WIf@3IfMT0:P3I
fMT00`3o09T0fMWI0=WIf@090=WIf@80o`2I;`3IfMT20?l0VAH0fMWI00<0o`2I0=WIf@3IfMT0:P3I
fMT20?l0VA<0fMWI00<0o`2I0=WIf@3IfMT0B@3IfMT00100fMWI00<000000=WIf@3IfMT0:`3IfMT0
0`3o09T0fMWI0=WIf@070=WIf@030?l0V@3IfMT0fMWI0300fMWI00<0o`2I0=WIf@3IfMT04`3IfMT0
0`3o09T0fMWI0=WIf@0/0=WIf@030?l0V@3IfMT0fMWI0100fMWI0P3o09U;0=WIf@00403IfMT00`00
0000fMWI0=WIf@0/0=WIf@<0o`2I103IfMT20?l0VC<0fMWI0P3o09TD0=WIf@030?l0V@3IfMT0fMWI
02d0fMWI00<0o`2I0=WIf@3IfMT03`3IfMT00`3o09T0fMWI0=WIf@1:0=WIf@00403IfMT00`000000
fMWI0=WIf@0^0=WIf@H0o`2I=@3IfMT00`3o09T0fMWI0=WIf@0B0=WIf@030?l0V@3IfMT0fMWI02d0
fMWI00<0o`2I0=WIf@3IfMT03P3IfMT00`3o09T0fMWI0=WIf@1;0=WIf@00403IfMT00`000000fMWI
0=WIf@1Y0=WIf@80o`2I4P3IfMT00`3o09T0fMWI0=WIf@0_0=WIf@030?l0V@3IfMT0fMWI00`0fMWI
0P3o09U=0=WIf@00403IfMT00`000000fMWI0=WIf@1Z0=WIf@030?l0V@3IfMT0fMWI0100fMWI00<0
o`2I0=WIf@3IfMT0;`3IfMT20?l0V@d0fMWI00<0o`2I0=WIf@3IfMT0C03IfMT00100fMWI00<00000
0=WIf@3IfMT0J`3IfMT00`3o09T0fMWI0=WIf@0>0=WIf@030?l0V@3IfMT0fMWI0340fMWI00<0o`2I
0=WIf@3IfMT02P3IfMT00`3o09T0fMWI0=WIf@1=0=WIf@001`3IfMT4000000D0fMWI00<000000=WI
f@3IfMT0J`3IfMT00`3o09T0fMWI0=WIf@0>0=WIf@030?l0V@3IfMT0fMWI0340fMWI0P3o09T:0=WI
f@80o`2IC`3IfMT000T0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@1/0=WIf@03
0?l0V@3IfMT0fMWI00`0fMWI00<0o`2I0=WIf@3IfMT0<`3IfMT20?l0V@P0fMWI0P3o09U@0=WIf@00
2@3IfMT00`000000fMWI0=WIf@040=WIf@800000K@3IfMT00`3o09T0fMWI0=WIf@0<0=WIf@030?l0
V@3IfMT0fMWI03@0fMWI0P3o09T60=WIf@80o`2ID@3IfMT000030=WIf@000000000000800000103I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI06d0fMWI00<0o`2I0=WIf@3IfMT02P3I
fMT00`3o09T0fMWI0=WIf@0g0=WIf@80o`2I0P3IfMT20?l0VE<0fMWI00090=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0K@3IfMT20?l0V@/0fMWI00<0o`2I0=WIf@3IfMT0>@3IfMT3
0?l0VE@0fMWI00070=WIf@<000001P3IfMT00`000000fMWI0=WIf@1^0=WIf@030?l0V@3IfMT0fMWI
00P0fMWI00<0o`2I0=WIf@3IfMT0T@3IfMT000T0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@1^0=WIf@80o`2I203IfMT00`3o09T0fMWI0=WIf@2B0=WIf@00403IfMT00`000000fMWI
0=WIf@1_0=WIf@80o`2I1P3IfMT20?l0VI@0fMWI000@0=WIf@030000003IfMT0fMWI0700fMWI0P3o
09T40=WIf@80o`2IU@3IfMT00100fMWI00<000000=WIf@3IfMT0L@3IfMT50?l0VIL0fMWI000@0=WI
f@030000003IfMT0fMWI0?l0fMWI3P3IfMT00100fMWI00<000000=WIf@3IfMT0o`3IfMT>0=WIf@00
403IfMT00`000000fMWI0=WIf@3o0=WIf@h0fMWI000@0=WIf@030000003IfMT0fMWI0?l0fMWI3P3I
fMT00100fMWI00<000000=WIf@3IfMT0>03IfMT3000003P0fMWI100000030=WIf@800000=@3IfMT4
00000080fMWI0`00000e0=WIf@@000000`3IfMT2000001D0fMWI000?0=WIf@H006Ko<P3IfMT:001V
oc80fMWI2`00I_l00`3IfMT000000=WIf@0^0=WIf@/006Ko0`3IfMT00`000000fMWI0=WIf@0/0=WI
f@X006Ko0P3IfMT010000000fMWI0=WIf@00000D0=WIf@003`3IfMT9001Vobd0fMWI3`00I_l^0=WI
f@d006Ko00<000000=WIf@3IfMT0;03IfMT=001Vo`80fMWI00<000000=WIf@3IfMT0:P3IfMT>001V
o`040000003IfMT0fMWI000001@0fMWI000@0=WIf@040000003IfMT0fMWI0=WIf@D006Ko:`3IfMT4
001Vo`<0fMWI0`0000020=WIf@D006Ko:`3IfMT4001Vo`@0fMWI00D000000=WIf@3IfMT0fMWI0000
0004001Vob/0fMWI1000I_l60=WIf@030000003IfMT0fMWI00<006Ko00<000000=WIf@3IfMT0:@3I
fMT5001Vo`L0fMWI00<00000001Vo`00I_l00P00I_l20=WIf@030000003IfMT0fMWI0180fMWI000@
0=WIf@030000003IfMT0fMWI00@0fMWI0`00I_lY0=WIf@<006Ko1@3IfMT00`000000fMWI0=WIf@05
0=WIf@<006Ko:03IfMT5001Vo`D0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@<006Ko:@3I
fMT4001Vo`L0fMWI00@000000=WIf@3IfMT0fMWI1000I_lY0=WIf@@006Ko2P3IfMT010000000fMWI
001Vo`0000020=WIf@030000003IfMT0fMWI0180fMWI000@0=WIf@030000003IfMT0fMWI00D0fMWI
0`00I_lW0=WIf@<006Ko1P3IfMT00`000000fMWI0=WIf@060=WIf@@006Ko9@3IfMT3001Vo`H0fMWI
0`0000030=WIf@040000003IfMT0fMWI000000<006Ko9`3IfMT3001Vo`L0fMWI0`0000030=WIf@03
0000003IfMT006Ko008006Ko9P3IfMT4001Vo`T0fMWI00@000000=WIf@3IfMT000000P3IfMT01000
0000fMWI0=WIf@00000D0=WIf@00403IfMT00`000000fMWI0=WIf@060=WIf@<006Ko9@3IfMT3001V
o`L0fMWI100000070=WIf@<006Ko903IfMT2001Vo`T0fMWI00<000000=WIf@3IfMT00P3IfMT20000
0080fMWI0`00I_lU0=WIf@<006Ko2P3IfMT010000000fMWI0=WIf@3IfMT3000000<006Ko903IfMT3
001Vo``0fMWI0P0000040=WIf@8000005@3IfMT00100fMWI00<000000=WIf@3IfMT01`3IfMT3001V
ob80fMWI1000I_lD0=WIf@<006Ko8P3IfMT2001Voa@0fMWI0`00I_lS0=WIf@<006Ko4`3IfMT4001V
ob40fMWI0`00I_lZ0=WIf@00403IfMT00`000000fMWI0=WIf@080=WIf@<006Ko803IfMT3001VoaL0
fMWI0`00I_lP0=WIf@<006Ko5@3IfMT3001Vob40fMWI0`00I_lF0=WIf@<006Ko803IfMT2001Vob/0
fMWI000@0=WIf@030000003IfMT0fMWI00T0fMWI0`00I_lN0=WIf@<006Ko6@3IfMT3001Voah0fMWI
0`00I_lG0=WIf@<006Ko7`3IfMT3001VoaP0fMWI0`00I_lN0=WIf@8006Ko9@3IfMT2000000D0fMWI
00090=WIfA@000000`00I_lM0000008006Ko6`000003001Voa`000000`00I_lI000000<006Ko7@00
0003001VoaX000000`00I_lL000000<006Ko6P00000:0=WIf@040000003IfMT0fMWI000000@0fMWI
000@0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@00I_l00P00I_l70=WIf@030000003I
fMT0fMWI00X0fMWI00<000000=WIf@3IfMT0103IfMT2001Vo`<0fMWI00<000000=WIf@3IfMT02@3I
fMT00`000000fMWI0=WIf@0:0=WIf@0400000000I_l006Ko001Vo`P0fMWI00<000000=WIf@3IfMT0
2P3IfMT010000000fMWI0=WIf@3IfMT3001Vo`D0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000
fMWI0=WIf@080=WIf@<006Ko2`3IfMT00`000000fMWI0=WIf@090=WIf@040000003IfMT0fMWI0=WI
f@<006Ko1P3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00L0fMWI0`00I_l00`00
0000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@00I_l00P00I_l80=WI
f@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@050=WI
f@00403IfMT00`000000fMWI0=WIf@0<0=WIf@<006Ko6@3IfMT2001Voa00fMWI00<000000=WIf@3I
fMT0303IfMT3001VoaL0fMWI0`00I_lB0=WIf@030000003IfMT0fMWI00T0fMWI0`00I_lI0=WIf@<0
06Ko4`3IfMT00`000000fMWI0=WIf@080=WIf@<006Ko603IfMT3001VoaD0fMWI00<000000=WIf@3I
fMT03P3IfMT00`000000fMWI0=WIf@050=WIf@00403IfMT00`000000fMWI0=WIf@0=0=WIf@<006Ko
5`3IfMT3001Vob00fMWI0P00I_lF0=WIf@<006Ko803IfMT3001VoaL0fMWI0`00I_lP0=WIf@<006Ko
5P3IfMT3001VobH0fMWI100000050=WIf@00403IfMT00`000000fMWI0=WIf@0>0=WIf@<006Ko5@3I
fMT3001Vob80fMWI0P00I_lD0=WIf@<006Ko8P3IfMT4001Voa@0fMWI0`00I_lR0=WIf@<006Ko4`3I
fMT3001VobT0fMWI00<000000=WIf@3IfMT01@3IfMT00100fMWI00<000000=WIf@3IfMT03`3IfMT4
001Voa40fMWI1000I_lS0=WIf@<006Ko4P3IfMT3001VobD0fMWI0`00I_lB0=WIf@<006Ko903IfMT4
001Voa00fMWI0`00I_lZ0=WIf@030000003IfMT0fMWI00D0fMWI000@0=WIf@030000003IfMT0fMWI
0140fMWI0`00I_l?0=WIf@<006Ko9P3IfMT4001Vo`l0fMWI0`00I_lW0=WIf@<006Ko403IfMT3001V
obL0fMWI0`00I_l>0=WIf@<006Ko<`3IfMT00100fMWI00<000000=WIf@3IfMT04P3IfMT3001Vo``0
fMWI1000I_lY0=WIf@@006Ko303IfMT3001VobT0fMWI0`00I_l>0=WIf@<006Ko:@3IfMT3001Vo``0
fMWI0`00I_ld0=WIf@00403IfMT00`000000fMWI0=WIf@0C0=WIf@@006Ko2@3IfMT3001Vob`0fMWI
1000I_l90=WIf@@006Ko:`3IfMT4001Vo`X0fMWI1000I_l[0=WIf@<006Ko2@3IfMT4001VocD0fMWI
000@0=WIf@030000003IfMT0fMWI01@0fMWI1000I_l60=WIf@@006Ko;`3IfMT3001Vo`H0fMWI1000
I_l_0=WIf@@006Ko1@3IfMT5001Vobh0fMWI1000I_l60=WIf@@006Ko=P3IfMT00100fMWI00<00000
0=WIf@3IfMT05P3IfMT;001Voc40fMWI2`00I_la0=WIf@`006Ko<03IfMT;001VocP0fMWI000@0=WI
f@030000003IfMT0fMWI01L0fMWI2000I_ld0=WIf@P006Ko=@3IfMT7001VocD0fMWI2000I_li0=WI
f@00403IfMT00`000000fMWI0=WIf@3o0=WIf@h0fMWI000@0=WIf@030000003IfMT0fMWI0?l0fMWI
3P3IfMT00100fMWI00<000000=WIf@3IfMT0o`3IfMT>0=WIf@00403IfMT00`000000fMWI0=WIf@3o
0=WIf@h0fMWI000@0=WIf@030000003IfMT0fMWI0?l0fMWI3P3IfMT00100fMWI00<000000=WIf@3I
fMT0o`3IfMT>0=WIf@00403IfMT00`000000fMWI0=WIf@0K0=WIf@H0<ol0k03IfMT00100fMWI00<0
00000=WIf@3IfMT06P3IfMT903?o0>X0fMWI000@0=WIf@030000003IfMT0fMWI01T0fMWI0`0co`04
0=WIf@D0<ol0j03IfMT000L0fMWI100000050=WIf@030000003IfMT0fMWI01P0fMWI0`0co`070=WI
f@@0<ol0i`3IfMT000T0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0G0=WIf@<0
<ol02P3IfMT203?o0>L0fMWI00090=WIf@030000003IfMT0fMWI00@0fMWI0P00000H0=WIf@80<ol0
2`3IfMT203?o0>L0fMWI00090=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT05P3I
fMT303?o00`0fMWI0P0co`2O0=WIf@L0<ol0@03IfMT000T0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@0F0=WIf@80<ol03@3IfMT203?o09d0fMWI2`0co`0n0=WIf@001`3IfMT30000
00H0fMWI00<000000=WIf@3IfMT05@3IfMT203?o00h0fMWI0`0co`2K0=WIf@@0<ol01@3IfMT303?o
03h0fMWI00090=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT05@3IfMT203?o00l0
fMWI0P0co`2J0=WIf@<0<ol02@3IfMT203?o03d0fMWI000@0=WIf@030000003IfMT0fMWI01@0fMWI
0P0co`0@0=WIf@<0<ol0V03IfMT303?o00X0fMWI100co`0k0=WIf@00403IfMT00`000000fMWI0=WI
f@0C0=WIf@<0<ol04@3IfMT203?o09P0fMWI0P0co`0<0=WIf@@0<ol0>P3IfMT00100fMWI00<00000
0=WIf@3IfMT04`3IfMT203?o0180fMWI0`0co`2F0=WIf@80<ol03`3IfMT203?o03X0fMWI000@0=WI
f@030000003IfMT0fMWI01<0fMWI0P0co`0C0=WIf@80<ol0U@3IfMT303?o00l0fMWI0`0co`0i0=WI
f@00403IfMT00`000000fMWI0=WIf@0C0=WIf@80<ol04`3IfMT303?o09<0fMWI0`0co`0A0=WIf@80
<ol0>@3IfMT00100fMWI00<000000=WIf@3IfMT04P3IfMT203?o01D0fMWI0P0co`2C0=WIf@80<ol0
4P3IfMT303?o03P0fMWI000@0=WIf@030000003IfMT0fMWI0180fMWI0P0co`0E0=WIf@<0<ol0T@3I
fMT203?o01@0fMWI0P0co`0h0=WIf@00403IfMT00`000000fMWI0=WIf@0B0=WIf@80<ol05P3IfMT2
03?o0300fMWI2@0co`1G0=WIf@<0<ol0503IfMT303?o03L0fMWI000@0=WIf@030000003IfMT0fMWI
0140fMWI0`0co`0F0=WIf@<0<ol0;P3IfMT=03?o05@0fMWI0P0co`0F0=WIf@80<ol0=`3IfMT00100
fMWI00<000000=WIf@3IfMT04@3IfMT203?o01P0fMWI0P0co`0/0=WIf@D0<ol01P3IfMT503?o0580
fMWI0P0co`0G0=WIf@<0<ol0=P3IfMT00100fMWI00<000000=WIf@3IfMT04@3IfMT203?o01P0fMWI
0`0co`0Z0=WIf@@0<ol02`3IfMT303?o0540fMWI0P0co`0H0=WIf@80<ol0=P3IfMT00100fMWI00<0
00000=WIf@3IfMT0403IfMT203?o01X0fMWI0P0co`0Y0=WIf@<0<ol03P3IfMT303?o04l0fMWI0P0c
o`0I0=WIf@80<ol0=P3IfMT00100fMWI00<000000=WIf@3IfMT0403IfMT203?o01X0fMWI0P0co`0X
0=WIf@<0<ol0403IfMT403?o04`0fMWI0`0co`0J0=WIf@80<ol0=@3IfMT00100fMWI00<000000=WI
f@3IfMT03`3IfMT303?o01/0fMWI0P0co`0V0=WIf@<0<ol04`3IfMT403?o04X0fMWI0P0co`0K0=WI
f@80<ol0=@3IfMT00100fMWI00<000000=WIf@3IfMT03`3IfMT203?o01`0fMWI0P0co`0V0=WIf@80
<ol05P3IfMT303?o04P0fMWI0P0co`0L0=WIf@<0<ol0=03IfMT00100fMWI00<000000=WIf@3IfMT0
3`3IfMT203?o01d0fMWI0P0co`0T0=WIf@80<ol0603IfMT403?o04D0fMWI0`0co`0M0=WIf@80<ol0
=03IfMT000L0fMWI100000050=WIf@030000003IfMT0fMWI00h0fMWI0P0co`0N0=WIf@80<ol08`3I
fMT303?o01X0fMWI1@0co`120=WIf@80<ol07P3IfMT203?o03@0fMWI00070=WIf@030000003IfMT0
fMWI00H0fMWI00<000000=WIf@3IfMT03P3IfMT203?o01l0fMWI0P0co`0R0=WIf@80<ol0703IfMT6
03?o00h0fMWI3@0co`0T0=WIf@<0<ol07`3IfMT203?o03<0fMWI00080=WIf@030000003IfMT0fMWI
00D0fMWI0P00000>0=WIf@<0<ol07`3IfMT203?o0240fMWI0P0co`0P0=WIf@D0<ol01`3IfMTE03?o
0240fMWI0P0co`0P0=WIf@80<ol0<`3IfMT000T0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@0=0=WIf@80<ol0803IfMT303?o01l0fMWI0`0co`0R0=WIfA00<ol02`3IfMT503?o01l0
fMWI0P0co`0R0=WIf@80<ol0<P3IfMT000X0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI
0=WIf@0=0=WIf@80<ol08@3IfMT203?o01h0fMWI0`0co`0U0=WIf@T0<ol04`3IfMT403?o01`0fMWI
0`0co`0R0=WIf@80<ol0<P3IfMT000L0fMWI00@000000=WIf@3IfMT000001@3IfMT00`000000fMWI
0=WIf@0<0=WIf@80<ol08P3IfMT303?o01d0fMWI0P0co`140=WIf@<0<ol06`3IfMT203?o02<0fMWI
0`0co`0a0=WIf@00203IfMT2000000H0fMWI00<000000=WIf@3IfMT0303IfMT203?o02<0fMWI0P0c
o`0L0=WIf@80<ol0AP3IfMT303?o01T0fMWI0`0co`0T0=WIf@80<ol0<@3IfMT00100fMWI00<00000
0=WIf@3IfMT02`3IfMT303?o02<0fMWI0`0co`0J0=WIf@<0<ol0A`3IfMT403?o01L0fMWI0P0co`0U
0=WIf@80<ol0<@3IfMT00100fMWI00<000000=WIf@3IfMT02`3IfMT203?o02D0fMWI0P0co`0J0=WI
f@80<ol0BP3IfMT303?o01D0fMWI0`0co`0V0=WIf@80<ol0<03IfMT00100fMWI00<000000=WIf@3I
fMT02`3IfMT203?o02D0fMWI0`0co`0H0=WIf@<0<ol0B`3IfMT303?o01<0fMWI0`0co`0W0=WIf@80
<ol0<03IfMT00100fMWI00<000000=WIf@3IfMT02P3IfMT203?o02L0fMWI0P0co`0H0=WIf@80<ol0
C@3IfMT403?o0100fMWI0`0co`0X0=WIf@<0<ol0;`3IfMT00100fMWI00<000000=WIf@3IfMT02P3I
fMT203?o02L0fMWI0`0co`0F0=WIf@80<ol0D03IfMT303?o00h0fMWI0`0co`0Z0=WIf@80<ol0;`3I
fMT00100fMWI00<000000=WIf@3IfMT02P3IfMT203?o02P0fMWI0P0co`0E0=WIf@<0<ol0D@3IfMT3
03?o00`0fMWI0`0co`0[0=WIf@80<ol0;`3IfMT00100fMWI00<000000=WIf@3IfMT02@3IfMT203?o
02T0fMWI0P0co`0E0=WIf@80<ol0D`3IfMT303?o00T0fMWI100co`0]0=WIf@80<ol0;P3IfMT00100
fMWI00<000000=WIf@3IfMT02@3IfMT203?o02X0fMWI0P0co`0C0=WIf@<0<ol0E03IfMT503?o00D0
fMWI100co`0^0=WIf@80<ol0;P3IfMT00100fMWI00<000000=WIf@3IfMT02@3IfMT203?o02X0fMWI
0P0co`0C0=WIf@80<ol0EP3IfMT;03?o0340fMWI0P0co`0]0=WIf@00403IfMT00`000000fMWI0=WI
f@080=WIf@80<ol0:`3IfMT303?o0140fMWI0P0co`1J0=WIf@L0<ol0<P3IfMT203?o02d0fMWI000@
0=WIf@030000003IfMT0fMWI00P0fMWI0P0co`0/0=WIf@<0<ol03`3IfMT303?o09<0fMWI0`0co`0/
0=WIf@00403IfMT00`000000fMWI0=WIf@080=WIf@80<ol0;@3IfMT303?o00d0fMWI0`0co`2E0=WI
f@80<ol0;03IfMT00100fMWI00<000000=WIf@3IfMT01`3IfMT203?o02l0fMWI0P0co`0=0=WIf@80
<ol0UP3IfMT203?o01<0fMWI00<0<ol00=WIf@3IfMT05P3IfMT00100fMWI00<000000=WIf@3IfMT0
1`3IfMT203?o02l0fMWI0`0co`0;0=WIf@80<ol0V03IfMT203?o0140fMWI0`0co`0G0=WIf@00403I
fMT00`000000fMWI0=WIf@060=WIf@<0<ol0<03IfMT303?o00P0fMWI100co`2H0=WIf@80<ol04@3I
fMT203?o01P0fMWI000@0=WIf@030000003IfMT0fMWI00H0fMWI0P0co`0b0=WIf@<0<ol01P3IfMT4
03?o09T0fMWI0`0co`0@0=WIf@80<ol0603IfMT000P0fMWI0P0000060=WIf@030000003IfMT0fMWI
00D0fMWI0P0co`0d0=WIf@@0<ol00`3IfMT303?o09`0fMWI0P0co`0?0=WIf@<0<ol0603IfMT000L0
fMWI00@000000=WIf@3IfMT000001@3IfMT00`000000fMWI0=WIf@050=WIf@80<ol0=@3IfMT803?o
09h0fMWI0P0co`0>0=WIf@80<ol06@3IfMT000X0fMWI00<000000=WIf@3IfMT00`3IfMT2000000D0
fMWI0P0co`0g0=WIf@H0<ol0W`3IfMT303?o00`0fMWI0P0co`0J0=WIf@00203IfMT2000000H0fMWI
00<000000=WIf@3IfMT00`3IfMT303?o0=d0fMWI0`0co`0;0=WIf@80<ol06P3IfMT000X0fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@<0<ol0g`3IfMT203?o00X0fMWI0P0c
o`0K0=WIf@001`3IfMT010000000fMWI0=WIf@0000050=WIf@030000003IfMT0fMWI0080fMWI0P0c
o`3P0=WIf@<0<ol0203IfMT303?o01/0fMWI00080=WIf@8000001P3IfMT010000000fMWI0=WIf@3I
fMT203?o0>80fMWI0`0co`060=WIf@<0<ol0703IfMT00100fMWI00<000000=WIf@3IfMT00`0co`3S
0=WIf@<0<ol0103IfMT303?o01d0fMWI000@0=WIf@030000003IfMT0fMWI0080<ol0i@3IfMT803?o
01h0fMWI000@0=WIf@030000003IfMT0<ol00080<ol0iP3IfMT603?o01l0fMWI000?0=WIf@D0<ol0
j@3IfMT203?o0240fMWI000?0=WIf@@0<ol0o`3IfMT>0=WIf@00403IfMT00`000000fMWI0=WIf@3o
0=WIf@h0fMWI000@0=WIf@030000003IfMT0fMWI0?l0fMWI3P3IfMT00100fMWI00<000000=WIf@3I
fMT0o`3IfMT>0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WI
f@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WIf@00o`3IfMTQ0=WI
f@003@3IfMT2000000030=WIf@00000000000?l0fMWI3`3IfMT000h0fMWI00<000000=WIf@000000
o`3IfMT@0=WIf@003`3IfMT00`000000fMWI0=WIf@3o0=WIf@l0fMWI000>0=WIf@030000003IfMT0
00000?l0fMWI403IfMT000d0fMWI0P0000000`3IfMT000000000003o0=WIf@l0fMWI003o0=WIfB40
fMWI003o0=WIfB40fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-1.2944, -3.47954, \
0.0808005, 0.0435338}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        xLPlot[0, 1, 1, 
          ViewPoint \[Rule] {1\ , 1, 
              1\ }], \[IndentingNewLine]DisplayFunction \[Rule] \
$DisplayFunction];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .98974 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0773503 1.1547 -1.28478e-17 1.1547 [
[.83978 .3328 0 -7.23502 ]
[.83978 .3328 12 1.76498 ]
[.72665 .21491 0 -7.80382 ]
[.72665 .21491 6 1.19618 ]
[.58196 .06436 0 -8.67134 ]
[.58196 .06436 6 .32866 ]
[.77787 .16489 0 -8.5482 ]
[.77787 .16489 16 1.2643 ]
[.51948 .99939 -11.8747 0 ]
[.51948 .99939 12.1253 9 ]
[.60813 .97761 -11.2962 0 ]
[.60813 .97761 12.7038 9 ]
[.70999 .95253 -2.65359 0 ]
[.70999 .95253 3.34641 9 ]
[.82825 .92336 -7.34904 0 ]
[.82825 .92336 10.651 9 ]
[.96719 .88901 -6.60422 0 ]
[.96719 .88901 11.3958 9 ]
[.71827 1.02423 -7.07624 0 ]
[.71827 1.02423 8.92376 9.8125 ]
[.88407 .41359 0 -6.93839 ]
[.88407 .41359 12 2.06161 ]
[.92964 .57066 0 -6.45143 ]
[.92964 .57066 6 2.54857 ]
[.98764 .77116 0 -5.86705 ]
[.98764 .77116 6 3.13295 ]
[.99614 .54294 0 -7.03072 ]
[.99614 .54294 16 2.78178 ]
[ 0 0 0 0 ]
[ 1 .98974 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.85714 .37115 m
.5 0 L
s
.82745 .34029 m
.82128 .34404 L
s
[(-1)] .83978 .3328 -1 .60778 Mshowa
.71502 .22345 m
.7092 .22772 L
s
[(0)] .72665 .21491 -1 .73418 Mshowa
.57137 .07417 m
.56608 .07908 L
s
[(1)] .58196 .06436 -1 .92696 Mshowa
.125 Mabswid
.80696 .319 m
.80329 .32131 L
s
.78554 .29674 m
.78191 .29911 L
s
.76312 .27345 m
.75954 .27588 L
s
.73964 .24904 m
.7361 .25154 L
s
.68916 .19658 m
.68572 .19921 L
s
.66198 .16833 m
.6586 .17104 L
s
.63336 .13859 m
.63005 .14138 L
s
.60321 .10725 m
.59996 .11012 L
s
.84707 .36068 m
.84333 .36288 L
s
.53772 .0392 m
.53463 .04223 L
s
.5021 .00218 m
.49909 .00529 L
s
gsave
.77787 .16489 -61 -12.5482 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
1.000 setlinewidth
grestore
.25 Mabswid
.5 .98974 m
1 .86603 L
s
.51933 .98496 m
.51925 .97774 L
s
[(-0.4)] .51948 .99939 -0.01044 -1 Mshowa
.60728 .9632 m
.60686 .95599 L
s
[(-0.2)] .60813 .97761 -0.05865 -1 Mshowa
.70833 .93819 m
.70751 .93102 L
s
[(0)] .70999 .95253 -0.11547 -1 Mshowa
.82564 .90917 m
.82434 .90207 L
s
[(0.2)] .82825 .92336 -0.18344 -1 Mshowa
.96347 .87506 m
.96162 .86809 L
s
[(0.4)] .96719 .88901 -0.2662 -1 Mshowa
.125 Mabswid
.54023 .97979 m
.54014 .97546 L
s
.56183 .97444 m
.56169 .97012 L
s
.58417 .96892 m
.58397 .96459 L
s
.63121 .95728 m
.6309 .95296 L
s
.65599 .95114 m
.65562 .94683 L
s
.68169 .94479 m
.68125 .94048 L
s
.73599 .93135 m
.73543 .92706 L
s
.76472 .92424 m
.76409 .91996 L
s
.79458 .91685 m
.79387 .91258 L
s
.85798 .90117 m
.85712 .89692 L
s
.89167 .89283 m
.89073 .8886 L
s
.9268 .88414 m
.92578 .87993 L
s
gsave
.71827 1.02423 -68.0762 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
1.000 setlinewidth
grestore
.25 Mabswid
.85714 .37115 m
1 .86603 L
s
.87138 .42047 m
.86503 .42391 L
s
[(-1)] .88407 .41359 -1 .54187 Mshowa
.91639 .57641 m
.90977 .57928 L
s
[(0)] .92964 .57066 -1 .43365 Mshowa
.97383 .77536 m
.96692 .77746 L
s
[(1)] .98764 .77116 -1 .30379 Mshowa
.125 Mabswid
.87959 .4489 m
.87575 .4509 L
s
.88816 .47862 m
.88429 .48055 L
s
.89714 .5097 m
.89323 .51158 L
s
.90654 .54227 m
.9026 .54407 L
s
.92674 .61224 m
.92273 .61388 L
s
.93761 .64991 m
.93357 .65146 L
s
.94905 .68954 m
.94498 .691 L
s
.96111 .7313 m
.957 .73266 L
s
.86352 .39324 m
.85974 .39536 L
s
.98727 .82192 m
.98309 .82307 L
s
gsave
.99614 .54294 -61 -11.0307 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x3) show
1.000 setlinewidth
grestore
.25 Mabswid
.5 .57735 m
.5 .98974 L
s
.5 .98974 m
1 .86603 L
s
1 .86603 m
.85714 .37115 L
s
.85714 .37115 m
.5 .57735 L
s
.14286 .37115 m
.5 0 L
s
.5 0 m
.5 .57735 L
s
.5 .57735 m
0 .86603 L
s
0 .86603 m
.14286 .37115 L
s
.5 .57735 m
.5 .98974 L
s
.5 .98974 m
0 .86603 L
s
0 .86603 m
.14286 .37115 L
s
.14286 .37115 m
.5 .57735 L
s
.85714 .37115 m
.5 0 L
s
.5 0 m
.5 .57735 L
s
.5 .57735 m
1 .86603 L
s
1 .86603 m
.85714 .37115 L
s
0 0 m
1 0 L
1 .98974 L
0 .98974 L
closepath
clip
newpath
.5 Mabswid
.31697 .92503 m
.32175 .89412 L
s
.34005 .92303 m
.31697 .92503 L
s
.38847 .88876 m
.34005 .92303 L
s
.32175 .89412 m
.35324 .83296 L
s
.3028 .86224 m
.37177 .86587 L
s
.26192 .83069 m
.3028 .86224 L
s
.25288 .77302 m
.26192 .83069 L
s
.45633 .82603 m
.38847 .88876 L
s
.37177 .86587 m
.46152 .84269 L
s
.35324 .83296 m
.40682 .74727 L
s
.27547 .69384 m
.25288 .77302 L
s
.24496 .76069 m
.19804 .72127 L
s
.32411 .77956 m
.24496 .76069 L
s
.19804 .72127 m
.1876 .66362 L
s
.42739 .77791 m
.32411 .77956 L
s
.46152 .84269 m
.5619 .79642 L
s
.53505 .74143 m
.45633 .82603 L
s
.1876 .66362 m
.21358 .59234 L
s
.32567 .60021 m
.27547 .69384 L
s
.54365 .75797 m
.42739 .77791 L
s
.16238 .62221 m
.23695 .63584 L
s
.12611 .598 m
.16238 .62221 L
s
.13155 .56448 m
.12611 .598 L
s
.40682 .74727 m
.47497 .64528 L
s
.10665 .5647 m
.12822 .56126 L
s
.17743 .52458 m
.13155 .56448 L
s
.12822 .56126 m
.19052 .55166 L
s
.5619 .79642 m
.66113 .73298 L
s
.21358 .59234 m
.27176 .51393 L
s
.19052 .55166 m
.28669 .53799 L
s
.65991 .72378 m
.54365 .75797 L
s
.61437 .64364 m
.53505 .74143 L
s
.25804 .48258 m
.17743 .52458 L
s
.39617 .50101 m
.32567 .60021 L
s
.28669 .53799 m
.40609 .52338 L
s
.47497 .64528 m
.5482 .53693 L
s
.27176 .51393 m
.3543 .43617 L
s
.66113 .73298 m
.74709 .6597 L
s
.76286 .68058 m
.65991 .72378 L
s
.36384 .4437 m
.25804 .48258 L
s
.40609 .52338 m
.53551 .51153 L
s
.68361 .54252 m
.61437 .64364 L
s
.47729 .40606 m
.39617 .50101 L
s
.84034 .63413 m
.76286 .68058 L
s
.4826 .41341 m
.36384 .4437 L
s
.3543 .43617 m
.45066 .36736 L
s
.74709 .6597 m
.80886 .58456 L
s
.5482 .53693 m
.61631 .43289 L
s
.53551 .51153 m
.66065 .50612 L
s
.88287 .58997 m
.84034 .63413 L
s
.73308 .44808 m
.68361 .54252 L
s
.60079 .39676 m
.4826 .41341 L
s
.55827 .3251 m
.47729 .40606 L
s
.66065 .50612 m
.76777 .5102 L
s
.80886 .58456 m
.83807 .51519 L
s
.45066 .36736 m
.54897 .31535 L
s
.88485 .55273 m
.88287 .58997 L
s
.61631 .43289 m
.66968 .34344 L
s
.76777 .5102 m
.84522 .52565 L
s
.70516 .39763 m
.60079 .39676 L
s
.84522 .52565 m
.88485 .55273 L
s
.83807 .51519 m
.83001 .45814 L
s
.75536 .3694 m
.73308 .44808 L
s
.62858 .26676 m
.55827 .3251 L
s
.54897 .31535 m
.63742 .28666 L
s
.78432 .41813 m
.70516 .39763 L
s
.83001 .45814 m
.78432 .41813 L
s
.66968 .34344 m
.70056 .27736 L
s
.7463 .3137 m
.75536 .3694 L
s
.63742 .28666 m
.7057 .2856 L
s
.67926 .23752 m
.62858 .26676 L
s
.7057 .2856 m
.7463 .3137 L
s
.70056 .27736 m
.70414 .24098 L
s
.70414 .24098 m
.67926 .23752 L
s
.25 Mabswid
.14286 .37115 m
.5 0 L
s
.5 0 m
.5 .57735 L
s
.5 .57735 m
0 .86603 L
s
0 .86603 m
.14286 .37115 L
s
.85714 .37115 m
.5 0 L
s
.5 0 m
.5 .57735 L
s
.5 .57735 m
1 .86603 L
s
1 .86603 m
.85714 .37115 L
s
.85714 .37115 m
.5 0 L
s
.82745 .34029 m
.82128 .34404 L
s
[(-1)] .83978 .3328 -1 .60778 Mshowa
.71502 .22345 m
.7092 .22772 L
s
[(0)] .72665 .21491 -1 .73418 Mshowa
.57137 .07417 m
.56608 .07908 L
s
[(1)] .58196 .06436 -1 .92696 Mshowa
.125 Mabswid
.80696 .319 m
.80329 .32131 L
s
.78554 .29674 m
.78191 .29911 L
s
.76312 .27345 m
.75954 .27588 L
s
.73964 .24904 m
.7361 .25154 L
s
.68916 .19658 m
.68572 .19921 L
s
.66198 .16833 m
.6586 .17104 L
s
.63336 .13859 m
.63005 .14138 L
s
.60321 .10725 m
.59996 .11012 L
s
.84707 .36068 m
.84333 .36288 L
s
.53772 .0392 m
.53463 .04223 L
s
.5021 .00218 m
.49909 .00529 L
s
gsave
.77787 .16489 -61 -12.5482 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x1) show
1.000 setlinewidth
grestore
.25 Mabswid
.5 .98974 m
1 .86603 L
s
.51933 .98496 m
.51925 .97774 L
s
[(-0.4)] .51948 .99939 -0.01044 -1 Mshowa
.60728 .9632 m
.60686 .95599 L
s
[(-0.2)] .60813 .97761 -0.05865 -1 Mshowa
.70833 .93819 m
.70751 .93102 L
s
[(0)] .70999 .95253 -0.11547 -1 Mshowa
.82564 .90917 m
.82434 .90207 L
s
[(0.2)] .82825 .92336 -0.18344 -1 Mshowa
.96347 .87506 m
.96162 .86809 L
s
[(0.4)] .96719 .88901 -0.2662 -1 Mshowa
.125 Mabswid
.54023 .97979 m
.54014 .97546 L
s
.56183 .97444 m
.56169 .97012 L
s
.58417 .96892 m
.58397 .96459 L
s
.63121 .95728 m
.6309 .95296 L
s
.65599 .95114 m
.65562 .94683 L
s
.68169 .94479 m
.68125 .94048 L
s
.73599 .93135 m
.73543 .92706 L
s
.76472 .92424 m
.76409 .91996 L
s
.79458 .91685 m
.79387 .91258 L
s
.85798 .90117 m
.85712 .89692 L
s
.89167 .89283 m
.89073 .8886 L
s
.9268 .88414 m
.92578 .87993 L
s
gsave
.71827 1.02423 -68.0762 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x2) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 285},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00017B000`400?l00000o`00003oR03IfMT0
0`000000fMWI0=WIf@2E0=WIf@00Q`3IfMT3000009H0fMWI00260=WIf@<0000000<0fMWI0000003I
fMT0U03IfMT008D0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@2B0=WIf@00
Q03IfMT01@000000fMWI0=WIf@3IfMT0000000<0fMWI00<000000=WIf@3IfMT0T@3IfMT008<0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0900fMWI
00220=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WI
f@2?0=WIf@00P@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0SP3IfMT00800fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@050=WI
f@030000003IfMT0fMWI08d0fMWI001o0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT01P3IfMT00`000000fMWI0=WIf@2<0=WIf@00OP3IfMT00`000000fMWI0=WIf@070=WIf@030000
003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00T0fMWI1000001n0=WIf@00O03IfMT0
0`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@000000303IfMT0
0`000000fMWI0=WIf@1m0=WIf@00O03IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI
00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@1m0=WIf@00N`3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@1m0=WIf@00NP3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00/0fMWI
00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@1m0=WIf@00N@3IfMT00`000000fMWI0=WI
f@0<0=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT0103IfMT3000007l0fMWI001h
0=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@05
0=WIf@030000003IfMT0fMWI07d0fMWI001g0=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WI
f@3IfMT03P3IfMT00`000000fMWI0=WIf@240=WIf@00MP3IfMT00`000000fMWI0=WIf@0?0=WIf@03
0000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT0P`3IfMT007D0fMWI00<000000=WIf@3IfMT0
403IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI0880fMWI001d0=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI000000230=WIf@00L`3IfMT0
0`000000fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI00h0fMWI00D000000=WIf@3IfMT0fMWI0000
00220=WIf@00LP3IfMT00`000000fMWI0=WIf@0C0=WIf@030000003IfMT0fMWI01<0fMWI00<00000
0=WIf@3IfMT0O`3IfMT00740fMWI00<000000=WIf@3IfMT0503IfMT00`000000fMWI0=WIf@0D0=WI
f@030000003IfMT0fMWI07h0fMWI001`0=WIf@030000003IfMT0fMWI01D0fMWI00<000000=WIf@3I
fMT05@3IfMT00`000000fMWI0=WIf@1m0=WIf@00K`3IfMT00`000000fMWI0=WIf@0F0=WIf@030000
003IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT0O03IfMT006h0fMWI00<000000=WIf@3IfMT05`3I
fMT00`000000fMWI0=WIf@0G0=WIf@030000003IfMT0fMWI07/0fMWI001]0=WIf@030000003IfMT0
fMWI01P0fMWI00<000000=WIf@3IfMT0603IfMT00`000000fMWI0=WIf@1j0=WIf@00K03IfMT00`00
0000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI01P0fMWI0P00001k0=WIf@00J`3IfMT00`000000
fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI01L0fMWI00<000000=WIf@000000N`3IfMT006X0fMWI
00<000000=WIf@3IfMT06`3IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI07P0fMWI
001Y0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT06`3IfMT00`000000fMWI0=WI
f@1g0=WIf@00J03IfMT00`000000fMWI0=WIf@0M0=WIf@030000003IfMT0fMWI01`0fMWI00<00000
0=WIf@3IfMT0MP3IfMT006L0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0M0=WI
f@030000003IfMT0fMWI07D0fMWI001V0=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3I
fMT07P3IfMT00`000000fMWI0=WIf@1d0=WIf@00I@3IfMT00`000000fMWI0=WIf@0P0=WIf@030000
003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT0L`3IfMT006@0fMWI00<000000=WIf@3IfMT08@3I
fMT00`000000fMWI0=WIf@0P0=WIf@030000003IfMT0fMWI0780fMWI001T0=WIf@030000003IfMT0
fMWI0240fMWI00<000000=WIf@3IfMT07`3IfMT3000007<0fMWI001S0=WIf@030000003IfMT0fMWI
0280fMWI00<000000=WIf@3IfMT08P3IfMT00`000000fMWI0=WIf@1`0=WIf@00HP3IfMT00`000000
fMWI0=WIf@0S0=WIf@030000003IfMT0fMWI02<0fMWI00<000000=WIf@3IfMT08`3IfMT200000003
0=WIf@00000000000080fMWI100000110=WIf@00H@3IfMT00`000000fMWI0=WIf@0T0=WIf@030000
003IfMT0fMWI02@0fMWI00<000000=WIf@3IfMT08`3IfMT00`000000fMWI000000050=WIf@030000
003IfMT0fMWI0400fMWI001P0=WIf@030000003IfMT0fMWI02D0fMWI00<000000=WIf@3IfMT09@3I
fMT00`000000fMWI0=WIf@0S0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0@03I
fMT005l0fMWI00<000000=WIf@3IfMT09P3IfMT00`000000fMWI0=WIf@0V0=WIf@030000003IfMT0
fMWI0240fMWI00<000000=WIf@0000001@3IfMT00`000000fMWI0=WIf@100=WIf@00GP3IfMT00`00
0000fMWI0=WIf@0W0=WIf@030000003IfMT0fMWI02L0fMWI00<000000=WIf@3IfMT07`3IfMT20000
00030=WIf@000000000000@0fMWI00<000000=WIf@3IfMT0@03IfMT005d0fMWI00<000000=WIf@3I
fMT0:03IfMT00`000000fMWI0=WIf@0X0=WIf@030000003IfMT0fMWI02D0fMWI0`0000120=WIf@00
G03IfMT00`000000fMWI0=WIf@0Y0=WIf@030000003IfMT0fMWI02L0fMWI0`00000X0=WIf@030000
003IfMT0fMWI0400fMWI001K0=WIf@030000003IfMT0fMWI02X0fMWI00<000000=WIf@3IfMT0:P3I
fMT00`000000fMWI0=WIf@1X0=WIf@00FP3IfMT00`000000fMWI0=WIf@0[0=WIf@030000003IfMT0
fMWI02/0fMWI00<000000=WIf@3IfMT0I`3IfMT005T0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI06H0fMWI001H0=WIf@030000003IfMT0fMWI02d0
fMWI00<000000=WIf@3IfMT0;03IfMT00`000000fMWI0=WIf@1V0=WIf@00E`3IfMT00`000000fMWI
0=WIf@0^0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0I@3IfMT005H0fMWI00<0
00000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0fMWI00X0fMWI0P00
001H0=WIf@00E@3IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI02l0fMWI00<00000
0=WIf@3IfMT0203IfMT010000000fMWI0=WIf@00001G0=WIf@00E03IfMT00`000000fMWI0=WIf@0a
0=WIf@030000003IfMT0fMWI02h0fMWI00<000000=WIf@0000002@3IfMT010000000fMWI0=WIf@00
001G0=WIf@00D`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI0340fMWI00<00000
0=WIf@3IfMT01P3IfMT010000000fMWI0=WIf@00001G0=WIf@00DP3IfMT00`000000fMWI0=WIf@0c
0=WIf@030000003IfMT0fMWI0380fMWI00<000000=WIf@3IfMT01@3IfMT010000000fMWI0=WIf@00
001G0=WIf@00D@3IfMT00`000000fMWI0=WIf@0d0=WIf@030000003IfMT0fMWI03<0fMWI00<00000
0=WIf@3IfMT0103IfMT010000000fMWI0=WIf@00001G0=WIf@00D03IfMT00`000000fMWI0=WIf@0e
0=WIf@030000003IfMT0fMWI03@0fMWI00<000000=WIf@3IfMT0103IfMT2000005P0fMWI001?0=WI
f@030000003IfMT0fMWI03H0fMWI00<000000=WIf@3IfMT0=@3IfMT00`000000fMWI0=WIf@1M0=WI
f@00CP3IfMT00`000000fMWI0=WIf@0g0=WIf@030000003IfMT0fMWI03H0fMWI00<000000=WIf@3I
fMT0G03IfMT004d0fMWI00<000000=WIf@3IfMT0>03IfMT00`000000fMWI0=WIf@0e0=WIf@030000
003IfMT0000005d0fMWI001<0=WIf@030000003IfMT0fMWI03T0fMWI00<000000=WIf@3IfMT0>03I
fMT00`000000fMWI0=WIf@1J0=WIf@00C03IfMT00`000000fMWI0=WIf@0i0=WIf@030000003IfMT0
fMWI03T0fMWI00<000000=WIf@3IfMT0F@3IfMT004/0fMWI00<000000=WIf@3IfMT0>P3IfMT00`00
0000fMWI0=WIf@0]0=WIf@<000002P3IfMT00`000000fMWI0=WIf@1H0=WIf@00BP3IfMT00`000000
fMWI0=WIf@0k0=WIf@030000003IfMT0fMWI02/0fMWI0P0000030=WIf@@000001`3IfMT00`000000
fMWI0=WIf@1G0=WIf@00B@3IfMT00`000000fMWI0=WIf@0l0=WIf@030000003IfMT0fMWI02T0fMWI
0P0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0EP3IfMT004P0fMWI00<0
00000=WIf@3IfMT0?@3IfMT00`000000fMWI0=WIf@0W0=WIf@8000002P3IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT0fMWI05D0fMWI00170=WIf@030000003IfMT0fMWI03h0fMWI00<00000
0=WIf@3IfMT09P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00H0fMWI00<00000
0=WIf@000000EP3IfMT004H0fMWI00<000000=WIf@3IfMT0?`3IfMT00`000000fMWI0=WIf@0T0=WI
f@8000003@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI05<0fMWI00150=WIf@03
0000003IfMT0fMWI0400fMWI00<000000=WIf@3IfMT08P3IfMT2000000l0fMWI00<000000=WIf@3I
fMT02@3IfMT00`000000fMWI0=WIf@1C0=WIf@00A03IfMT00`000000fMWI0=WIf@110=WIf@030000
003IfMT0fMWI0200fMWI0P00000@0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0
DP3IfMT004<0fMWI00<000000=WIf@3IfMT0@P3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003I
fMT0fMWI0100fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@1A0=WIf@00@P3IfMT0
0`000000fMWI0=WIf@130=WIf@030000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT04@3IfMT0
0`000000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI0500fMWI00110=WIf@030000003IfMT0fMWI
04@0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI
00d0fMWI0P00001A0=WIf@00@03IfMT00`000000fMWI0=WIf@150=WIf@030000003IfMT0fMWI01/0
fMWI0P00000E0=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT0CP3IfMT003l0fMWI
00<000000=WIf@3IfMT0AP3IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI01D0fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@1=0=WIf@00?P3IfMT00`000000fMWI0=WI
f@170=WIf@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT0103IfMTE00000140fMWI00<0
00000=WIf@3IfMT0C03IfMT003d0fMWI00<000000=WIf@3IfMT0B03IfMT00`000000fMWI0=WIf@0H
0=WIf@030000003IfMT0fMWI0080fMWI0`00000A0=WIf@040000003IfMT0fMWI0=WIf@800000403I
fMT00`000000fMWI0=WIf@1;0=WIf@00?03IfMT00`000000fMWI0=WIf@190=WIf@030000003IfMT0
fMWI01L0fMWI00<000000=WIf@3IfMT00`00000C0=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@1:0=WIf@00>`3IfMT00`000000fMWI0=WIf@1:0=WI
f@030000003IfMT0fMWI01D0fMWI1@00000F0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WI
f@3IfMT03P3IfMT00`000000fMWI0=WIf@190=WIf@00>P3IfMT00`000000fMWI0=WIf@1;0=WIf@03
0000003IfMT0fMWI01@0fMWI0`00000H0=WIf@030000003IfMT0fMWI00L0fMWI0P00000=0=WIf@03
0000003IfMT0000004X0fMWI000i0=WIf@030000003IfMT0fMWI04`0fMWI00<000000=WIf@3IfMT0
4P3IfMT3000001X0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0=0=WIf@030000
003IfMT0fMWI04L0fMWI000h0=WIf@030000003IfMT0fMWI04d0fMWI00<000000=WIf@3IfMT03`3I
fMT4000001/0fMWI00<000000=WIf@3IfMT02`3IfMT2000000h0fMWI00<000000=WIf@3IfMT0AP3I
fMT003L0fMWI00<000000=WIf@3IfMT0CP3IfMT00`000000fMWI0=WIf@0<0=WIf@<000000P3IfMT0
0`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT0303IfMT0
0`000000fMWI0=WIf@150=WIf@00=P3IfMT00`000000fMWI0=WIf@1?0=WIf@030000003IfMT0fMWI
00X0fMWI0P0000030=WIf@800000703IfMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI
00d0fMWI00<000000=WIf@3IfMT03@3IfMT4000003<0fMWI000e0=WIf@030000003IfMT0fMWI0500
fMWI00<000000=WIf@3IfMT0203IfMT2000000@0fMWI00<000000=WIf@3IfMT0703IfMT00`000000
fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000
fMWI0=WIf@0b0=WIf@00=03IfMT00`000000fMWI0=WIf@1A0=WIf@030000003IfMT0fMWI00H0fMWI
0P0000050=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI
0=WIf@0<0=WIf@030000003IfMT0000000l0fMWI00<000000=WIf@3IfMT0<P3IfMT003@0fMWI00<0
00000=WIf@3IfMT0D@3IfMT00`000000fMWI0=WIf@040=WIf@8000001P3IfMT00`000000fMWI0=WI
f@0M0=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WI
f@040=WIf@@00000103IfMT00`000000fMWI0=WIf@0b0=WIf@00<`3IfMT00`000000fMWI0=WIf@1B
0=WIf@030000003IfMT0fMWI0080fMWI0P0000070=WIf@030000003IfMT0fMWI01d0fMWI00<00000
0=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00/0fMWI00<00000
0=WIf@3IfMT0<P3IfMT00380fMWI00<000000=WIf@3IfMT0D`3IfMT00`000000fMWI0=WIf@020000
00P0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI
0100fMWI00<000000=WIf@3IfMT02@3IfMT3000003@0fMWI000a0=WIf@030000003IfMT0fMWI05@0
fMWI0`0000090=WIf@030000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT04P3IfMT00`000000
fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0<P3IfMT00300fMWI
00<000000=WIf@3IfMT0E03IfMT2000000X0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI
0=WIf@0C0=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT0?P3IfMT002l0fMWI00<0
00000=WIf@3IfMT0D`3IfMT2000000030=WIf@000000fMWI00P0fMWI00<000000=WIf@3IfMT07`3I
fMT00`000000fMWI0=WIf@0D0=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@000000?`3I
fMT002h0fMWI00<000000=WIf@3IfMT0DP3IfMT2000000<0fMWI00<000000=WIf@3IfMT01P3IfMT0
0`000000fMWI0=WIf@0P0=WIf@030000003IfMT0fMWI01@0fMWI00<000000=WIf@3IfMT04`3IfMT0
0`000000fMWI0=WIf@0l0=WIf@00;@3IfMT00`000000fMWI0=WIf@1A0=WIf@8000001@3IfMT00`00
0000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0200fMWI00<000000=WIf@3IfMT05@3IfMT00`00
0000fMWI0=WIf@0D0=WIf@030000003IfMT0fMWI03/0fMWI000/0=WIf@030000003IfMT0fMWI0500
fMWI0P0000070=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000
fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI01D0fMWI00<000000=WIf@3IfMT0>P3IfMT002/0fMWI
00<000000=WIf@3IfMT0C`3IfMT2000000T0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI
0=WIf@0Q0=WIf@030000003IfMT0fMWI01L0fMWI00<000000=WIf@3IfMT05@3IfMT00`000000fMWI
0=WIf@0i0=WIf@00:P3IfMT00`000000fMWI0=WIf@1>0=WIf@8000002`3IfMT010000000fMWI0=WI
f@3IfMT2000002@0fMWI00<000000=WIf@3IfMT05`3IfMT00`000000fMWI0=WIf@0D0=WIf@030000
003IfMT0000003X0fMWI000Y0=WIf@030000003IfMT0fMWI04h0fMWI00<000000=WIf@3IfMT02`3I
fMT010000000fMWI0=WIf@00000U0=WIf@030000003IfMT0fMWI01P0fMWI00<000000=WIf@3IfMT0
5`3IfMT00`000000fMWI0=WIf@0g0=WIf@00:03IfMT00`000000fMWI0=WIf@1=0=WIf@8000003P3I
fMT00`000000fMWI0000000U0=WIf@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT0603I
fMT00`000000fMWI0=WIf@0f0=WIf@00:03IfMT3000004`0fMWI00<000000=WIf@3IfMT03P3IfMT2
000002H0fMWI00<000000=WIf@3IfMT0603IfMT00`000000fMWI0=WIf@0G0=WIf@<00000>03IfMT0
02L0fMWI00@000000=WIf@3IfMT0fMWI0P0000190=WIf@030000003IfMT0fMWI00l0fMWI00<00000
0=WIf@3IfMT0903IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI01D0fMWI0P000003
0=WIf@030000003IfMT0fMWI03D0fMWI000W0=WIf@030000003IfMT0fMWI00<0fMWI0P0000150=WI
f@8000004@3IfMT2000002H0fMWI00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@0C0=WI
f@8000001@3IfMT00`000000fMWI0=WIf@0e0=WIf@009`3IfMT00`000000fMWI0=WIf@050=WIf@03
0000003IfMT0fMWI0440fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0000000U0=WIf@03
0000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@050=WIf@03
0000003IfMT0fMWI03D0fMWI000W0=WIf@030000003IfMT0fMWI00H0fMWI0P00000o0=WIf@800000
4P3IfMT010000000fMWI0=WIf@00000T0=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3I
fMT04@3IfMT2000000P0fMWI00<000000=WIf@3IfMT0=@3IfMT002H0fMWI00<000000=WIf@3IfMT0
2@3IfMT2000003`0fMWI00<000000=WIf@3IfMT04@3IfMT01@000000fMWI0=WIf@3IfMT0000002@0
fMWI00<000000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@0?0=WIf@8000002P3IfMT2000003H0
fMWI000V0=WIf@030000003IfMT0fMWI00/0fMWI0P00000i0=WIf@030000003IfMT0fMWI0140fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0D0=WIfB8000002@3IfMT00`000000fMWI
0=WIf@0>0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT02@3IfMT4000002L0fMWI
000V0=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT0=03IfMT2000001<0fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0<0=WIf@P000003@3IfMT00`000000fMWI0=WI
f@0B0=WIf@@00000103IfMT00`000000fMWI0=WIf@0=0=WIf@8000003P3IfMT00`000000fMWI0=WI
f@0;0=WIf@030000003IfMT0fMWI02H0fMWI000U0=WIf@030000003IfMT0fMWI00l0fMWI0P00000c
0=WIf@030000003IfMT0fMWI0180fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@04
0=WIf@P00000503IfMT00`000000fMWI0=WIf@0G0=WIf@D000003@3IfMT200000140fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@0V0=WIf@009@3IfMT00`000000fMWI0=WIf@0A0=WI
f@800000<03IfMT00`000000fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI00@0fMWI2000000L0=WI
f@030000003IfMT0fMWI01/0fMWI1@0000070=WIf@8000004`3IfMT00`000000fMWI0=WIf@020=WI
f@@00000103IfMT00`000000fMWI0=WIf@0V0=WIf@009@3IfMT00`000000fMWI0=WIf@0C0=WIf@80
0000;03IfMT2000001@0fMWI00<000000=WIf@0000001@0000000`3IfMT000000=WIf@0P0=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT00P3IfMT400000080fMWI00<000000=WIf@3I
fMT04`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI02H0fMWI000U0=WIf@030000
003IfMT0fMWI01D0fMWI00<000000=WIf@3IfMT0:03IfMT00`000000fMWI0=WIf@0B0=WIf@@00000
1`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT0
1`3IfMT3000001D0fMWI00<000000=WIf@3IfMT0203IfMT3000002P0fMWI000T0=WIf@030000003I
fMT0fMWI01L0fMWI0P00000V0=WIf@8000004@3IfMT4000000030=WIf@000000fMWI00P0fMWI00<0
00000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI00D0fMWI0P00
00030=WIf@030000003IfMT0fMWI0180fMWI0P00000;0=WIf@030000003IfMT0fMWI02H0fMWI000T
0=WIf@030000003IfMT0fMWI01T0fMWI0P00000S0=WIf@030000003IfMT0fMWI00d0fMWI10000004
0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0M
0=WIf@030000003IfMT0fMWI00<0fMWI0P0000060=WIf@030000003IfMT0fMWI0100fMWI00<00000
0=WIf@000000=03IfMT002@0fMWI00<000000=WIf@3IfMT06`3IfMT200000200fMWI00<000000=WI
f@3IfMT02P3IfMT4000000L0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0M0=WI
f@030000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@070=WI
f@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT0<P3IfMT002<0fMWI00<000000=WIf@3I
fMT07P3IfMT00`000000fMWI0=WIf@0K0=WIf@8000002@3IfMT4000000X0fMWI00<000000=WIf@3I
fMT02P3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI01d0fMWI00@000000=WIf@3I
fMT0fMWI0P00000;0=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT0<@3IfMT002<0
fMWI00<000000=WIf@3IfMT07`3IfMT2000001X0fMWI00<000000=WIf@3IfMT01@3IfMT4000000h0
fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@0K0=WIf@030000003IfMT0fMWI01h0
fMWI00@000000=WIf@00000000003P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI
0340fMWI000S0=WIf@030000003IfMT0fMWI0240fMWI0P00000G0=WIf@030000003IfMT0fMWI0080
fMWI1000000A0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT06`3IfMT00`000000
fMWI0=WIf@0N0=WIf@8000004@3IfMT200000100fMWI00<000000=WIf@3IfMT0<@3IfMT002<0fMWI
00<000000=WIf@3IfMT08`3IfMT2000001@0fMWI00<000000=WIf@3IfMT00`00000D0=WIf@030000
003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@0N0=WIf@800000
503IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI0340fMWI000R0=WIf@030000003I
fMT0fMWI02H0fMWI00<000000=WIf@3IfMT0403IfMT010000000fMWI00000000000F0=WIf@030000
003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@0M0=WIf@<00000
5P3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI0300fMWI000R0=WIf@030000003I
fMT0fMWI02L0fMWI0P00000?0=WIf@<000005`3IfMT00`000000fMWI0=WIf@0>0=WIf@030000003I
fMT0fMWI01T0fMWI00<000000=WIf@3IfMT06`3IfMT200000080fMWI00<000000=WIf@3IfMT05@3I
fMT00`000000fMWI0=WIf@0;0=WIf@800000<P3IfMT00280fMWI00<000000=WIf@3IfMT0:@3IfMT2
000000/0fMWI0P00000J0=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT0603IfMT0
0`000000fMWI0=WIf@0K0=WIf@050000003IfMT0fMWI0=WIf@0000006@3IfMT00`000000fMWI0=WI
f@0;0=WIf@030000003IfMT0fMWI0300fMWI000Q0=WIf@030000003IfMT0fMWI02`0fMWI0P000006
0=WIf@<000006`3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI01L0fMWI00<00000
0=WIf@3IfMT06P3IfMT2000000@0fMWI00<000000=WIf@3IfMT0603IfMT00`000000fMWI0=WIf@0;
0=WIf@030000003IfMT0fMWI02l0fMWI000Q0=WIf@030000003IfMT0fMWI02h0fMWI00<000000=WI
f@3IfMT00`0000000`3IfMT000000=WIf@0J0=WIf@030000003IfMT0fMWI0100fMWI00<000000=WI
f@3IfMT05`3IfMT00`000000fMWI0=WIf@0H0=WIf@8000001@3IfMT00`000000fMWI0=WIf@0I0=WI
f@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0;`3IfMT00240fMWI00<000000=WIf@3I
fMT0;`3IfMT2000000<0fMWI00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@0A0=WIf@03
0000003IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT05`3IfMT2000000L0fMWI00<000000=WIf@3I
fMT06@3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI02l0fMWI000Q0=WIf@030000
003IfMT0fMWI02`0fMWI0`0000020=WIf@<000006`3IfMT00`000000fMWI0=WIf@0B0=WIf@030000
003IfMT0fMWI01D0fMWI00<000000=WIf@3IfMT05`3IfMT00`000000fMWI0=WIf@060=WIf@030000
003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0_0=WIf@00803I
fMT00`000000fMWI0=WIf@0[0=WIf@8000001P3IfMT2000001X0fMWI00<000000=WIf@3IfMT04`3I
fMT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI01D0fMWI0P0000090=WIf@030000003I
fMT0fMWI01/0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0^0=WIf@00803IfMT0
0`000000fMWI0=WIf@0X0=WIf@<000001`3IfMT00`000000fMWI0=WIf@02000001P0fMWI00<00000
0=WIf@3IfMT04`3IfMT00`000000fMWI0=WIf@0D0=WIf@030000003IfMT0fMWI01@0fMWI0P00000:
0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0^
0=WIf@00803IfMT00`000000fMWI0=WIf@0V0=WIf@8000002@3IfMT00`000000fMWI0=WIf@030=WI
f@8000005@3IfMT00`000000fMWI0=WIf@0D0=WIf@030000003IfMT0fMWI01<0fMWI00<000000=WI
f@3IfMT0503IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WI
f@3IfMT02P3IfMT200000300fMWI000O0=WIf@030000003IfMT0fMWI02@0fMWI0`00000:0=WIf@03
0000003IfMT0fMWI00H0fMWI0P00000B0=WIf@030000003IfMT0fMWI01D0fMWI00<000000=WIf@3I
fMT04`3IfMT00`000000fMWI0=WIf@0B0=WIf@800000303IfMT00`000000fMWI0=WIf@0M0=WIf@03
0000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT0;@3IfMT001l0fMWI00<000000=WIf@3IfMT0
8P3IfMT2000000`0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@0A0=WIf@800000
3P3IfMT00`000000fMWI0=WIf@0M0=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT0
;@3IfMT001l0fMWI00<000000=WIf@3IfMT0803IfMT2000000d0fMWI00<000000=WIf@3IfMT02`3I
fMT2000000d0fMWI00<000000=WIf@3IfMT05`3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003I
fMT0fMWI0100fMWI0P00000?0=WIf@030000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT0303I
fMT00`000000fMWI0=WIf@0]0=WIf@007`3IfMT00`000000fMWI0=WIf@0N0=WIf@8000003@3IfMT2
00000100fMWI0P00000;0=WIf@030000003IfMT0fMWI01L0fMWI00<000000=WIf@3IfMT0403IfMT0
0`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT07P3IfMT0
0`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI02d0fMWI000N0=WIf@030000003IfMT0fMWI
01d0fMWI0P00000>0=WIf@030000003IfMT0fMWI0180fMWI0P0000080=WIf@030000003IfMT0fMWI
01P0fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@0>0=WIf@8000004@3IfMT00`00
0000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT0;03IfMT001h0
fMWI00<000000=WIf@3IfMT06`3IfMT2000000l0fMWI00<000000=WIf@3IfMT05@3IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT03`3IfMT00`000000
fMWI0=WIf@0=0=WIf@8000004`3IfMT00`000000fMWI0=WIf@0P0=WIf@030000003IfMT0fMWI00`0
fMWI00<000000=WIf@3IfMT0;03IfMT001h0fMWI00<000000=WIf@3IfMT06@3IfMT200000100fMWI
00<000000=WIf@3IfMT05`3IfMT2000000<0fMWI00<000000=WIf@3IfMT06P3IfMT00`000000fMWI
0=WIf@0>0=WIf@030000003IfMT0fMWI00H0fMWI7`00000Q0=WIf@030000003IfMT0fMWI00`0fMWI
00<000000=WIf@3IfMT0;03IfMT001d0fMWI00<000000=WIf@3IfMT0603IfMT200000140fMWI00<0
00000=WIf@3IfMT06P3IfMT2000000030=WIf@000000fMWI01/0fMWI00<000000=WIf@3IfMT00P3I
fMTE000000D0fMWI00<000000=WIf@3IfMT0503IfMT00`000000fMWI0=WIf@0A00000100fMWI00<0
00000=WIf@3IfMT0303IfMT2000002d0fMWI000M0=WIf@030000003IfMT0fMWI01H0fMWI0P00000B
0=WIf@030000003IfMT0fMWI01d0fMWI0P00000H0=WIf@T000002`3IfMT00`000000fMWI0=WIf@0:
0=WIf@8000005P3IfMT00`000000fMWI0=WIf@0B0=WIf@D000002`3IfMT00`000000fMWI0=WIf@0=
0=WIf@030000003IfMT0fMWI02/0fMWI000M0=WIf@030000003IfMT0fMWI01@0fMWI0P00000C0=WI
f@030000003IfMT0fMWI01d0fMWI00@000000=WIf@3IfMT000003`3IfMT8000000@0fMWI00<00000
0=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@090=WIf@800000603IfMT00`000000fMWI0=WIf@0G
0=WIf@H000001@3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI02/0fMWI000L0=WI
f@030000003IfMT0fMWI01<0fMWI0P00000E0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WI
f@3IfMT00P3IfMT2000000@0fMWI2@00000<0=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@0G0=WIf@030000003IfMT0fMWI01h0fMWI1@00000A0=WI
f@030000003IfMT0fMWI02X0fMWI000L0=WIf@030000003IfMT0fMWI0180fMWI00<000000=WIf@3I
fMT0503IfMT00`000000fMWI0=WIf@0M0=WIf@030000003IfMT0000000P000005@3IfMT00`000000
fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00L0fMWI0P00000J0=WIf@030000003IfMT0fMWI0280
fMWI1000000>0=WIf@030000003IfMT0fMWI02X0fMWI000L0=WIf@030000003IfMT0fMWI0140fMWI
00<000000=WIf@3IfMT0503IfMT00`000000fMWI0=WIf@0H0=WIf@P000001`3IfMT2000001D0fMWI
00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@060=WIf@8000006`3IfMT00`000000fMWI
0=WIf@0R0=WIf@030000003IfMT0fMWI0080fMWI0P00000<0=WIf@030000003IfMT0fMWI01P0fMWI
0P0000000`3IfMT00000000000030=WIf@800000203IfMT001`0fMWI00<000000=WIf@3IfMT0403I
fMT00`000000fMWI0=WIf@0D0=WIf@030000003IfMT0fMWI0140fMWI200000040=WIf@030000003I
fMT0fMWI00X0fMWI00<000000=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003I
fMT0fMWI00@0fMWI0P00000M0=WIf@030000003IfMT0fMWI0280fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI01T0fMWI00<000000=WIf@0000000`3I
fMT010000000fMWI0=WIf@0000070=WIf@006`3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003I
fMT0fMWI01D0fMWI00<000000=WIf@3IfMT02@3IfMT8000000/0fMWI00<000000=WIf@3IfMT0303I
fMT200000180fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI01`0fMWI00<000000=WIf@3IfMT08P3IfMT00`000000fMWI0=WIf@060=WIf@8000002P3I
fMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT01@3I
fMT001/0fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0
fMWI0080fMWI2000000C0=WIf@030000003IfMT0fMWI00h0fMWI0P00000@0=WIf@030000003IfMT0
fMWI00P0fMWI00<000000=WIf@3IfMT00`3IfMT2000001l0fMWI00<000000=WIf@3IfMT08P3IfMT0
0`000000fMWI0=WIf@080=WIf@800000203IfMT00`000000fMWI0=WIf@0H0=WIf@030000003IfMT0
000000@0fMWI0P0000080=WIf@006`3IfMT00`000000fMWI0=WIf@0=0=WIf@8000005@3IfMT80000
01X0fMWI00<000000=WIf@3IfMT04@3IfMT2000000h0fMWI00<000000=WIf@3IfMT0203IfMT01000
0000fMWI0=WIf@3IfMT200000200fMWI00<000000=WIf@3IfMT08`3IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI00@0fMWI0P00000I0=WIf@80000000<0fMWI0000000000001@3IfMT0
0`000000fMWI0=WIf@050=WIf@006P3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI
00d0fMWI200000020=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT0503IfMT00`00
0000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT00P00000Q0=WI
f@030000003IfMT0fMWI02<0fMWI00<000000=WIf@3IfMT0303IfMT2000000H0fMWI00<000000=WI
f@3IfMT07@3IfMT010000000fMWI0=WIf@0000070=WIf@006P3IfMT00`000000fMWI0=WIf@0<0=WI
f@030000003IfMT0fMWI00L0fMWI1`0000090=WIf@030000003IfMT0fMWI01d0fMWI00<000000=WI
f@3IfMT05@3IfMT2000000/0fMWI00<000000=WIf@3IfMT01P3IfMT010000000fMWI0=WIf@00000S
0=WIf@030000003IfMT0fMWI02<0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI01h0fMWI0P0000080=WIf@006P3IfMT00`000000fMWI0=WIf@0;0=WI
f@030000003IfMT0fMWI0080fMWI1P00000?0=WIf@030000003IfMT0fMWI01d0fMWI00<000000=WI
f@3IfMT0603IfMT2000000T0fMWI00<000000=WIf@3IfMT01P3IfMT3000002<0fMWI00<000000=WI
f@3IfMT08`3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT01@3IfMT200000240fMWI000J0=WIf@030000003IfMT0fMWI00X0fMWI1P00000D0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT06`3IfMT2000000L0fMWI00<000000=WIf@3I
fMT01@3IfMT2000002@0fMWI00<000000=WIf@3IfMT0903IfMT00`000000fMWI0=WIf@0?0=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@00000P0=WI
f@006@3IfMT00`000000fMWI0=WIf@050=WIf@H000006P3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI02<0fMWI00<000000=WIf@3IfMT09@3IfMT00`000000fMWI0=WIf@0?0=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT010000000fMWI0=WIf@00000P0=WI
f@006@3IfMT00`000000fMWI0=WIf@020=WIf@<00000103IfMT00`000000fMWI0=WIf@0H0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT07`3IfMT2000000@0fMWI00<000000=WIf@3I
fMT00P3IfMT3000002D0fMWI00<000000=WIf@3IfMT0903IfMT00`000000fMWI0=WIf@0@0=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT010000000fMWI0=WIf@00000P0=WI
f@006@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI01L0fMWI00<000000=WIf@3I
fMT07@3IfMT00`000000fMWI0=WIf@0R0=WIf@8000000P3IfMT00`000000fMWI0=WIf@0200000003
0=WIf@000000fMWI02@0fMWI00<000000=WIf@3IfMT09@3IfMT00`000000fMWI0=WIf@0@0=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT010000000fMWI0=WIf@00000P0=WI
f@00603IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI01L0fMWI00<000000=WIf@3I
fMT0703IfMT00`000000fMWI0=WIf@0U0=WIf@D000000P3IfMT00`000000fMWI0=WIf@0S0=WIf@03
0000003IfMT0fMWI02D0fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@060=WIf@03
0000003IfMT0fMWI0080fMWI00@000000=WIf@3IfMT00000803IfMT001P0fMWI00<000000=WIf@3I
fMT02@3IfMT00`000000fMWI0=WIf@0G0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@3I
fMT0:03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02<0fMWI00<000000=WIf@3I
fMT09@3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00D0fMWI0P0000050=WIf@80
00008@3IfMT001P0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0F0=WIf@030000
003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT09P3IfMT5000000030=WIf@000000fMWI02@0fMWI
00<000000=WIf@3IfMT09@3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00@0fMWI
00<000000=WIf@000000:03IfMT001P0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WI
f@0E0=WIf@030000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT09@3IfMT200000080fMWI00<0
00000=WIf@3IfMT00P00000T0=WIf@030000003IfMT0fMWI02H0fMWI00<000000=WIf@3IfMT04@3I
fMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI02H0fMWI000G0=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT05@3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0
fMWI02@0fMWI0P0000040=WIf@050000003IfMT0fMWI0000003IfMT00P00000R0=WIf@030000003I
fMT0fMWI02D0fMWI00<000000=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI02D0fMWI000G0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT05@3IfMT0
0`000000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI02@0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI000000040=WIf@030000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT09@3IfMT0
0`000000fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT09@3IfMT0
01L0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI
01`0fMWI00<000000=WIf@3IfMT08P3IfMT2000000L0fMWI00<000000=WIf@0000001@3IfMT20000
01d0fMWI00<000000=WIf@3IfMT09P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI
00T0fMWI00<000000=WIf@3IfMT09@3IfMT001H0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000
fMWI0=WIf@0D0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT08@3IfMT2000000T0
fMWI0P0000080=WIf@8000006P3IfMT00`000000fMWI0=WIf@0V0=WIf@030000003IfMT0fMWI0140
fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0T0=WIf@005P3IfMT00`000000fMWI
0=WIf@0;0=WIf@800000503IfMT00`000000fMWI0=WIf@0K0=WIf@030000003IfMT0fMWI0200fMWI
0P00000;0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT05`3IfMT00`000000fMWI
0=WIf@0U0=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI
0=WIf@0T0=WIf@005P3IfMT00`000000fMWI0=WIf@0=0=WIf@8000004P3IfMT00`000000fMWI0=WI
f@0K0=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WI
f@0:0=WIf@8000005P3IfMT00`000000fMWI0=WIf@0U0=WIf@030000003IfMT0fMWI0140fMWI00<0
00000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@0T0=WIf@005P3IfMT00`000000fMWI0=WIf@0?
0=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT06`3IfMT00`000000fMWI0=WIf@0N
0=WIf@8000003@3IfMT2000000h0fMWI0P00000C0=WIf@030000003IfMT0fMWI02D0fMWI00<00000
0=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@0=0=WIf@8000009@3IfMT001D0fMWI00<000000=WI
f@3IfMT04@3IfMT2000000h0fMWI00<000000=WIf@3IfMT06`3IfMT00`000000fMWI0=WIf@0L0=WI
f@8000003P3IfMT00`000000fMWI0000000@0=WIf@8000004@3IfMT00`000000fMWI0=WIf@0U0=WI
f@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT03P3IfMT2000002D0fMWI000E0=WIf@03
0000003IfMT0fMWI01<0fMWI0P00000;0=WIf@030000003IfMT0fMWI01/0fMWI00<000000=WIf@3I
fMT06`3IfMT200000100fMWI00<000000=WIf@0000004P3IfMT00`000000fMWI0=WIf@0=0=WIf@03
0000003IfMT0fMWI02D0fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@0@0=WIf@03
0000003IfMT0fMWI02<0fMWI000E0=WIf@030000003IfMT0fMWI01D0fMWI0`0000080=WIf@030000
003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@0?0=WIf@040000
003IfMT0fMWI000001<0fMWI0P00000<0=WIf@030000003IfMT0fMWI02D0fMWI00<000000=WIf@3I
fMT04@3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI02<0fMWI000D0=WIf@030000
003IfMT0fMWI01T0fMWI1@0000030=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT0
6@3IfMT200000140fMWI00D000000=WIf@3IfMT0fMWI0000000E0=WIf@8000002P3IfMT00`000000
fMWI0=WIf@0T0=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT04`3IfMT00`000000
fMWI0=WIf@0R0=WIf@00503IfMT00`000000fMWI0=WIf@0N0=WIf@D000006`3IfMT00`000000fMWI
0=WIf@0G0=WIf@8000004`3IfMT01@000000fMWI0=WIf@3IfMT0000001L0fMWI0P0000070=WIf@03
0000003IfMT0fMWI02@0fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@0D0=WIf@03
0000003IfMT0fMWI0280fMWI000D0=WIf@030000003IfMT0fMWI0200fMWI00<000000=WIf@3IfMT0
1@00000E0=WIf@030000003IfMT0fMWI01L0fMWI00<000000=WIf@3IfMT04P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI01L0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI
0=WIf@0U0=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT05@3IfMT00`000000fMWI
0=WIf@0R0=WIf@00503IfMT00`000000fMWI0=WIf@0P0=WIf@030000003IfMT0fMWI00D0fMWI0`00
000A0=WIf@030000003IfMT0fMWI01H0fMWI0P00000D0=WIf@030000003IfMT0fMWI00<0fMWI00<0
00000=WIf@3IfMT0603IfMT200000080fMWI00<000000=WIf@3IfMT09@3IfMT00`000000fMWI0=WI
f@0?0=WIf@800000603IfMT00`000000fMWI0=WIf@0R0=WIf@004`3IfMT00`000000fMWI0=WIf@0P
0=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT0503IfMT2000001H0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0J0=WIf@<000009P3IfMT00`000000fMWI0=WIf@0>
0=WIf@8000006`3IfMT00`000000fMWI0=WIf@0Q0=WIf@004`3IfMT00`000000fMWI0=WIf@0P0=WI
f@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT04`3IfMT2000001L0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@0K0=WIf@8000009@3IfMT00`000000fMWI0=WIf@0>0=WI
f@030000003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT08@3IfMT001<0fMWI00<000000=WIf@3I
fMT07`3IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI0180fMWI00<000000=WIf@3I
fMT05P3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3I
fMT00P00000R0=WIf@030000003IfMT0fMWI00d0fMWI0P00000N0=WIf@8000008P3IfMT00180fMWI
00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI0140fMWI
0P00000I0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT06@3IfMT00`000000fMWI
0=WIf@030=WIf@800000803IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI01h0fMWI
0P00000R0=WIf@004P3IfMT00`000000fMWI0=WIf@0P0=WIf@030000003IfMT0fMWI01T0fMWI00<0
00000=WIf@3IfMT03`3IfMT2000001X0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WI
f@0I0=WIf@030000003IfMT0fMWI00D0fMWI0P00000M0=WIf@030000003IfMT0fMWI00/0fMWI0P00
000R0=WIf@030000003IfMT0fMWI0200fMWI000B0=WIf@030000003IfMT0fMWI01l0fMWI00<00000
0=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@0>0=WIf@8000006`3IfMT00`000000fMWI0=WIf@07
0=WIf@030000003IfMT0fMWI01P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0I
0=WIf@030000003IfMT0fMWI00X0fMWI0P00000T0=WIf@030000003IfMT0fMWI0200fMWI000B0=WI
f@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT0603IfMT00`000000fMWI0=WIf@0>0=WI
f@030000003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@0G0=WI
f@030000003IfMT0fMWI00X0fMWI0P00000H0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0903IfMT00`000000fMWI0=WIf@0P0=WIf@004@3IfMT00`000000fMWI0=WIf@0P0=WIf@03
0000003IfMT0fMWI01P0fMWI00<000000=WIf@3IfMT0303IfMT2000001d0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI00d0fMWI0P00000E0=WIf@03
0000003IfMT0fMWI00T0fMWI0P00000X0=WIf@030000003IfMT0fMWI01l0fMWI000A0=WIf@030000
003IfMT0fMWI0200fMWI00<000000=WIf@3IfMT05`3IfMT00`000000fMWI0=WIf@0;0=WIf@800000
7`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI01D0fMWI00<000000=WIf@3IfMT0
403IfMT200000140fMWI0P00000;0=WIf@030000003IfMT0fMWI02P0fMWI00<000000=WIf@3IfMT0
7`3IfMT00140fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0F0=WIf@030000003I
fMT0fMWI00T0fMWI0P00000P0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT05@3I
fMT00`000000fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT02@3I
fMT2000002/0fMWI00<000000=WIf@3IfMT07`3IfMT00100fMWI00<000000=WIf@3IfMT08P3IfMT0
0`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT07`3IfMT0
0`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI01@0fMWI00<000000=WIf@3IfMT0503IfMT2
000000`0fMWI00<000000=WIf@3IfMT0203IfMT2000002h0fMWI00<000000=WIf@3IfMT07P3IfMT0
0100fMWI00<000000=WIf@3IfMT08P3IfMT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI
00L0fMWI0P00000R0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT04`3IfMT00`00
0000fMWI0=WIf@0G0=WIf@8000002@3IfMT00`000000fMWI0=WIf@070=WIf@800000<03IfMT00`00
0000fMWI0=WIf@0N0=WIf@00403IfMT00`000000fMWI0=WIf@0R0=WIf@030000003IfMT0fMWI01@0
fMWI00<000000=WIf@3IfMT01P3IfMT2000002<0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000
fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000
fMWI0=WIf@060=WIf@800000<P3IfMT00`000000fMWI0=WIf@0N0=WIf@00403IfMT00`000000fMWI
0=WIf@0R0=WIf@030000003IfMT0fMWI01@0fMWI00<000000=WIf@3IfMT0103IfMT2000002@0fMWI
00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI01`0fMWI
0P0000040=WIf@030000003IfMT0fMWI00@0fMWI0`00000d0=WIf@8000007`3IfMT000l0fMWI00<0
00000=WIf@3IfMT08`3IfMT00`000000fMWI0=WIf@0C0=WIf@030000003IfMT0fMWI00@0fMWI00<0
00000=WIf@3IfMT0903IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI0140fMWI00<0
00000=WIf@3IfMT07P3IfMT2000000030=WIf@000000fMWI00@0fMWI0P00000h0=WIf@030000003I
fMT0fMWI01d0fMWI000?0=WIf@030000003IfMT0fMWI02@0fMWI00<000000=WIf@3IfMT04P3IfMT0
0`000000fMWI0=WIf@020=WIf@8000009P3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0
fMWI0100fMWI00<000000=WIf@3IfMT0803IfMT300000080fMWI0`00000j0=WIf@030000003IfMT0
fMWI01d0fMWI000?0=WIf@030000003IfMT0fMWI02@0fMWI00<000000=WIf@3IfMT04@3IfMT01000
0000fMWI0=WIf@3IfMT2000002L0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@0?
0=WIf@030000003IfMT0fMWI0200fMWI00<000000=WIf@3IfMT00`00000m0=WIf@030000003IfMT0
fMWI01d0fMWI000>0=WIf@030000003IfMT0fMWI02D0fMWI00<000000=WIf@3IfMT04@3IfMT01000
0000fMWI00000000000Y0=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT03P3IfMT0
0`000000fMWI0=WIf@0P0=WIf@040000003IfMT0000000000080fMWI0P00000m0=WIf@030000003I
fMT0fMWI01`0fMWI000>0=WIf@030000003IfMT0fMWI02D0fMWI00<000000=WIf@3IfMT04@3IfMT2
000002X0fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0
fMWI0200fMWI0`0000060=WIf@800000>`3IfMT00`000000fMWI0=WIf@0L0=WIf@003P3IfMT00`00
0000fMWI0=WIf@0U0=WIf@030000003IfMT0fMWI0100fMWI0P00000Z0=WIf@030000003IfMT0fMWI
0100fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0O0=WIf@8000002`3IfMT20000
03T0fMWI00<000000=WIf@3IfMT0703IfMT000h0fMWI00<000000=WIf@3IfMT09P3IfMT00`000000
fMWI0=WIf@0=0=WIf@<00000:`3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00`0
fMWI00<000000=WIf@3IfMT0703IfMT4000000h0fMWI00<000000=WIf@3IfMT0=P3IfMT00`000000
fMWI0=WIf@0L0=WIf@003@3IfMT00`000000fMWI0=WIf@0W0=WIf@030000003IfMT0fMWI00/0fMWI
0P0000020=WIf@030000003IfMT0fMWI02P0fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI
0=WIf@0;0=WIf@030000003IfMT0fMWI01/0fMWI0P0000020=WIf@030000003IfMT0fMWI00h0fMWI
0P00000g0=WIf@030000003IfMT0fMWI01/0fMWI000=0=WIf@030000003IfMT0fMWI02L0fMWI00<0
00000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02P0fMWI00<0
00000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI01T0fMWI0`00
00020=WIf@8000004`3IfMT2000003D0fMWI00<000000=WIf@3IfMT06`3IfMT000d0fMWI00<00000
0=WIf@3IfMT0:03IfMT00`000000fMWI0=WIf@070=WIf@800000103IfMT00`000000fMWI0=WIf@0X
0=WIf@030000003IfMT0fMWI0180fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0F
0=WIf@@00000103IfMT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI0380fMWI00<00000
0=WIf@3IfMT06`3IfMT000`0fMWI00<000000=WIf@3IfMT0:P3IfMT00`000000fMWI0=WIf@040=WI
f@8000001P3IfMT00`000000fMWI0=WIf@0W0=WIf@030000003IfMT0fMWI01<0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@0D0=WIf@<000001`3IfMT00`000000fMWI0=WIf@0G0=WI
f@800000<`3IfMT00`000000fMWI0=WIf@0J0=WIf@00303IfMT00`000000fMWI0=WIf@0[0=WIf@80
00000`3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI02L0fMWI00<000000=WIf@3I
fMT04`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0100fMWI100000090=WIf@03
0000003IfMT0fMWI01X0fMWI0P00000`0=WIf@800000703IfMT000`0fMWI00<000000=WIf@3IfMT0
;@3IfMT3000000T0fMWI00<000000=WIf@3IfMT09P3IfMT00`000000fMWI0=WIf@0D0=WIf@030000
003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT03P3IfMT3000000/0fMWI0P00000O0=WIf@800000
;`3IfMT00`000000fMWI0=WIf@0J0=WIf@00303IfMT00`000000fMWI0=WIf@0/0=WIf@<000002@3I
fMT00`000000fMWI0=WIf@0V0=WIf@030000003IfMT0fMWI01D0fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@0<0=WIf@<000003@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003I
fMT0fMWI02`0fMWI00<000000=WIf@3IfMT06P3IfMT000/0fMWI00<000000=WIf@3IfMT0:`3IfMT2
000000<0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@0V0=WIf@030000003IfMT0
fMWI01D0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@090=WIf@@000003P3IfMT2
000002D0fMWI0P00000]0=WIf@030000003IfMT0fMWI01T0fMWI000;0=WIf@030000003IfMT0fMWI
02X0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI
02D0fMWI00<000000=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
00L0fMWI0`00000@0=WIf@800000:@3IfMT2000002/0fMWI00<000000=WIf@3IfMT06@3IfMT000/0
fMWI00<000000=WIf@3IfMT0:03IfMT2000000P0fMWI0P0000040=WIf@030000003IfMT0fMWI02D0
fMWI00<000000=WIf@3IfMT05`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0
fMWI1000000B0=WIf@030000003IfMT0fMWI02/0fMWI0P00000Y0=WIf@030000003IfMT0fMWI01T0
fMWI000:0=WIf@030000003IfMT0fMWI02L0fMWI0P00000<0=WIf@050000003IfMT0fMWI0=WIf@00
00009`3IfMT00`000000fMWI0=WIf@0G0=WIf@030000003IfMT0fMWI0080fMWI00@000000=WIf@3I
fMT0fMWI1000000D0=WIf@800000<03IfMT00`000000fMWI0=WIf@0W0=WIf@030000003IfMT0fMWI
00<0fMWI1000000A0=WIf@002P3IfMT00`000000fMWI0=WIf@0U0=WIf@8000003`3IfMT4000002H0
fMWI00<000000=WIf@3IfMT0603IfMT010000000fMWI0=WIf@3IfMT5000001L0fMWI00<000000=WI
f@3IfMT0<@3IfMT2000002L0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0@0=WI
f@002P3IfMT00`000000fMWI0=WIf@0T0=WIf@030000003IfMT0fMWI0180fMWI1000000R0=WIf@03
0000003IfMT0fMWI01P0fMWI1P00000I0=WIf@800000=P3IfMT2000002D0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000fMWI0=WIf@0@0=WIf@002@3IfMT00`000000fMWI0=WIf@0S0=WIf@800000
503IfMT00`000000fMWI0=WIf@020=WIf@@000007P3IfMT00`000000fMWI0=WIf@0B0=WIf@H00000
00D0fMWI0000003IfMT0fMWI0000000H0=WIf@800000>P3IfMT00`000000fMWI0=WIf@0S0=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0403IfMT000T0fMWI00<000000=WIf@3IfMT0
8@3IfMT2000001H0fMWI00<000000=WIf@3IfMT01P3IfMT4000001T0fMWI00<000000=WIf@3IfMT0
3P3IfMT5000000L0fMWI00<000000=WIf@000000603IfMT00`000000fMWI0=WIf@0k0=WIf@800000
8`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0100fMWI00090=WIf@030000003I
fMT0fMWI01l0fMWI0P00000H0=WIf@030000003IfMT0fMWI00X0fMWI1000000D0=WIf@030000003I
fMT0fMWI00X0fMWI1@00000<0=WIf@8000005`3IfMT200000400fMWI0P00000Q0=WIf@030000003I
fMT0fMWI0080fMWI0`00000B0=WIf@002@3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0
fMWI01P0fMWI00<000000=WIf@3IfMT03P3IfMTQ00000140fMWI00<000000=WIf@3IfMT05@3IfMT0
0`000000fMWI0=WIf@120=WIf@8000007P3IfMT2000000H0fMWI00<000000=WIf@3IfMT0403IfMT0
00P0fMWI00<000000=WIf@3IfMT07@3IfMT2000001`0fMWI00<000000=WIf@3IfMT0803IfMT00`00
0000fMWI0=WIf@0K0=WIf@8000005@3IfMT2000004L0fMWI00<000000=WIf@3IfMT07@3IfMT00`00
0000fMWI0=WIf@0F0=WIf@00203IfMT00`000000fMWI0=WIf@0K0=WIf@8000007P3IfMT00`000000
fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI01/0fMWI00<000000=WIf@0000004`3IfMT2000004X0
fMWI0P00000M0=WIf@030000003IfMT0fMWI01H0fMWI00080=WIf@030000003IfMT0fMWI01T0fMWI
0P00000P0=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT06P3IfMT010000000fMWI
0=WIf@00000B0=WIf@030000003IfMT0fMWI04`0fMWI0P00000K0=WIf@030000003IfMT0fMWI01H0
fMWI00070=WIf@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI
0=WIf@0N0=WIf@030000003IfMT0fMWI01X0fMWI00D000000=WIf@3IfMT0fMWI0000000@0=WIf@80
0000D@3IfMT2000001X0fMWI00<000000=WIf@3IfMT05@3IfMT000L0fMWI00<000000=WIf@3IfMT0
5`3IfMT2000002<0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0J0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT2000005D0fMWI00<000000=WIf@3IfMT0
5`3IfMT00`000000fMWI0=WIf@0E0=WIf@001`3IfMT00`000000fMWI0=WIf@0E0=WIf@8000009@3I
fMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT00`3I
fMT00`000000fMWI0=WIf@0:0=WIf@800000F03IfMT2000001L0fMWI00<000000=WIf@3IfMT05@3I
fMT000L0fMWI00<000000=WIf@3IfMT04`3IfMT2000002P0fMWI00<000000=WIf@3IfMT06`3IfMT0
0`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT2
000005`0fMWI0P00000E0=WIf@030000003IfMT0fMWI01D0fMWI00060=WIf@030000003IfMT0fMWI
01<0fMWI00<000000=WIf@3IfMT0:03IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI
01X0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@060=WIf@800000H03IfMT00`00
0000fMWI0=WIf@0C0=WIf@030000003IfMT0fMWI01@0fMWI00060=WIf@030000003IfMT0fMWI0140
fMWI0P00000[0=WIf@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT06P3IfMT00`000000
fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI0`00001S0=WIf@8000004`3IfMT00`000000
fMWI0=WIf@0D0=WIf@001P3IfMT00`000000fMWI0=WIf@0?0=WIf@800000;@3IfMT00`000000fMWI
0=WIf@0I0=WIf@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT01P3IfMT010000000fMWI
0=WIf@3IfMT2000006P0fMWI0P00000A0=WIf@030000003IfMT0fMWI01@0fMWI00050=WIf@030000
003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000fMWI0=WIf@0H0=WIf@030000
003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT01`3IfMT010000000fMWI00000000001/0=WIf@80
0000403IfMT00`000000fMWI0=WIf@0C0=WIf@001@3IfMT00`000000fMWI0=WIf@0=0=WIf@800000
<@3IfMT00`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT0
203IfMT200000700fMWI00<000000=WIf@3IfMT0303IfMT2000001D0fMWI00050=WIf@030000003I
fMT0fMWI00/0fMWI0P00000c0=WIf@030000003IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT0603I
fMT00`000000fMWI0=WIf@060=WIf@@00000LP3IfMT2000000d0fMWI00<000000=WIf@3IfMT04`3I
fMT000D0fMWI00<000000=WIf@3IfMT02@3IfMT2000003D0fMWI00<000000=WIf@3IfMT05@3IfMT0
0`000000fMWI0=WIf@0H0=WIf@030000003IfMT0fMWI00D0fMWI0P0000030=WIf@030000003IfMT0
fMWI0780fMWI0P00000;0=WIf@030000003IfMT0fMWI01<0fMWI00040=WIf@030000003IfMT0fMWI
00T0fMWI00<000000=WIf@3IfMT0=P3IfMT2000001D0fMWI00<000000=WIf@3IfMT05`3IfMT00`00
0000fMWI0=WIf@040=WIf@8000001@3IfMT00`000000fMWI0=WIf@1d0=WIf@8000002P3IfMT00`00
0000fMWI0=WIf@0B0=WIf@00103IfMT00`000000fMWI0=WIf@070=WIf@800000>`3IfMT00`000000
fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI01L0fMWI00<000000=WIf@3IfMT00`3IfMT2000000L0
fMWI00<000000=WIf@3IfMT0MP3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0180
fMWI00040=WIf@030000003IfMT0fMWI00D0fMWI0P00000n0=WIf@030000003IfMT0fMWI0100fMWI
00<000000=WIf@3IfMT05@3IfMT200000080fMWI100000090=WIf@030000003IfMT0fMWI07L0fMWI
0P0000070=WIf@030000003IfMT0fMWI0180fMWI00030=WIf@030000003IfMT0fMWI00@0fMWI0P00
00110=WIf@8000003`3IfMT00`000000fMWI0=WIf@0E0=WIf@D000003@3IfMT00`000000fMWI0=WI
f@1i0=WIf@8000001P3IfMT00`000000fMWI0=WIf@0A0=WIf@000`3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI04<0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0B
0=WIf@@000004@3IfMT00`000000fMWI0=WIf@1k0=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT04@3IfMT000<0fMWI00@000000=WIf@3IfMT0fMWI0P0000170=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT03`3IfMT4000000030=WIf@000000fMWI0180fMWI00<00000
0=WIf@3IfMT0O03IfMT2000000<0fMWI00<000000=WIf@3IfMT04@3IfMT000<0fMWI00@000000=WI
f@0000000000BP3IfMT2000000X0fMWI00<000000=WIf@3IfMT02`3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@1n0=WIf@80000000<0fMWI0000003IfMT04P3IfMT0
0080fMWI0`00001>0=WIf@X000002P3IfMT4000000L0fMWI00<000000=WIf@3IfMT04`3IfMT00`00
0000fMWI0=WIf@200=WIf@<000004P3IfMT00080fMWI0`00001G0=WIf@/000002P3IfMT00`000000
fMWI0=WIf@0D0=WIf@030000003IfMT0fMWI0800fMWI0`00000B0=WIf@001@3IfMT400000580fMWI
00<000000=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI07P0fMWI
00@000000=WIf@3IfMT0fMWI1000000E0=WIf@002@3IfMT4000004h0fMWI00<000000=WIf@3IfMT0
403IfMT2000001P0fMWI00<000000=WIf@3IfMT0N03IfMT4000001T0fMWI000=0=WIf@@00000B@3I
fMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI01P0fMWI00<000000=WIf@3IfMT0M03I
fMT4000000030=WIf@000000fMWI01X0fMWI000A0=WIf@@00000A@3IfMT00`000000fMWI0=WIf@0?
0=WIf@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT0KP3IfMT00`000000fMWI00000003
00000240fMWI000E0=WIf@@00000@03IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI
01X0fMWI00<000000=WIf@3IfMT0K03IfMT4000002D0fMWI000I0=WIf@@00000?03IfMT00`000000
fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT0I@3IfMT00`000000
fMWI0=WIf@04000002T0fMWI000M0=WIf@@00000=`3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT0I03IfMT4000002d0fMWI000Q0=WIf@@00000<`3I
fMT00`000000fMWI0=WIf@0<0=WIf@8000007`3IfMT00`000000fMWI0=WIf@1P0=WIf@@0000000<0
fMWI0000003IfMT0;P3IfMT002D0fMWI1000000_0=WIf@030000003IfMT0fMWI00/0fMWI00<00000
0=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@1L0=WIf@@000005@3IfMT2000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0@0=WIf@00:@3IfMT4000002/0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@0P0=WIf@030000003IfMT0fMWI05<0fMWI00<000000=WI
f@3IfMT00P3IfMT5000001L0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI0=WIf@0@
0=WIf@00;@3IfMT4000002L0fMWI00<000000=WIf@3IfMT0203IfMT2000002<0fMWI00<000000=WI
f@3IfMT0D`3IfMT5000001`0fMWI00@000000=WIf@3IfMT000001`3IfMT500000140fMWI000a0=WI
f@@000008`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI02<0fMWI00<000000=WI
f@3IfMT0D03IfMT5000001l0fMWI00@000000=WIf@3IfMT000001`3IfMT010000000fMWI0=WIf@00
000B0=WIf@00=@3IfMT4000001h0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@0T
0=WIf@030000003IfMT0fMWI04/0fMWI1@00000T0=WIf@040000003IfMT0fMWI000000P0fMWI00<0
00000=WIf@0000004P3IfMT003T0fMWI1000000J0=WIf@030000003IfMT0fMWI00D0fMWI0P00000W
0=WIf@030000003IfMT0fMWI04P0fMWI1000000X0=WIf@040000003IfMT0fMWI000000T0fMWI0P00
000B0=WIf@00?@3IfMT4000001H0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0W
0=WIf@030000003IfMT0fMWI04<0fMWI1@00000]0=WIf@8000002`3IfMT00`000000fMWI0=WIf@0@
0=WIf@00@@3IfMT400000180fMWI1`00000Z0=WIf@030000003IfMT0fMWI0400fMWI1000001A0=WI
f@00A@3IfMT5000003h0fMWI00<000000=WIf@3IfMT0?03IfMT4000005D0fMWI001:0=WIf@@00000
>P3IfMT00`000000fMWI0=WIf@0d0=WIf@040000003IfMT0fMWI0=WIf@D00000F03IfMT004h0fMWI
1000000f0=WIf@030000003IfMT0fMWI03@0fMWI1000000G0=WIf@800000103IfMT00`000000fMWI
0=WIf@020=WIf@@00000=`3IfMT00580fMWI1000000b0=WIf@030000003IfMT0fMWI02d0fMWI00<0
00000=WIf@3IfMT01@00000I0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0
>03IfMT005H0fMWI1000000^0=WIf@030000003IfMT0fMWI02`0fMWI1000000N0=WIf@040000003I
fMT0fMWI000000T0fMWI00<000000=WIf@3IfMT0=`3IfMT005X0fMWI1000000Z0=WIf@030000003I
fMT0fMWI02H0fMWI00<000000=WIf@0000000`00000R0=WIf@040000003IfMT0fMWI000000X0fMWI
00<000000=WIf@3IfMT0=P3IfMT005h0fMWI1000000V0=WIf@030000003IfMT0fMWI02@0fMWI1000
000V0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT0=@3IfMT00680fMWI1000
000R0=WIf@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT0103IfMT4000002X0fMWI00@0
00000=WIf@3IfMT00000203IfMT010000000fMWI0=WIf@00000g0=WIf@00IP3IfMT4000001h0fMWI
00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@05000002h0fMWI0P00000:0=WIf@800000
>03IfMT006X0fMWI1000000J0=WIf@030000003IfMT0fMWI01P0fMWI1000000H0=WIf@800000G`3I
fMT006h0fMWI1000000F0=WIf@030000003IfMT0fMWI01<0fMWI1@00000K0=WIf@040000003IfMT0
fMWI000005h0fMWI001b0=WIf@@000004P3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0
fMWI00@000007`3IfMT010000000fMWI0=WIf@00001N0=WIf@00MP3IfMT4000000h0fMWI00<00000
0=WIf@3IfMT0303IfMT4000002<0fMWI00@000000=WIf@3IfMT00000GP3IfMT007X0fMWI1000000:
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT5000002L0fMWI00@00000
0=WIf@3IfMT00000GP3IfMT007h0fMWI100000060=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@0000000`00000[0=WIf@040000003IfMT0fMWI000005h0fMWI00220=WIf@@000000P3IfMT0
0`000000fMWI0=WIf@0400000300fMWI0P00001O0=WIf@00QP3IfMT5000001H0fMWI0P0000040=WI
f@030000003IfMT0fMWI0080fMWI1000001`0=WIf@00X03IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI0740fMWI002P0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WI
f@3IfMT0L03IfMT009X0fMWI100000020=WIf@040000003IfMT0fMWI000000X0fMWI00<000000=WI
f@3IfMT0K`3IfMT00:00fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@1^0=WI
f@00X03IfMT010000000fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI00000700fMWI00290=WI
f@800000103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI0P00000:0=WI
f@800000L@3IfMT008P0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI0=WIf@270=WI
f@00R03IfMT010000000fMWI0=WIf@0000070=WIf@D00000R03IfMT00880fMWI100000020=WIf@04
0000003IfMT0fMWI000000L0fMWI00@000000=WIf@3IfMT00000R@3IfMT008P0fMWI00@000000=WI
f@3IfMT00000203IfMT00`000000fMWI000000290=WIf@00R03IfMT010000000fMWI0=WIf@000009
0=WIf@800000R@3IfMT008T0fMWI0P00000;0=WIf@030000003IfMT0fMWI08L0fMWI002m0=WIf@80
000000<0fMWI0000000000000P3IfMT4000005P0fMWI002n0=WIf@030000003IfMT0000000<0fMWI
00<000000=WIf@3IfMT0F@3IfMT00;l0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WI
f@1H0=WIf@00_P3IfMT00`000000fMWI000000050=WIf@030000003IfMT0fMWI05L0fMWI002m0=WI
f@80000000<0fMWI0000000000001@3IfMT00`000000fMWI0=WIf@1F0=WIf@00a03IfMT010000000
fMWI0=WIf@00001H0=WIf@00a@3IfMT2000005T0fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287}, {284, 0}} -> {0.0599755, -4.43509*^-6, \
0.00323508, 0.00323508}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Evaluatable->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(number = 16\ \ \  (*\ 
        for\ more\ frames\ make\ number\ larger\ *) ;\)\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(Do[
        ListPlot[\[IndentingNewLine]\({{x1[t] - 2, 0}, {x2[t], 
                    0}, {x3[t] + 2, 0}} //. 
                allRules\)\[IndentingNewLine] //. {c1 \[Rule] 0, 
                c2 \[Rule] 1, c3 \[Rule] 0}\ \[IndentingNewLine] // 
            Evaluate, \[IndentingNewLine]PlotStyle \[Rule] {PointSize[
                0.05]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-4\), 
                4}, {\(-1\), 1}}], \[IndentingNewLine]{t, 0, 
          2\ \[Pi] \((1 - 1/number)\), 2\ \[Pi]\ /number}];\)\)\)], "Input",
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.33839 .30902 Mdot
.5 .30902 Mdot
.66161 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0>0=WIf@H0
00002P3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@050=WIf@H0
00005@3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3I
fMT000003P3IfMT:000000H0fMWI0`00000I0=WIf@X000006P3IfMT3000000D0fMWI2P00000@0=WI
f@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P00000P0=WIf@8000003`3IfMT:000000P0fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT00`3IfMT:00000140fMWI0P00000P
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00G`3IfMT<00000200fMWI3000000P0=WI
f@`00000G@3IfMT005l0fMWI3000000P0=WIf@`00000803IfMT<000005d0fMWI001O0=WIf@`00000
803IfMT<00000200fMWI3000001M0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT00P3IfMT<000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT>000000H0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT00P3IfMT<000000@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI00<000000=WI
f@3IfMT07`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00l0fMWI300000040=WI
f@030000003IfMT0fMWI01T0fMWI3000000K0=WIf@030000003IfMT0fMWI0080fMWI3000000A0=WI
f@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@050=WI
f@00H03IfMT:00000280fMWI2P00000R0=WIf@X00000GP3IfMT00600fMWI2P00000R0=WIf@X00000
8P3IfMT:000005h0fMWI001R0=WIf@H000009P3IfMT6000002H0fMWI1P00001P0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@80
0000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00P3IfMT400000080fMWI
0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI
00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI
001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI
0=WIf@030=WIf@800000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI
0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT0
00002`3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@04
0000003IfMT0fMWI000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@06
0=WIf@030000003IfMT0fMWI08`0fMWI001g0=WIf@8000002P3IfMT2000000<0fMWI100000050=WI
f@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000
003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT0
07d0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI
00<0fMWI0P00002=0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT00`00
0000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001m0=WIf@8000002@3IfMT4000000D0
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@00000:0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT00`3IfMT2000008d0fMWI001f0=WIf@040000003IfMT0fMWI000000X0fMWI00@000000=WIf@3I
fMT0fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI0000
00/0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT01000
0000fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@2<0=WIf@00M`3IfMT2000000T0fMWI100000020=WIf@@000001@3IfMT2
000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI0028
0=WIf@@000001@3IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00
RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00R03IfMT3
000009D0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.33669 .30902 Mdot
.5 .30902 Mdot
.66331 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0>0=WIf@H0
00002P3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@060=WIf@H0
0000503IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3I
fMT000003P3IfMT:000000H0fMWI0`00000I0=WIf@X000006P3IfMT3000000H0fMWI2P00000?0=WI
f@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P00000P0=WIf@8000003`3IfMT:000000P0fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT0103IfMT:00000100fMWI0P00000P
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00G`3IfMT<00000200fMWI3000000Q0=WI
f@`00000G03IfMT005l0fMWI3000000P0=WIf@`000008@3IfMT<000005`0fMWI001O0=WIf@`00000
803IfMT<00000240fMWI3000001L0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT00P3IfMT<000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT>000000H0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT00`3IfMT<000000<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI00<000000=WI
f@3IfMT07`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00l0fMWI300000040=WI
f@030000003IfMT0fMWI01T0fMWI3000000K0=WIf@030000003IfMT0fMWI00<0fMWI3000000@0=WI
f@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@050=WI
f@00H03IfMT:00000280fMWI2P00000S0=WIf@X00000G@3IfMT00600fMWI2P00000R0=WIf@X00000
8`3IfMT:000005d0fMWI001R0=WIf@H000009P3IfMT6000002L0fMWI1P00001O0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@80
0000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00P3IfMT400000080fMWI
0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI
00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI
001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI
0=WIf@030=WIf@800000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI
0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT0
00002`3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@04
0000003IfMT0fMWI000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@06
0=WIf@030000003IfMT0fMWI08`0fMWI001g0=WIf@8000002P3IfMT2000000<0fMWI100000050=WI
f@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000
003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT0
07d0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI
00<0fMWI0P00002=0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT00`00
0000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001m0=WIf@8000002@3IfMT4000000D0
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@00000:0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT00`3IfMT2000008d0fMWI001f0=WIf@040000003IfMT0fMWI000000X0fMWI00@000000=WIf@3I
fMT0fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI0000
00/0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT01000
0000fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@2<0=WIf@00M`3IfMT2000000T0fMWI100000020=WIf@@000001@3IfMT2
000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI0028
0=WIf@@000001@3IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00
RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00R03IfMT3
000009D0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.33166 .30902 Mdot
.5 .30902 Mdot
.66834 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0=0=WIf@H0
00002`3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@070=WIf@H0
00004`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3I
fMT000003@3IfMT:000000L0fMWI0`00000I0=WIf@X000006P3IfMT3000000L0fMWI2P00000>0=WI
f@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P00000P0=WIf@8000003P3IfMT:000000T0fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT01@3IfMT:000000l0fMWI0P00000P
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00GP3IfMT<00000240fMWI3000000R0=WI
f@`00000F`3IfMT005h0fMWI3000000Q0=WIf@`000008P3IfMT<000005/0fMWI001N0=WIf@`00000
8@3IfMT<00000280fMWI3000001K0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00@00000
0=WIf@3IfMT0fMWI300000050=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI3P0000060=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003I
fMT0fMWI00@0fMWI300000020=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D0fMWI00090=WIf@030000003IfMT0
fMWI01l0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0>0=WIf@`000001@3IfMT0
0`000000fMWI0=WIf@0I0=WIf@`000006`3IfMT00`000000fMWI0=WIf@040=WIf@`000003`3IfMT0
0`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT01@3IfMT0
05l0fMWI2P00000S0=WIf@X00000903IfMT:000005`0fMWI001O0=WIf@X000008`3IfMT:000002@0
fMWI2P00001L0=WIf@00H@3IfMT6000002L0fMWI1P00000X0=WIf@H00000GP3IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3I
fMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT20000
08d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI100000020=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000080=WIf@03
0000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT00`3IfMT2000008d0fMWI001f0=WIf@040000003IfMT0fMWI000000X0fMWI00@000000=WIf@3I
fMT0fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI0000
00/0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT01000
0000fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@2<0=WIf@00M`3IfMT2000000X0fMWI0P0000030=WIf@@000001@3IfMT2
000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001m
0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<
0=WIf@00O03IfMT010000000fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@03
0=WIf@800000S@3IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<00000
0=WIf@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@06
0=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<00000
0=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WI
f@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000
003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT0
07L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT30000
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002@3IfMT00`00
0000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0
fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
00<0fMWI0P00002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI
0=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;
0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@00000
0=WIf@3IfMT00000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI
00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000090=WIf@@000000P3IfMT4000000D0fMWI0P00
002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00R03I
fMT4000000D0fMWI00<000000=WIf@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT008X0
fMWI00<000000=WIf@3IfMT0T`3IfMT008X0fMWI00<000000=WIf@3IfMT0T`3IfMT008P0fMWI0`00
002E0=WIf@00RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.32349 .30902 Mdot
.5 .30902 Mdot
.67651 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0:0=WIf@H0
00003P3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@090=WIf@H0
00004@3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3I
fMT000002P3IfMT:000000X0fMWI0`00000I0=WIf@X000006P3IfMT3000000T0fMWI2P00000<0=WI
f@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P00000P0=WIf@8000002`3IfMT:000000`0fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT01`3IfMT:000000d0fMWI0P00000P
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00F`3IfMT<000002@0fMWI3000000T0=WI
f@`00000F@3IfMT005/0fMWI3000000T0=WIf@`00000903IfMT<000005T0fMWI001K0=WIf@`00000
903IfMT<000002@0fMWI3000001I0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI3@000000
0`3IfMT000000=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI3P0000060=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@000000300000060=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@050=WIf@002@3IfMT00`000000fMWI0=WIf@0O0=WI
f@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT02`3IfMT<000000P0fMWI00<000000=WI
f@3IfMT06@3IfMT<000001/0fMWI00<000000=WIf@3IfMT01P3IfMT<000000d0fMWI00<000000=WI
f@3IfMT07`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00D0fMWI001L0=WIf@X0
00009P3IfMT:000002H0fMWI2P00001J0=WIf@00G03IfMT:000002H0fMWI2P00000V0=WIf@X00000
FP3IfMT005h0fMWI1P00000Z0=WIf@H00000:P3IfMT6000005`0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI001g0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@@000000P3IfMT3000000H0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI
0=WIf@060=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
0P00002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@04
0000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3I
fMT00000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<00000
0=WIf@3IfMT0S03IfMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3I
fMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3IfMT20000
00@0fMWI00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT20000
08d0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI0`0000060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000090=WIf@@000001@3IfMT2000008d0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001g0=WIf@80
0000103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@03
0000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000
003IfMT0fMWI000000X0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@80
0000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT30000
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT01000
0000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI
000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003I
fMT0fMWI08`0fMWI001g0=WIf@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT0
0940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<
0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT008P0fMWI10000005
0=WIf@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT2000008d0fMWI002:0=WIf@030000
003IfMT0fMWI09<0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI00280=WIf@<00000U@3IfMT0
08X0fMWI00<000000=WIf@3IfMT0T`3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.3125 .30902 Mdot
.5 .30902 Mdot
.6875 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@070=WIf@H0
00004@3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@0<0=WIf@H0
00003P3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3I
fMT000001`3IfMT:000000d0fMWI0`00000I0=WIf@X000006P3IfMT3000000`0fMWI2P0000090=WI
f@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P00000P0=WIf@800000203IfMT:000000l0fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT02P3IfMT:000000X0fMWI0P00000P
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00F03IfMT<000002L0fMWI3000000W0=WI
f@`00000EP3IfMT005P0fMWI3000000W0=WIf@`000009`3IfMT<000005H0fMWI001H0=WIf@`00000
9`3IfMT<000002L0fMWI3000001F0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI30000004
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT>000000H0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@020=WIf@`00000103IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI00<000000=WI
f@3IfMT07`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00P0fMWI3000000;0=WI
f@030000003IfMT0fMWI01T0fMWI3000000K0=WIf@030000003IfMT0fMWI00T0fMWI3000000:0=WI
f@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@050=WI
f@00F@3IfMT:000002T0fMWI2P00000Y0=WIf@X00000E`3IfMT005T0fMWI2P00000Y0=WIf@X00000
:@3IfMT:000005L0fMWI001K0=WIf@H00000;@3IfMT6000002d0fMWI1P00001I0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@80
0000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00P3IfMT400000080fMWI
0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI
00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI
001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI
0=WIf@030=WIf@800000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI
0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT0
00002`3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@04
0000003IfMT0fMWI000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@06
0=WIf@030000003IfMT0fMWI08`0fMWI001g0=WIf@8000002P3IfMT2000000<0fMWI100000050=WI
f@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000
003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT0
07d0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI
00<0fMWI0P00002=0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT00`00
0000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001m0=WIf@8000002@3IfMT4000000D0
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@00000:0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT00`3IfMT2000008d0fMWI001f0=WIf@040000003IfMT0fMWI000000X0fMWI00@000000=WIf@3I
fMT0fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI0000
00/0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT01000
0000fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@2<0=WIf@00M`3IfMT2000000T0fMWI100000020=WIf@@000001@3IfMT2
000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI0028
0=WIf@@000001@3IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00
RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00R03IfMT3
000009D0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.29911 .30902 Mdot
.5 .30902 Mdot
.70089 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@040=WIf@H0
0000503IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@0@0=WIf@H0
00002P3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3I
fMT00000103IfMT:00000100fMWI0`00000I0=WIf@X000006P3IfMT300000100fMWI2P0000050=WI
f@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P00000P0=WIf@8000001@3IfMT:00000180fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT03P3IfMT:000000H0fMWI0P00000P
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00E@3IfMT<000002X0fMWI3000000[0=WI
f@`00000DP3IfMT005D0fMWI3000000Z0=WIf@`00000:`3IfMT<00000580fMWI001E0=WIf@`00000
:P3IfMT<000002/0fMWI3000001B0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0000000`000001P3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI3P0000060=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0000000<000000D0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@050=WIf@002@3IfMT00`000000fMWI0=WIf@0O0=WI
f@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT01@3IfMT<000000h0fMWI00<000000=WI
f@3IfMT06@3IfMT<000001/0fMWI00<000000=WIf@3IfMT03@3IfMT<000000H0fMWI00<000000=WI
f@3IfMT07`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00D0fMWI001F0=WIf@X0
0000;03IfMT:000002d0fMWI2P00001C0=WIf@00EP3IfMT:000002`0fMWI2P00000]0=WIf@X00000
D`3IfMT005P0fMWI1P00000`0=WIf@H00000<@3IfMT6000005D0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI001g0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@@000000P3IfMT3000000H0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI
0=WIf@060=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
0P00002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@04
0000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3I
fMT00000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<00000
0=WIf@3IfMT0S03IfMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3I
fMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3IfMT20000
00@0fMWI00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT20000
08d0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI0`0000060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000090=WIf@@000001@3IfMT2000008d0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001g0=WIf@80
0000103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@03
0000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000
003IfMT0fMWI000000X0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@80
0000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT30000
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT01000
0000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI
000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003I
fMT0fMWI08`0fMWI001g0=WIf@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT0
0940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<
0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT008P0fMWI10000005
0=WIf@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT2000008d0fMWI002:0=WIf@030000
003IfMT0fMWI09<0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI00280=WIf@<00000U@3IfMT0
08X0fMWI00<000000=WIf@3IfMT0T`3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.28382 .30902 Mdot
.5 .30902 Mdot
.71618 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@06000001P0
fMWI00<000000=WIf@3IfMT06@3IfMT6000001h0fMWI00<000000=WIf@3IfMT0503IfMT6000000H0
fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0000000L0
fMWI000;0=WIf@8000007`3IfMT010000000fMWI0=WIf@00000N0=WIf@030000003IfMT0fMWI00/0
0000503IfMT3000001T0fMWI2P00000J0=WIf@<00000503IfMT:000000050=WIf@000000fMWI0=WI
f@0000007P3IfMT010000000fMWI0=WIf@00000O0=WIf@8000001`3IfMT000`0fMWI00<000000=WI
f@3IfMT07P3IfMT200000200fMWI0P0000000`3IfMT0000000000008000001H0fMWI00<000000=WI
f@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT04P3IfMT:00000080fMWI0P00000P0=WI
f@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00D@3IfMT<000002h0fMWI3000000_0=WIf@`0
0000CP3IfMT00540fMWI3000000^0=WIf@`00000;`3IfMT<000004h0fMWI001A0=WIf@`00000;P3I
fMT<000002l0fMWI3000001>0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0103IfMT010000000fMWI0=WIf@3IfMT<000000@0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI3P0000060=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@`000000P3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D0fMWI00090=WIf@030000003IfMT0fMWI
01l0fMWI00<000000=WIf@3IfMT07`3IfMT010000000fMWI0=WIf@3IfMT<00000180fMWI00<00000
0=WIf@3IfMT06@3IfMT<000001/0fMWI00<000000=WIf@3IfMT04@3IfMT<00000080fMWI00<00000
0=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00D0fMWI001B0=WI
f@X00000<03IfMT:00000340fMWI2P00001?0=WIf@00DP3IfMT:00000300fMWI2P00000a0=WIf@X0
0000C`3IfMT005@0fMWI1P00000d0=WIf@H00000=@3IfMT600000540fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3I
fMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI001g0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@@000000P3IfMT3000000H0
fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000
fMWI0=WIf@060=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI
00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0
fMWI0P00002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WI
f@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WI
f@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WI
f@3IfMT00000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<0
00000=WIf@3IfMT0S03IfMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=
0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3IfMT2
000000@0fMWI00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT0
07`0fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT2
000008d0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI0`0000060=WIf@030000003IfMT0
fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0
fMWI00H0fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000090=WIf@@000001@3IfMT20000
08d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@800000103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WI
f@3IfMT01@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@04
0000003IfMT0fMWI000000X0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WI
f@800000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3
000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT0
10000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0
fMWI000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000
003IfMT0fMWI08`0fMWI001g0=WIf@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT008P0fMWI1000
00050=WIf@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT2000008d0fMWI002:0=WIf@03
0000003IfMT0fMWI09<0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI00280=WIf@<00000U@3I
fMT008X0fMWI00<000000=WIf@3IfMT0T`3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.26724 .30902 Mdot
.5 .30902 Mdot
.73276 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT07@3IfMT6000001d0fMWI00<000000=WIf@3I
fMT06@3IfMT6000001h0fMWI00<000000=WIf@3IfMT0603IfMT600000080fMWI00<000000=WIf@3I
fMT07`3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0000000L0fMWI000;0=WIf@800000
7`3IfMT010000000fMWI0=WIf@00000M0=WIf@X000006@3IfMT3000001T0fMWI2P00000J0=WIf@<0
0000603IfMT;000001h0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@X000006`3IfMT00`000000fMWI0=WIf@0G0=WIf@X0
0000703IfMT00`000000fMWI0=WIf@0F0=WIf@X00000803IfMT200000240fMWI00<000000=WIf@3I
fMT01@3IfMT004`0fMWI3000000c0=WIf@`00000<`3IfMT<000004X0fMWI001<0=WIf@`00000<`3I
fMT<000003<0fMWI3000001:0=WIf@00C03IfMT<000003<0fMWI3000000c0=WIf@`00000BP3IfMT0
00T0fMWIo`00000A000000L0fMWI00090=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI300000020=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI00@0fMWI3P0000060=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00`000001@3IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@050=WIf@002@3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI01h0fMWI
3000000G0=WIf@030000003IfMT0fMWI01T0fMWI3000000K0=WIf@030000003IfMT0fMWI01D0fMWI
3000000P0=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT01@3IfMT004d0fMWI2P00
000e0=WIf@X00000=@3IfMT:000004/0fMWI001=0=WIf@X00000=@3IfMT:000003D0fMWI2P00001;
0=WIf@00C`3IfMT6000003T0fMWI1P00000i0=WIf@H00000C@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0
fMWI00H0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT01000
0000fMWI0=WIf@0000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2
000008d0fMWI001f0=WIf@040000003IfMT0fMWI000000X0fMWI00@000000=WIf@3IfMT0fMWI0`00
00060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000/0fMWI00@0
00000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WI
f@0000080=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01P3IfMT00`000000
fMWI0=WIf@2<0=WIf@00M`3IfMT2000000X0fMWI0P0000030=WIf@@000001@3IfMT2000008d0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT0
0940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<
0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001m0=WIf@800000
103IfMT00`000000fMWI0=WIf@020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03I
fMT010000000fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0
S03IfMT007`0fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@030=WIf@800000
S@3IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0
S03IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000
003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0
1P3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P00
00040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<0
00000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WI
f@050=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@00000
0=WIf@3IfMT000002P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00
002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<00000
1P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000
003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT0
0000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WI
f@3IfMT0S03IfMT007L0fMWI0P0000090=WIf@@000000P3IfMT4000000D0fMWI0P00002=0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00R03IfMT4000000D0
fMWI00<000000=WIf@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI
0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT008X0fMWI00<00000
0=WIf@3IfMT0T`3IfMT008X0fMWI00<000000=WIf@3IfMT0T`3IfMT008P0fMWI0`00002E0=WIf@00
RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.25 .30902 Mdot
.5 .30902 Mdot
.75 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT0603IfMT6000000030=WIf@000000fMWI01l0
fMWI00<000000=WIf@3IfMT06@3IfMT6000001h0fMWI00<000000=WIf@3IfMT07@3IfMT6000001l0
fMWI00<000000=WIf@3IfMT0703IfMT00`000000fMWI000000070=WIf@002`3IfMT2000001l0fMWI
00@000000=WIf@3IfMT00000603IfMT:000001h0fMWI0`00000I0=WIf@X000006P3IfMT3000001d0
fMWI2P00000J0=WIf@040000003IfMT0fMWI000001l0fMWI0P0000070=WIf@00303IfMT00`000000
fMWI0=WIf@0N0=WIf@8000006@3IfMT:00000200fMWI00<000000=WIf@3IfMT05`3IfMT:000001`0
fMWI00<000000=WIf@3IfMT06`3IfMT:000001/0fMWI0P00000Q0=WIf@030000003IfMT0fMWI00D0
fMWI00170=WIf@`00000>03IfMT<000003P0fMWI300000150=WIf@00A`3IfMT<000003P0fMWI3000
000h0=WIf@`00000A@3IfMT004L0fMWI3000000h0=WIf@`00000>03IfMT<000004D0fMWI00090=WI
fOl000004@0000070=WIf@002@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT0103IfMT>000000H0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT>000000H0
fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT0103IfMT>000000H0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D0fMWI00090=WIf@030000003IfMT0fMWI01l0fMWI
00<000000=WIf@3IfMT06@3IfMT<000001`0fMWI00<000000=WIf@3IfMT06@3IfMT<000001/0fMWI
00<000000=WIf@3IfMT06P3IfMT<000001/0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI
0=WIf@050=WIf@00B03IfMT:000003X0fMWI2P00000j0=WIf@X00000AP3IfMT004P0fMWI2P00000j
0=WIf@X00000>P3IfMT:000004H0fMWI001:0=WIf@H00000?P3IfMT6000003h0fMWI1P0000180=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3I
fMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3I
fMT00`000000fMWI0=WIf@2<0=WIf@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00P3IfMT4
00000080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3IfMT01@3IfMT0
0`000000fMWI0=WIf@030=WIf@800000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT0
10000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@00000
0=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI
001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000
fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WIf@8000002P3IfMT2000000<0fMWI
100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@030000
003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT0
0`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@00000;0=WIf@030000
003IfMT0fMWI00<0fMWI0P00002=0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@<00000
1P3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000
003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT00000
203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001m0=WIf@8000002@3I
fMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000
S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT0
0940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WI
f@020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00
00090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WI
f@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@030000003IfMT0fMWI00@0fMWI00<0
00000=WIf@3IfMT00`3IfMT2000008d0fMWI001f0=WIf@040000003IfMT0fMWI000000X0fMWI00@0
00000=WIf@3IfMT0fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003I
fMT0fMWI000000/0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WI
f@3IfMT01P3IfMT00`000000fMWI0=WIf@2<0=WIf@00M`3IfMT2000000T0fMWI100000020=WIf@@0
00001@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3I
fMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI00280=WIf@@000001@3IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00
002=0=WIf@00RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00RP3IfMT00`000000fMWI0=WIf@2C0=WI
f@00R03IfMT3000009D0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.23276 .30902 Mdot
.5 .30902 Mdot
.76724 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT0503IfMT6000000D0fMWI00<000000=WIf@3I
fMT07P3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@0P0=WIf@03
0000003IfMT0000000D000006P3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0000000L0
fMWI000;0=WIf@8000007`3IfMT010000000fMWI0=WIf@00000D0=WIf@/000000P3IfMT00`000000
fMWI0=WIf@0L0=WIf@<000006@3IfMT:000001X0fMWI0`00000O0=WIf@030000003IfMT0fMWI00X0
00005@3IfMT010000000fMWI0=WIf@00000O0=WIf@8000001`3IfMT000`0fMWI00<000000=WIf@3I
fMT07P3IfMT2000001D0fMWI2P0000000`3IfMT000000000000Q0=WIf@030000003IfMT0fMWI01L0
fMWI2P00000L0=WIf@030000003IfMT0fMWI01h0fMWI3000000F0=WIf@8000008@3IfMT00`000000
fMWI0=WIf@050=WIf@00@`3IfMT<000003`0fMWI3000000m0=WIf@`00000@03IfMT004<0fMWI3000
000l0=WIf@`00000?@3IfMT<00000400fMWI00130=WIf@`00000?03IfMT<000003d0fMWI30000010
0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@040=WIf@040000003IfMT0fMWI0=WIf@`00000103IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00@0fMWI3P0000060=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT00`3IfMT<00000080fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WI
f@030000003IfMT0fMWI00D0fMWI00090=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3I
fMT05@3IfMT<00000200fMWI00<000000=WIf@3IfMT06@3IfMT<000001/0fMWI00<000000=WIf@3I
fMT07`3IfMT<000001H0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@050=WIf@00
A03IfMT:000003h0fMWI2P00000o0=WIf@X00000@@3IfMT004@0fMWI2P00000n0=WIf@X00000?`3I
fMT:00000440fMWI00160=WIf@H00000@P3IfMT6000004<0fMWI1P0000130=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000
S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT0
0940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00P3IfMT400000080fMWI0`00
00060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00<0
00000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI001f
0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WI
f@030=WIf@800000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI0=WI
f@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000
2`3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000
003IfMT0fMWI000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WI
f@030000003IfMT0fMWI08`0fMWI001g0=WIf@8000002P3IfMT2000000<0fMWI100000050=WIf@80
0000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0
fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0
fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0
fMWI0P00002=0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@<000001P3IfMT00`000000
fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0
fMWI00<000000=WIf@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000
fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001m0=WIf@8000002@3IfMT4000000D0fMWI
0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<
0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000
003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@<00000
1P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@030000
003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3I
fMT010000000fMWI0=WIf@00000:0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0
0`3IfMT2000008d0fMWI001f0=WIf@040000003IfMT0fMWI000000X0fMWI00@000000=WIf@3IfMT0
fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000/0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000
fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01P3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00M`3IfMT2000000T0fMWI100000020=WIf@@000001@3IfMT20000
08d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI00280=WI
f@@000001@3IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00RP3I
fMT00`000000fMWI0=WIf@2C0=WIf@00RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00R03IfMT30000
09D0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.21618 .30902 Mdot
.5 .30902 Mdot
.78382 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT03`3IfMT6000000X0fMWI00<000000=WIf@3I
fMT07P3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@0P0=WIf@03
0000003IfMT0fMWI00<0fMWI1P00000F0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI000000l0fMWI2P0000050=WIf@04
0000003IfMT0fMWI000001h0fMWI0`00000I0=WIf@X000006P3IfMT3000001l0fMWI00@000000=WI
f@3IfMT000000`3IfMT:00000140fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P00000@0=WIf@X000001P3IfMT200000240fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT07P3IfMT2000000@0fMWI2P00000B
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00?P3IfMT<00000440fMWI300000110=WI
f@`00000?03IfMT003h0fMWI300000110=WIf@`00000@@3IfMT<000003`0fMWI000n0=WIf@`00000
@@3IfMT<00000440fMWI3000000l0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@`000000`3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT>000000H0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@040000003IfMT0fMWI0=WIf@`000001@3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D0fMWI00090=WIf@030000003IfMT0
fMWI01l0fMWI00<000000=WIf@3IfMT0403IfMT<000000<0fMWI00<000000=WIf@3IfMT07`3IfMT0
0`000000fMWI0=WIf@0I0=WIf@`000006`3IfMT00`000000fMWI0=WIf@0O0=WIf@040000003IfMT0
fMWI0=WIf@`000004P3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00D0fMWI000o
0=WIf@X00000@`3IfMT:000004<0fMWI2P00000m0=WIf@00?`3IfMT:000004<0fMWI2P0000130=WI
f@X00000?@3IfMT00440fMWI1P0000170=WIf@H00000A`3IfMT6000003l0fMWI002A0=WIf@030000
003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT0
0940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=
0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI001g0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@@000000P3IfMT30000
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT00`00
0000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0
fMWI00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI
00<0fMWI0P00002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI
0=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;
0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@00000
0=WIf@3IfMT00000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI
00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00
002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3I
fMT2000000@0fMWI00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03I
fMT007`0fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@030=WIf@030000003I
fMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3I
fMT2000008d0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI0`0000060=WIf@030000003I
fMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003I
fMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000090=WIf@@000001@3IfMT2
000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001g
0=WIf@800000103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI0`000006
0=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<00000
0=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI001f0=WI
f@040000003IfMT0fMWI000000X0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@03
0=WIf@800000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3I
fMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3I
fMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003I
fMT0fMWI000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@03
0000003IfMT0fMWI08`0fMWI001g0=WIf@8000002@3IfMT400000080fMWI100000050=WIf@800000
S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT0
0940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<
0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000
003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT008P0fMWI
100000050=WIf@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI00<0
00000=WIf@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT2000008d0fMWI002:0=WI
f@030000003IfMT0fMWI09<0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI00280=WIf@<00000
U@3IfMT008X0fMWI00<000000=WIf@3IfMT0T`3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.20089 .30902 Mdot
.5 .30902 Mdot
.79911 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT02`3IfMT6000000h0fMWI00<000000=WIf@3I
fMT07P3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@0P0=WIf@03
0000003IfMT0fMWI00P0fMWI1P00000A0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI000000/0fMWI2P0000090=WIf@04
0000003IfMT0fMWI000001h0fMWI0`00000I0=WIf@X000006P3IfMT3000001l0fMWI00@000000=WI
f@3IfMT00000203IfMT:000000`0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P00000<0=WIf@X000002P3IfMT200000240fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT07P3IfMT2000000T0fMWI2P00000=
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00>P3IfMT<000004D0fMWI300000160=WI
f@`00000=`3IfMT003X0fMWI300000150=WIf@`00000AP3IfMT<000003L0fMWI000j0=WIf@`00000
A@3IfMT<000004H0fMWI3000000g0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0000000<000000H0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI3P0000060=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
000000`000001P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@050=WIf@002@3IfMT00`000000fMWI0=WIf@0O0=WI
f@030000003IfMT0fMWI00`0fMWI300000070=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WI
f@3IfMT06@3IfMT<000001/0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@060=WI
f@`000003@3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00D0fMWI000k0=WIf@X0
0000A`3IfMT:000004P0fMWI2P00000h0=WIf@00>`3IfMT:000004L0fMWI2P0000180=WIf@X00000
>03IfMT003d0fMWI1P00001;0=WIf@H00000C03IfMT6000003X0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI001g0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@@000000P3IfMT3000000H0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI
0=WIf@060=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
0P00002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@04
0000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3I
fMT00000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<00000
0=WIf@3IfMT0S03IfMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3I
fMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3IfMT20000
00@0fMWI00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT20000
08d0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI0`0000060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000090=WIf@@000001@3IfMT2000008d0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001g0=WIf@80
0000103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@03
0000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000
003IfMT0fMWI000000X0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@80
0000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT30000
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT01000
0000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI
000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003I
fMT0fMWI08`0fMWI001g0=WIf@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT0
0940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<
0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT008P0fMWI10000005
0=WIf@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT2000008d0fMWI002:0=WIf@030000
003IfMT0fMWI09<0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI00280=WIf@<00000U@3IfMT0
08X0fMWI00<000000=WIf@3IfMT0T`3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.1875 .30902 Mdot
.5 .30902 Mdot
.8125 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT01`3IfMT600000180fMWI00<000000=WIf@3I
fMT07P3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@0P0=WIf@03
0000003IfMT0fMWI00/0fMWI1P00000>0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI000000L0fMWI2P00000=0=WIf@04
0000003IfMT0fMWI000001h0fMWI0`00000I0=WIf@X000006P3IfMT3000001l0fMWI00@000000=WI
f@3IfMT000002`3IfMT:000000T0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P0000080=WIf@X000003P3IfMT200000240fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT07P3IfMT2000000`0fMWI2P00000:
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00=P3IfMT<000004T0fMWI300000190=WI
f@`00000=03IfMT003H0fMWI300000190=WIf@`00000B@3IfMT<000003@0fMWI000f0=WIf@`00000
B@3IfMT<000004T0fMWI3000000d0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT00P3IfMT<000000@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT>000000H0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT00P3IfMT<000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI00<000000=WI
f@3IfMT07`3IfMT00`000000fMWI0=WIf@080=WIf@`000002`3IfMT00`000000fMWI0=WIf@0O0=WI
f@030000003IfMT0fMWI01T0fMWI3000000K0=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WI
f@3IfMT02@3IfMT<000000X0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@050=WI
f@00=`3IfMT:000004/0fMWI2P00001;0=WIf@X00000=@3IfMT003L0fMWI2P00001;0=WIf@X00000
B`3IfMT:000003D0fMWI000i0=WIf@H00000C`3IfMT6000004l0fMWI1P00000g0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@80
0000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00P3IfMT400000080fMWI
0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI
00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI
001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI
0=WIf@030=WIf@800000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI
0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT0
00002`3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@04
0000003IfMT0fMWI000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@06
0=WIf@030000003IfMT0fMWI08`0fMWI001g0=WIf@8000002P3IfMT2000000<0fMWI100000050=WI
f@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000
003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT0
07d0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI
00<0fMWI0P00002=0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT00`00
0000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001m0=WIf@8000002@3IfMT4000000D0
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@00000:0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT00`3IfMT2000008d0fMWI001f0=WIf@040000003IfMT0fMWI000000X0fMWI00@000000=WIf@3I
fMT0fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI0000
00/0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT01000
0000fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@2<0=WIf@00M`3IfMT2000000T0fMWI100000020=WIf@@000001@3IfMT2
000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI0028
0=WIf@@000001@3IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00
RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00R03IfMT3
000009D0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.17651 .30902 Mdot
.5 .30902 Mdot
.82349 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT0103IfMT6000001D0fMWI00<000000=WIf@3I
fMT07P3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@0P0=WIf@03
0000003IfMT0fMWI00h0fMWI1P00000;0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI000000@0fMWI2P00000@0=WIf@04
0000003IfMT0fMWI000001h0fMWI0`00000I0=WIf@X000006P3IfMT3000001l0fMWI00@000000=WI
f@3IfMT000003P3IfMT:000000H0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P0000050=WIf@X000004@3IfMT200000240fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT07P3IfMT2000000l0fMWI2P000007
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00<`3IfMT<000004`0fMWI3000001<0=WI
f@`00000<@3IfMT003<0fMWI3000001<0=WIf@`00000C03IfMT<00000340fMWI000c0=WIf@`00000
C03IfMT<000004`0fMWI3000000a0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@000000300000060=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI3P0000060=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI00@0fMWI3@0000000`3IfMT000000=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@050=WIf@002@3IfMT00`000000fMWI0=WIf@0O0=WI
f@030000003IfMT0fMWI00D0fMWI3000000>0=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WI
f@3IfMT06@3IfMT<000001/0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0<0=WI
f@`000001`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00D0fMWI000d0=WIf@X0
0000CP3IfMT:000004h0fMWI2P00000b0=WIf@00=03IfMT:000004h0fMWI2P00001>0=WIf@X00000
<P3IfMT003H0fMWI1P00001B0=WIf@H00000DP3IfMT6000003@0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI001g0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@@000000P3IfMT3000000H0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI
0=WIf@060=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
0P00002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@04
0000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3I
fMT00000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<00000
0=WIf@3IfMT0S03IfMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3I
fMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3IfMT20000
00@0fMWI00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT20000
08d0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI0`0000060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000090=WIf@@000001@3IfMT2000008d0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001g0=WIf@80
0000103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@03
0000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000
003IfMT0fMWI000000X0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@80
0000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT30000
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT01000
0000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI
000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003I
fMT0fMWI08`0fMWI001g0=WIf@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT0
0940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<
0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT008P0fMWI10000005
0=WIf@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT2000008d0fMWI002:0=WIf@030000
003IfMT0fMWI09<0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI00280=WIf@<00000U@3IfMT0
08X0fMWI00<000000=WIf@3IfMT0T`3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.16834 .30902 Mdot
.5 .30902 Mdot
.83166 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT00P3IfMT6000001L0fMWI00<000000=WIf@3I
fMT07P3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@0P0=WIf@03
0000003IfMT0fMWI0100fMWI1P0000090=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI00000080fMWI2P00000B0=WIf@04
0000003IfMT0fMWI000001h0fMWI0`00000I0=WIf@X000006P3IfMT3000001l0fMWI00@000000=WI
f@3IfMT00000403IfMT:000000@0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P0000030=WIf@X000004`3IfMT200000240fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT07P3IfMT200000140fMWI2P000005
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00<@3IfMT<000004h0fMWI3000001>0=WI
f@`00000;`3IfMT00340fMWI3000001>0=WIf@`00000CP3IfMT<000002l0fMWI000a0=WIf@`00000
CP3IfMT<000004h0fMWI3000000_0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI30000002
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT>000000H0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0<000000D0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D0fMWI00090=WIf@030000003IfMT0fMWI
01l0fMWI00<000000=WIf@3IfMT00`3IfMT<00000100fMWI00<000000=WIf@3IfMT07`3IfMT00`00
0000fMWI0=WIf@0I0=WIf@`000006`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI
00h0fMWI300000050=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT01@3IfMT00380
fMWI2P00001@0=WIf@X00000D03IfMT:00000300fMWI000b0=WIf@X00000D03IfMT:00000500fMWI
2P00000`0=WIf@00=03IfMT6000005@0fMWI1P00001D0=WIf@H00000<P3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI100000020=WIf@<00000
1P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000
003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3I
fMT010000000fMWI0=WIf@0000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0
0`3IfMT2000008d0fMWI001f0=WIf@040000003IfMT0fMWI000000X0fMWI00@000000=WIf@3IfMT0
fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000/0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000
fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01P3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00M`3IfMT2000000X0fMWI0P0000030=WIf@@000001@3IfMT20000
08d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001m0=WI
f@800000103IfMT00`000000fMWI0=WIf@020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WI
f@00O03IfMT010000000fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@030=WI
f@800000S@3IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WI
f@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WI
f@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WI
f@3IfMT01P3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@80
0000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0
fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT3000000H0
fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002@3IfMT00`000000
fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI
00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0
fMWI0P00002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WI
f@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WI
f@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WI
f@3IfMT00000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<0
00000=WIf@3IfMT0S03IfMT007L0fMWI0P0000090=WIf@@000000P3IfMT4000000D0fMWI0P00002=
0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00R03IfMT4
000000D0fMWI00<000000=WIf@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT00`00
0000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT008X0fMWI
00<000000=WIf@3IfMT0T`3IfMT008X0fMWI00<000000=WIf@3IfMT0T`3IfMT008P0fMWI0`00002E
0=WIf@00RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.16331 .30902 Mdot
.5 .30902 Mdot
.83669 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00@000000=WIf@3IfMT0fMWI1P00000H0=WIf@030000003IfMT0fMWI
01h0fMWI00<000000=WIf@3IfMT06@3IfMT6000001h0fMWI00<000000=WIf@3IfMT0803IfMT00`00
0000fMWI0=WIf@0B0=WIf@H000001`3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT00000
00L0fMWI000;0=WIf@8000007`3IfMT01@000000fMWI0=WIf@000000fMWI00X000004`3IfMT01000
0000fMWI0=WIf@00000N0=WIf@<000006@3IfMT:000001X0fMWI0`00000O0=WIf@040000003IfMT0
fMWI00000180fMWI2P0000020=WIf@040000003IfMT0fMWI000001l0fMWI0P0000070=WIf@00303I
fMT00`000000fMWI0=WIf@0N0=WIf@8000000P3IfMT:000001@0fMWI0P00000Q0=WIf@030000003I
fMT0fMWI01L0fMWI2P00000L0=WIf@030000003IfMT0fMWI01h0fMWI0P00000C0=WIf@X000000`3I
fMT200000240fMWI00<000000=WIf@3IfMT01@3IfMT00300fMWI3000001?0=WIf@`00000D03IfMT<
000002d0fMWI000`0=WIf@`00000C`3IfMT<00000500fMWI3000000]0=WIf@00<03IfMT<000004l0
fMWI3000001@0=WIf@`00000;@3IfMT000T0fMWIo`00000A000000L0fMWI00090=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@020=WIf@`000000`3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI3P0000060=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT00P3IfMT<000000<0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D0fMWI00090=WIf@030000003IfMT0
fMWI01l0fMWI00<000000=WIf@3IfMT00P3IfMT<00000140fMWI00<000000=WIf@3IfMT07`3IfMT0
0`000000fMWI0=WIf@0I0=WIf@`000006`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0
fMWI0100fMWI300000030=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT01@3IfMT0
0340fMWI2P00001A0=WIf@X00000DP3IfMT:000002h0fMWI000a0=WIf@X00000D@3IfMT:00000580
fMWI2P00000^0=WIf@00<`3IfMT6000005D0fMWI1P00001F0=WIf@H00000<03IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3I
fMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT20000
08d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI100000020=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000080=WIf@03
0000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT00`3IfMT2000008d0fMWI001f0=WIf@040000003IfMT0fMWI000000X0fMWI00@000000=WIf@3I
fMT0fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI0000
00/0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT01000
0000fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@2<0=WIf@00M`3IfMT2000000X0fMWI0P0000030=WIf@@000001@3IfMT2
000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001m
0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<
0=WIf@00O03IfMT010000000fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@03
0=WIf@800000S@3IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<00000
0=WIf@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@06
0=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<00000
0=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WI
f@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000
003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT0
07L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT30000
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002@3IfMT00`00
0000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0
fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
00<0fMWI0P00002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI
0=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;
0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@00000
0=WIf@3IfMT00000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI
00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000090=WIf@@000000P3IfMT4000000D0fMWI0P00
002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00R03I
fMT4000000D0fMWI00<000000=WIf@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT008X0
fMWI00<000000=WIf@3IfMT0T`3IfMT008X0fMWI00<000000=WIf@3IfMT0T`3IfMT008P0fMWI0`00
002E0=WIf@00RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.16161 .30902 Mdot
.5 .30902 Mdot
.83839 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT01P00000I0=WIf@030000003IfMT0fMWI01h0
fMWI00<000000=WIf@3IfMT06@3IfMT6000001h0fMWI00<000000=WIf@3IfMT0803IfMT00`000000
fMWI0=WIf@0B0=WIf@H000001`3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0000000L0
fMWI000;0=WIf@8000007`3IfMT00`000000fMWI0=WIf@0;000001@0fMWI00@000000=WIf@3IfMT0
00007P3IfMT3000001T0fMWI2P00000J0=WIf@<000007`3IfMT010000000fMWI0=WIf@00000B0=WI
f@X000000P3IfMT010000000fMWI0=WIf@00000O0=WIf@8000001`3IfMT000`0fMWI00<000000=WI
f@3IfMT07P3IfMT2000000030=WIf@000000000000P000005@3IfMT200000240fMWI00<000000=WI
f@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT07P3IfMT2000001<0fMWI2P0000030=WI
f@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00;`3IfMT<00000500fMWI3000001@0=WIf@`0
0000;@3IfMT002l0fMWI3000001@0=WIf@`00000D03IfMT<000002d0fMWI000_0=WIf@`00000D03I
fMT<00000500fMWI3000000]0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI0=WIf@`00000103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI3P0000060=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT00P3IfMT<000000<0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D0fMWI00090=WIf@030000003IfMT0fMWI
01l0fMWI00@000000=WIf@3IfMT0fMWI3000000B0=WIf@030000003IfMT0fMWI01l0fMWI00<00000
0=WIf@3IfMT06@3IfMT<000001/0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0@
0=WIf@`000000`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00D0fMWI000`0=WI
f@X00000DP3IfMT:00000580fMWI2P00000^0=WIf@00<03IfMT:00000580fMWI2P00001B0=WIf@X0
0000;P3IfMT00380fMWI1P00001F0=WIf@H00000EP3IfMT600000300fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3I
fMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI001g0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@@000000P3IfMT3000000H0
fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000
fMWI0=WIf@060=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI
00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0
fMWI0P00002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WI
f@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WI
f@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WI
f@3IfMT00000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<0
00000=WIf@3IfMT0S03IfMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=
0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3IfMT2
000000@0fMWI00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT0
07`0fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT2
000008d0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI0`0000060=WIf@030000003IfMT0
fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0
fMWI00H0fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000090=WIf@@000001@3IfMT20000
08d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@800000103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WI
f@3IfMT01@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@04
0000003IfMT0fMWI000000X0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WI
f@800000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3
000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT0
10000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0
fMWI000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000
003IfMT0fMWI08`0fMWI001g0=WIf@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT008P0fMWI1000
00050=WIf@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT2000008d0fMWI002:0=WIf@03
0000003IfMT0fMWI09<0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI00280=WIf@<00000U@3I
fMT008X0fMWI00<000000=WIf@3IfMT0T`3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.16331 .30902 Mdot
.5 .30902 Mdot
.83669 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00@000000=WIf@3IfMT0fMWI1P00000H0=WIf@030000003IfMT0fMWI
01h0fMWI00<000000=WIf@3IfMT06@3IfMT6000001h0fMWI00<000000=WIf@3IfMT0803IfMT00`00
0000fMWI0=WIf@0B0=WIf@H000001`3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT00000
00L0fMWI000;0=WIf@8000007`3IfMT01@000000fMWI0=WIf@000000fMWI00X000004`3IfMT01000
0000fMWI0=WIf@00000N0=WIf@<000006@3IfMT:000001X0fMWI0`00000O0=WIf@040000003IfMT0
fMWI00000180fMWI2P0000020=WIf@040000003IfMT0fMWI000001l0fMWI0P0000070=WIf@00303I
fMT00`000000fMWI0=WIf@0N0=WIf@8000000P3IfMT:000001@0fMWI0P00000Q0=WIf@030000003I
fMT0fMWI01L0fMWI2P00000L0=WIf@030000003IfMT0fMWI01h0fMWI0P00000C0=WIf@X000000`3I
fMT200000240fMWI00<000000=WIf@3IfMT01@3IfMT00300fMWI3000001?0=WIf@`00000D03IfMT<
000002d0fMWI000`0=WIf@`00000C`3IfMT<00000500fMWI3000000]0=WIf@00<03IfMT<000004l0
fMWI3000001@0=WIf@`00000;@3IfMT000T0fMWIo`00000A000000L0fMWI00090=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@020=WIf@`000000`3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI3P0000060=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT00P3IfMT<000000<0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D0fMWI00090=WIf@030000003IfMT0
fMWI01l0fMWI00<000000=WIf@3IfMT00P3IfMT<00000140fMWI00<000000=WIf@3IfMT07`3IfMT0
0`000000fMWI0=WIf@0I0=WIf@`000006`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0
fMWI0100fMWI300000030=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT01@3IfMT0
0340fMWI2P00001A0=WIf@X00000DP3IfMT:000002h0fMWI000a0=WIf@X00000D@3IfMT:00000580
fMWI2P00000^0=WIf@00<`3IfMT6000005D0fMWI1P00001F0=WIf@H00000<03IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3I
fMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT20000
08d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI100000020=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000080=WIf@03
0000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT00`3IfMT2000008d0fMWI001f0=WIf@040000003IfMT0fMWI000000X0fMWI00@000000=WIf@3I
fMT0fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI0000
00/0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT01000
0000fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@2<0=WIf@00M`3IfMT2000000X0fMWI0P0000030=WIf@@000001@3IfMT2
000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001m
0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<
0=WIf@00O03IfMT010000000fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@03
0=WIf@800000S@3IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<00000
0=WIf@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@06
0=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<00000
0=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WI
f@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000
003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT0
07L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT30000
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002@3IfMT00`00
0000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0
fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
00<0fMWI0P00002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI
0=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;
0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@00000
0=WIf@3IfMT00000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI
00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000090=WIf@@000000P3IfMT4000000D0fMWI0P00
002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00R03I
fMT4000000D0fMWI00<000000=WIf@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT008X0
fMWI00<000000=WIf@3IfMT0T`3IfMT008X0fMWI00<000000=WIf@3IfMT0T`3IfMT008P0fMWI0`00
002E0=WIf@00RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.16834 .30902 Mdot
.5 .30902 Mdot
.83166 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT00P3IfMT6000001L0fMWI00<000000=WIf@3I
fMT07P3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@0P0=WIf@03
0000003IfMT0fMWI0100fMWI1P0000090=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI00000080fMWI2P00000B0=WIf@04
0000003IfMT0fMWI000001h0fMWI0`00000I0=WIf@X000006P3IfMT3000001l0fMWI00@000000=WI
f@3IfMT00000403IfMT:000000@0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P0000030=WIf@X000004`3IfMT200000240fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT07P3IfMT200000140fMWI2P000005
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00<@3IfMT<000004h0fMWI3000001>0=WI
f@`00000;`3IfMT00340fMWI3000001>0=WIf@`00000CP3IfMT<000002l0fMWI000a0=WIf@`00000
CP3IfMT<000004h0fMWI3000000_0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI30000002
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT>000000H0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0<000000D0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D0fMWI00090=WIf@030000003IfMT0fMWI
01l0fMWI00<000000=WIf@3IfMT00`3IfMT<00000100fMWI00<000000=WIf@3IfMT07`3IfMT00`00
0000fMWI0=WIf@0I0=WIf@`000006`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI
00h0fMWI300000050=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT01@3IfMT00380
fMWI2P00001@0=WIf@X00000D03IfMT:00000300fMWI000b0=WIf@X00000D03IfMT:00000500fMWI
2P00000`0=WIf@00=03IfMT6000005@0fMWI1P00001D0=WIf@H00000<P3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI100000020=WIf@<00000
1P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000
003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3I
fMT010000000fMWI0=WIf@0000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0
0`3IfMT2000008d0fMWI001f0=WIf@040000003IfMT0fMWI000000X0fMWI00@000000=WIf@3IfMT0
fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000/0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000
fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01P3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00M`3IfMT2000000X0fMWI0P0000030=WIf@@000001@3IfMT20000
08d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001m0=WI
f@800000103IfMT00`000000fMWI0=WIf@020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WI
f@00O03IfMT010000000fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@030=WI
f@800000S@3IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WI
f@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WI
f@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WI
f@3IfMT01P3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@80
0000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0
fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT3000000H0
fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002@3IfMT00`000000
fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI
00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0
fMWI0P00002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WI
f@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WI
f@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WI
f@3IfMT00000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<0
00000=WIf@3IfMT0S03IfMT007L0fMWI0P0000090=WIf@@000000P3IfMT4000000D0fMWI0P00002=
0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00R03IfMT4
000000D0fMWI00<000000=WIf@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT00`00
0000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT008X0fMWI
00<000000=WIf@3IfMT0T`3IfMT008X0fMWI00<000000=WIf@3IfMT0T`3IfMT008P0fMWI0`00002E
0=WIf@00RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.17651 .30902 Mdot
.5 .30902 Mdot
.82349 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT0103IfMT6000001D0fMWI00<000000=WIf@3I
fMT07P3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@0P0=WIf@03
0000003IfMT0fMWI00h0fMWI1P00000;0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI000000@0fMWI2P00000@0=WIf@04
0000003IfMT0fMWI000001h0fMWI0`00000I0=WIf@X000006P3IfMT3000001l0fMWI00@000000=WI
f@3IfMT000003P3IfMT:000000H0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P0000050=WIf@X000004@3IfMT200000240fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT07P3IfMT2000000l0fMWI2P000007
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00<`3IfMT<000004`0fMWI3000001<0=WI
f@`00000<@3IfMT003<0fMWI3000001<0=WIf@`00000C03IfMT<00000340fMWI000c0=WIf@`00000
C03IfMT<000004`0fMWI3000000a0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@000000300000060=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI3P0000060=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI00@0fMWI3@0000000`3IfMT000000=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@050=WIf@002@3IfMT00`000000fMWI0=WIf@0O0=WI
f@030000003IfMT0fMWI00D0fMWI3000000>0=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WI
f@3IfMT06@3IfMT<000001/0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0<0=WI
f@`000001`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00D0fMWI000d0=WIf@X0
0000CP3IfMT:000004h0fMWI2P00000b0=WIf@00=03IfMT:000004h0fMWI2P00001>0=WIf@X00000
<P3IfMT003H0fMWI1P00001B0=WIf@H00000DP3IfMT6000003@0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI001g0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@@000000P3IfMT3000000H0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI
0=WIf@060=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
0P00002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@04
0000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3I
fMT00000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<00000
0=WIf@3IfMT0S03IfMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3I
fMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3IfMT20000
00@0fMWI00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT20000
08d0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI0`0000060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000090=WIf@@000001@3IfMT2000008d0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001g0=WIf@80
0000103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@03
0000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000
003IfMT0fMWI000000X0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@80
0000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT30000
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT01000
0000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI
000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003I
fMT0fMWI08`0fMWI001g0=WIf@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT0
0940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<
0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT008P0fMWI10000005
0=WIf@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT2000008d0fMWI002:0=WIf@030000
003IfMT0fMWI09<0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI00280=WIf@<00000U@3IfMT0
08X0fMWI00<000000=WIf@3IfMT0T`3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.1875 .30902 Mdot
.5 .30902 Mdot
.8125 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT01`3IfMT600000180fMWI00<000000=WIf@3I
fMT07P3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@0P0=WIf@03
0000003IfMT0fMWI00/0fMWI1P00000>0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI000000L0fMWI2P00000=0=WIf@04
0000003IfMT0fMWI000001h0fMWI0`00000I0=WIf@X000006P3IfMT3000001l0fMWI00@000000=WI
f@3IfMT000002`3IfMT:000000T0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P0000080=WIf@X000003P3IfMT200000240fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT07P3IfMT2000000`0fMWI2P00000:
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00=P3IfMT<000004T0fMWI300000190=WI
f@`00000=03IfMT003H0fMWI300000190=WIf@`00000B@3IfMT<000003@0fMWI000f0=WIf@`00000
B@3IfMT<000004T0fMWI3000000d0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT00P3IfMT<000000@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT>000000H0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT00P3IfMT<000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI00<000000=WI
f@3IfMT07`3IfMT00`000000fMWI0=WIf@080=WIf@`000002`3IfMT00`000000fMWI0=WIf@0O0=WI
f@030000003IfMT0fMWI01T0fMWI3000000K0=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WI
f@3IfMT02@3IfMT<000000X0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@050=WI
f@00=`3IfMT:000004/0fMWI2P00001;0=WIf@X00000=@3IfMT003L0fMWI2P00001;0=WIf@X00000
B`3IfMT:000003D0fMWI000i0=WIf@H00000C`3IfMT6000004l0fMWI1P00000g0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@80
0000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00P3IfMT400000080fMWI
0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI
00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI
001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI
0=WIf@030=WIf@800000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI
0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT0
00002`3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@04
0000003IfMT0fMWI000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@06
0=WIf@030000003IfMT0fMWI08`0fMWI001g0=WIf@8000002P3IfMT2000000<0fMWI100000050=WI
f@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000
003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT0
07d0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI
00<0fMWI0P00002=0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT00`00
0000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001m0=WIf@8000002@3IfMT4000000D0
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@00000:0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT00`3IfMT2000008d0fMWI001f0=WIf@040000003IfMT0fMWI000000X0fMWI00@000000=WIf@3I
fMT0fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI0000
00/0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT01000
0000fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@2<0=WIf@00M`3IfMT2000000T0fMWI100000020=WIf@@000001@3IfMT2
000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI0028
0=WIf@@000001@3IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00
RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00R03IfMT3
000009D0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.20089 .30902 Mdot
.5 .30902 Mdot
.79911 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT02`3IfMT6000000h0fMWI00<000000=WIf@3I
fMT07P3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@0P0=WIf@03
0000003IfMT0fMWI00P0fMWI1P00000A0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI000000/0fMWI2P0000090=WIf@04
0000003IfMT0fMWI000001h0fMWI0`00000I0=WIf@X000006P3IfMT3000001l0fMWI00@000000=WI
f@3IfMT00000203IfMT:000000`0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P00000<0=WIf@X000002P3IfMT200000240fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT07P3IfMT2000000T0fMWI2P00000=
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00>P3IfMT<000004D0fMWI300000160=WI
f@`00000=`3IfMT003X0fMWI300000150=WIf@`00000AP3IfMT<000003L0fMWI000j0=WIf@`00000
A@3IfMT<000004H0fMWI3000000g0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0000000<000000H0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI3P0000060=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
000000`000001P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@050=WIf@002@3IfMT00`000000fMWI0=WIf@0O0=WI
f@030000003IfMT0fMWI00`0fMWI300000070=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WI
f@3IfMT06@3IfMT<000001/0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@060=WI
f@`000003@3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00D0fMWI000k0=WIf@X0
0000A`3IfMT:000004P0fMWI2P00000h0=WIf@00>`3IfMT:000004L0fMWI2P0000180=WIf@X00000
>03IfMT003d0fMWI1P00001;0=WIf@H00000C03IfMT6000003X0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI001g0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@@000000P3IfMT3000000H0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI
0=WIf@060=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
0P00002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@04
0000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3I
fMT00000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<00000
0=WIf@3IfMT0S03IfMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3I
fMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3IfMT20000
00@0fMWI00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT20000
08d0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI0`0000060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000090=WIf@@000001@3IfMT2000008d0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001g0=WIf@80
0000103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@03
0000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000
003IfMT0fMWI000000X0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@80
0000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT30000
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT01000
0000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI
000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003I
fMT0fMWI08`0fMWI001g0=WIf@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT0
0940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<
0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT008P0fMWI10000005
0=WIf@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT2000008d0fMWI002:0=WIf@030000
003IfMT0fMWI09<0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI00280=WIf@<00000U@3IfMT0
08X0fMWI00<000000=WIf@3IfMT0T`3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.21618 .30902 Mdot
.5 .30902 Mdot
.78382 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT03`3IfMT6000000X0fMWI00<000000=WIf@3I
fMT07P3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@0P0=WIf@03
0000003IfMT0fMWI00<0fMWI1P00000F0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI000000l0fMWI2P0000050=WIf@04
0000003IfMT0fMWI000001h0fMWI0`00000I0=WIf@X000006P3IfMT3000001l0fMWI00@000000=WI
f@3IfMT000000`3IfMT:00000140fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P00000@0=WIf@X000001P3IfMT200000240fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT07P3IfMT2000000@0fMWI2P00000B
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00?P3IfMT<00000440fMWI300000110=WI
f@`00000?03IfMT003h0fMWI300000110=WIf@`00000@@3IfMT<000003`0fMWI000n0=WIf@`00000
@@3IfMT<00000440fMWI3000000l0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@`000000`3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT>000000H0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@040000003IfMT0fMWI0=WIf@`000001@3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D0fMWI00090=WIf@030000003IfMT0
fMWI01l0fMWI00<000000=WIf@3IfMT0403IfMT<000000<0fMWI00<000000=WIf@3IfMT07`3IfMT0
0`000000fMWI0=WIf@0I0=WIf@`000006`3IfMT00`000000fMWI0=WIf@0O0=WIf@040000003IfMT0
fMWI0=WIf@`000004P3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00D0fMWI000o
0=WIf@X00000@`3IfMT:000004<0fMWI2P00000m0=WIf@00?`3IfMT:000004<0fMWI2P0000130=WI
f@X00000?@3IfMT00440fMWI1P0000170=WIf@H00000A`3IfMT6000003l0fMWI002A0=WIf@030000
003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT0
0940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=
0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI001g0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@@000000P3IfMT30000
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT00`00
0000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0
fMWI00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI
00<0fMWI0P00002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI
0=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;
0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@00000
0=WIf@3IfMT00000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI
00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00
002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3I
fMT2000000@0fMWI00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03I
fMT007`0fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@030=WIf@030000003I
fMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3I
fMT2000008d0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI0`0000060=WIf@030000003I
fMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003I
fMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000090=WIf@@000001@3IfMT2
000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001g
0=WIf@800000103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI0`000006
0=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<00000
0=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI001f0=WI
f@040000003IfMT0fMWI000000X0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@03
0=WIf@800000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3I
fMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3I
fMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003I
fMT0fMWI000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@03
0000003IfMT0fMWI08`0fMWI001g0=WIf@8000002@3IfMT400000080fMWI100000050=WIf@800000
S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT0
0940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<
0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000
003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT008P0fMWI
100000050=WIf@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI00<0
00000=WIf@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT2000008d0fMWI002:0=WI
f@030000003IfMT0fMWI09<0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI00280=WIf@<00000
U@3IfMT008X0fMWI00<000000=WIf@3IfMT0T`3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.23276 .30902 Mdot
.5 .30902 Mdot
.76724 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT0503IfMT6000000D0fMWI00<000000=WIf@3I
fMT07P3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@0P0=WIf@03
0000003IfMT0000000D000006P3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0000000L0
fMWI000;0=WIf@8000007`3IfMT010000000fMWI0=WIf@00000D0=WIf@/000000P3IfMT00`000000
fMWI0=WIf@0L0=WIf@<000006@3IfMT:000001X0fMWI0`00000O0=WIf@030000003IfMT0fMWI00X0
00005@3IfMT010000000fMWI0=WIf@00000O0=WIf@8000001`3IfMT000`0fMWI00<000000=WIf@3I
fMT07P3IfMT2000001D0fMWI2P0000000`3IfMT000000000000Q0=WIf@030000003IfMT0fMWI01L0
fMWI2P00000L0=WIf@030000003IfMT0fMWI01h0fMWI3000000F0=WIf@8000008@3IfMT00`000000
fMWI0=WIf@050=WIf@00@`3IfMT<000003`0fMWI3000000m0=WIf@`00000@03IfMT004<0fMWI3000
000l0=WIf@`00000?@3IfMT<00000400fMWI00130=WIf@`00000?03IfMT<000003d0fMWI30000010
0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@040=WIf@040000003IfMT0fMWI0=WIf@`00000103IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00@0fMWI3P0000060=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT00`3IfMT<00000080fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WI
f@030000003IfMT0fMWI00D0fMWI00090=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3I
fMT05@3IfMT<00000200fMWI00<000000=WIf@3IfMT06@3IfMT<000001/0fMWI00<000000=WIf@3I
fMT07`3IfMT<000001H0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@050=WIf@00
A03IfMT:000003h0fMWI2P00000o0=WIf@X00000@@3IfMT004@0fMWI2P00000n0=WIf@X00000?`3I
fMT:00000440fMWI00160=WIf@H00000@P3IfMT6000004<0fMWI1P0000130=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000
S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT0
0940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00P3IfMT400000080fMWI0`00
00060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00<0
00000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI001f
0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WI
f@030=WIf@800000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI0=WI
f@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000
2`3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000
003IfMT0fMWI000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WI
f@030000003IfMT0fMWI08`0fMWI001g0=WIf@8000002P3IfMT2000000<0fMWI100000050=WIf@80
0000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0
fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0
fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0
fMWI0P00002=0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@<000001P3IfMT00`000000
fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0
fMWI00<000000=WIf@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000
fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001m0=WIf@8000002@3IfMT4000000D0fMWI
0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<
0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000
003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@<00000
1P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@030000
003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3I
fMT010000000fMWI0=WIf@00000:0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0
0`3IfMT2000008d0fMWI001f0=WIf@040000003IfMT0fMWI000000X0fMWI00@000000=WIf@3IfMT0
fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000/0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000
fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01P3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00M`3IfMT2000000T0fMWI100000020=WIf@@000001@3IfMT20000
08d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI00280=WI
f@@000001@3IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00RP3I
fMT00`000000fMWI0=WIf@2C0=WIf@00RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00R03IfMT30000
09D0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.25 .30902 Mdot
.5 .30902 Mdot
.75 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT0603IfMT6000000030=WIf@000000fMWI01l0
fMWI00<000000=WIf@3IfMT06@3IfMT6000001h0fMWI00<000000=WIf@3IfMT07@3IfMT6000001l0
fMWI00<000000=WIf@3IfMT0703IfMT00`000000fMWI000000070=WIf@002`3IfMT2000001l0fMWI
00@000000=WIf@3IfMT00000603IfMT:000001h0fMWI0`00000I0=WIf@X000006P3IfMT3000001d0
fMWI2P00000J0=WIf@040000003IfMT0fMWI000001l0fMWI0P0000070=WIf@00303IfMT00`000000
fMWI0=WIf@0N0=WIf@8000006@3IfMT:00000200fMWI00<000000=WIf@3IfMT05`3IfMT:000001`0
fMWI00<000000=WIf@3IfMT06`3IfMT:000001/0fMWI0P00000Q0=WIf@030000003IfMT0fMWI00D0
fMWI00170=WIf@`00000>03IfMT<000003P0fMWI300000150=WIf@00A`3IfMT<000003P0fMWI3000
000h0=WIf@`00000A@3IfMT004L0fMWI3000000h0=WIf@`00000>03IfMT<000004D0fMWI00090=WI
fOl000004@0000070=WIf@002@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT0103IfMT>000000H0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT>000000H0
fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT0103IfMT>000000H0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D0fMWI00090=WIf@030000003IfMT0fMWI01l0fMWI
00<000000=WIf@3IfMT06@3IfMT<000001`0fMWI00<000000=WIf@3IfMT06@3IfMT<000001/0fMWI
00<000000=WIf@3IfMT06P3IfMT<000001/0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI
0=WIf@050=WIf@00B03IfMT:000003X0fMWI2P00000j0=WIf@X00000AP3IfMT004P0fMWI2P00000j
0=WIf@X00000>P3IfMT:000004H0fMWI001:0=WIf@H00000?P3IfMT6000003h0fMWI1P0000180=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3I
fMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3I
fMT00`000000fMWI0=WIf@2<0=WIf@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00P3IfMT4
00000080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3IfMT01@3IfMT0
0`000000fMWI0=WIf@030=WIf@800000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT0
10000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@00000
0=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI
001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000
fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WIf@8000002P3IfMT2000000<0fMWI
100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@030000
003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT0
0`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@00000;0=WIf@030000
003IfMT0fMWI00<0fMWI0P00002=0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@<00000
1P3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000
003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT00000
203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001m0=WIf@8000002@3I
fMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000
S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT0
0940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WI
f@020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00
00090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WI
f@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@030000003IfMT0fMWI00@0fMWI00<0
00000=WIf@3IfMT00`3IfMT2000008d0fMWI001f0=WIf@040000003IfMT0fMWI000000X0fMWI00@0
00000=WIf@3IfMT0fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003I
fMT0fMWI000000/0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WI
f@3IfMT01P3IfMT00`000000fMWI0=WIf@2<0=WIf@00M`3IfMT2000000T0fMWI100000020=WIf@@0
00001@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3I
fMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI00280=WIf@@000001@3IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00
002=0=WIf@00RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00RP3IfMT00`000000fMWI0=WIf@2C0=WI
f@00R03IfMT3000009D0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.26724 .30902 Mdot
.5 .30902 Mdot
.73276 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT07@3IfMT6000001d0fMWI00<000000=WIf@3I
fMT06@3IfMT6000001h0fMWI00<000000=WIf@3IfMT0603IfMT600000080fMWI00<000000=WIf@3I
fMT07`3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0000000L0fMWI000;0=WIf@800000
7`3IfMT010000000fMWI0=WIf@00000M0=WIf@X000006@3IfMT3000001T0fMWI2P00000J0=WIf@<0
0000603IfMT;000001h0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@X000006`3IfMT00`000000fMWI0=WIf@0G0=WIf@X0
0000703IfMT00`000000fMWI0=WIf@0F0=WIf@X00000803IfMT200000240fMWI00<000000=WIf@3I
fMT01@3IfMT004`0fMWI3000000c0=WIf@`00000<`3IfMT<000004X0fMWI001<0=WIf@`00000<`3I
fMT<000003<0fMWI3000001:0=WIf@00C03IfMT<000003<0fMWI3000000c0=WIf@`00000BP3IfMT0
00T0fMWIo`00000A000000L0fMWI00090=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI300000020=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI00@0fMWI3P0000060=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00`000001@3IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@050=WIf@002@3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI01h0fMWI
3000000G0=WIf@030000003IfMT0fMWI01T0fMWI3000000K0=WIf@030000003IfMT0fMWI01D0fMWI
3000000P0=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT01@3IfMT004d0fMWI2P00
000e0=WIf@X00000=@3IfMT:000004/0fMWI001=0=WIf@X00000=@3IfMT:000003D0fMWI2P00001;
0=WIf@00C`3IfMT6000003T0fMWI1P00000i0=WIf@H00000C@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0
fMWI00H0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT01000
0000fMWI0=WIf@0000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2
000008d0fMWI001f0=WIf@040000003IfMT0fMWI000000X0fMWI00@000000=WIf@3IfMT0fMWI0`00
00060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000/0fMWI00@0
00000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WI
f@0000080=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01P3IfMT00`000000
fMWI0=WIf@2<0=WIf@00M`3IfMT2000000X0fMWI0P0000030=WIf@@000001@3IfMT2000008d0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT0
0940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<
0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001m0=WIf@800000
103IfMT00`000000fMWI0=WIf@020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03I
fMT010000000fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0
S03IfMT007`0fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@030=WIf@800000
S@3IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0
S03IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000
003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0
1P3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P00
00040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<0
00000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WI
f@050=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@00000
0=WIf@3IfMT000002P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00
002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<00000
1P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000
003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT0
0000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WI
f@3IfMT0S03IfMT007L0fMWI0P0000090=WIf@@000000P3IfMT4000000D0fMWI0P00002=0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00R03IfMT4000000D0
fMWI00<000000=WIf@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI
0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT008X0fMWI00<00000
0=WIf@3IfMT0T`3IfMT008X0fMWI00<000000=WIf@3IfMT0T`3IfMT008P0fMWI0`00002E0=WIf@00
RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.28382 .30902 Mdot
.5 .30902 Mdot
.71618 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@06000001P0
fMWI00<000000=WIf@3IfMT06@3IfMT6000001h0fMWI00<000000=WIf@3IfMT0503IfMT6000000H0
fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0000000L0
fMWI000;0=WIf@8000007`3IfMT010000000fMWI0=WIf@00000N0=WIf@030000003IfMT0fMWI00/0
0000503IfMT3000001T0fMWI2P00000J0=WIf@<00000503IfMT:000000050=WIf@000000fMWI0=WI
f@0000007P3IfMT010000000fMWI0=WIf@00000O0=WIf@8000001`3IfMT000`0fMWI00<000000=WI
f@3IfMT07P3IfMT200000200fMWI0P0000000`3IfMT0000000000008000001H0fMWI00<000000=WI
f@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT04P3IfMT:00000080fMWI0P00000P0=WI
f@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00D@3IfMT<000002h0fMWI3000000_0=WIf@`0
0000CP3IfMT00540fMWI3000000^0=WIf@`00000;`3IfMT<000004h0fMWI001A0=WIf@`00000;P3I
fMT<000002l0fMWI3000001>0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0103IfMT010000000fMWI0=WIf@3IfMT<000000@0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI3P0000060=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@`000000P3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D0fMWI00090=WIf@030000003IfMT0fMWI
01l0fMWI00<000000=WIf@3IfMT07`3IfMT010000000fMWI0=WIf@3IfMT<00000180fMWI00<00000
0=WIf@3IfMT06@3IfMT<000001/0fMWI00<000000=WIf@3IfMT04@3IfMT<00000080fMWI00<00000
0=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00D0fMWI001B0=WI
f@X00000<03IfMT:00000340fMWI2P00001?0=WIf@00DP3IfMT:00000300fMWI2P00000a0=WIf@X0
0000C`3IfMT005@0fMWI1P00000d0=WIf@H00000=@3IfMT600000540fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3I
fMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI001g0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@@000000P3IfMT3000000H0
fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000
fMWI0=WIf@060=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI
00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0
fMWI0P00002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WI
f@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WI
f@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WI
f@3IfMT00000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<0
00000=WIf@3IfMT0S03IfMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=
0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3IfMT2
000000@0fMWI00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT0
07`0fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT2
000008d0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI0`0000060=WIf@030000003IfMT0
fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0
fMWI00H0fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000090=WIf@@000001@3IfMT20000
08d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@800000103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WI
f@3IfMT01@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@04
0000003IfMT0fMWI000000X0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WI
f@800000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3
000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT0
10000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0
fMWI000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000
003IfMT0fMWI08`0fMWI001g0=WIf@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT008P0fMWI1000
00050=WIf@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT2000008d0fMWI002:0=WIf@03
0000003IfMT0fMWI09<0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI00280=WIf@<00000U@3I
fMT008X0fMWI00<000000=WIf@3IfMT0T`3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.29911 .30902 Mdot
.5 .30902 Mdot
.70089 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@040=WIf@H0
0000503IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@0@0=WIf@H0
00002P3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3I
fMT00000103IfMT:00000100fMWI0`00000I0=WIf@X000006P3IfMT300000100fMWI2P0000050=WI
f@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P00000P0=WIf@8000001@3IfMT:00000180fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT03P3IfMT:000000H0fMWI0P00000P
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00E@3IfMT<000002X0fMWI3000000[0=WI
f@`00000DP3IfMT005D0fMWI3000000Z0=WIf@`00000:`3IfMT<00000580fMWI001E0=WIf@`00000
:P3IfMT<000002/0fMWI3000001B0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0000000`000001P3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI3P0000060=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0000000<000000D0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@050=WIf@002@3IfMT00`000000fMWI0=WIf@0O0=WI
f@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT01@3IfMT<000000h0fMWI00<000000=WI
f@3IfMT06@3IfMT<000001/0fMWI00<000000=WIf@3IfMT03@3IfMT<000000H0fMWI00<000000=WI
f@3IfMT07`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00D0fMWI001F0=WIf@X0
0000;03IfMT:000002d0fMWI2P00001C0=WIf@00EP3IfMT:000002`0fMWI2P00000]0=WIf@X00000
D`3IfMT005P0fMWI1P00000`0=WIf@H00000<@3IfMT6000005D0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI001g0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@@000000P3IfMT3000000H0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI
0=WIf@060=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
0P00002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@04
0000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3I
fMT00000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<00000
0=WIf@3IfMT0S03IfMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3I
fMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3IfMT20000
00@0fMWI00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT20000
08d0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI0`0000060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000090=WIf@@000001@3IfMT2000008d0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001g0=WIf@80
0000103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@03
0000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000
003IfMT0fMWI000000X0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@80
0000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT30000
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT01000
0000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI
000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003I
fMT0fMWI08`0fMWI001g0=WIf@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT0
0940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<
0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT008P0fMWI10000005
0=WIf@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT2000008d0fMWI002:0=WIf@030000
003IfMT0fMWI09<0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI00280=WIf@<00000U@3IfMT0
08X0fMWI00<000000=WIf@3IfMT0T`3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.3125 .30902 Mdot
.5 .30902 Mdot
.6875 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@070=WIf@H0
00004@3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@0<0=WIf@H0
00003P3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3I
fMT000001`3IfMT:000000d0fMWI0`00000I0=WIf@X000006P3IfMT3000000`0fMWI2P0000090=WI
f@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P00000P0=WIf@800000203IfMT:000000l0fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT02P3IfMT:000000X0fMWI0P00000P
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00F03IfMT<000002L0fMWI3000000W0=WI
f@`00000EP3IfMT005P0fMWI3000000W0=WIf@`000009`3IfMT<000005H0fMWI001H0=WIf@`00000
9`3IfMT<000002L0fMWI3000001F0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI30000004
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT>000000H0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@020=WIf@`00000103IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI00<000000=WI
f@3IfMT07`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00P0fMWI3000000;0=WI
f@030000003IfMT0fMWI01T0fMWI3000000K0=WIf@030000003IfMT0fMWI00T0fMWI3000000:0=WI
f@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@050=WI
f@00F@3IfMT:000002T0fMWI2P00000Y0=WIf@X00000E`3IfMT005T0fMWI2P00000Y0=WIf@X00000
:@3IfMT:000005L0fMWI001K0=WIf@H00000;@3IfMT6000002d0fMWI1P00001I0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@80
0000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00P3IfMT400000080fMWI
0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI
00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI
001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI
0=WIf@030=WIf@800000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI
0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT0
00002`3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@04
0000003IfMT0fMWI000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@06
0=WIf@030000003IfMT0fMWI08`0fMWI001g0=WIf@8000002P3IfMT2000000<0fMWI100000050=WI
f@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000
003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT0
07d0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI
00<0fMWI0P00002=0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT00`00
0000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001m0=WIf@8000002@3IfMT4000000D0
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@00000:0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT00`3IfMT2000008d0fMWI001f0=WIf@040000003IfMT0fMWI000000X0fMWI00@000000=WIf@3I
fMT0fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI0000
00/0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT01000
0000fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@2<0=WIf@00M`3IfMT2000000T0fMWI100000020=WIf@@000001@3IfMT2
000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI0028
0=WIf@@000001@3IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00
RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00R03IfMT3
000009D0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.32349 .30902 Mdot
.5 .30902 Mdot
.67651 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0:0=WIf@H0
00003P3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@090=WIf@H0
00004@3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3I
fMT000002P3IfMT:000000X0fMWI0`00000I0=WIf@X000006P3IfMT3000000T0fMWI2P00000<0=WI
f@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P00000P0=WIf@8000002`3IfMT:000000`0fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT01`3IfMT:000000d0fMWI0P00000P
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00F`3IfMT<000002@0fMWI3000000T0=WI
f@`00000F@3IfMT005/0fMWI3000000T0=WIf@`00000903IfMT<000005T0fMWI001K0=WIf@`00000
903IfMT<000002@0fMWI3000001I0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI3@000000
0`3IfMT000000=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI3P0000060=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@000000300000060=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@050=WIf@002@3IfMT00`000000fMWI0=WIf@0O0=WI
f@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT02`3IfMT<000000P0fMWI00<000000=WI
f@3IfMT06@3IfMT<000001/0fMWI00<000000=WIf@3IfMT01P3IfMT<000000d0fMWI00<000000=WI
f@3IfMT07`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00D0fMWI001L0=WIf@X0
00009P3IfMT:000002H0fMWI2P00001J0=WIf@00G03IfMT:000002H0fMWI2P00000V0=WIf@X00000
FP3IfMT005h0fMWI1P00000Z0=WIf@H00000:P3IfMT6000005`0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI001g0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@@000000P3IfMT3000000H0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI
0=WIf@060=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
0P00002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@04
0000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3I
fMT00000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<00000
0=WIf@3IfMT0S03IfMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3I
fMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3IfMT20000
00@0fMWI00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT20000
08d0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI0`0000060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000090=WIf@@000001@3IfMT2000008d0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001g0=WIf@80
0000103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@03
0000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000
003IfMT0fMWI000000X0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@80
0000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT30000
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT01000
0000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI
000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003I
fMT0fMWI08`0fMWI001g0=WIf@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT0
0940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<
0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0
fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT008P0fMWI10000005
0=WIf@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT2000008d0fMWI002:0=WIf@030000
003IfMT0fMWI09<0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI00280=WIf@<00000U@3IfMT0
08X0fMWI00<000000=WIf@3IfMT0T`3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.33166 .30902 Mdot
.5 .30902 Mdot
.66834 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0=0=WIf@H0
00002`3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@070=WIf@H0
00004`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3I
fMT000003@3IfMT:000000L0fMWI0`00000I0=WIf@X000006P3IfMT3000000L0fMWI2P00000>0=WI
f@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P00000P0=WIf@8000003P3IfMT:000000T0fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT01@3IfMT:000000l0fMWI0P00000P
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00GP3IfMT<00000240fMWI3000000R0=WI
f@`00000F`3IfMT005h0fMWI3000000Q0=WIf@`000008P3IfMT<000005/0fMWI001N0=WIf@`00000
8@3IfMT<00000280fMWI3000001K0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00@00000
0=WIf@3IfMT0fMWI300000050=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI3P0000060=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003I
fMT0fMWI00@0fMWI300000020=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D0fMWI00090=WIf@030000003IfMT0
fMWI01l0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0>0=WIf@`000001@3IfMT0
0`000000fMWI0=WIf@0I0=WIf@`000006`3IfMT00`000000fMWI0=WIf@040=WIf@`000003`3IfMT0
0`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT01@3IfMT0
05l0fMWI2P00000S0=WIf@X00000903IfMT:000005`0fMWI001O0=WIf@X000008`3IfMT:000002@0
fMWI2P00001L0=WIf@00H@3IfMT6000002L0fMWI1P00000X0=WIf@H00000GP3IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3I
fMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT20000
08d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI
002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI100000020=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000080=WIf@03
0000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT00`3IfMT2000008d0fMWI001f0=WIf@040000003IfMT0fMWI000000X0fMWI00@000000=WIf@3I
fMT0fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI0000
00/0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT01000
0000fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@2<0=WIf@00M`3IfMT2000000X0fMWI0P0000030=WIf@@000001@3IfMT2
000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI001m
0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<
0=WIf@00O03IfMT010000000fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT000002`3IfMT00`000000fMWI0=WIf@03
0=WIf@800000S@3IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<00000
0=WIf@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@06
0=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<00000
0=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WI
f@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000
003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT0
07L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT30000
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002@3IfMT00`00
0000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0S03IfMT007H0
fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
00<0fMWI0P00002=0=WIf@00MP3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI
0=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;
0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@00000
0=WIf@3IfMT00000203IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI
00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000090=WIf@@000000P3IfMT4000000D0fMWI0P00
002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI
08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WI
f@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00R03I
fMT4000000D0fMWI00<000000=WIf@3IfMT0S03IfMT008X0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT008X0
fMWI00<000000=WIf@3IfMT0T`3IfMT008X0fMWI00<000000=WIf@3IfMT0T`3IfMT008P0fMWI0`00
002E0=WIf@00RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.33669 .30902 Mdot
.5 .30902 Mdot
.66331 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3IfMTQ
0=WIf@00o`3IfMTQ0=WIf@00R03IfMT4000009@0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI
002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00PP3IfMT4000000@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI00280=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
RP3IfMT00`000000fMWI0=WIf@040=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@0
00000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00L03IfMT400000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT000002`3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI00@000000=WI
f@3IfMT000000P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001g0=WI
f@8000002@3IfMT400000080fMWI100000050=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007d0fMWI0P0000040=WIf@030000003IfMT0fMWI
0080fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001l0=WIf@040000003IfMT0fMWI0000
00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00O03IfMT010000000
fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI00<0fMWI0P00002=0=WIf@00MP3IfMT400000080
fMWI00@000000=WIf@3IfMT00000203IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0
fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O@3IfMT2000000T0fMWI100000050=WIf@800000S@3IfMT00940fMWI
00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00
T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT007L0fMWI0P0000040=WIf@03
0000003IfMT0fMWI0080fMWI100000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT2000008d0fMWI001`0=WIf@@00000
0P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@00000;0=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT00000203IfMT0
10000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0S03I
fMT007L0fMWI0P00000:0=WIf@8000000`3IfMT4000000D0fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI000<0=WIf@030000003IfMT0fMWI01h0fMWI0P00000O0=WIf@@0
00007P3IfMT4000001d0fMWI00<000000=WIf@3IfMT0703IfMT4000001h0fMWI1000000O0=WIf@80
00008@3IfMT00`000000fMWI0=WIf@050=WIf@00303IfMT00`000000fMWI0=WIf@0M0=WIf@040000
003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0L0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0O0=WIf@04
0000003IfMT0fMWI00000200fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI1@00000Q0=WIf@03
0000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0L0=WIf@80
00007`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT06`3IfMT5000000H0fMWI00040=WIf@@0000000D0fMWI0000003IfMT0fMWI0000000I0=WIf@@0
00000`3IfMT2000001T0fMWI100000040=WIf@030000003IfMT0fMWI01L0fMWI100000040=WIf@03
0000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI01h0fMWI0P00000N0=WIf@040000003IfMT0fMWI000000L0fMWI000:0=WIf@03
0000003IfMT000000280fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0>0=WIf@H0
00002P3IfMT00`000000fMWI0=WIf@0I0=WIf@H000007P3IfMT00`000000fMWI0=WIf@060=WIf@H0
0000503IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@00
00001`3IfMT000/0fMWI0P00000O0=WIf@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3I
fMT000003P3IfMT:000000H0fMWI0`00000I0=WIf@X000006P3IfMT3000000H0fMWI2P00000?0=WI
f@040000003IfMT0fMWI000001h0fMWI00@000000=WIf@3IfMT000007`3IfMT2000000L0fMWI000<
0=WIf@030000003IfMT0fMWI01h0fMWI0P00000P0=WIf@8000003`3IfMT:000000P0fMWI00<00000
0=WIf@3IfMT05`3IfMT:000001`0fMWI00<000000=WIf@3IfMT0103IfMT:00000100fMWI0P00000P
0=WIf@8000008@3IfMT00`000000fMWI0=WIf@050=WIf@00G`3IfMT<00000200fMWI3000000Q0=WI
f@`00000G03IfMT005l0fMWI3000000P0=WIf@`000008@3IfMT<000005`0fMWI001O0=WIf@`00000
803IfMT<00000240fMWI3000001L0=WIf@002@3IfMWo0000014000001`3IfMT000T0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT00P3IfMT<000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT>000000H0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT00`3IfMT<000000<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT01@3IfMT000T0fMWI00<000000=WI
f@3IfMT07`3IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI00l0fMWI300000040=WI
f@030000003IfMT0fMWI01T0fMWI3000000K0=WIf@030000003IfMT0fMWI00<0fMWI3000000@0=WI
f@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@050=WI
f@00H03IfMT:00000280fMWI2P00000S0=WIf@X00000G@3IfMT00600fMWI2P00000R0=WIf@X00000
8`3IfMT:000005d0fMWI001R0=WIf@H000009P3IfMT6000002L0fMWI1P00001O0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A
0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@80
0000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03I
fMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00P3IfMT400000080fMWI
0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI000000P0fMWI
00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08`0fMWI
001f0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI
0=WIf@030=WIf@800000S@3IfMT007H0fMWI00@000000=WIf@3IfMT000002P3IfMT010000000fMWI
0=WIf@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0S03IfMT007H0fMWI00@000000=WIf@3IfMT0
00002`3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@04
0000003IfMT0fMWI000000P0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@06
0=WIf@030000003IfMT0fMWI08`0fMWI001g0=WIf@8000002P3IfMT2000000<0fMWI100000050=WI
f@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0
S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI
0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WI
f@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000
003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT0
07d0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@030000003IfMT0fMWI
08`0fMWI001l0=WIf@040000003IfMT0fMWI000000/0fMWI00<000000=WIf@3IfMT00`3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI
00<0fMWI0P00002=0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@2<0=WIf@00O03IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT0S03IfMT007`0fMWI00@000000=WIf@3IfMT00000203IfMT00`00
0000fMWI0=WIf@060=WIf@030000003IfMT0fMWI08`0fMWI001m0=WIf@8000002@3IfMT4000000D0
fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WI
f@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@03
0000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003I
fMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940
fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<0
00000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WI
f@00M`3IfMT2000000@0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT010000000fMWI0=WIf@0000090=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2<0=WIf@00
MP3IfMT010000000fMWI0=WIf@00000:0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT00`3IfMT2000008d0fMWI001f0=WIf@040000003IfMT0fMWI000000X0fMWI00@000000=WIf@3I
fMT0fMWI0`0000060=WIf@030000003IfMT0fMWI08`0fMWI001f0=WIf@040000003IfMT0fMWI0000
00/0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@2<0=WIf@00MP3IfMT01000
0000fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@2<0=WIf@00M`3IfMT2000000T0fMWI100000020=WIf@@000001@3IfMT2
000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@030000003IfMT0fMWI08`0
fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI002A0=WIf@800000S@3IfMT00940fMWI00<00000
0=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI00<000000=WIf@3I
fMT0S03IfMT00940fMWI00<000000=WIf@3IfMT0S03IfMT00940fMWI0P00002=0=WIf@00T@3IfMT0
0`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000fMWI0=WIf@2<0=WIf@00T@3IfMT00`000000
fMWI0=WIf@2<0=WIf@00T@3IfMT2000008d0fMWI002A0=WIf@030000003IfMT0fMWI08`0fMWI0028
0=WIf@@000001@3IfMT00`000000fMWI0=WIf@2<0=WIf@00RP3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI08`0fMWI002:0=WIf@030000003IfMT0fMWI00@0fMWI0P00002=0=WIf@00
RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00RP3IfMT00`000000fMWI0=WIf@2C0=WIf@00R03IfMT3
000009D0fMWI002:0=WIf@030000003IfMT0fMWI09<0fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.875, 0}} -> {-4.26898, -1.0536, \
0.0294412, 0.0119092}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(Do[
        ListPlot[\[IndentingNewLine]\({{x1[t] - 2, 0}, {x2[t], 
                    0}, {x3[t] + 2, 0}} //. 
                allRules\)\[IndentingNewLine] //. {c1 \[Rule] 0, 
                c2 \[Rule] 0, c3 \[Rule] 1}\ \[IndentingNewLine] // 
            Evaluate, \[IndentingNewLine]PlotStyle \[Rule] {PointSize[
                0.05]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-4\), 
                4}, {\(-1\), 1}}], \[IndentingNewLine]{t, 0, 
          2\ \[Pi] \((1 - 1/number)\)/Sqrt[5/3], 
          2\ \(\[Pi]\ /number\)/Sqrt[5/3]}];\)\)\)], "Input",
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.32995 .30902 Mdot
.4467 .30902 Mdot
.82995 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT0:P3IfMT2000000<0fMWI
0P00000E0=WIf@T000003P3IfMT2000000030=WIf@000000fMWI01@0fMWI2@00000@0=WIf@030000
003IfMT0fMWI02`0fMWI0P0000000`3IfMT000000=WIf@0^0=WIf@8000000`3IfMT2000001X0fMWI
2@00000?0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
000_0=WIf@<000005@3IfMT<000000l0fMWI0P00000C0=WIf@`000003`3IfMT00`000000fMWI0=WI
f@0^0=WIf@800000<@3IfMT3000001X0fMWI3000000:0=WIf@@00000<03IfMT2000000X0fMWI002=
0=WIf@l000008@3IfMT?000000d0fMWI00<000000=WIf@3IfMT0O@3IfMT?000004P0fMWI002<0=WI
fA000000803IfMT@000000d0fMWI0`00001l0=WIfA000000B03IfMT008`0fMWI4@00000O0=WIfA40
0000303IfMT00`000000fMWI0=WIf@1l0=WIfA400000A`3IfMT008/0fMWI4`00000M0=WIfA<00000
2`3IfMT00`000000fMWI0=WIf@1k0=WIfA<00000AP3IfMT008/0fMWI4`00000M0=WIfA<000002`3I
fMT00`000000fMWI0=WIf@1k0=WIfA<00000AP3IfMT008/0fMWI4`00000M0=WIfA<000002`3IfMT0
0`000000fMWI0=WIf@1k0=WIfA<00000AP3IfMT008/0fMWI4`00000M0=WIfA<000002`3IfMT00`00
0000fMWI0=WIf@1k0=WIfA<00000AP3IfMT008X0fMWI5000000L0=WIfA@000002`3IfMT00`000000
fMWI0=WIf@1j0=WIfA@00000AP3IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI01<00000203IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI4`00
00000`3IfMT000000=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI01<00000203IfMT00`000000fMWI0=WI
f@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT000d0fMWI00<00000
0=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI01D0fMWI4`000008
0=WIf@030000003IfMT0fMWI0180fMWI4`00000;0=WIf@030000003IfMT0fMWI0300fMWI00<00000
0=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0E0=WIfA<00000203IfMT00`000000fMWI0=WIf@0`
0=WIf@030000003IfMT0fMWI00P0fMWI002;0=WIfA<000007@3IfMTC000000/0fMWI00<000000=WI
f@3IfMT0N`3IfMTC000004H0fMWI002<0=WIfA4000007`3IfMTA000000`0fMWI00<000000=WIf@3I
fMT0O03IfMTA000004L0fMWI002<0=WIfA000000803IfMT@000000d0fMWI00<000000=WIf@3IfMT0
O03IfMT@000004P0fMWI002=0=WIf@l000008@3IfMT?000000d0fMWI0`00001m0=WIf@l00000B03I
fMT008h0fMWI3000000T0=WIf@`000003`3IfMT00`000000fMWI0=WIf@1n0=WIf@`00000BP3IfMT0
0900fMWI2@00000W0=WIf@T00000403IfMT00`000000fMWI0=WIf@200=WIf@T00000B`3IfMT009@0
fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI08@0
fMWI00<000000=WIf@3IfMT0C@3IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT30000
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:l0fMWI100000070=WIf@8000001@3IfMT7000000@0fMWI1@0000080=WIf@030000003IfMT0fMWI
0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000060=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT01P3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0=0=WIf@050000003IfMT0fMWI0=WI
f@0000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@0:0=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI
00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WIf@030000003IfMT0fMWI00X0fMWI00<00000
0=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<000001P3IfMT5000000P0fMWI0`00003D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000L0fMWI0P0000060=WIf@D00000203I
fMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT010000000fMWI0=WIf@0000070=WIf@8000002P3I
fMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0e03IfMT0
0;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI
00D0fMWI1000003C0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0
fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WIf@3I
fMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03I
fMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003I
fMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0
fMWI0P0000080=WIf@030000003IfMT0fMWI00D0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0
fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000080=WIf@030000003IfMT0fMWI00T0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI
00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@0?0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@04
0=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5
000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0
fMWI002_0=WIf@040000003IfMT0fMWI000000h0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI
1000000>0=WIf@L00000103IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00
003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00b`3IfMT7000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000
003IfMT0fMWI0=@0fMWI003>0=WIf@030000003IfMT0fMWI00P0fMWI1000003C0=WIf@00cP3IfMT0
0`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000
fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00b`3IfMT2000000030=WIf@00
0000fMWI0>00fMWI003=0=WIf@800000h@3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.32841 .30902 Mdot
.44772 .30902 Mdot
.82841 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT0:P3IfMT2000000<0fMWI
0P00000D0=WIf@T000003`3IfMT2000000030=WIf@000000fMWI01@0fMWI2@00000@0=WIf@030000
003IfMT0fMWI02`0fMWI0P0000000`3IfMT000000=WIf@0^0=WIf@8000000`3IfMT2000001X0fMWI
2@00000?0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
000_0=WIf@<00000503IfMT<00000100fMWI0P00000C0=WIf@`000003`3IfMT00`000000fMWI0=WI
f@0^0=WIf@800000<@3IfMT3000001X0fMWI3000000:0=WIf@@00000<03IfMT2000000X0fMWI002<
0=WIf@l000008P3IfMT?000000d0fMWI00<000000=WIf@3IfMT0O@3IfMT?000004P0fMWI002;0=WI
fA0000008@3IfMT@000000d0fMWI0`00001l0=WIfA000000B03IfMT008/0fMWI4@00000P0=WIfA40
0000303IfMT00`000000fMWI0=WIf@1l0=WIfA400000A`3IfMT008X0fMWI4`00000N0=WIfA<00000
2`3IfMT00`000000fMWI0=WIf@1k0=WIfA<00000AP3IfMT008X0fMWI4`00000N0=WIfA<000002`3I
fMT00`000000fMWI0=WIf@1k0=WIfA<00000AP3IfMT008X0fMWI4`00000N0=WIfA<000002`3IfMT0
0`000000fMWI0=WIf@1k0=WIfA<00000AP3IfMT008X0fMWI4`00000N0=WIfA<000002`3IfMT00`00
0000fMWI0=WIf@1k0=WIfA<00000AP3IfMT008T0fMWI5000000M0=WIfA@000002`3IfMT00`000000
fMWI0=WIf@1j0=WIfA@00000AP3IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT00000018000002@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI4`00
00000`3IfMT000000=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI01<00000203IfMT00`000000fMWI0=WI
f@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT000d0fMWI00<00000
0=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI01@0fMWI4`000009
0=WIf@030000003IfMT0fMWI0180fMWI4`00000;0=WIf@030000003IfMT0fMWI0300fMWI00<00000
0=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0E0=WIfA<00000203IfMT00`000000fMWI0=WIf@0`
0=WIf@030000003IfMT0fMWI00P0fMWI002:0=WIfA<000007P3IfMTC000000/0fMWI00<000000=WI
f@3IfMT0N`3IfMTC000004H0fMWI002;0=WIfA400000803IfMTA000000`0fMWI00<000000=WIf@3I
fMT0O03IfMTA000004L0fMWI002;0=WIfA0000008@3IfMT@000000d0fMWI00<000000=WIf@3IfMT0
O03IfMT@000004P0fMWI002<0=WIf@l000008P3IfMT?000000d0fMWI0`00001m0=WIf@l00000B03I
fMT008d0fMWI3000000U0=WIf@`000003`3IfMT00`000000fMWI0=WIf@1n0=WIf@`00000BP3IfMT0
08l0fMWI2@00000X0=WIf@T00000403IfMT00`000000fMWI0=WIf@200=WIf@T00000B`3IfMT009<0
fMWI00<000000=WIf@3IfMT0;P3IfMT00`000000fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI08@0
fMWI00<000000=WIf@3IfMT0C@3IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT30000
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:l0fMWI100000070=WIf@8000001@3IfMT7000000@0fMWI1@0000080=WIf@030000003IfMT0fMWI
0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000060=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT01P3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0=0=WIf@050000003IfMT0fMWI0=WI
f@0000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@0:0=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI
00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WIf@030000003IfMT0fMWI00X0fMWI00<00000
0=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<000001P3IfMT5000000P0fMWI0`00003D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000L0fMWI0P0000060=WIf@D00000203I
fMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT010000000fMWI0=WIf@0000070=WIf@8000002P3I
fMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0e03IfMT0
0;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI
00D0fMWI1000003C0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0
fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WIf@3I
fMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03I
fMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003I
fMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0
fMWI0P0000080=WIf@030000003IfMT0fMWI00D0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0
fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000080=WIf@030000003IfMT0fMWI00T0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI
00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@0?0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@04
0=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5
000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0
fMWI002_0=WIf@040000003IfMT0fMWI000000h0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI
1000000>0=WIf@L00000103IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00
003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00b`3IfMT7000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000
003IfMT0fMWI0=@0fMWI003>0=WIf@030000003IfMT0fMWI00P0fMWI1000003C0=WIf@00cP3IfMT0
0`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000
fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00b`3IfMT2000000030=WIf@00
0000fMWI0>00fMWI003=0=WIf@800000h@3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.32386 .30902 Mdot
.45076 .30902 Mdot
.82386 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT0:P3IfMT2000000<0fMWI
0P00000C0=WIf@T00000403IfMT2000000030=WIf@000000fMWI01D0fMWI2@00000?0=WIf@030000
003IfMT0fMWI02`0fMWI0P0000000`3IfMT000000=WIf@0^0=WIf@8000000`3IfMT2000001P0fMWI
2@00000A0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
000_0=WIf@<000004`3IfMT<00000140fMWI0P00000D0=WIf@`000003P3IfMT00`000000fMWI0=WI
f@0^0=WIf@800000<@3IfMT3000001P0fMWI3000000<0=WIf@@00000<03IfMT2000000X0fMWI002;
0=WIf@l00000903IfMT?000000`0fMWI00<000000=WIf@3IfMT0N`3IfMT?000004X0fMWI002:0=WI
fA0000008`3IfMT@000000`0fMWI0`00001j0=WIfA000000BP3IfMT008X0fMWI4@00000R0=WIfA40
00002`3IfMT00`000000fMWI0=WIf@1j0=WIfA400000B@3IfMT008T0fMWI4`00000P0=WIfA<00000
2P3IfMT00`000000fMWI0=WIf@1i0=WIfA<00000B03IfMT008T0fMWI4`00000P0=WIfA<000002P3I
fMT00`000000fMWI0=WIf@1i0=WIfA<00000B03IfMT008T0fMWI4`00000P0=WIfA<000002P3IfMT0
0`000000fMWI0=WIf@1i0=WIfA<00000B03IfMT008T0fMWI4`00000P0=WIfA<000002P3IfMT00`00
0000fMWI0=WIf@1i0=WIfA<00000B03IfMT008P0fMWI5000000O0=WIfA@000002P3IfMT00`000000
fMWI0=WIf@1h0=WIfA@00000B03IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIfAD000002@3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI5@0000090=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIfAD000002@3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT000d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0
fMWI01<0fMWI4`00000:0=WIf@030000003IfMT0fMWI01<0fMWI4`00000:0=WIf@030000003IfMT0
fMWI0300fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0C0=WIfA<000002P3IfMT0
0`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI00P0fMWI00290=WIfA<00000803IfMTC0000
00X0fMWI00<000000=WIf@3IfMT0N@3IfMTC000004P0fMWI002:0=WIfA4000008P3IfMTA000000/0
fMWI00<000000=WIf@3IfMT0NP3IfMTA000004T0fMWI002:0=WIfA0000008`3IfMT@000000`0fMWI
00<000000=WIf@3IfMT0NP3IfMT@000004X0fMWI002;0=WIf@l00000903IfMT?000000`0fMWI0`00
001k0=WIf@l00000BP3IfMT008`0fMWI3000000W0=WIf@`000003P3IfMT00`000000fMWI0=WIf@1l
0=WIf@`00000C03IfMT008h0fMWI2@00000Z0=WIf@T000003`3IfMT00`000000fMWI0=WIf@1n0=WI
f@T00000C@3IfMT00980fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0A0=WIf@03
0000003IfMT0fMWI0880fMWI00<000000=WIf@3IfMT0C`3IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@8000001@3IfMT7000000@0fMWI1@0000080=WI
f@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000060=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01P3IfMT2000000L0fMWI00<000000=WI
f@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0=0=WIf@05
0000003IfMT0fMWI0=WIf@0000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI
0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03P3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00[P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003IfMT0fMWI0=WIf@80
00001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0
e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<000001P3IfMT50000
00P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000L0fMWI0P00
00060=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT010000000fMWI0=WIf@00
00070=WIf@8000002P3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00D0fMWI00<00000
0=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WI
f@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI
0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<0
00000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI0`00003D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00
003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00[`3IfMT4000000L0fMWI0P0000080=WIf@030000003IfMT0fMWI00D0fMWI1@0000080=WIf@03
0000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000080=WIf@03
0000003IfMT0fMWI00T0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000
003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01@3I
fMT400000=<0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT0
0`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WI
f@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<00000
0=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@03
0000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000h0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3I
fMT0e03IfMT00:l0fMWI1000000>0=WIf@L00000103IfMT5000000P0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00b`3IfMT7000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0
fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI
0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@030000003IfMT0fMWI00P0fMWI1000
003C0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WI
f@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00b`3I
fMT2000000030=WIf@000000fMWI0>00fMWI003=0=WIf@800000h@3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.31648 .30902 Mdot
.45568 .30902 Mdot
.81648 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT0:P3IfMT2000000<0fMWI
0P00000@0=WIf@T000004`3IfMT2000000030=WIf@000000fMWI01L0fMWI2@00000=0=WIf@030000
003IfMT0fMWI02`0fMWI0P0000000`3IfMT000000=WIf@0^0=WIf@8000000`3IfMT2000001D0fMWI
2@00000D0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
000_0=WIf@<00000403IfMT<000001@0fMWI0P00000F0=WIf@`00000303IfMT00`000000fMWI0=WI
f@0^0=WIf@800000<@3IfMT3000001D0fMWI3000000?0=WIf@@00000<03IfMT2000000X0fMWI0028
0=WIf@l00000:@3IfMT?000000X0fMWI00<000000=WIf@3IfMT0N03IfMT?000004d0fMWI00270=WI
fA000000:03IfMT@000000X0fMWI0`00001g0=WIfA000000C@3IfMT008L0fMWI4@00000W0=WIfA40
00002@3IfMT00`000000fMWI0=WIf@1g0=WIfA400000C03IfMT008H0fMWI4`00000U0=WIfA<00000
203IfMT00`000000fMWI0=WIf@1f0=WIfA<00000B`3IfMT008H0fMWI4`00000U0=WIfA<00000203I
fMT00`000000fMWI0=WIf@1f0=WIfA<00000B`3IfMT008H0fMWI4`00000U0=WIfA<00000203IfMT0
0`000000fMWI0=WIf@1f0=WIfA<00000B`3IfMT008H0fMWI4`00000U0=WIfA<00000203IfMT00`00
0000fMWI0=WIf@1f0=WIfA<00000B`3IfMT008D0fMWI5000000T0=WIfA@00000203IfMT00`000000
fMWI0=WIf@1e0=WIfA@00000B`3IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@060=WIfA<000000`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@0C000000P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WI
f@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WI
f@080=WIf@030000003IfMT0fMWI00D0fMWI4`0000030=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI000=
0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0@
0=WIfA<000003@3IfMT00`000000fMWI0=WIf@0E0=WIfA<00000203IfMT00`000000fMWI0=WIf@0`
0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0403IfMTC000000d0fMWI00<00000
0=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@080=WIf@00QP3IfMTC000002D0fMWI4`0000080=WI
f@030000003IfMT0fMWI07H0fMWI4`00001;0=WIf@00Q`3IfMTA000002L0fMWI4@0000090=WIf@03
0000003IfMT0fMWI07L0fMWI4@00001<0=WIf@00Q`3IfMT@000002P0fMWI4000000:0=WIf@030000
003IfMT0fMWI07L0fMWI4000001=0=WIf@00R03IfMT?000002T0fMWI3`00000:0=WIf@<00000N03I
fMT?000004d0fMWI00290=WIf@`00000;03IfMT<000000`0fMWI00<000000=WIf@3IfMT0N@3IfMT<
000004l0fMWI002;0=WIf@T00000;`3IfMT9000000d0fMWI00<000000=WIf@3IfMT0N`3IfMT90000
0500fMWI002?0=WIf@030000003IfMT0fMWI03D0fMWI00<000000=WIf@3IfMT03`3IfMT00`000000
fMWI0=WIf@1o0=WIf@030000003IfMT0fMWI0580fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI002_0=WIf@@000001`3IfMT2000000D0fMWI1`0000040=WIf@D00000203IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@8000001P3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00H0fMWI0P0000070=WIf@030000003IfMT0fMWI
0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03@3IfMT01@000000
fMWI0=WIf@3IfMT0000000T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3I
fMT02P3IfMT00`000000fMWI0=WIf@050=WIf@@00000d`3IfMT00:h0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@8000001@3IfMT010000000fMWI0=WIf@3IfMT2000000L0
fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI
002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WI
f@040000003IfMT0fMWI000000h0fMWI0P0000030=WIf@800000103IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@@00000403IfMT3000000H0fMWI1@0000080=WI
f@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI100000070=WIf@8000001P3I
fMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT000001`3I
fMT2000000X0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0
fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`00
0000fMWI0=WIf@050=WIf@@00000d`3IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0<0=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WI
f@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI1@0000080=WIf@03
0000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
303IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0:0=WIf@030000003I
fMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000l0fMWI00<000000=WIf@3IfMT02P3I
fMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000l0fMWI1@0000080=WIf@<00000e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0
fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@050=WIf@D00000203IfMT00`000000
fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@800000203IfMT00`000000
fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI
0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI1000
003C0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<00000
0=WIf@3IfMT0103IfMT010000000fMWI0=WIf@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03I
fMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0
fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@00000>0=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0
fMWI002_0=WIf@@000003P3IfMT7000000@0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00</0fMWI1`0000070=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@03
0000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3IfMT0
203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@@00000d`3I
fMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0
fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00</0fMWI0P00
00000`3IfMT000000=WIf@3P0=WIf@00c@3IfMT200000>40fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.30653 .30902 Mdot
.46231 .30902 Mdot
.80653 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT0:P3IfMT2000000<0fMWI
0P00000<0=WIf@T000005`3IfMT2000000030=WIf@000000fMWI01X0fMWI2@00000:0=WIf@030000
003IfMT0fMWI02`0fMWI0P0000000`3IfMT000000=WIf@0^0=WIf@8000000`3IfMT200000140fMWI
2@00000H0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
000_0=WIf@<00000303IfMT<000001P0fMWI0P00000I0=WIf@`000002@3IfMT00`000000fMWI0=WI
f@0^0=WIf@800000<@3IfMT300000140fMWI3000000C0=WIf@@00000<03IfMT2000000X0fMWI0024
0=WIf@l00000<03IfMT?000000L0fMWI00<000000=WIf@3IfMT0M03IfMT?00000540fMWI00230=WI
fA000000;`3IfMT@000000L0fMWI0`00001c0=WIfA000000D@3IfMT008<0fMWI4@00000^0=WIfA40
00001P3IfMT00`000000fMWI0=WIf@1c0=WIfA400000D03IfMT00880fMWI4`00000/0=WIfA<00000
1@3IfMT00`000000fMWI0=WIf@1b0=WIfA<00000C`3IfMT00880fMWI4`00000/0=WIfA<000001@3I
fMT00`000000fMWI0=WIf@1b0=WIfA<00000C`3IfMT00880fMWI4`00000/0=WIfA<000001@3IfMT0
0`000000fMWI0=WIf@1b0=WIfA<00000C`3IfMT00880fMWI4`00000/0=WIfA<000001@3IfMT00`00
0000fMWI0=WIf@1b0=WIfA<00000C`3IfMT00840fMWI5000000[0=WIfA@000001@3IfMT00`000000
fMWI0=WIf@1a0=WIfA@00000C`3IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@020=WIfA<000001`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@030=WIfA<000001@3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00@000000=WIf@3IfMT0fMWI4`0000070=WIf@030000003IfMT0fMWI00L0fMWI
00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI
00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI
000=0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WI
f@0<0=WIfA<000004@3IfMT00`000000fMWI0=WIf@0H0=WIfA<000001@3IfMT00`000000fMWI0=WI
f@0`0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0303IfMTC00000140fMWI00<0
00000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@080=WIf@00PP3IfMTC000002`0fMWI4`000005
0=WIf@030000003IfMT0fMWI0780fMWI4`00001?0=WIf@00P`3IfMTA000002h0fMWI4@0000060=WI
f@030000003IfMT0fMWI07<0fMWI4@00001@0=WIf@00P`3IfMT@000002l0fMWI400000070=WIf@03
0000003IfMT0fMWI07<0fMWI4000001A0=WIf@00Q03IfMT?00000300fMWI3`0000070=WIf@<00000
M03IfMT?00000540fMWI00250=WIf@`00000<`3IfMT<000000T0fMWI00<000000=WIf@3IfMT0M@3I
fMT<000005<0fMWI00270=WIf@T00000=P3IfMT9000000X0fMWI00<000000=WIf@3IfMT0M`3IfMT9
000005@0fMWI002;0=WIf@030000003IfMT0fMWI03`0fMWI00<000000=WIf@3IfMT0303IfMT00`00
0000fMWI0=WIf@1k0=WIf@030000003IfMT0fMWI05H0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI002_0=WIf@@000001`3IfMT2000000D0fMWI1`0000040=WIf@D00000203IfMT0
0`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@8000001P3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00H0fMWI0P0000070=WIf@030000003IfMT0
fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03@3IfMT01@00
0000fMWI0=WIf@3IfMT0000000T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@050=WIf@@00000d`3IfMT00:h0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@0?0=WIf@8000001@3IfMT010000000fMWI0=WIf@3IfMT20000
00L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0
fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00<0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_
0=WIf@040000003IfMT0fMWI000000h0fMWI0P0000030=WIf@800000103IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@@00000403IfMT3000000H0fMWI1@000008
0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI100000070=WIf@800000
1P3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT00000
1`3IfMT2000000X0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@050=WIf@030000003I
fMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT0
0`000000fMWI0=WIf@050=WIf@@00000d`3IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@0<0=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI1@0000080=WI
f@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0303IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000l0fMWI00<000000=WIf@3IfMT0
2P3IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000l0fMWI1@0000080=WIf@<00000e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@050=WIf@D00000203IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@800000203IfMT00`00
0000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000
fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI
1000003C0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<0
00000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0
e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003I
fMT0fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@00000>0=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI
0=@0fMWI002_0=WIf@@000003P3IfMT7000000@0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00</0fMWI1`0000070=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WI
f@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@@00000
d`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT0
0<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00</0fMWI
0P0000000`3IfMT000000=WIf@3P0=WIf@00c@3IfMT200000>40fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.29442 .30902 Mdot
.47039 .30902 Mdot
.79442 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT0:P3IfMT2000000<0fMWI
0P0000070=WIf@T00000703IfMT2000000030=WIf@000000fMWI01d0fMWI2@0000070=WIf@030000
003IfMT0fMWI02`0fMWI0P0000000`3IfMT000000=WIf@0^0=WIf@8000000`3IfMT2000000`0fMWI
2@00000M0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
000_0=WIf@<000001`3IfMT<000001d0fMWI0P00000L0=WIf@`000001P3IfMT00`000000fMWI0=WI
f@0^0=WIf@800000<@3IfMT3000000`0fMWI3000000H0=WIf@@00000<03IfMT2000000X0fMWI001o
0=WIf@l00000>03IfMT?000000@0fMWI00<000000=WIf@3IfMT0K`3IfMT?000005H0fMWI001n0=WI
fA000000=`3IfMT@000000@0fMWI0`00001^0=WIfA000000EP3IfMT007h0fMWI4@00000f0=WIfA40
00000`3IfMT00`000000fMWI0=WIf@1^0=WIfA400000E@3IfMT007d0fMWI4`00000d0=WIfA<00000
0P3IfMT00`000000fMWI0=WIf@1]0=WIfA<00000E03IfMT007d0fMWI4`00000d0=WIfA<000000P3I
fMT00`000000fMWI0=WIf@1]0=WIfA<00000E03IfMT007d0fMWI4`00000d0=WIfA<000000P3IfMT0
0`000000fMWI0=WIf@1]0=WIfA<00000E03IfMT007d0fMWI4`00000d0=WIfA<000000P3IfMT00`00
0000fMWI0=WIf@1]0=WIfA<00000E03IfMT007`0fMWI5000000c0=WIfA@000000P3IfMT00`000000
fMWI0=WIf@1/0=WIfA@00000E03IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMTC00000080fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@060=WIfA<000000P3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI4`0000020=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT000d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0
fMWI00L0fMWI4`00000F0=WIf@030000003IfMT0fMWI01/0fMWI4`0000020=WIf@030000003IfMT0
fMWI0300fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@070=WIfA<000005P3IfMT0
0`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI00P0fMWI001m0=WIfA<00000=03IfMTC0000
0080fMWI00<000000=WIf@3IfMT0K@3IfMTC000005@0fMWI001n0=WIfA400000=P3IfMTA000000<0
fMWI00<000000=WIf@3IfMT0KP3IfMTA000005D0fMWI001n0=WIfA000000=`3IfMT@000000@0fMWI
00<000000=WIf@3IfMT0KP3IfMT@000005H0fMWI001o0=WIf@l00000>03IfMT?000000@0fMWI0`00
001_0=WIf@l00000EP3IfMT00800fMWI3000000k0=WIf@`000001P3IfMT00`000000fMWI0=WIf@1`
0=WIf@`00000F03IfMT00880fMWI2@00000n0=WIf@T000001`3IfMT00`000000fMWI0=WIf@1b0=WI
f@T00000F@3IfMT008H0fMWI00<000000=WIf@3IfMT0A03IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI07H0fMWI00<000000=WIf@3IfMT0F`3IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@8000001@3IfMT7000000@0fMWI1@0000080=WI
f@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000060=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01P3IfMT2000000L0fMWI00<000000=WI
f@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0=0=WIf@05
0000003IfMT0fMWI0=WIf@0000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI
0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03P3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00[P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003IfMT0fMWI0=WIf@80
00001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0
e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<000001P3IfMT50000
00P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000L0fMWI0P00
00060=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT010000000fMWI0=WIf@00
00070=WIf@8000002P3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00D0fMWI00<00000
0=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WI
f@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI
0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<0
00000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI0`00003D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00
003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00[`3IfMT4000000L0fMWI0P0000080=WIf@030000003IfMT0fMWI00D0fMWI1@0000080=WIf@03
0000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000080=WIf@03
0000003IfMT0fMWI00T0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000
003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01@3I
fMT400000=<0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT0
0`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WI
f@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<00000
0=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@03
0000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000h0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3I
fMT0e03IfMT00:l0fMWI1000000>0=WIf@L00000103IfMT5000000P0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00b`3IfMT7000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0
fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI
0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@030000003IfMT0fMWI00P0fMWI1000
003C0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WI
f@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00b`3I
fMT2000000030=WIf@000000fMWI0>00fMWI003=0=WIf@800000h@3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.2806 .30902 Mdot
.4796 .30902 Mdot
.7806 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT0:P3IfMT2000000<0fMWI
0P0000000`3IfMT000000000000700000280fMWI0P0000000`3IfMT000000=WIf@0Q0=WIf@T00000
0`3IfMT00`000000fMWI0=WIf@0/0=WIf@80000000<0fMWI0000003IfMT0;P3IfMT2000000<0fMWI
0P0000060=WIf@T000008`3IfMT00`000000fMWI0=WIf@0]0=WIf@8000002P3IfMT00140fMWI0P00
000`0=WIf@@00000;`3IfMT3000000030=WIf@000000000000X000008`3IfMT200000200fMWI3000
00020=WIf@030000003IfMT0fMWI02h0fMWI0P00000a0=WIf@<000001P3IfMT<000001h0fMWI1000
000`0=WIf@8000002P3IfMT007T0fMWI3`0000120=WIfA000000J`3IfMT?000005`0fMWI001h0=WI
fA000000@@3IfMTC000006P0fMWI4000001L0=WIf@00N03IfMTA00000400fMWI4@00001Z0=WIfA40
0000F`3IfMT007L0fMWI4`00000n0=WIfA<00000J03IfMTC000005X0fMWI001g0=WIfA<00000?P3I
fMTC000006P0fMWI4`00001J0=WIf@00M`3IfMTC000003h0fMWI4`00001X0=WIfA<00000FP3IfMT0
07L0fMWI4`00000n0=WIfA<00000J03IfMTC000005X0fMWI001f0=WIfA@00000?@3IfMTD000006L0
fMWI5000001J0=WIf@003@3IfMWo000009X000002P3IfMT000d0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT010000000fMWI0=WIf@3IfMTC000000P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI
0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI
0=WIf@070=WIf@030000003IfMT0fMWI01<00000203IfMT00`000000fMWI0=WIf@080=WIf@030000
003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000
003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000
003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT010000000fMWI0=WIf@3IfMTC000000P0
fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0
fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0
fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@003@3IfMT00`000000fMWI
0=WIf@0`0=WIf@030000003IfMT0fMWI0300fMWI00@000000=WIf@3IfMT0fMWI4`00000L0=WIf@03
0000003IfMT0fMWI01l0fMWI4`00000a0=WIf@030000003IfMT0fMWI0300fMWI00@000000=WIf@3I
fMT0fMWI4`00000L0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0203IfMT007L0
fMWI4`00000n0=WIfA<00000J03IfMTC000005X0fMWI001h0=WIfA400000@03IfMTA000006X0fMWI
4@00001K0=WIf@00N03IfMT@00000440fMWI4@00001Z0=WIfA000000G03IfMT007T0fMWI3`000012
0=WIfA800000J@3IfMT?000005`0fMWI001j0=WIf@`00000A@3IfMT<00000080fMWI00<000000=WI
f@3IfMT0JP3IfMT<000005h0fMWI001l0=WIf@T00000B03IfMT9000000<0fMWI00<000000=WIf@3I
fMT0K03IfMT9000005l0fMWI00200=WIf@030000003IfMT0fMWI04h0fMWI00<000000=WIf@3IfMT0
1@3IfMT00`000000fMWI0=WIf@1`0=WIf@030000003IfMT0fMWI0640fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI002_0=WIf@@000001`3IfMT2000000D0fMWI1`0000040=WIf@D0
0000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@80
00001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00H0fMWI0P0000070=WIf@03
0000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
3@3IfMT01@000000fMWI0=WIf@3IfMT0000000T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00h0fMWI
00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@050=WIf@@00000d`3IfMT00:h0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0?0=WIf@8000001@3IfMT010000000fMWI0=WI
f@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI1@0000080=WIf@030000003I
fMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI
0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000h0fMWI0P0000030=WIf@800000103IfMT00`00
0000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@@00000403IfMT3000000H0
fMWI1@0000080=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI10000007
0=WIf@8000001P3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WI
f@3IfMT000001`3IfMT2000000X0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@050=WI
f@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT04@3IfMT00`000000fMWI0=WIf@050=WIf@@00000d`3IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI
1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002h
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000l0fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000l0fMWI1@0000080=WI
f@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@050=WIf@D00000
203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@800000
203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT02@3I
fMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00D0fMWI1000003C0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00l0fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@3IfMT2000000L0fMWI00<00000
0=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WI
f@030000003IfMT0fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0
2P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@00000>0=WIf@030000
003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002_0=WIf@@000003P3IfMT7000000@0fMWI1@0000080=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00</0fMWI1`0000070=WIf@030000003IfMT0fMWI0=@0
fMWI003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<0
00000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@08
0=WIf@@00000d`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3I
fMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3I
fMT00</0fMWI0P0000000`3IfMT000000=WIf@3P0=WIf@00c@3IfMT200000>40fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.2656 .30902 Mdot
.4896 .30902 Mdot
.7656 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT0:P3IfMT;000002P0fMWI
0P0000000`3IfMT000000=WIf@0U0=WIf@T00000;P3IfMT2000000030=WIf@000000fMWI02h0fMWI
0P0000030=WIf@/00000:@3IfMT00`000000fMWI0=WIf@0]0=WIf@8000002P3IfMT00140fMWI0P00
000`0=WIf@@00000;@3IfMT<000002T0fMWI0P00000T0=WIf@`00000;`3IfMT200000340fMWI3`00
000T0=WIf@@00000<03IfMT2000000X0fMWI001c0=WIf@l00000C03IfMT?00000680fMWI3`00001R
0=WIf@00LP3IfMT@000004/0fMWI4000001Q0=WIfA000000HP3IfMT00780fMWI4@00001:0=WIfA40
0000H03IfMTA00000640fMWI001a0=WIfA<00000B03IfMTC000005h0fMWI4`00001P0=WIf@00L@3I
fMTC000004P0fMWI4`00001N0=WIfA<00000H03IfMT00740fMWI4`0000180=WIfA<00000GP3IfMTC
00000600fMWI001a0=WIfA<00000B03IfMTC000005h0fMWI4`00001P0=WIf@00L03IfMTD000004L0
fMWI5000001M0=WIfA@00000H03IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00D0fMWI4`0000040=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00@0fMWI4`0000040=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@050=WIfA<00000103I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT000d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0^0=WIfA<000008P3IfMT0
0`000000fMWI0=WIf@0S0=WIfA<00000;@3IfMT00`000000fMWI0=WIf@0^0=WIfA<000008P3IfMT0
0`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI00P0fMWI001a0=WIfA<00000B03IfMTC0000
05h0fMWI4`00001P0=WIf@00LP3IfMTA000004X0fMWI4@00001P0=WIfA400000H@3IfMT00780fMWI
4000001;0=WIfA000000H@3IfMT@00000680fMWI001c0=WIf@l00000C03IfMT?00000680fMWI3`00
001R0=WIf@00M03IfMT<000004l0fMWI3000001U0=WIf@`00000I03IfMT007H0fMWI2@00001B0=WI
f@T00000J03IfMT9000006D0fMWI001j0=WIf@030000003IfMT0fMWI05P0fMWI00D000000=WIf@3I
fMT0fMWI0000001/0=WIf@030000003IfMT0fMWI06L0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI002_0=WIf@@000001`3IfMT2000000D0fMWI1`0000040=WIf@D00000203IfMT0
0`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@8000001P3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00H0fMWI0P0000070=WIf@030000003IfMT0
fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03@3IfMT01@00
0000fMWI0=WIf@3IfMT0000000T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@050=WIf@@00000d`3IfMT00:h0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@0?0=WIf@8000001@3IfMT010000000fMWI0=WIf@3IfMT20000
00L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0
fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00<0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_
0=WIf@040000003IfMT0fMWI000000h0fMWI0P0000030=WIf@800000103IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@@00000403IfMT3000000H0fMWI1@000008
0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI100000070=WIf@800000
1P3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT00000
1`3IfMT2000000X0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@050=WIf@030000003I
fMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT0
0`000000fMWI0=WIf@050=WIf@@00000d`3IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@0<0=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI1@0000080=WI
f@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0303IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000l0fMWI00<000000=WIf@3IfMT0
2P3IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000l0fMWI1@0000080=WIf@<00000e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@050=WIf@D00000203IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@800000203IfMT00`00
0000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000
fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI
1000003C0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<0
00000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0
e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003I
fMT0fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@00000>0=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI
0=@0fMWI002_0=WIf@@000003P3IfMT7000000@0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00</0fMWI1`0000070=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WI
f@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@@00000
d`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT0
0<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00</0fMWI
0P0000000`3IfMT000000=WIf@3P0=WIf@00c@3IfMT200000>40fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.25 .30902 Mdot
.5 .30902 Mdot
.75 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT09@3IfMT9000000030=WI
f@000000000002`0fMWI0P0000000`3IfMT000000=WIf@0Z0=WIf@T00000:@3IfMT2000000030=WI
f@000000fMWI02h0fMWI2P00000_0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3I
fMT200000300fMWI1000000V0=WIf@`00000<03IfMT2000002T0fMWI3000000Z0=WIf@800000;P3I
fMT<000002X0fMWI1000000`0=WIf@8000002P3IfMT006`0fMWI3`00001H0=WIf@l00000E`3IfMT?
000006P0fMWI001[0=WIfA000000E`3IfMT@000005H0fMWI4000001X0=WIf@00J`3IfMTA000005H0
fMWI4@00001E0=WIfA400000I`3IfMT006X0fMWI4`00001D0=WIfA<00000D`3IfMTC000006H0fMWI
001Z0=WIfA<00000E03IfMTC000005<0fMWI4`00001V0=WIf@00JP3IfMTC000005@0fMWI4`00001C
0=WIfA<00000IP3IfMT006X0fMWI4`00001D0=WIfA<00000D`3IfMTC000006H0fMWI001Y0=WIfA@0
0000D`3IfMTD00000580fMWI5000001V0=WIf@003@3IfMWo000009X000002P3IfMT000d0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI5@00
000:0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@0000004P00000:0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@0000004`0000090=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@003@3IfMT00`000000fMWI0=WIf@0`
0=WIf@030000003IfMT0fMWI02L0fMWI4`00000Y0=WIf@030000003IfMT0fMWI02P0fMWI4`00000X
0=WIf@030000003IfMT0fMWI02P0fMWI4`00000X0=WIf@030000003IfMT0fMWI0300fMWI00<00000
0=WIf@3IfMT0203IfMT006X0fMWI4`00001D0=WIfA<00000D`3IfMTC000006H0fMWI001[0=WIfA40
0000EP3IfMTA000005D0fMWI4@00001W0=WIf@00J`3IfMT@000005L0fMWI4000001F0=WIfA000000
J03IfMT006`0fMWI3`00001H0=WIf@l00000E`3IfMT?000006P0fMWI001]0=WIf@`00000F`3IfMT<
000005X0fMWI3000001Z0=WIf@00K`3IfMT9000005h0fMWI2@00001M0=WIf@T00000J`3IfMT007<0
fMWI00<000000=WIf@3IfMT0H`3IfMT2000006D0fMWI00<000000=WIf@3IfMT0K@3IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@8000001@3IfMT70000
00@0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI0000
00L0fMWI0P0000060=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01P3IfMT20000
00L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0=0=WIf@050000003IfMT0fMWI0=WIf@0000002@3IfMT00`000000fMWI0=WIf@050=WI
f@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT03P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00
[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000
003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI
00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@0A0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WI
f@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<00000
0=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P000004
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WI
f@<000001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3I
fMT4000000L0fMWI0P0000060=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT0
10000000fMWI0=WIf@0000070=WIf@8000002P3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03I
fMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0
fMWI00D0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00^03IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WI
f@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0303IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003I
fMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3I
fMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5
000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000080=WIf@030000003IfMT0fMWI00D0
fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0
fMWI0P0000080=WIf@030000003IfMT0fMWI00T0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0
fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI
0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00T0fMWI00<0
00000=WIf@3IfMT01@3IfMT400000=<0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI0=WIf@8000001`3I
fMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000h0
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000>0=WIf@L00000103IfMT5000000P0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT3
00000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT7000000L0fMWI00<000000=WI
f@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00
cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@030000003I
fMT0fMWI00P0fMWI1000003C0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`00
0000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI
0=WIf@3O0=WIf@00b`3IfMT2000000030=WIf@000000fMWI0>00fMWI003=0=WIf@800000h@3IfMT0
0001\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.2344 .30902 Mdot
.5104 .30902 Mdot
.7344 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT07`3IfMT900000080fMWI
0P0000030=WIf@800000;03IfMT2000000030=WIf@000000fMWI02d0fMWI2P00000U0=WIf@800000
00<0fMWI0000003IfMT0:03IfMT900000080fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI
0P00000:0=WIf@004@3IfMT200000300fMWI1000000P0=WIf@`000000`3IfMT300000300fMWI0P00
000]0=WIf@`000009P3IfMT2000002L0fMWI3@00000`0=WIf@@00000<03IfMT2000000X0fMWI001V
0=WIf@l00000HP3IfMT?000004`0fMWI3`00001_0=WIf@00I@3IfMT@00000640fMWI4000001;0=WI
fA000000K`3IfMT006D0fMWI4@00001P0=WIfA400000BP3IfMTA000006h0fMWI001T0=WIfA<00000
GP3IfMTC000004P0fMWI4`00001]0=WIf@00I03IfMTC000005h0fMWI4`0000180=WIfA<00000K@3I
fMT006@0fMWI4`00001N0=WIfA<00000B03IfMTC000006d0fMWI001T0=WIfA<00000GP3IfMTC0000
04P0fMWI4`00001]0=WIf@00H`3IfMTD000005d0fMWI500000170=WIfA@00000K@3IfMT000d0fMWI
o`00002J000000X0fMWI000=0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@020=WIfA<000001P3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT00`3IfMTC000000H0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT00P3I
fMTC000000L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT000d0fMWI00<000000=WIf@3IfMT0<03IfMT0
0`000000fMWI0=WIf@0Q0=WIfA<00000;`3IfMT00`000000fMWI0=WIf@0/0=WIfA<00000903IfMT0
0`000000fMWI0=WIf@0Q0=WIfA<00000;`3IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0
fMWI00P0fMWI001T0=WIfA<00000GP3IfMTC000004P0fMWI4`00001]0=WIf@00I@3IfMTA00000600
fMWI4@00001:0=WIfA400000KP3IfMT006D0fMWI4000001Q0=WIfA000000B`3IfMT@000006l0fMWI
001V0=WIf@l00000HP3IfMT?000004`0fMWI3`00001_0=WIf@00I`3IfMT<000006D0fMWI3000001?
0=WIf@`00000L@3IfMT006T0fMWI2@00001W0=WIf@X00000DP3IfMT900000780fMWI001]0=WIf@03
0000003IfMT0fMWI06T0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@1H0=WIf@03
0000003IfMT0fMWI07@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WI
f@@000001`3IfMT2000000D0fMWI1`0000040=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WI
f@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@8000001P3IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI00H0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03@3IfMT01@000000fMWI0=WIf@3IfMT00000
00T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000
fMWI0=WIf@050=WIf@@00000d`3IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@0?0=WIf@8000001@3IfMT010000000fMWI0=WIf@3IfMT2000000L0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000
003IfMT0fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI
000000h0fMWI0P0000030=WIf@800000103IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0
fMWI0=@0fMWI002_0=WIf@@00000403IfMT3000000H0fMWI1@0000080=WIf@<00000e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00;T0fMWI100000070=WIf@8000001P3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000X0fMWI0P00
00070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@050=WI
f@@00000d`3IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@04
0000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0
fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI
0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002i
0=WIf@040000003IfMT0fMWI000000l0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WI
f@3D0=WIf@00^@3IfMT4000000l0fMWI1@0000080=WIf@<00000e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@80
0000203IfMT00`000000fMWI0=WIf@050=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00
[`3IfMT010000000fMWI0=WIf@0000070=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@80
00001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000
003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3I
fMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00[P3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT0103IfMT0
10000000fMWI0=WIf@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI1@000008
0=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00
[`3IfMT010000000fMWI0=WIf@00000>0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@@00000
3P3IfMT7000000@0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT30000
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0</0fMWI1`0000070=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@030000003IfMT0fMWI00P0
fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI
0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@@00000d`3IfMT00<h0fMWI00<00000
0=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3I
fMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00</0fMWI0P0000000`3IfMT000000=WI
f@3P0=WIf@00c@3IfMT200000>40fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.2194 .30902 Mdot
.5204 .30902 Mdot
.7194 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT06@3IfMT9000000P0fMWI
0P0000030=WIf@800000;03IfMT2000000030=WIf@000000fMWI02d0fMWI00<000000=WIf@3IfMT0
0P3IfMT900000240fMWI0P0000000`3IfMT000000=WIf@0R0=WIf@T000000`3IfMT2000000<0fMWI
0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
000J0=WIf@`000002@3IfMT300000300fMWI0P00000^0=WIf@030000003IfMT0fMWI00`000008P3I
fMT200000240fMWI300000040=WIf@<00000<03IfMT400000300fMWI0P00000:0=WIf@00H03IfMT?
000006X0fMWI00<000000=WIf@0000003P0000120=WIf@l00000M@3IfMT005l0fMWI4000001Z0=WI
fA400000@@3IfMT@000007D0fMWI001O0=WIfA400000J@3IfMTB00000400fMWI4@00001d0=WIf@00
GP3IfMTC000006P0fMWI4`00000n0=WIfA<00000L`3IfMT005h0fMWI4`00001X0=WIfA<00000?P3I
fMTC000007<0fMWI001N0=WIfA<00000J03IfMTC000003h0fMWI4`00001c0=WIf@00GP3IfMTC0000
06P0fMWI4`00000n0=WIfA<00000L`3IfMT005d0fMWI5000001W0=WIfA@00000?@3IfMTD000007<0
fMWI000=0=WIfOl00000VP00000:0=WIf@003@3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00H0fMWI4`0000020=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI4`0000020=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@060=WIfA<000000P3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI000=0=WIf@030000003IfMT0
fMWI0300fMWI00<000000=WIf@3IfMT06`3IfMTC00000080fMWI00<000000=WIf@3IfMT0<03IfMT0
0`000000fMWI0=WIf@0`0=WIfA<00000803IfMT00`000000fMWI0=WIf@0K0=WIfA<000000P3IfMT0
0`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0203IfMT0
05h0fMWI4`00001X0=WIfA<00000?P3IfMTC000007<0fMWI001O0=WIfA400000J@3IfMTB00000400
fMWI4@00001d0=WIf@00G`3IfMT@000006X0fMWI4@0000110=WIfA000000M@3IfMT00600fMWI3`00
001Z0=WIfA400000@P3IfMT?000007D0fMWI001Q0=WIf@`00000K03IfMT00`000000fMWI0=WIf@0<
000004D0fMWI3000001g0=WIf@00H`3IfMT9000006d0fMWI00<000000=WIf@3IfMT00P3IfMT90000
04P0fMWI2@00001h0=WIf@00I`3IfMT00`000000fMWI0=WIf@1_0=WIf@030000003IfMT0fMWI00H0
fMWI00<000000=WIf@3IfMT0CP3IfMT00`000000fMWI0=WIf@1j0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT50000
00P0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT20000
00H0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0
fMWI00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WI
f@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002^0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT2000000D0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[`3IfMT010000000fMWI0=WIf@00000>0=WIf@8000000`3IfMT2000000@0fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT400000100fMWI0`0000060=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3I
fMT2000000H0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0
fMWI000000L0fMWI0P00000:0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
0140fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002h0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0303IfMT010000000fMWI0=WIf@3IfMT2000000L0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@D0
0000203IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT02P3I
fMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT010000000fMWI0=WIf@00000?0=WIf@030000003I
fMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI1000000?0=WIf@D00000203IfMT3
00000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI002_0=WIf@@000001`3IfMT2000000P0fMWI00<000000=WIf@3IfMT01@3IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000P0
fMWI00<000000=WIf@3IfMT02@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00T0fMWI
00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WI
f@050=WIf@@00000d`3IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0?
0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003I
fMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT0
0`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT00`00
0000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00X0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003;0=WIf@L000001`3IfMT00`000000fMWI0=WIf@3D0=WI
f@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@030000
003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3IfMT0203I
fMT400000=<0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI
003;0=WIf@80000000<0fMWI0000003IfMT0h03IfMT00<d0fMWI0P00003Q0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.20558 .30902 Mdot
.52961 .30902 Mdot
.70558 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT04`3IfMT9000000h0fMWI
0P0000030=WIf@800000;03IfMT2000000030=WIf@000000fMWI02d0fMWI00<000000=WIf@3IfMT0
1P3IfMT9000001d0fMWI0P0000000`3IfMT000000=WIf@0M0=WIf@T00000203IfMT2000000<0fMWI
0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
000D0=WIf@`000003`3IfMT300000300fMWI0P00000^0=WIf@030000003IfMT0fMWI00@0fMWI3000
000N0=WIf@800000703IfMT<000000T0fMWI0`00000`0=WIf@@00000<03IfMT2000000X0fMWI001J
0=WIf@l00000L03IfMT00`000000fMWI0=WIf@030=WIf@l00000>@3IfMT?000007X0fMWI001I0=WI
fA000000L03IfMT300000080fMWI4000000h0=WIfA000000NP3IfMT005T0fMWI4@00001_0=WIf@03
0000003IfMT0fMWI0080fMWI4@00000g0=WIfA400000N@3IfMT005P0fMWI4`00001^0=WIf@040000
003IfMT0fMWI0=WIfA<00000=@3IfMTC000007P0fMWI001H0=WIfA<00000KP3IfMT010000000fMWI
0=WIf@3IfMTC000003D0fMWI4`00001h0=WIf@00F03IfMTC000006h0fMWI00@000000=WIf@3IfMT0
fMWI4`00000e0=WIfA<00000N03IfMT005P0fMWI4`00001^0=WIf@040000003IfMT0fMWI0=WIfA<0
0000=@3IfMTC000007P0fMWI001G0=WIfA@00000KP3IfMT00`000000fMWI0=WIf@0D000003@0fMWI
5000001h0=WIf@003@3IfMWo000009X000002P3IfMT000d0fMWI00<000000=WIf@3IfMT01`3IfMT0
0`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT0
0`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT0
0`000000fMWI0=WIf@0C000000P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@08
0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@07
0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@07
0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT010000000fMWI0=WIf@3I
fMTC000000P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT010000000fMWI0=WIf@3IfMTC000000L0fMWI
00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI
00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI
00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI
00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@003@3IfMT00`000000fMWI0=WI
f@0`0=WIf@030000003IfMT0fMWI01D0fMWI4`0000080=WIf@030000003IfMT0fMWI0300fMWI00<0
00000=WIf@3IfMT0<03IfMT010000000fMWI0=WIf@3IfMTC000001`0fMWI00<000000=WIf@3IfMT0
5P3IfMTC000000L0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0`0=WIf@030000
003IfMT0fMWI00P0fMWI001H0=WIfA<00000KP3IfMT010000000fMWI0=WIf@3IfMTC000003D0fMWI
4`00001h0=WIf@00F@3IfMTA000006l0fMWI00<000000=WIf@3IfMT00P3IfMTA000003L0fMWI4@00
001i0=WIf@00F@3IfMT@00000700fMWI00<000000=WIf@3IfMT00P3IfMT@000003P0fMWI4000001j
0=WIf@00FP3IfMT?00000700fMWI0`0000030=WIf@l00000>@3IfMT?000007X0fMWI001K0=WIf@`0
0000LP3IfMT00`000000fMWI0=WIf@040=WIf@`00000?03IfMT<000007`0fMWI001M0=WIf@T00000
L`3IfMT00`000000fMWI0=WIf@060=WIf@T00000?`3IfMT9000007d0fMWI001Q0=WIf@030000003I
fMT0fMWI07D0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@150=WIf@030000003I
fMT0fMWI07l0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@@00000
1`3IfMT2000000D0fMWI1`0000040=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3I
fMT010000000fMWI0=WIf@0000070=WIf@8000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00H0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT03@3IfMT01@000000fMWI0=WIf@3IfMT0000000T0fMWI
00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WI
f@050=WIf@@00000d`3IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0?
0=WIf@8000001@3IfMT010000000fMWI0=WIf@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03I
fMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0
fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000h0
fMWI0P0000030=WIf@800000103IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0
fMWI002_0=WIf@@00000403IfMT3000000H0fMWI1@0000080=WIf@<00000e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00;T0fMWI100000070=WIf@8000001P3IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000X0fMWI0P0000070=WI
f@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT04@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@050=WIf@@00000
d`3IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI00`0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002h
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT0303IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@04
0000003IfMT0fMWI000000l0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WI
f@00^@3IfMT4000000l0fMWI1@0000080=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT3
00000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203I
fMT00`000000fMWI0=WIf@050=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT0
10000000fMWI0=WIf@0000070=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3I
fMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI00l0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0
fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`00
0000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00[P3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT0103IfMT010000000
fMWI0=WIf@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI1@0000080=WIf@03
0000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
403IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT0
10000000fMWI0=WIf@00000>0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@@000003P3IfMT7
000000@0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00</0fMWI
1`0000070=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@030000003IfMT0fMWI00P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D
0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@@00000d`3IfMT00<h0fMWI00<000000=WIf@3I
fMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3I
fMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00</0fMWI0P0000000`3IfMT000000=WIf@3P0=WI
f@00c@3IfMT200000>40fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.19347 .30902 Mdot
.53769 .30902 Mdot
.69347 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT03P3IfMT9000001<0fMWI
0P0000030=WIf@800000;03IfMT2000000030=WIf@000000fMWI02d0fMWI00<000000=WIf@3IfMT0
2@3IfMT9000001X0fMWI0P0000000`3IfMT000000=WIf@0H0=WIf@T000003@3IfMT2000000<0fMWI
0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
000?0=WIf@`00000503IfMT300000300fMWI0P00000^0=WIf@030000003IfMT0fMWI00L0fMWI3000
000K0=WIf@8000005`3IfMT<000000h0fMWI0`00000`0=WIf@@00000<03IfMT2000000X0fMWI001E
0=WIf@l00000M@3IfMT00`000000fMWI0=WIf@060=WIf@l00000<@3IfMT?000007l0fMWI001D0=WI
fA000000M@3IfMT3000000D0fMWI4000000`0=WIfA000000O`3IfMT005@0fMWI4@00001d0=WIf@03
0000003IfMT0fMWI00D0fMWI4@00000_0=WIfA400000OP3IfMT005<0fMWI4`00001c0=WIf@030000
003IfMT0fMWI00@0fMWI4`00000]0=WIfA<00000O@3IfMT005<0fMWI4`00001c0=WIf@030000003I
fMT0fMWI00@0fMWI4`00000]0=WIfA<00000O@3IfMT005<0fMWI4`00001c0=WIf@030000003IfMT0
fMWI00@0fMWI4`00000]0=WIfA<00000O@3IfMT005<0fMWI4`00001c0=WIf@030000003IfMT0fMWI
00@0fMWI4`00000]0=WIfA<00000O@3IfMT00580fMWI5000001c0=WIf@030000003IfMT0fMWI00<0
fMWI5000000/0=WIfA@00000O@3IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00H0fMWI4`0000030=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@040=WIfA<000001@3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@060=WIfA<000000P3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT000d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0@0=WIfA<000003@3IfMT0
0`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0103IfMTC
000001T0fMWI00<000000=WIf@3IfMT04@3IfMTC000000`0fMWI00<000000=WIf@3IfMT0<03IfMT0
0`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI00P0fMWI001C0=WIfA<00000L`3IfMT00`00
0000fMWI0=WIf@040=WIfA<00000;@3IfMTC000007d0fMWI001D0=WIfA400000M03IfMT00`000000
fMWI0=WIf@050=WIfA400000;`3IfMTA000007h0fMWI001D0=WIfA000000M@3IfMT00`000000fMWI
0=WIf@050=WIfA000000<03IfMT@000007l0fMWI001E0=WIf@l00000M@3IfMT3000000H0fMWI3`00
000a0=WIf@l00000O`3IfMT005H0fMWI3000001g0=WIf@030000003IfMT0fMWI00L0fMWI3000000d
0=WIf@`00000P@3IfMT005P0fMWI2@00001h0=WIf@030000003IfMT0fMWI00T0fMWI2@00000g0=WI
f@T00000PP3IfMT005`0fMWI00<000000=WIf@3IfMT0NP3IfMT00`000000fMWI0=WIf@0=0=WIf@03
0000003IfMT0fMWI03d0fMWI00<000000=WIf@3IfMT0Q03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@8000001@3IfMT7000000@0fMWI1@0000080=WI
f@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000060=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01P3IfMT2000000L0fMWI00<000000=WI
f@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0=0=WIf@05
0000003IfMT0fMWI0=WIf@0000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI
0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03P3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00[P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003IfMT0fMWI0=WIf@80
00001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0
e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<000001P3IfMT50000
00P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000L0fMWI0P00
00060=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT010000000fMWI0=WIf@00
00070=WIf@8000002P3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00D0fMWI00<00000
0=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WI
f@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI
0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<0
00000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI0`00003D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00
003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00[`3IfMT4000000L0fMWI0P0000080=WIf@030000003IfMT0fMWI00D0fMWI1@0000080=WIf@03
0000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000080=WIf@03
0000003IfMT0fMWI00T0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000
003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01@3I
fMT400000=<0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT0
0`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WI
f@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<00000
0=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@03
0000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000h0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3I
fMT0e03IfMT00:l0fMWI1000000>0=WIf@L00000103IfMT5000000P0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00b`3IfMT7000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0
fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI
0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@030000003IfMT0fMWI00P0fMWI1000
003C0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WI
f@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00b`3I
fMT2000000030=WIf@000000fMWI0>00fMWI003=0=WIf@800000h@3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.18352 .30902 Mdot
.54432 .30902 Mdot
.68352 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT02P3IfMT9000001L0fMWI
0P0000030=WIf@800000;03IfMT2000000030=WIf@000000fMWI02d0fMWI00<000000=WIf@3IfMT0
303IfMT9000001L0fMWI0P0000000`3IfMT000000=WIf@0D0=WIf@T000004@3IfMT2000000<0fMWI
0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
000;0=WIf@`00000603IfMT300000300fMWI0P00000^0=WIf@030000003IfMT0fMWI00X0fMWI3000
000H0=WIf@8000004`3IfMT<00000180fMWI0`00000`0=WIf@@00000<03IfMT2000000X0fMWI001A
0=WIf@l00000N@3IfMT00`000000fMWI0=WIf@090=WIf@l00000:P3IfMT?000008<0fMWI001@0=WI
fA000000N@3IfMT3000000P0fMWI4000000Y0=WIfA000000P`3IfMT00500fMWI4@00001h0=WIf@03
0000003IfMT0fMWI00P0fMWI4@00000X0=WIfA400000PP3IfMT004l0fMWI4`00001g0=WIf@030000
003IfMT0fMWI00L0fMWI4`00000V0=WIfA<00000P@3IfMT004l0fMWI4`00001g0=WIf@030000003I
fMT0fMWI00L0fMWI4`00000V0=WIfA<00000P@3IfMT004l0fMWI4`00001g0=WIf@030000003IfMT0
fMWI00L0fMWI4`00000V0=WIfA<00000P@3IfMT004l0fMWI4`00001g0=WIf@030000003IfMT0fMWI
00L0fMWI4`00000V0=WIfA<00000P@3IfMT004h0fMWI5000001g0=WIf@030000003IfMT0fMWI00H0
fMWI5000000U0=WIfA@00000P@3IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI0080fMWI4`0000070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIfA<000000P3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@020=WIfA<000001P3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT000d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0<0=WIfA<000004@3IfMT0
0`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT01`3IfMTC
000001H0fMWI00<000000=WIf@3IfMT03@3IfMTC00000100fMWI00<000000=WIf@3IfMT0<03IfMT0
0`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI00P0fMWI001?0=WIfA<00000M`3IfMT00`00
0000fMWI0=WIf@070=WIfA<000009P3IfMTC00000840fMWI001@0=WIfA400000N03IfMT00`000000
fMWI0=WIf@080=WIfA400000:03IfMTA00000880fMWI001@0=WIfA000000N@3IfMT00`000000fMWI
0=WIf@080=WIfA000000:@3IfMT@000008<0fMWI001A0=WIf@l00000N@3IfMT3000000T0fMWI3`00
000Z0=WIf@l00000P`3IfMT00580fMWI3000001k0=WIf@030000003IfMT0fMWI00X0fMWI3000000]
0=WIf@`00000Q@3IfMT005@0fMWI2@00001l0=WIf@030000003IfMT0fMWI00`0fMWI2@00000`0=WI
f@T00000QP3IfMT005P0fMWI00<000000=WIf@3IfMT0OP3IfMT00`000000fMWI0=WIf@0@0=WIf@03
0000003IfMT0fMWI03H0fMWI00<000000=WIf@3IfMT0R03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@8000001@3IfMT7000000@0fMWI1@0000080=WI
f@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000060=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01P3IfMT2000000L0fMWI00<000000=WI
f@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0=0=WIf@05
0000003IfMT0fMWI0=WIf@0000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI
0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03P3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00[P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003IfMT0fMWI0=WIf@80
00001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0
e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<000001P3IfMT50000
00P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000L0fMWI0P00
00060=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT010000000fMWI0=WIf@00
00070=WIf@8000002P3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00D0fMWI00<00000
0=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WI
f@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI
0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<0
00000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI0`00003D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00
003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00[`3IfMT4000000L0fMWI0P0000080=WIf@030000003IfMT0fMWI00D0fMWI1@0000080=WIf@03
0000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000080=WIf@03
0000003IfMT0fMWI00T0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000
003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01@3I
fMT400000=<0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT0
0`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WI
f@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<00000
0=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@03
0000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000h0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3I
fMT0e03IfMT00:l0fMWI1000000>0=WIf@L00000103IfMT5000000P0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00b`3IfMT7000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0
fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI
0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@030000003IfMT0fMWI00P0fMWI1000
003C0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WI
f@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00b`3I
fMT2000000030=WIf@000000fMWI0>00fMWI003=0=WIf@800000h@3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.17614 .30902 Mdot
.54924 .30902 Mdot
.67614 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT01`3IfMT9000001X0fMWI
0P0000030=WIf@800000;03IfMT2000000030=WIf@000000fMWI02d0fMWI00<000000=WIf@3IfMT0
3P3IfMT9000001D0fMWI0P0000000`3IfMT000000=WIf@0@0=WIf@T000005@3IfMT2000000<0fMWI
0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
00080=WIf@`000006`3IfMT300000300fMWI0P00000^0=WIf@030000003IfMT0fMWI00`0fMWI3000
000F0=WIf@8000003`3IfMT<000001H0fMWI0`00000`0=WIf@@00000<03IfMT2000000X0fMWI001>
0=WIf@l00000O03IfMT00`000000fMWI0=WIf@0;0=WIf@l00000903IfMT?000008L0fMWI001=0=WI
fA000000O03IfMT3000000X0fMWI4000000S0=WIfA000000Q`3IfMT004d0fMWI4@00001k0=WIf@03
0000003IfMT0fMWI00X0fMWI4@00000R0=WIfA400000QP3IfMT004`0fMWI4`00001j0=WIf@030000
003IfMT0fMWI00T0fMWI4`00000P0=WIfA<00000Q@3IfMT004`0fMWI4`00001j0=WIf@030000003I
fMT0fMWI00T0fMWI4`00000P0=WIfA<00000Q@3IfMT004`0fMWI4`00001j0=WIf@030000003IfMT0
fMWI00T0fMWI4`00000P0=WIfA<00000Q@3IfMT004`0fMWI4`00001j0=WIf@030000003IfMT0fMWI
00T0fMWI4`00000P0=WIfA<00000Q@3IfMT004/0fMWI5000001j0=WIf@030000003IfMT0fMWI00P0
fMWI5000000O0=WIfA@00000Q@3IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0000001<000002@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0000000C000000T0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIfAD000002@3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT000d0fMWI00<000000=WIf@3IfMT0<03IfMT0
0`000000fMWI0=WIf@090=WIfA<00000503IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0
fMWI0300fMWI00<000000=WIf@3IfMT02@3IfMTC000001@0fMWI00<000000=WIf@3IfMT02@3IfMTC
000001@0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0
fMWI00P0fMWI001<0=WIfA<00000NP3IfMT00`000000fMWI0=WIf@090=WIfA<00000803IfMTC0000
08D0fMWI001=0=WIfA400000N`3IfMT00`000000fMWI0=WIf@0:0=WIfA4000008P3IfMTA000008H0
fMWI001=0=WIfA000000O03IfMT00`000000fMWI0=WIf@0:0=WIfA0000008`3IfMT@000008L0fMWI
001>0=WIf@l00000O03IfMT3000000/0fMWI3`00000T0=WIf@l00000Q`3IfMT004l0fMWI3000001n
0=WIf@030000003IfMT0fMWI00`0fMWI3000000W0=WIf@`00000R@3IfMT00540fMWI2@00001o0=WI
f@030000003IfMT0fMWI00h0fMWI2@00000Z0=WIf@T00000RP3IfMT005D0fMWI00<000000=WIf@3I
fMT0P@3IfMT00`000000fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3I
fMT0S03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WI
f@8000001@3IfMT7000000@0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@04
0000003IfMT0fMWI000000L0fMWI0P0000060=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT01P3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@0=0=WIf@050000003IfMT0fMWI0=WIf@0000002@3IfMT00`00
0000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00D0
fMWI1000003C0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI
0P0000050=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00
[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT0
0`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3I
fMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2
000000<0fMWI0P0000040=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:l0fMWI1000000@0=WIf@<000001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00^@3IfMT4000000L0fMWI0P0000060=WIf@D00000203IfMT00`000000fMWI0=WI
f@3D0=WIf@00^@3IfMT010000000fMWI0=WIf@0000070=WIf@8000002P3IfMT2000000L0fMWI00<0
00000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00D0fMWI1000003C0=WI
f@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI00@000000=WIf@3I
fMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI
00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI00@00000
0=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002i
0=WIf@@000003`3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT30000
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000080=WIf@03
0000003IfMT0fMWI00D0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000
003IfMT0fMWI000000L0fMWI0P0000080=WIf@030000003IfMT0fMWI00T0fMWI0P0000070=WIf@03
0000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
3`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0
e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0
fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<00000
0=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WI
f@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WI
f@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000
003IfMT0fMWI000000h0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000>0=WIf@L00000
103IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT70000
00L0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI1000003C0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O
0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00
cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00b`3IfMT2000000030=WIf@000000fMWI0>00fMWI003=
0=WIf@800000h@3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.17159 .30902 Mdot
.55228 .30902 Mdot
.67159 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT01@3IfMT9000001`0fMWI
0P0000030=WIf@800000;03IfMT2000000030=WIf@000000fMWI02d0fMWI00<000000=WIf@3IfMT0
3`3IfMT9000001@0fMWI0P0000000`3IfMT000000=WIf@0?0=WIf@T000005P3IfMT2000000<0fMWI
0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
00060=WIf@`000007@3IfMT300000300fMWI0P00000^0=WIf@030000003IfMT0fMWI00d0fMWI3000
000E0=WIf@8000003P3IfMT<000001L0fMWI0`00000`0=WIf@@00000<03IfMT2000000X0fMWI001<
0=WIf@l00000OP3IfMT00`000000fMWI0=WIf@0<0=WIf@l000008P3IfMT?000008P0fMWI001;0=WI
fA000000OP3IfMT3000000/0fMWI4000000Q0=WIfA000000R03IfMT004/0fMWI4@00001m0=WIf@03
0000003IfMT0fMWI00/0fMWI4@00000P0=WIfA400000Q`3IfMT004X0fMWI4`00001l0=WIf@030000
003IfMT0fMWI00X0fMWI4`00000N0=WIfA<00000QP3IfMT004X0fMWI4`00001l0=WIf@030000003I
fMT0fMWI00X0fMWI4`00000N0=WIfA<00000QP3IfMT004X0fMWI4`00001l0=WIf@030000003IfMT0
fMWI00X0fMWI4`00000N0=WIfA<00000QP3IfMT004X0fMWI4`00001l0=WIf@030000003IfMT0fMWI
00X0fMWI4`00000N0=WIfA<00000QP3IfMT004T0fMWI5000001l0=WIf@030000003IfMT0fMWI00T0
fMWI5000000M0=WIfA@00000QP3IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIfA<000000P3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI01<000002@3IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT0fMWI00P0fMWI4`0000000`3IfMT000000=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@003@3IfMT0
0`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI00L0fMWI4`00000F0=WIf@030000003IfMT0
fMWI0300fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0:0=WIfA<000004`3IfMT0
0`000000fMWI0=WIf@080=WIfA<000005@3IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0
fMWI0300fMWI00<000000=WIf@3IfMT0203IfMT004X0fMWI4`00001l0=WIf@030000003IfMT0fMWI
00X0fMWI4`00000N0=WIfA<00000QP3IfMT004/0fMWI4@00001m0=WIf@030000003IfMT0fMWI00/0
fMWI4@00000P0=WIfA400000Q`3IfMT004/0fMWI4000001n0=WIf@030000003IfMT0fMWI00/0fMWI
4000000Q0=WIfA000000R03IfMT004`0fMWI3`00001n0=WIf@<00000303IfMT?00000280fMWI3`00
00280=WIf@00C@3IfMT<00000800fMWI00<000000=WIf@3IfMT03@3IfMT<000002D0fMWI3000002:
0=WIf@00C`3IfMT900000840fMWI00<000000=WIf@3IfMT03`3IfMT9000002P0fMWI2@00002;0=WI
f@00D`3IfMT00`000000fMWI0=WIf@230=WIf@030000003IfMT0fMWI01<0fMWI00<000000=WIf@3I
fMT0;P3IfMT00`000000fMWI0=WIf@2=0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WI
f@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI00D000000=WIf@3I
fMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI00X0
fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT03`3IfMT2000000D0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@03
0000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT01000
0000fMWI0=WIf@00000>0=WIf@8000000`3IfMT2000000@0fMWI00<000000=WIf@3IfMT02P3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00[`3IfMT400000100fMWI0`0000060=WIf@D00000203IfMT30000
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT3
00000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@00
00080=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00
000:0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WI
f@3IfMT01@3IfMT400000=<0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0303IfMT010000000fMWI0=WIf@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@D00000203IfMT00`000000
fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI
00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WI
f@3D0=WIf@00^@3IfMT010000000fMWI0=WIf@00000?0=WIf@030000003IfMT0fMWI00X0fMWI00<0
00000=WIf@3IfMT0e03IfMT00;T0fMWI1000000?0=WIf@D00000203IfMT300000=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@@0
00001`3IfMT2000000P0fMWI00<000000=WIf@3IfMT01@3IfMT5000000P0fMWI00<000000=WIf@3I
fMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000P0fMWI00<000000=WIf@3I
fMT02@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
1@3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI00l0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@@00000d`3I
fMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0
fMWI00@0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WI
f@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0403IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3I
fMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00
[`3IfMT4000000h0fMWI1`0000040=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003;0=WIf@L000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000
fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@030000003IfMT0fMWI00P0fMWI
00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3IfMT0203IfMT400000=<0fMWI003>
0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@03
0000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003;0=WIf@80000000<0
fMWI0000003IfMT0h03IfMT00<d0fMWI0P00003Q0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.17005 .30902 Mdot
.5533 .30902 Mdot
.67005 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT01@3IfMT9000001`0fMWI
0P0000030=WIf@800000;03IfMT2000000030=WIf@000000fMWI02d0fMWI00<000000=WIf@3IfMT0
3`3IfMT9000001@0fMWI0P0000000`3IfMT000000=WIf@0>0=WIf@T000005`3IfMT2000000<0fMWI
0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
00060=WIf@`000007@3IfMT300000300fMWI0P00000^0=WIf@030000003IfMT0fMWI00d0fMWI3000
000E0=WIf@8000003@3IfMT<000001P0fMWI0`00000`0=WIf@@00000<03IfMT2000000X0fMWI001<
0=WIf@l00000OP3IfMT00`000000fMWI0=WIf@0<0=WIf@l000008@3IfMT?000008T0fMWI001;0=WI
fA000000OP3IfMT3000000/0fMWI4000000P0=WIfA000000R@3IfMT004/0fMWI4@00001m0=WIf@03
0000003IfMT0fMWI00/0fMWI4@00000O0=WIfA400000R03IfMT004X0fMWI4`00001l0=WIf@030000
003IfMT0fMWI00X0fMWI4`00000M0=WIfA<00000Q`3IfMT004X0fMWI4`00001l0=WIf@030000003I
fMT0fMWI00X0fMWI4`00000M0=WIfA<00000Q`3IfMT004X0fMWI4`00001l0=WIf@030000003IfMT0
fMWI00X0fMWI4`00000M0=WIfA<00000Q`3IfMT004X0fMWI4`00001l0=WIf@030000003IfMT0fMWI
00X0fMWI4`00000M0=WIfA<00000Q`3IfMT004T0fMWI5000001l0=WIf@030000003IfMT0fMWI00T0
fMWI5000000L0=WIfA@00000Q`3IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIfA<000000P3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI01<000002@3IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT0fMWI00L0fMWI4`0000020=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI000=
0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT01`3IfMTC000001H0fMWI00<00000
0=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI00X0fMWI4`00000C
0=WIf@030000003IfMT0fMWI00L0fMWI4`00000F0=WIf@030000003IfMT0fMWI0300fMWI00<00000
0=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@080=WIf@00BP3IfMTC000007`0fMWI00<000000=WI
f@3IfMT02P3IfMTC000001d0fMWI4`0000270=WIf@00B`3IfMTA000007d0fMWI00<000000=WIf@3I
fMT02`3IfMTA000001l0fMWI4@0000280=WIf@00B`3IfMT@000007h0fMWI00<000000=WIf@3IfMT0
2`3IfMT@00000200fMWI400000290=WIf@00C03IfMT?000007h0fMWI0`00000<0=WIf@l000008@3I
fMT?000008T0fMWI001=0=WIf@`00000P03IfMT00`000000fMWI0=WIf@0=0=WIf@`00000903IfMT<
000008/0fMWI001?0=WIf@T00000P@3IfMT00`000000fMWI0=WIf@0?0=WIf@T000009`3IfMT90000
08`0fMWI001C0=WIf@030000003IfMT0fMWI08<0fMWI00<000000=WIf@3IfMT04`3IfMT00`000000
fMWI0=WIf@0]0=WIf@030000003IfMT0fMWI08h0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI002_0=WIf@@000001`3IfMT2000000D0fMWI1`0000040=WIf@D00000203IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@8000001P3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00H0fMWI0P0000070=WIf@030000003IfMT0fMWI
0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03@3IfMT01@000000
fMWI0=WIf@3IfMT0000000T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3I
fMT02P3IfMT00`000000fMWI0=WIf@050=WIf@@00000d`3IfMT00:h0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@8000001@3IfMT010000000fMWI0=WIf@3IfMT2000000L0
fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI
002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WI
f@040000003IfMT0fMWI000000h0fMWI0P0000030=WIf@800000103IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@@00000403IfMT3000000H0fMWI1@0000080=WI
f@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI100000070=WIf@8000001P3I
fMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT000001`3I
fMT2000000X0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0
fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`00
0000fMWI0=WIf@050=WIf@@00000d`3IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0<0=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WI
f@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI1@0000080=WIf@03
0000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
303IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0:0=WIf@030000003I
fMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000l0fMWI00<000000=WIf@3IfMT02P3I
fMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000l0fMWI1@0000080=WIf@<00000e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0
fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@050=WIf@D00000203IfMT00`000000
fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@800000203IfMT00`000000
fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI
0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI1000
003C0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<00000
0=WIf@3IfMT0103IfMT010000000fMWI0=WIf@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03I
fMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0
fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@00000>0=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0
fMWI002_0=WIf@@000003P3IfMT7000000@0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00</0fMWI1`0000070=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@03
0000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3IfMT0
203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@@00000d`3I
fMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0
fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00</0fMWI0P00
00000`3IfMT000000=WIf@3P0=WIf@00c@3IfMT200000>40fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.17159 .30902 Mdot
.55228 .30902 Mdot
.67159 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT01@3IfMT9000001`0fMWI
0P0000030=WIf@800000;03IfMT2000000030=WIf@000000fMWI02d0fMWI00<000000=WIf@3IfMT0
3`3IfMT9000001@0fMWI0P0000000`3IfMT000000=WIf@0?0=WIf@T000005P3IfMT2000000<0fMWI
0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
00060=WIf@`000007@3IfMT300000300fMWI0P00000^0=WIf@030000003IfMT0fMWI00d0fMWI3000
000E0=WIf@8000003P3IfMT<000001L0fMWI0`00000`0=WIf@@00000<03IfMT2000000X0fMWI001<
0=WIf@l00000OP3IfMT00`000000fMWI0=WIf@0<0=WIf@l000008P3IfMT?000008P0fMWI001;0=WI
fA000000OP3IfMT3000000/0fMWI4000000Q0=WIfA000000R03IfMT004/0fMWI4@00001m0=WIf@03
0000003IfMT0fMWI00/0fMWI4@00000P0=WIfA400000Q`3IfMT004X0fMWI4`00001l0=WIf@030000
003IfMT0fMWI00X0fMWI4`00000N0=WIfA<00000QP3IfMT004X0fMWI4`00001l0=WIf@030000003I
fMT0fMWI00X0fMWI4`00000N0=WIfA<00000QP3IfMT004X0fMWI4`00001l0=WIf@030000003IfMT0
fMWI00X0fMWI4`00000N0=WIfA<00000QP3IfMT004X0fMWI4`00001l0=WIf@030000003IfMT0fMWI
00X0fMWI4`00000N0=WIfA<00000QP3IfMT004T0fMWI5000001l0=WIf@030000003IfMT0fMWI00T0
fMWI5000000M0=WIfA@00000QP3IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIfA<000000P3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI01<000002@3IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT0fMWI00P0fMWI4`0000000`3IfMT000000=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@003@3IfMT0
0`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI00L0fMWI4`00000F0=WIf@030000003IfMT0
fMWI0300fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0:0=WIfA<000004`3IfMT0
0`000000fMWI0=WIf@080=WIfA<000005@3IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0
fMWI0300fMWI00<000000=WIf@3IfMT0203IfMT004X0fMWI4`00001l0=WIf@030000003IfMT0fMWI
00X0fMWI4`00000N0=WIfA<00000QP3IfMT004/0fMWI4@00001m0=WIf@030000003IfMT0fMWI00/0
fMWI4@00000P0=WIfA400000Q`3IfMT004/0fMWI4000001n0=WIf@030000003IfMT0fMWI00/0fMWI
4000000Q0=WIfA000000R03IfMT004`0fMWI3`00001n0=WIf@<00000303IfMT?00000280fMWI3`00
00280=WIf@00C@3IfMT<00000800fMWI00<000000=WIf@3IfMT03@3IfMT<000002D0fMWI3000002:
0=WIf@00C`3IfMT900000840fMWI00<000000=WIf@3IfMT03`3IfMT9000002P0fMWI2@00002;0=WI
f@00D`3IfMT00`000000fMWI0=WIf@230=WIf@030000003IfMT0fMWI01<0fMWI00<000000=WIf@3I
fMT0;P3IfMT00`000000fMWI0=WIf@2=0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WI
f@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI00D000000=WIf@3I
fMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI00X0
fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT03`3IfMT2000000D0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@03
0000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT01000
0000fMWI0=WIf@00000>0=WIf@8000000`3IfMT2000000@0fMWI00<000000=WIf@3IfMT02P3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00[`3IfMT400000100fMWI0`0000060=WIf@D00000203IfMT30000
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT3
00000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@00
00080=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00
000:0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WI
f@3IfMT01@3IfMT400000=<0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0303IfMT010000000fMWI0=WIf@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@D00000203IfMT00`000000
fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI
00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WI
f@3D0=WIf@00^@3IfMT010000000fMWI0=WIf@00000?0=WIf@030000003IfMT0fMWI00X0fMWI00<0
00000=WIf@3IfMT0e03IfMT00;T0fMWI1000000?0=WIf@D00000203IfMT300000=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@@0
00001`3IfMT2000000P0fMWI00<000000=WIf@3IfMT01@3IfMT5000000P0fMWI00<000000=WIf@3I
fMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000P0fMWI00<000000=WIf@3I
fMT02@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
1@3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI00l0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@@00000d`3I
fMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0
fMWI00@0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WI
f@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0403IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3I
fMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00
[`3IfMT4000000h0fMWI1`0000040=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003;0=WIf@L000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000
fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@030000003IfMT0fMWI00P0fMWI
00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3IfMT0203IfMT400000=<0fMWI003>
0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@03
0000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003;0=WIf@80000000<0
fMWI0000003IfMT0h03IfMT00<d0fMWI0P00003Q0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.17614 .30902 Mdot
.54924 .30902 Mdot
.67614 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT01`3IfMT9000001X0fMWI
0P0000030=WIf@800000;03IfMT2000000030=WIf@000000fMWI02d0fMWI00<000000=WIf@3IfMT0
3P3IfMT9000001D0fMWI0P0000000`3IfMT000000=WIf@0@0=WIf@T000005@3IfMT2000000<0fMWI
0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
00080=WIf@`000006`3IfMT300000300fMWI0P00000^0=WIf@030000003IfMT0fMWI00`0fMWI3000
000F0=WIf@8000003`3IfMT<000001H0fMWI0`00000`0=WIf@@00000<03IfMT2000000X0fMWI001>
0=WIf@l00000O03IfMT00`000000fMWI0=WIf@0;0=WIf@l00000903IfMT?000008L0fMWI001=0=WI
fA000000O03IfMT3000000X0fMWI4000000S0=WIfA000000Q`3IfMT004d0fMWI4@00001k0=WIf@03
0000003IfMT0fMWI00X0fMWI4@00000R0=WIfA400000QP3IfMT004`0fMWI4`00001j0=WIf@030000
003IfMT0fMWI00T0fMWI4`00000P0=WIfA<00000Q@3IfMT004`0fMWI4`00001j0=WIf@030000003I
fMT0fMWI00T0fMWI4`00000P0=WIfA<00000Q@3IfMT004`0fMWI4`00001j0=WIf@030000003IfMT0
fMWI00T0fMWI4`00000P0=WIfA<00000Q@3IfMT004`0fMWI4`00001j0=WIf@030000003IfMT0fMWI
00T0fMWI4`00000P0=WIfA<00000Q@3IfMT004/0fMWI5000001j0=WIf@030000003IfMT0fMWI00P0
fMWI5000000O0=WIfA@00000Q@3IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0000001<000002@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0000000C000000T0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIfAD000002@3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT000d0fMWI00<000000=WIf@3IfMT0<03IfMT0
0`000000fMWI0=WIf@090=WIfA<00000503IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0
fMWI0300fMWI00<000000=WIf@3IfMT02@3IfMTC000001@0fMWI00<000000=WIf@3IfMT02@3IfMTC
000001@0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0
fMWI00P0fMWI001<0=WIfA<00000NP3IfMT00`000000fMWI0=WIf@090=WIfA<00000803IfMTC0000
08D0fMWI001=0=WIfA400000N`3IfMT00`000000fMWI0=WIf@0:0=WIfA4000008P3IfMTA000008H0
fMWI001=0=WIfA000000O03IfMT00`000000fMWI0=WIf@0:0=WIfA0000008`3IfMT@000008L0fMWI
001>0=WIf@l00000O03IfMT3000000/0fMWI3`00000T0=WIf@l00000Q`3IfMT004l0fMWI3000001n
0=WIf@030000003IfMT0fMWI00`0fMWI3000000W0=WIf@`00000R@3IfMT00540fMWI2@00001o0=WI
f@030000003IfMT0fMWI00h0fMWI2@00000Z0=WIf@T00000RP3IfMT005D0fMWI00<000000=WIf@3I
fMT0P@3IfMT00`000000fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3I
fMT0S03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WI
f@8000001@3IfMT7000000@0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@04
0000003IfMT0fMWI000000L0fMWI0P0000060=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT01P3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@0=0=WIf@050000003IfMT0fMWI0=WIf@0000002@3IfMT00`00
0000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00D0
fMWI1000003C0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI
0P0000050=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00
[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT0
0`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3I
fMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2
000000<0fMWI0P0000040=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:l0fMWI1000000@0=WIf@<000001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00^@3IfMT4000000L0fMWI0P0000060=WIf@D00000203IfMT00`000000fMWI0=WI
f@3D0=WIf@00^@3IfMT010000000fMWI0=WIf@0000070=WIf@8000002P3IfMT2000000L0fMWI00<0
00000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00D0fMWI1000003C0=WI
f@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI00@000000=WIf@3I
fMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI
00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI00@00000
0=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002i
0=WIf@@000003`3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT30000
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000080=WIf@03
0000003IfMT0fMWI00D0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000
003IfMT0fMWI000000L0fMWI0P0000080=WIf@030000003IfMT0fMWI00T0fMWI0P0000070=WIf@03
0000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
3`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0
e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0
fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<00000
0=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WI
f@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WI
f@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000
003IfMT0fMWI000000h0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000>0=WIf@L00000
103IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT70000
00L0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI1000003C0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O
0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00
cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00b`3IfMT2000000030=WIf@000000fMWI0>00fMWI003=
0=WIf@800000h@3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.18352 .30902 Mdot
.54432 .30902 Mdot
.68352 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT02P3IfMT9000001L0fMWI
0P0000030=WIf@800000;03IfMT2000000030=WIf@000000fMWI02d0fMWI00<000000=WIf@3IfMT0
303IfMT9000001L0fMWI0P0000000`3IfMT000000=WIf@0D0=WIf@T000004@3IfMT2000000<0fMWI
0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
000;0=WIf@`00000603IfMT300000300fMWI0P00000^0=WIf@030000003IfMT0fMWI00X0fMWI3000
000H0=WIf@8000004`3IfMT<00000180fMWI0`00000`0=WIf@@00000<03IfMT2000000X0fMWI001A
0=WIf@l00000N@3IfMT00`000000fMWI0=WIf@090=WIf@l00000:P3IfMT?000008<0fMWI001@0=WI
fA000000N@3IfMT3000000P0fMWI4000000Y0=WIfA000000P`3IfMT00500fMWI4@00001h0=WIf@03
0000003IfMT0fMWI00P0fMWI4@00000X0=WIfA400000PP3IfMT004l0fMWI4`00001g0=WIf@030000
003IfMT0fMWI00L0fMWI4`00000V0=WIfA<00000P@3IfMT004l0fMWI4`00001g0=WIf@030000003I
fMT0fMWI00L0fMWI4`00000V0=WIfA<00000P@3IfMT004l0fMWI4`00001g0=WIf@030000003IfMT0
fMWI00L0fMWI4`00000V0=WIfA<00000P@3IfMT004l0fMWI4`00001g0=WIf@030000003IfMT0fMWI
00L0fMWI4`00000V0=WIfA<00000P@3IfMT004h0fMWI5000001g0=WIf@030000003IfMT0fMWI00H0
fMWI5000000U0=WIfA@00000P@3IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI0080fMWI4`0000070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIfA<000000P3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@020=WIfA<000001P3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT000d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0<0=WIfA<000004@3IfMT0
0`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT01`3IfMTC
000001H0fMWI00<000000=WIf@3IfMT03@3IfMTC00000100fMWI00<000000=WIf@3IfMT0<03IfMT0
0`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI00P0fMWI001?0=WIfA<00000M`3IfMT00`00
0000fMWI0=WIf@070=WIfA<000009P3IfMTC00000840fMWI001@0=WIfA400000N03IfMT00`000000
fMWI0=WIf@080=WIfA400000:03IfMTA00000880fMWI001@0=WIfA000000N@3IfMT00`000000fMWI
0=WIf@080=WIfA000000:@3IfMT@000008<0fMWI001A0=WIf@l00000N@3IfMT3000000T0fMWI3`00
000Z0=WIf@l00000P`3IfMT00580fMWI3000001k0=WIf@030000003IfMT0fMWI00X0fMWI3000000]
0=WIf@`00000Q@3IfMT005@0fMWI2@00001l0=WIf@030000003IfMT0fMWI00`0fMWI2@00000`0=WI
f@T00000QP3IfMT005P0fMWI00<000000=WIf@3IfMT0OP3IfMT00`000000fMWI0=WIf@0@0=WIf@03
0000003IfMT0fMWI03H0fMWI00<000000=WIf@3IfMT0R03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@8000001@3IfMT7000000@0fMWI1@0000080=WI
f@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000060=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01P3IfMT2000000L0fMWI00<000000=WI
f@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0=0=WIf@05
0000003IfMT0fMWI0=WIf@0000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI
0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03P3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00[P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003IfMT0fMWI0=WIf@80
00001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0
e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<000001P3IfMT50000
00P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000L0fMWI0P00
00060=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT010000000fMWI0=WIf@00
00070=WIf@8000002P3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00D0fMWI00<00000
0=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WI
f@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI
0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<0
00000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI0`00003D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00
003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00[`3IfMT4000000L0fMWI0P0000080=WIf@030000003IfMT0fMWI00D0fMWI1@0000080=WIf@03
0000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000080=WIf@03
0000003IfMT0fMWI00T0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000
003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01@3I
fMT400000=<0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT0
0`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WI
f@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<00000
0=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@03
0000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000h0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3I
fMT0e03IfMT00:l0fMWI1000000>0=WIf@L00000103IfMT5000000P0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00b`3IfMT7000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0
fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI
0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@030000003IfMT0fMWI00P0fMWI1000
003C0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WI
f@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00b`3I
fMT2000000030=WIf@000000fMWI0>00fMWI003=0=WIf@800000h@3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.19347 .30902 Mdot
.53769 .30902 Mdot
.69347 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT03P3IfMT9000001<0fMWI
0P0000030=WIf@800000;03IfMT2000000030=WIf@000000fMWI02d0fMWI00<000000=WIf@3IfMT0
2@3IfMT9000001X0fMWI0P0000000`3IfMT000000=WIf@0H0=WIf@T000003@3IfMT2000000<0fMWI
0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
000?0=WIf@`00000503IfMT300000300fMWI0P00000^0=WIf@030000003IfMT0fMWI00L0fMWI3000
000K0=WIf@8000005`3IfMT<000000h0fMWI0`00000`0=WIf@@00000<03IfMT2000000X0fMWI001E
0=WIf@l00000M@3IfMT00`000000fMWI0=WIf@060=WIf@l00000<@3IfMT?000007l0fMWI001D0=WI
fA000000M@3IfMT3000000D0fMWI4000000`0=WIfA000000O`3IfMT005@0fMWI4@00001d0=WIf@03
0000003IfMT0fMWI00D0fMWI4@00000_0=WIfA400000OP3IfMT005<0fMWI4`00001c0=WIf@030000
003IfMT0fMWI00@0fMWI4`00000]0=WIfA<00000O@3IfMT005<0fMWI4`00001c0=WIf@030000003I
fMT0fMWI00@0fMWI4`00000]0=WIfA<00000O@3IfMT005<0fMWI4`00001c0=WIf@030000003IfMT0
fMWI00@0fMWI4`00000]0=WIfA<00000O@3IfMT005<0fMWI4`00001c0=WIf@030000003IfMT0fMWI
00@0fMWI4`00000]0=WIfA<00000O@3IfMT00580fMWI5000001c0=WIf@030000003IfMT0fMWI00<0
fMWI5000000/0=WIfA@00000O@3IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00H0fMWI4`0000030=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@040=WIfA<000001@3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@060=WIfA<000000P3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT000d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0@0=WIfA<000003@3IfMT0
0`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0103IfMTC
000001T0fMWI00<000000=WIf@3IfMT04@3IfMTC000000`0fMWI00<000000=WIf@3IfMT0<03IfMT0
0`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI00P0fMWI001C0=WIfA<00000L`3IfMT00`00
0000fMWI0=WIf@040=WIfA<00000;@3IfMTC000007d0fMWI001D0=WIfA400000M03IfMT00`000000
fMWI0=WIf@050=WIfA400000;`3IfMTA000007h0fMWI001D0=WIfA000000M@3IfMT00`000000fMWI
0=WIf@050=WIfA000000<03IfMT@000007l0fMWI001E0=WIf@l00000M@3IfMT3000000H0fMWI3`00
000a0=WIf@l00000O`3IfMT005H0fMWI3000001g0=WIf@030000003IfMT0fMWI00L0fMWI3000000d
0=WIf@`00000P@3IfMT005P0fMWI2@00001h0=WIf@030000003IfMT0fMWI00T0fMWI2@00000g0=WI
f@T00000PP3IfMT005`0fMWI00<000000=WIf@3IfMT0NP3IfMT00`000000fMWI0=WIf@0=0=WIf@03
0000003IfMT0fMWI03d0fMWI00<000000=WIf@3IfMT0Q03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@8000001@3IfMT7000000@0fMWI1@0000080=WI
f@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000060=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01P3IfMT2000000L0fMWI00<000000=WI
f@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0=0=WIf@05
0000003IfMT0fMWI0=WIf@0000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI
0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03P3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00[P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003IfMT0fMWI0=WIf@80
00001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0
e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<000001P3IfMT50000
00P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000L0fMWI0P00
00060=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT010000000fMWI0=WIf@00
00070=WIf@8000002P3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00D0fMWI00<00000
0=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WI
f@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI
0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<0
00000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI0`00003D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00
003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00[`3IfMT4000000L0fMWI0P0000080=WIf@030000003IfMT0fMWI00D0fMWI1@0000080=WIf@03
0000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000080=WIf@03
0000003IfMT0fMWI00T0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000
003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01@3I
fMT400000=<0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT0
0`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WI
f@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<00000
0=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@03
0000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000h0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3I
fMT0e03IfMT00:l0fMWI1000000>0=WIf@L00000103IfMT5000000P0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00b`3IfMT7000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0
fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI
0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@030000003IfMT0fMWI00P0fMWI1000
003C0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WI
f@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00b`3I
fMT2000000030=WIf@000000fMWI0>00fMWI003=0=WIf@800000h@3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.20558 .30902 Mdot
.52961 .30902 Mdot
.70558 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT04`3IfMT9000000h0fMWI
0P0000030=WIf@800000;03IfMT2000000030=WIf@000000fMWI02d0fMWI00<000000=WIf@3IfMT0
1P3IfMT9000001d0fMWI0P0000000`3IfMT000000=WIf@0M0=WIf@T00000203IfMT2000000<0fMWI
0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
000D0=WIf@`000003`3IfMT300000300fMWI0P00000^0=WIf@030000003IfMT0fMWI00@0fMWI3000
000N0=WIf@800000703IfMT<000000T0fMWI0`00000`0=WIf@@00000<03IfMT2000000X0fMWI001J
0=WIf@l00000L03IfMT00`000000fMWI0=WIf@030=WIf@l00000>@3IfMT?000007X0fMWI001I0=WI
fA000000L03IfMT300000080fMWI4000000h0=WIfA000000NP3IfMT005T0fMWI4@00001_0=WIf@03
0000003IfMT0fMWI0080fMWI4@00000g0=WIfA400000N@3IfMT005P0fMWI4`00001^0=WIf@040000
003IfMT0fMWI0=WIfA<00000=@3IfMTC000007P0fMWI001H0=WIfA<00000KP3IfMT010000000fMWI
0=WIf@3IfMTC000003D0fMWI4`00001h0=WIf@00F03IfMTC000006h0fMWI00@000000=WIf@3IfMT0
fMWI4`00000e0=WIfA<00000N03IfMT005P0fMWI4`00001^0=WIf@040000003IfMT0fMWI0=WIfA<0
0000=@3IfMTC000007P0fMWI001G0=WIfA@00000KP3IfMT00`000000fMWI0=WIf@0D000003@0fMWI
5000001h0=WIf@003@3IfMWo000009X000002P3IfMT000d0fMWI00<000000=WIf@3IfMT01`3IfMT0
0`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT0
0`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT0
0`000000fMWI0=WIf@0C000000P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@08
0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@07
0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@07
0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT010000000fMWI0=WIf@3I
fMTC000000P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT010000000fMWI0=WIf@3IfMTC000000L0fMWI
00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI
00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI
00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI
00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@003@3IfMT00`000000fMWI0=WI
f@0`0=WIf@030000003IfMT0fMWI01D0fMWI4`0000080=WIf@030000003IfMT0fMWI0300fMWI00<0
00000=WIf@3IfMT0<03IfMT010000000fMWI0=WIf@3IfMTC000001`0fMWI00<000000=WIf@3IfMT0
5P3IfMTC000000L0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0`0=WIf@030000
003IfMT0fMWI00P0fMWI001H0=WIfA<00000KP3IfMT010000000fMWI0=WIf@3IfMTC000003D0fMWI
4`00001h0=WIf@00F@3IfMTA000006l0fMWI00<000000=WIf@3IfMT00P3IfMTA000003L0fMWI4@00
001i0=WIf@00F@3IfMT@00000700fMWI00<000000=WIf@3IfMT00P3IfMT@000003P0fMWI4000001j
0=WIf@00FP3IfMT?00000700fMWI0`0000030=WIf@l00000>@3IfMT?000007X0fMWI001K0=WIf@`0
0000LP3IfMT00`000000fMWI0=WIf@040=WIf@`00000?03IfMT<000007`0fMWI001M0=WIf@T00000
L`3IfMT00`000000fMWI0=WIf@060=WIf@T00000?`3IfMT9000007d0fMWI001Q0=WIf@030000003I
fMT0fMWI07D0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@150=WIf@030000003I
fMT0fMWI07l0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@@00000
1`3IfMT2000000D0fMWI1`0000040=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3I
fMT010000000fMWI0=WIf@0000070=WIf@8000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00H0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT03@3IfMT01@000000fMWI0=WIf@3IfMT0000000T0fMWI
00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WI
f@050=WIf@@00000d`3IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0?
0=WIf@8000001@3IfMT010000000fMWI0=WIf@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03I
fMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0
fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000h0
fMWI0P0000030=WIf@800000103IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0
fMWI002_0=WIf@@00000403IfMT3000000H0fMWI1@0000080=WIf@<00000e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00;T0fMWI100000070=WIf@8000001P3IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000X0fMWI0P0000070=WI
f@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT04@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@050=WIf@@00000
d`3IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI00`0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002h
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT0303IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@04
0000003IfMT0fMWI000000l0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WI
f@00^@3IfMT4000000l0fMWI1@0000080=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT3
00000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203I
fMT00`000000fMWI0=WIf@050=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT0
10000000fMWI0=WIf@0000070=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3I
fMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI00l0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0
fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`00
0000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00[P3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT0103IfMT010000000
fMWI0=WIf@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI1@0000080=WIf@03
0000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
403IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT0
10000000fMWI0=WIf@00000>0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@@000003P3IfMT7
000000@0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00</0fMWI
1`0000070=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@030000003IfMT0fMWI00P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D
0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@@00000d`3IfMT00<h0fMWI00<000000=WIf@3I
fMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3I
fMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00</0fMWI0P0000000`3IfMT000000=WIf@3P0=WI
f@00c@3IfMT200000>40fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.2194 .30902 Mdot
.5204 .30902 Mdot
.7194 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT06@3IfMT9000000P0fMWI
0P0000030=WIf@800000;03IfMT2000000030=WIf@000000fMWI02d0fMWI00<000000=WIf@3IfMT0
0P3IfMT900000240fMWI0P0000000`3IfMT000000=WIf@0R0=WIf@T000000`3IfMT2000000<0fMWI
0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
000J0=WIf@`000002@3IfMT300000300fMWI0P00000^0=WIf@030000003IfMT0fMWI00`000008P3I
fMT200000240fMWI300000040=WIf@<00000<03IfMT400000300fMWI0P00000:0=WIf@00H03IfMT?
000006X0fMWI00<000000=WIf@0000003P0000120=WIf@l00000M@3IfMT005l0fMWI4000001Z0=WI
fA400000@@3IfMT@000007D0fMWI001O0=WIfA400000J@3IfMTB00000400fMWI4@00001d0=WIf@00
GP3IfMTC000006P0fMWI4`00000n0=WIfA<00000L`3IfMT005h0fMWI4`00001X0=WIfA<00000?P3I
fMTC000007<0fMWI001N0=WIfA<00000J03IfMTC000003h0fMWI4`00001c0=WIf@00GP3IfMTC0000
06P0fMWI4`00000n0=WIfA<00000L`3IfMT005d0fMWI5000001W0=WIfA@00000?@3IfMTD000007<0
fMWI000=0=WIfOl00000VP00000:0=WIf@003@3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00H0fMWI4`0000020=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI4`0000020=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@060=WIfA<000000P3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI000=0=WIf@030000003IfMT0
fMWI0300fMWI00<000000=WIf@3IfMT06`3IfMTC00000080fMWI00<000000=WIf@3IfMT0<03IfMT0
0`000000fMWI0=WIf@0`0=WIfA<00000803IfMT00`000000fMWI0=WIf@0K0=WIfA<000000P3IfMT0
0`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0203IfMT0
05h0fMWI4`00001X0=WIfA<00000?P3IfMTC000007<0fMWI001O0=WIfA400000J@3IfMTB00000400
fMWI4@00001d0=WIf@00G`3IfMT@000006X0fMWI4@0000110=WIfA000000M@3IfMT00600fMWI3`00
001Z0=WIfA400000@P3IfMT?000007D0fMWI001Q0=WIf@`00000K03IfMT00`000000fMWI0=WIf@0<
000004D0fMWI3000001g0=WIf@00H`3IfMT9000006d0fMWI00<000000=WIf@3IfMT00P3IfMT90000
04P0fMWI2@00001h0=WIf@00I`3IfMT00`000000fMWI0=WIf@1_0=WIf@030000003IfMT0fMWI00H0
fMWI00<000000=WIf@3IfMT0CP3IfMT00`000000fMWI0=WIf@1j0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT50000
00P0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT20000
00H0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0
fMWI00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WI
f@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002^0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT2000000D0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[`3IfMT010000000fMWI0=WIf@00000>0=WIf@8000000`3IfMT2000000@0fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT400000100fMWI0`0000060=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3I
fMT2000000H0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0
fMWI000000L0fMWI0P00000:0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
0140fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002h0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0303IfMT010000000fMWI0=WIf@3IfMT2000000L0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@D0
0000203IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT02P3I
fMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT010000000fMWI0=WIf@00000?0=WIf@030000003I
fMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI1000000?0=WIf@D00000203IfMT3
00000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI002_0=WIf@@000001`3IfMT2000000P0fMWI00<000000=WIf@3IfMT01@3IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000P0
fMWI00<000000=WIf@3IfMT02@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00T0fMWI
00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WI
f@050=WIf@@00000d`3IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0?
0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003I
fMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT0
0`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT00`00
0000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00X0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003;0=WIf@L000001`3IfMT00`000000fMWI0=WIf@3D0=WI
f@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@030000
003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3IfMT0203I
fMT400000=<0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI
003;0=WIf@80000000<0fMWI0000003IfMT0h03IfMT00<d0fMWI0P00003Q0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.2344 .30902 Mdot
.5104 .30902 Mdot
.7344 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT07`3IfMT900000080fMWI
0P0000030=WIf@800000;03IfMT2000000030=WIf@000000fMWI02d0fMWI2P00000U0=WIf@800000
00<0fMWI0000003IfMT0:03IfMT900000080fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI
0P00000:0=WIf@004@3IfMT200000300fMWI1000000P0=WIf@`000000`3IfMT300000300fMWI0P00
000]0=WIf@`000009P3IfMT2000002L0fMWI3@00000`0=WIf@@00000<03IfMT2000000X0fMWI001V
0=WIf@l00000HP3IfMT?000004`0fMWI3`00001_0=WIf@00I@3IfMT@00000640fMWI4000001;0=WI
fA000000K`3IfMT006D0fMWI4@00001P0=WIfA400000BP3IfMTA000006h0fMWI001T0=WIfA<00000
GP3IfMTC000004P0fMWI4`00001]0=WIf@00I03IfMTC000005h0fMWI4`0000180=WIfA<00000K@3I
fMT006@0fMWI4`00001N0=WIfA<00000B03IfMTC000006d0fMWI001T0=WIfA<00000GP3IfMTC0000
04P0fMWI4`00001]0=WIf@00H`3IfMTD000005d0fMWI500000170=WIfA@00000K@3IfMT000d0fMWI
o`00002J000000X0fMWI000=0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@020=WIfA<000001P3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT00`3IfMTC000000H0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT00P3I
fMTC000000L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT000d0fMWI00<000000=WIf@3IfMT0<03IfMT0
0`000000fMWI0=WIf@0Q0=WIfA<00000;`3IfMT00`000000fMWI0=WIf@0/0=WIfA<00000903IfMT0
0`000000fMWI0=WIf@0Q0=WIfA<00000;`3IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0
fMWI00P0fMWI001T0=WIfA<00000GP3IfMTC000004P0fMWI4`00001]0=WIf@00I@3IfMTA00000600
fMWI4@00001:0=WIfA400000KP3IfMT006D0fMWI4000001Q0=WIfA000000B`3IfMT@000006l0fMWI
001V0=WIf@l00000HP3IfMT?000004`0fMWI3`00001_0=WIf@00I`3IfMT<000006D0fMWI3000001?
0=WIf@`00000L@3IfMT006T0fMWI2@00001W0=WIf@X00000DP3IfMT900000780fMWI001]0=WIf@03
0000003IfMT0fMWI06T0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@1H0=WIf@03
0000003IfMT0fMWI07@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WI
f@@000001`3IfMT2000000D0fMWI1`0000040=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WI
f@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@8000001P3IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI00H0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03@3IfMT01@000000fMWI0=WIf@3IfMT00000
00T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000
fMWI0=WIf@050=WIf@@00000d`3IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@0?0=WIf@8000001@3IfMT010000000fMWI0=WIf@3IfMT2000000L0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000
003IfMT0fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI
000000h0fMWI0P0000030=WIf@800000103IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0
fMWI0=@0fMWI002_0=WIf@@00000403IfMT3000000H0fMWI1@0000080=WIf@<00000e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00;T0fMWI100000070=WIf@8000001P3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000X0fMWI0P00
00070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@050=WI
f@@00000d`3IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@04
0000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0
fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI
0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002i
0=WIf@040000003IfMT0fMWI000000l0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WI
f@3D0=WIf@00^@3IfMT4000000l0fMWI1@0000080=WIf@<00000e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@80
0000203IfMT00`000000fMWI0=WIf@050=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00
[`3IfMT010000000fMWI0=WIf@0000070=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@80
00001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000
003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3I
fMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00[P3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT0103IfMT0
10000000fMWI0=WIf@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI1@000008
0=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00
[`3IfMT010000000fMWI0=WIf@00000>0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@@00000
3P3IfMT7000000@0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT30000
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0</0fMWI1`0000070=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@030000003IfMT0fMWI00P0
fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI
0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@@00000d`3IfMT00<h0fMWI00<00000
0=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3I
fMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00</0fMWI0P0000000`3IfMT000000=WI
f@3P0=WIf@00c@3IfMT200000>40fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.25 .30902 Mdot
.5 .30902 Mdot
.75 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT09@3IfMT9000000030=WI
f@000000000002`0fMWI0P0000000`3IfMT000000=WIf@0Z0=WIf@T00000:@3IfMT2000000030=WI
f@000000fMWI02h0fMWI2P00000_0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3I
fMT200000300fMWI1000000V0=WIf@`00000<03IfMT2000002T0fMWI3000000Z0=WIf@800000;P3I
fMT<000002X0fMWI1000000`0=WIf@8000002P3IfMT006`0fMWI3`00001H0=WIf@l00000E`3IfMT?
000006P0fMWI001[0=WIfA000000E`3IfMT@000005H0fMWI4000001X0=WIf@00J`3IfMTA000005H0
fMWI4@00001E0=WIfA400000I`3IfMT006X0fMWI4`00001D0=WIfA<00000D`3IfMTC000006H0fMWI
001Z0=WIfA<00000E03IfMTC000005<0fMWI4`00001V0=WIf@00JP3IfMTC000005@0fMWI4`00001C
0=WIfA<00000IP3IfMT006X0fMWI4`00001D0=WIfA<00000D`3IfMTC000006H0fMWI001Y0=WIfA@0
0000D`3IfMTD00000580fMWI5000001V0=WIf@003@3IfMWo000009X000002P3IfMT000d0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI5@00
000:0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@0000004P00000:0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@0000004`0000090=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@003@3IfMT00`000000fMWI0=WIf@0`
0=WIf@030000003IfMT0fMWI02L0fMWI4`00000Y0=WIf@030000003IfMT0fMWI02P0fMWI4`00000X
0=WIf@030000003IfMT0fMWI02P0fMWI4`00000X0=WIf@030000003IfMT0fMWI0300fMWI00<00000
0=WIf@3IfMT0203IfMT006X0fMWI4`00001D0=WIfA<00000D`3IfMTC000006H0fMWI001[0=WIfA40
0000EP3IfMTA000005D0fMWI4@00001W0=WIf@00J`3IfMT@000005L0fMWI4000001F0=WIfA000000
J03IfMT006`0fMWI3`00001H0=WIf@l00000E`3IfMT?000006P0fMWI001]0=WIf@`00000F`3IfMT<
000005X0fMWI3000001Z0=WIf@00K`3IfMT9000005h0fMWI2@00001M0=WIf@T00000J`3IfMT007<0
fMWI00<000000=WIf@3IfMT0H`3IfMT2000006D0fMWI00<000000=WIf@3IfMT0K@3IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@8000001@3IfMT70000
00@0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI0000
00L0fMWI0P0000060=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01P3IfMT20000
00L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0=0=WIf@050000003IfMT0fMWI0=WIf@0000002@3IfMT00`000000fMWI0=WIf@050=WI
f@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT03P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00
[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000
003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI
00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@0A0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WI
f@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<00000
0=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P000004
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WI
f@<000001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3I
fMT4000000L0fMWI0P0000060=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT0
10000000fMWI0=WIf@0000070=WIf@8000002P3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03I
fMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0
fMWI00D0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00^03IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WI
f@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0303IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003I
fMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3I
fMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5
000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000080=WIf@030000003IfMT0fMWI00D0
fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0
fMWI0P0000080=WIf@030000003IfMT0fMWI00T0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0
fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI
0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00T0fMWI00<0
00000=WIf@3IfMT01@3IfMT400000=<0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI0=WIf@8000001`3I
fMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000h0
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000>0=WIf@L00000103IfMT5000000P0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT3
00000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT7000000L0fMWI00<000000=WI
f@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00
cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@030000003I
fMT0fMWI00P0fMWI1000003C0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`00
0000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI
0=WIf@3O0=WIf@00b`3IfMT2000000030=WIf@000000fMWI0>00fMWI003=0=WIf@800000h@3IfMT0
0001\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.2656 .30902 Mdot
.4896 .30902 Mdot
.7656 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT0:P3IfMT;000002P0fMWI
0P0000000`3IfMT000000=WIf@0U0=WIf@T00000;P3IfMT2000000030=WIf@000000fMWI02h0fMWI
0P0000030=WIf@/00000:@3IfMT00`000000fMWI0=WIf@0]0=WIf@8000002P3IfMT00140fMWI0P00
000`0=WIf@@00000;@3IfMT<000002T0fMWI0P00000T0=WIf@`00000;`3IfMT200000340fMWI3`00
000T0=WIf@@00000<03IfMT2000000X0fMWI001c0=WIf@l00000C03IfMT?00000680fMWI3`00001R
0=WIf@00LP3IfMT@000004/0fMWI4000001Q0=WIfA000000HP3IfMT00780fMWI4@00001:0=WIfA40
0000H03IfMTA00000640fMWI001a0=WIfA<00000B03IfMTC000005h0fMWI4`00001P0=WIf@00L@3I
fMTC000004P0fMWI4`00001N0=WIfA<00000H03IfMT00740fMWI4`0000180=WIfA<00000GP3IfMTC
00000600fMWI001a0=WIfA<00000B03IfMTC000005h0fMWI4`00001P0=WIf@00L03IfMTD000004L0
fMWI5000001M0=WIfA@00000H03IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00D0fMWI4`0000040=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00@0fMWI4`0000040=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@050=WIfA<00000103I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT000d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0^0=WIfA<000008P3IfMT0
0`000000fMWI0=WIf@0S0=WIfA<00000;@3IfMT00`000000fMWI0=WIf@0^0=WIfA<000008P3IfMT0
0`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI00P0fMWI001a0=WIfA<00000B03IfMTC0000
05h0fMWI4`00001P0=WIf@00LP3IfMTA000004X0fMWI4@00001P0=WIfA400000H@3IfMT00780fMWI
4000001;0=WIfA000000H@3IfMT@00000680fMWI001c0=WIf@l00000C03IfMT?00000680fMWI3`00
001R0=WIf@00M03IfMT<000004l0fMWI3000001U0=WIf@`00000I03IfMT007H0fMWI2@00001B0=WI
f@T00000J03IfMT9000006D0fMWI001j0=WIf@030000003IfMT0fMWI05P0fMWI00D000000=WIf@3I
fMT0fMWI0000001/0=WIf@030000003IfMT0fMWI06L0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI002_0=WIf@@000001`3IfMT2000000D0fMWI1`0000040=WIf@D00000203IfMT0
0`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@8000001P3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00H0fMWI0P0000070=WIf@030000003IfMT0
fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03@3IfMT01@00
0000fMWI0=WIf@3IfMT0000000T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@050=WIf@@00000d`3IfMT00:h0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@0?0=WIf@8000001@3IfMT010000000fMWI0=WIf@3IfMT20000
00L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0
fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00<0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_
0=WIf@040000003IfMT0fMWI000000h0fMWI0P0000030=WIf@800000103IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@@00000403IfMT3000000H0fMWI1@000008
0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI100000070=WIf@800000
1P3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT00000
1`3IfMT2000000X0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@050=WIf@030000003I
fMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT0
0`000000fMWI0=WIf@050=WIf@@00000d`3IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@0<0=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI1@0000080=WI
f@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0303IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000l0fMWI00<000000=WIf@3IfMT0
2P3IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000l0fMWI1@0000080=WIf@<00000e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@050=WIf@D00000203IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@800000203IfMT00`00
0000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000
fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI
1000003C0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<0
00000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0
e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003I
fMT0fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@00000>0=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI
0=@0fMWI002_0=WIf@@000003P3IfMT7000000@0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00</0fMWI1`0000070=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WI
f@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@@00000
d`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT0
0<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00</0fMWI
0P0000000`3IfMT000000=WIf@3P0=WIf@00c@3IfMT200000>40fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.2806 .30902 Mdot
.4796 .30902 Mdot
.7806 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT0:P3IfMT2000000<0fMWI
0P0000000`3IfMT000000000000700000280fMWI0P0000000`3IfMT000000=WIf@0Q0=WIf@T00000
0`3IfMT00`000000fMWI0=WIf@0/0=WIf@80000000<0fMWI0000003IfMT0;P3IfMT2000000<0fMWI
0P0000060=WIf@T000008`3IfMT00`000000fMWI0=WIf@0]0=WIf@8000002P3IfMT00140fMWI0P00
000`0=WIf@@00000;`3IfMT3000000030=WIf@000000000000X000008`3IfMT200000200fMWI3000
00020=WIf@030000003IfMT0fMWI02h0fMWI0P00000a0=WIf@<000001P3IfMT<000001h0fMWI1000
000`0=WIf@8000002P3IfMT007T0fMWI3`0000120=WIfA000000J`3IfMT?000005`0fMWI001h0=WI
fA000000@@3IfMTC000006P0fMWI4000001L0=WIf@00N03IfMTA00000400fMWI4@00001Z0=WIfA40
0000F`3IfMT007L0fMWI4`00000n0=WIfA<00000J03IfMTC000005X0fMWI001g0=WIfA<00000?P3I
fMTC000006P0fMWI4`00001J0=WIf@00M`3IfMTC000003h0fMWI4`00001X0=WIfA<00000FP3IfMT0
07L0fMWI4`00000n0=WIfA<00000J03IfMTC000005X0fMWI001f0=WIfA@00000?@3IfMTD000006L0
fMWI5000001J0=WIf@003@3IfMWo000009X000002P3IfMT000d0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT010000000fMWI0=WIf@3IfMTC000000P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI
0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI
0=WIf@070=WIf@030000003IfMT0fMWI01<00000203IfMT00`000000fMWI0=WIf@080=WIf@030000
003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000
003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000
003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT010000000fMWI0=WIf@3IfMTC000000P0
fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0
fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0
fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@003@3IfMT00`000000fMWI
0=WIf@0`0=WIf@030000003IfMT0fMWI0300fMWI00@000000=WIf@3IfMT0fMWI4`00000L0=WIf@03
0000003IfMT0fMWI01l0fMWI4`00000a0=WIf@030000003IfMT0fMWI0300fMWI00@000000=WIf@3I
fMT0fMWI4`00000L0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0203IfMT007L0
fMWI4`00000n0=WIfA<00000J03IfMTC000005X0fMWI001h0=WIfA400000@03IfMTA000006X0fMWI
4@00001K0=WIf@00N03IfMT@00000440fMWI4@00001Z0=WIfA000000G03IfMT007T0fMWI3`000012
0=WIfA800000J@3IfMT?000005`0fMWI001j0=WIf@`00000A@3IfMT<00000080fMWI00<000000=WI
f@3IfMT0JP3IfMT<000005h0fMWI001l0=WIf@T00000B03IfMT9000000<0fMWI00<000000=WIf@3I
fMT0K03IfMT9000005l0fMWI00200=WIf@030000003IfMT0fMWI04h0fMWI00<000000=WIf@3IfMT0
1@3IfMT00`000000fMWI0=WIf@1`0=WIf@030000003IfMT0fMWI0640fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI002_0=WIf@@000001`3IfMT2000000D0fMWI1`0000040=WIf@D0
0000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@80
00001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00H0fMWI0P0000070=WIf@03
0000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
3@3IfMT01@000000fMWI0=WIf@3IfMT0000000T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00h0fMWI
00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@050=WIf@@00000d`3IfMT00:h0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0?0=WIf@8000001@3IfMT010000000fMWI0=WI
f@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI1@0000080=WIf@030000003I
fMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI
0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000h0fMWI0P0000030=WIf@800000103IfMT00`00
0000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@@00000403IfMT3000000H0
fMWI1@0000080=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI10000007
0=WIf@8000001P3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WI
f@3IfMT000001`3IfMT2000000X0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@050=WI
f@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT04@3IfMT00`000000fMWI0=WIf@050=WIf@@00000d`3IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI
1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002h
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000l0fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000l0fMWI1@0000080=WI
f@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@050=WIf@D00000
203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@800000
203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT02@3I
fMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00D0fMWI1000003C0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00l0fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@3IfMT2000000L0fMWI00<00000
0=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WI
f@030000003IfMT0fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0
2P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@00000>0=WIf@030000
003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002_0=WIf@@000003P3IfMT7000000@0fMWI1@0000080=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00</0fMWI1`0000070=WIf@030000003IfMT0fMWI0=@0
fMWI003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<0
00000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@08
0=WIf@@00000d`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3I
fMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3I
fMT00</0fMWI0P0000000`3IfMT000000=WIf@3P0=WIf@00c@3IfMT200000>40fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.29442 .30902 Mdot
.47039 .30902 Mdot
.79442 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT0:P3IfMT2000000<0fMWI
0P0000070=WIf@T00000703IfMT2000000030=WIf@000000fMWI01d0fMWI2@0000070=WIf@030000
003IfMT0fMWI02`0fMWI0P0000000`3IfMT000000=WIf@0^0=WIf@8000000`3IfMT2000000`0fMWI
2@00000M0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
000_0=WIf@<000001`3IfMT<000001d0fMWI0P00000L0=WIf@`000001P3IfMT00`000000fMWI0=WI
f@0^0=WIf@800000<@3IfMT3000000`0fMWI3000000H0=WIf@@00000<03IfMT2000000X0fMWI001o
0=WIf@l00000>03IfMT?000000@0fMWI00<000000=WIf@3IfMT0K`3IfMT?000005H0fMWI001n0=WI
fA000000=`3IfMT@000000@0fMWI0`00001^0=WIfA000000EP3IfMT007h0fMWI4@00000f0=WIfA40
00000`3IfMT00`000000fMWI0=WIf@1^0=WIfA400000E@3IfMT007d0fMWI4`00000d0=WIfA<00000
0P3IfMT00`000000fMWI0=WIf@1]0=WIfA<00000E03IfMT007d0fMWI4`00000d0=WIfA<000000P3I
fMT00`000000fMWI0=WIf@1]0=WIfA<00000E03IfMT007d0fMWI4`00000d0=WIfA<000000P3IfMT0
0`000000fMWI0=WIf@1]0=WIfA<00000E03IfMT007d0fMWI4`00000d0=WIfA<000000P3IfMT00`00
0000fMWI0=WIf@1]0=WIfA<00000E03IfMT007`0fMWI5000000c0=WIfA@000000P3IfMT00`000000
fMWI0=WIf@1/0=WIfA@00000E03IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMTC00000080fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@060=WIfA<000000P3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI4`0000020=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT000d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0
fMWI00L0fMWI4`00000F0=WIf@030000003IfMT0fMWI01/0fMWI4`0000020=WIf@030000003IfMT0
fMWI0300fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@070=WIfA<000005P3IfMT0
0`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI00P0fMWI001m0=WIfA<00000=03IfMTC0000
0080fMWI00<000000=WIf@3IfMT0K@3IfMTC000005@0fMWI001n0=WIfA400000=P3IfMTA000000<0
fMWI00<000000=WIf@3IfMT0KP3IfMTA000005D0fMWI001n0=WIfA000000=`3IfMT@000000@0fMWI
00<000000=WIf@3IfMT0KP3IfMT@000005H0fMWI001o0=WIf@l00000>03IfMT?000000@0fMWI0`00
001_0=WIf@l00000EP3IfMT00800fMWI3000000k0=WIf@`000001P3IfMT00`000000fMWI0=WIf@1`
0=WIf@`00000F03IfMT00880fMWI2@00000n0=WIf@T000001`3IfMT00`000000fMWI0=WIf@1b0=WI
f@T00000F@3IfMT008H0fMWI00<000000=WIf@3IfMT0A03IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI07H0fMWI00<000000=WIf@3IfMT0F`3IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@8000001@3IfMT7000000@0fMWI1@0000080=WI
f@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000060=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01P3IfMT2000000L0fMWI00<000000=WI
f@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0=0=WIf@05
0000003IfMT0fMWI0=WIf@0000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI
0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03P3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00[P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003IfMT0fMWI0=WIf@80
00001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0
e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<000001P3IfMT50000
00P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000L0fMWI0P00
00060=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT010000000fMWI0=WIf@00
00070=WIf@8000002P3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00D0fMWI00<00000
0=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WI
f@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI
0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<0
00000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI0`00003D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00
003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00[`3IfMT4000000L0fMWI0P0000080=WIf@030000003IfMT0fMWI00D0fMWI1@0000080=WIf@03
0000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000080=WIf@03
0000003IfMT0fMWI00T0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000
003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01@3I
fMT400000=<0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT0
0`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WI
f@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<00000
0=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@03
0000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000h0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3I
fMT0e03IfMT00:l0fMWI1000000>0=WIf@L00000103IfMT5000000P0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00b`3IfMT7000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0
fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI
0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@030000003IfMT0fMWI00P0fMWI1000
003C0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WI
f@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00b`3I
fMT2000000030=WIf@000000fMWI0>00fMWI003=0=WIf@800000h@3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.30653 .30902 Mdot
.46231 .30902 Mdot
.80653 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT0:P3IfMT2000000<0fMWI
0P00000<0=WIf@T000005`3IfMT2000000030=WIf@000000fMWI01X0fMWI2@00000:0=WIf@030000
003IfMT0fMWI02`0fMWI0P0000000`3IfMT000000=WIf@0^0=WIf@8000000`3IfMT200000140fMWI
2@00000H0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
000_0=WIf@<00000303IfMT<000001P0fMWI0P00000I0=WIf@`000002@3IfMT00`000000fMWI0=WI
f@0^0=WIf@800000<@3IfMT300000140fMWI3000000C0=WIf@@00000<03IfMT2000000X0fMWI0024
0=WIf@l00000<03IfMT?000000L0fMWI00<000000=WIf@3IfMT0M03IfMT?00000540fMWI00230=WI
fA000000;`3IfMT@000000L0fMWI0`00001c0=WIfA000000D@3IfMT008<0fMWI4@00000^0=WIfA40
00001P3IfMT00`000000fMWI0=WIf@1c0=WIfA400000D03IfMT00880fMWI4`00000/0=WIfA<00000
1@3IfMT00`000000fMWI0=WIf@1b0=WIfA<00000C`3IfMT00880fMWI4`00000/0=WIfA<000001@3I
fMT00`000000fMWI0=WIf@1b0=WIfA<00000C`3IfMT00880fMWI4`00000/0=WIfA<000001@3IfMT0
0`000000fMWI0=WIf@1b0=WIfA<00000C`3IfMT00880fMWI4`00000/0=WIfA<000001@3IfMT00`00
0000fMWI0=WIf@1b0=WIfA<00000C`3IfMT00840fMWI5000000[0=WIfA@000001@3IfMT00`000000
fMWI0=WIf@1a0=WIfA@00000C`3IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@020=WIfA<000001`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@030=WIfA<000001@3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00@000000=WIf@3IfMT0fMWI4`0000070=WIf@030000003IfMT0fMWI00L0fMWI
00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI
00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI
000=0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WI
f@0<0=WIfA<000004@3IfMT00`000000fMWI0=WIf@0H0=WIfA<000001@3IfMT00`000000fMWI0=WI
f@0`0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0303IfMTC00000140fMWI00<0
00000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@080=WIf@00PP3IfMTC000002`0fMWI4`000005
0=WIf@030000003IfMT0fMWI0780fMWI4`00001?0=WIf@00P`3IfMTA000002h0fMWI4@0000060=WI
f@030000003IfMT0fMWI07<0fMWI4@00001@0=WIf@00P`3IfMT@000002l0fMWI400000070=WIf@03
0000003IfMT0fMWI07<0fMWI4000001A0=WIf@00Q03IfMT?00000300fMWI3`0000070=WIf@<00000
M03IfMT?00000540fMWI00250=WIf@`00000<`3IfMT<000000T0fMWI00<000000=WIf@3IfMT0M@3I
fMT<000005<0fMWI00270=WIf@T00000=P3IfMT9000000X0fMWI00<000000=WIf@3IfMT0M`3IfMT9
000005@0fMWI002;0=WIf@030000003IfMT0fMWI03`0fMWI00<000000=WIf@3IfMT0303IfMT00`00
0000fMWI0=WIf@1k0=WIf@030000003IfMT0fMWI05H0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI002_0=WIf@@000001`3IfMT2000000D0fMWI1`0000040=WIf@D00000203IfMT0
0`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@8000001P3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00H0fMWI0P0000070=WIf@030000003IfMT0
fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03@3IfMT01@00
0000fMWI0=WIf@3IfMT0000000T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@050=WIf@@00000d`3IfMT00:h0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@0?0=WIf@8000001@3IfMT010000000fMWI0=WIf@3IfMT20000
00L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0
fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00<0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_
0=WIf@040000003IfMT0fMWI000000h0fMWI0P0000030=WIf@800000103IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@@00000403IfMT3000000H0fMWI1@000008
0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI100000070=WIf@800000
1P3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT00000
1`3IfMT2000000X0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@050=WIf@030000003I
fMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT0
0`000000fMWI0=WIf@050=WIf@@00000d`3IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@0<0=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI1@0000080=WI
f@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0303IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000l0fMWI00<000000=WIf@3IfMT0
2P3IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000l0fMWI1@0000080=WIf@<00000e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@050=WIf@D00000203IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@800000203IfMT00`00
0000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000
fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI
1000003C0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<0
00000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0
e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003I
fMT0fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@00000>0=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI
0=@0fMWI002_0=WIf@@000003P3IfMT7000000@0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00</0fMWI1`0000070=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WI
f@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@@00000
d`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT0
0<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00</0fMWI
0P0000000`3IfMT000000=WIf@3P0=WIf@00c@3IfMT200000>40fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.31648 .30902 Mdot
.45568 .30902 Mdot
.81648 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT0:P3IfMT2000000<0fMWI
0P00000@0=WIf@T000004`3IfMT2000000030=WIf@000000fMWI01L0fMWI2@00000=0=WIf@030000
003IfMT0fMWI02`0fMWI0P0000000`3IfMT000000=WIf@0^0=WIf@8000000`3IfMT2000001D0fMWI
2@00000D0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
000_0=WIf@<00000403IfMT<000001@0fMWI0P00000F0=WIf@`00000303IfMT00`000000fMWI0=WI
f@0^0=WIf@800000<@3IfMT3000001D0fMWI3000000?0=WIf@@00000<03IfMT2000000X0fMWI0028
0=WIf@l00000:@3IfMT?000000X0fMWI00<000000=WIf@3IfMT0N03IfMT?000004d0fMWI00270=WI
fA000000:03IfMT@000000X0fMWI0`00001g0=WIfA000000C@3IfMT008L0fMWI4@00000W0=WIfA40
00002@3IfMT00`000000fMWI0=WIf@1g0=WIfA400000C03IfMT008H0fMWI4`00000U0=WIfA<00000
203IfMT00`000000fMWI0=WIf@1f0=WIfA<00000B`3IfMT008H0fMWI4`00000U0=WIfA<00000203I
fMT00`000000fMWI0=WIf@1f0=WIfA<00000B`3IfMT008H0fMWI4`00000U0=WIfA<00000203IfMT0
0`000000fMWI0=WIf@1f0=WIfA<00000B`3IfMT008H0fMWI4`00000U0=WIfA<00000203IfMT00`00
0000fMWI0=WIf@1f0=WIfA<00000B`3IfMT008D0fMWI5000000T0=WIfA@00000203IfMT00`000000
fMWI0=WIf@1e0=WIfA@00000B`3IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@060=WIfA<000000`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@0C000000P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WI
f@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WI
f@080=WIf@030000003IfMT0fMWI00D0fMWI4`0000030=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI000=
0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0@
0=WIfA<000003@3IfMT00`000000fMWI0=WIf@0E0=WIfA<00000203IfMT00`000000fMWI0=WIf@0`
0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0403IfMTC000000d0fMWI00<00000
0=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@080=WIf@00QP3IfMTC000002D0fMWI4`0000080=WI
f@030000003IfMT0fMWI07H0fMWI4`00001;0=WIf@00Q`3IfMTA000002L0fMWI4@0000090=WIf@03
0000003IfMT0fMWI07L0fMWI4@00001<0=WIf@00Q`3IfMT@000002P0fMWI4000000:0=WIf@030000
003IfMT0fMWI07L0fMWI4000001=0=WIf@00R03IfMT?000002T0fMWI3`00000:0=WIf@<00000N03I
fMT?000004d0fMWI00290=WIf@`00000;03IfMT<000000`0fMWI00<000000=WIf@3IfMT0N@3IfMT<
000004l0fMWI002;0=WIf@T00000;`3IfMT9000000d0fMWI00<000000=WIf@3IfMT0N`3IfMT90000
0500fMWI002?0=WIf@030000003IfMT0fMWI03D0fMWI00<000000=WIf@3IfMT03`3IfMT00`000000
fMWI0=WIf@1o0=WIf@030000003IfMT0fMWI0580fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI002_0=WIf@@000001`3IfMT2000000D0fMWI1`0000040=WIf@D00000203IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@8000001P3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00H0fMWI0P0000070=WIf@030000003IfMT0fMWI
0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03@3IfMT01@000000
fMWI0=WIf@3IfMT0000000T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3I
fMT02P3IfMT00`000000fMWI0=WIf@050=WIf@@00000d`3IfMT00:h0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@8000001@3IfMT010000000fMWI0=WIf@3IfMT2000000L0
fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI
002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WI
f@040000003IfMT0fMWI000000h0fMWI0P0000030=WIf@800000103IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI0=@0fMWI002_0=WIf@@00000403IfMT3000000H0fMWI1@0000080=WI
f@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI100000070=WIf@8000001P3I
fMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT000001`3I
fMT2000000X0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0
fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT04@3IfMT00`00
0000fMWI0=WIf@050=WIf@@00000d`3IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0<0=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WI
f@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI1@0000080=WIf@03
0000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
303IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0:0=WIf@030000003I
fMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000l0fMWI00<000000=WIf@3IfMT02P3I
fMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000l0fMWI1@0000080=WIf@<00000e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0
fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@050=WIf@D00000203IfMT00`000000
fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@0000070=WIf@800000203IfMT00`000000
fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI
0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI1000
003C0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<00000
0=WIf@3IfMT0103IfMT010000000fMWI0=WIf@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03I
fMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0
fMWI00<0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@00000>0=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0
fMWI002_0=WIf@@000003P3IfMT7000000@0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00</0fMWI1`0000070=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@03
0000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3IfMT0
203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@@00000d`3I
fMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0
fMWI00<000000=WIf@3IfMT0g`3IfMT00<h0fMWI00<000000=WIf@3IfMT0g`3IfMT00</0fMWI0P00
00000`3IfMT000000=WIf@3P0=WIf@00c@3IfMT200000>40fMWI0000\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.32386 .30902 Mdot
.45076 .30902 Mdot
.82386 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT0:P3IfMT2000000<0fMWI
0P00000C0=WIf@T00000403IfMT2000000030=WIf@000000fMWI01D0fMWI2@00000?0=WIf@030000
003IfMT0fMWI02`0fMWI0P0000000`3IfMT000000=WIf@0^0=WIf@8000000`3IfMT2000001P0fMWI
2@00000A0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
000_0=WIf@<000004`3IfMT<00000140fMWI0P00000D0=WIf@`000003P3IfMT00`000000fMWI0=WI
f@0^0=WIf@800000<@3IfMT3000001P0fMWI3000000<0=WIf@@00000<03IfMT2000000X0fMWI002;
0=WIf@l00000903IfMT?000000`0fMWI00<000000=WIf@3IfMT0N`3IfMT?000004X0fMWI002:0=WI
fA0000008`3IfMT@000000`0fMWI0`00001j0=WIfA000000BP3IfMT008X0fMWI4@00000R0=WIfA40
00002`3IfMT00`000000fMWI0=WIf@1j0=WIfA400000B@3IfMT008T0fMWI4`00000P0=WIfA<00000
2P3IfMT00`000000fMWI0=WIf@1i0=WIfA<00000B03IfMT008T0fMWI4`00000P0=WIfA<000002P3I
fMT00`000000fMWI0=WIf@1i0=WIfA<00000B03IfMT008T0fMWI4`00000P0=WIfA<000002P3IfMT0
0`000000fMWI0=WIf@1i0=WIfA<00000B03IfMT008T0fMWI4`00000P0=WIfA<000002P3IfMT00`00
0000fMWI0=WIf@1i0=WIfA<00000B03IfMT008P0fMWI5000000O0=WIfA@000002P3IfMT00`000000
fMWI0=WIf@1h0=WIfA@00000B03IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIfAD000002@3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI5@0000090=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@070=WIfAD000002@3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT000d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0
fMWI01<0fMWI4`00000:0=WIf@030000003IfMT0fMWI01<0fMWI4`00000:0=WIf@030000003IfMT0
fMWI0300fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0C0=WIfA<000002P3IfMT0
0`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI00P0fMWI00290=WIfA<00000803IfMTC0000
00X0fMWI00<000000=WIf@3IfMT0N@3IfMTC000004P0fMWI002:0=WIfA4000008P3IfMTA000000/0
fMWI00<000000=WIf@3IfMT0NP3IfMTA000004T0fMWI002:0=WIfA0000008`3IfMT@000000`0fMWI
00<000000=WIf@3IfMT0NP3IfMT@000004X0fMWI002;0=WIf@l00000903IfMT?000000`0fMWI0`00
001k0=WIf@l00000BP3IfMT008`0fMWI3000000W0=WIf@`000003P3IfMT00`000000fMWI0=WIf@1l
0=WIf@`00000C03IfMT008h0fMWI2@00000Z0=WIf@T000003`3IfMT00`000000fMWI0=WIf@1n0=WI
f@T00000C@3IfMT00980fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0A0=WIf@03
0000003IfMT0fMWI0880fMWI00<000000=WIf@3IfMT0C`3IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@8000001@3IfMT7000000@0fMWI1@0000080=WI
f@030000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000060=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01P3IfMT2000000L0fMWI00<000000=WI
f@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0=0=WIf@05
0000003IfMT0fMWI0=WIf@0000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI
0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03P3IfMT00`000000
fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00[P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003IfMT0fMWI0=WIf@80
00001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0
e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<000001P3IfMT50000
00P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000L0fMWI0P00
00060=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT010000000fMWI0=WIf@00
00070=WIf@8000002P3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00D0fMWI00<00000
0=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WI
f@030000003IfMT0fMWI00D0fMWI1000003C0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI
0=@0fMWI002h0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<0
00000=WIf@3IfMT0e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI0`00003D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I
0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0
fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00
003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00[`3IfMT4000000L0fMWI0P0000080=WIf@030000003IfMT0fMWI00D0fMWI1@0000080=WIf@03
0000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000080=WIf@03
0000003IfMT0fMWI00T0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000
003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01@3I
fMT400000=<0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT0
0`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WI
f@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<00000
0=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@03
0000003IfMT0fMWI0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000h0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3I
fMT0e03IfMT00:l0fMWI1000000>0=WIf@L00000103IfMT5000000P0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00b`3IfMT7000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0
fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI
0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI003>0=WIf@030000003IfMT0fMWI00P0fMWI1000
003C0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WI
f@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00b`3I
fMT2000000030=WIf@000000fMWI0>00fMWI003=0=WIf@800000h@3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.309017 0.309017 [
[0 .29652 -6 -9 ]
[0 .29652 6 0 ]
[.125 .29652 -6 -9 ]
[.125 .29652 6 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -6 -9 ]
[.375 .29652 6 0 ]
[.625 .29652 -3 -9 ]
[.625 .29652 3 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -3 -9 ]
[.875 .29652 3 0 ]
[1 .29652 -3 -9 ]
[1 .29652 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-4)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-3)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-2)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-1)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(1)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(2)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(3)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(4)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.05 w
.32841 .30902 Mdot
.44772 .30902 Mdot
.82841 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.03333,
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3IfMVa
0=WIf@00o`3IfMVa0=WIf@00o`3IfMVa0=WIf@00b`3IfMT700000=h0fMWI003>0=WIf@030000003I
fMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI0=l0fMWI003>0=WIf@030000003IfMT0fMWI
00P0fMWI1000003C0=WIf@00``3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=@0fMWI
003>0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00b`3IfMT2000000030=WIf@000000fMWI
00T0fMWI00<000000=WIf@3IfMT0e03IfMT00<d0fMWI0P00000:0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:l0fMWI100000070=WIf@800000203IfMT00`000000fMWI0=WIf@05
0=WIf@D00000203IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT010000000fMWI0=WIf@000007
0=WIf@800000203IfMT00`000000fMWI0=WIf@090=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00Y@3IfMT3000000H0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@030=WIf@D00000203IfMT00`000000fMWI
0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000h0fMWI1`0000040=WI
f@D00000203IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI002i0=WIf@@000001`3IfMT2000000H0fMWI1@0000080=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@040000003IfMT0fMWI000000L0fMWI0P00000:0=WIf@800000
1`3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^03IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT01@3IfMT4
00000=<0fMWI002_0=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00`0fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WI
f@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
e03IfMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03I
fMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000
fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WI
f@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@03
0000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003I
fMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WI
f@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0fMWI0P0000050=WIf@L00000103IfMT5000000P0
fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000001`3IfMT2000000H0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@060=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI
00D000000=WIf@3IfMT0fMWI000000090=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002U0=WIf@<000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003I
fMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<0
00000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D
0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0e03IfMT00:l0fMWI00@000000=WIf@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<0
00001P3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI000@0=WIf@@00000;`3IfMT4000002d0fMWI1`00000/
0=WIf@L00000:`3IfMT00`000000fMWI0=WIf@0/0=WIf@L00000;03IfMT7000002h0fMWI1000000_
0=WIf@@000002@3IfMT00180fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT2
000002d0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0
fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0:`3IfMT010000000fMWI0=WIf@3IfMT200000300fMWI00<0
00000=WIf@3IfMT0203IfMT000h0fMWI1P00000c0=WIf@030000003IfMT0fMWI02`0fMWI00D00000
0=WIf@3IfMT0fMWI0000000_0=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3I
fMT00`000000fMWI0=WIf@0_0=WIf@050000003IfMT0fMWI0=WIf@000000<P3IfMT00`000000fMWI
0=WIf@0Z0=WIf@H000002@3IfMT000h0fMWI00D000000=WIf@3IfMT0fMWI0000000d0=WIf@030000
003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0/0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0c0=WIf@030000
003IfMT0fMWI02X0fMWI00D000000=WIf@3IfMT0fMWI0000000:0=WIf@001P3IfMT3000000H0fMWI
00@000000=WIf@3IfMT000009P3IfMT3000000X0fMWI0P00000T0=WIf@<000002@3IfMT2000002D0
fMWI0`0000080=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000
fMWI0=WIf@0a0=WIf@800000<P3IfMT2000002d0fMWI00@000000=WIf@3IfMT000002P3IfMT000l0
fMWI00@000000=WIf@3IfMT00000<P3IfMT200000380fMWI00<000000=WIf@3IfMT0;P3IfMT00`00
0000fMWI0=WIf@0/0=WIf@<00000;`3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI
02l0fMWI0P00000^0=WIf@040000003IfMT0fMWI000000X0fMWI000@0=WIf@030000003IfMT00000
03<0fMWI0P00000b0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0;03IfMT00`00
0000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0;`3IfMT20000
02h0fMWI00<000000=WIf@0000002P3IfMT00100fMWI00<000000=WIf@000000=03IfMT00`000000
fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0;@3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000
fMWI0000000:0=WIf@004@3IfMT2000003@0fMWI00<000000=WIf@3IfMT0:P3IfMT2000000<0fMWI
0P00000D0=WIf@T000003`3IfMT2000000030=WIf@000000fMWI01@0fMWI2@00000@0=WIf@030000
003IfMT0fMWI02`0fMWI0P0000000`3IfMT000000=WIf@0^0=WIf@8000000`3IfMT2000001X0fMWI
2@00000?0=WIf@030000003IfMT0fMWI02d0fMWI0P00000:0=WIf@004@3IfMT200000300fMWI1000
000_0=WIf@<00000503IfMT<00000100fMWI0P00000C0=WIf@`000003`3IfMT00`000000fMWI0=WI
f@0^0=WIf@800000<@3IfMT3000001X0fMWI3000000:0=WIf@@00000<03IfMT2000000X0fMWI002<
0=WIf@l000008P3IfMT?000000d0fMWI00<000000=WIf@3IfMT0O@3IfMT?000004P0fMWI002;0=WI
fA0000008@3IfMT@000000d0fMWI0`00001l0=WIfA000000B03IfMT008/0fMWI4@00000P0=WIfA40
0000303IfMT00`000000fMWI0=WIf@1l0=WIfA400000A`3IfMT008X0fMWI4`00000N0=WIfA<00000
2`3IfMT00`000000fMWI0=WIf@1k0=WIfA<00000AP3IfMT008X0fMWI4`00000N0=WIfA<000002`3I
fMT00`000000fMWI0=WIf@1k0=WIfA<00000AP3IfMT008X0fMWI4`00000N0=WIfA<000002`3IfMT0
0`000000fMWI0=WIf@1k0=WIfA<00000AP3IfMT008X0fMWI4`00000N0=WIfA<000002`3IfMT00`00
0000fMWI0=WIf@1k0=WIfA<00000AP3IfMT008T0fMWI5000000M0=WIfA@000002`3IfMT00`000000
fMWI0=WIf@1j0=WIfA@00000AP3IfMT000d0fMWIo`00002J000000X0fMWI000=0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT00000018000002@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI4`00
00000`3IfMT000000=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI01<00000203IfMT00`000000fMWI0=WI
f@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT000d0fMWI00<00000
0=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI01@0fMWI4`000009
0=WIf@030000003IfMT0fMWI0180fMWI4`00000;0=WIf@030000003IfMT0fMWI0300fMWI00<00000
0=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0E0=WIfA<00000203IfMT00`000000fMWI0=WIf@0`
0=WIf@030000003IfMT0fMWI00P0fMWI002:0=WIfA<000007P3IfMTC000000/0fMWI00<000000=WI
f@3IfMT0N`3IfMTC000004H0fMWI002;0=WIfA400000803IfMTA000000`0fMWI00<000000=WIf@3I
fMT0O03IfMTA000004L0fMWI002;0=WIfA0000008@3IfMT@000000d0fMWI00<000000=WIf@3IfMT0
O03IfMT@000004P0fMWI002<0=WIf@l000008P3IfMT?000000d0fMWI0`00001m0=WIf@l00000B03I
fMT008d0fMWI3000000U0=WIf@`000003`3IfMT00`000000fMWI0=WIf@1n0=WIf@`00000BP3IfMT0
08l0fMWI2@00000X0=WIf@T00000403IfMT00`000000fMWI0=WIf@200=WIf@T00000B`3IfMT009<0
fMWI00<000000=WIf@3IfMT0;P3IfMT00`000000fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI08@0
fMWI00<000000=WIf@3IfMT0C@3IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<0
00000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT30000
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@<00000
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0:l0fMWI100000070=WIf@8000001@3IfMT7000000@0fMWI1@0000080=WIf@030000003IfMT0fMWI
0=@0fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000060=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT01P3IfMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0=0=WIf@050000003IfMT0fMWI0=WI
f@0000002@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@0:0=WIf@03
0000003IfMT0fMWI00D0fMWI1000003C0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00l0fMWI0P0000050=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000
fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI
00<000000=WIf@3IfMT00`3IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI00@000000=WI
f@3IfMT000003P3IfMT2000000<0fMWI0P0000040=WIf@030000003IfMT0fMWI00X0fMWI00<00000
0=WIf@3IfMT0e03IfMT00:l0fMWI1000000@0=WIf@<000001P3IfMT5000000P0fMWI0`00003D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI
00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D
0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00
f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT4000000L0fMWI0P0000060=WIf@D00000203I
fMT00`000000fMWI0=WIf@3D0=WIf@00^@3IfMT010000000fMWI0=WIf@0000070=WIf@8000002P3I
fMT2000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0e03IfMT0
0;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI
00D0fMWI1000003C0=WIf@00^03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0
fMWI00@000000=WIf@3IfMT0fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002h0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0303IfMT5000000P0fMWI00<000000=WIf@3I
fMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000
003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00;P0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03I
fMT00;T0fMWI00@000000=WIf@3IfMT000003`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003I
fMT0fMWI0=@0fMWI002i0=WIf@@000003`3IfMT5000000P0fMWI0`00003D0=WIf@00f@3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000
003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0
fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0
fMWI003I0=WIf@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<00000
0=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3I
fMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT0
0`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00[`3IfMT4000000L0
fMWI0P0000080=WIf@030000003IfMT0fMWI00D0fMWI1@0000080=WIf@030000003IfMT0fMWI0=@0
fMWI002_0=WIf@040000003IfMT0fMWI000000L0fMWI0P0000080=WIf@030000003IfMT0fMWI00T0
fMWI0P0000070=WIf@030000003IfMT0fMWI0=@0fMWI002^0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00D0fMWI
00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@0?0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01@3IfMT400000=<0fMWI002^
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@04
0=WIf@040000003IfMT0fMWI0=WIf@8000001`3IfMT00`000000fMWI0=WIf@3D0=WIf@00[P3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT00`3IfMT5
000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00:h0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`00
0000fMWI0=WIf@3D0=WIf@00[P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0100
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI0=@0
fMWI002_0=WIf@040000003IfMT0fMWI000000h0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0e03IfMT00:l0fMWI
1000000>0=WIf@L00000103IfMT5000000P0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00
003D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WI
f@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3I
fMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT300000=@0fMWI003I0=WIf@030000003IfMT0fMWI
0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI
003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WIf@030000003IfMT0fMWI0=@0fMWI003I0=WI
f@<00000e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0
e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI00<000000=WIf@3IfMT0e03IfMT0
0=T0fMWI00<000000=WIf@3IfMT0e03IfMT00=T0fMWI0`00003D0=WIf@00f@3IfMT00`000000fMWI
0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D0=WIf@00f@3IfMT00`000000fMWI0=WIf@3D
0=WIf@00b`3IfMT7000000L0fMWI00<000000=WIf@3IfMT0e03IfMT00<h0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@3D0=WIf@00cP3IfMT00`000000fMWI0=WIf@080=WIf@030000
003IfMT0fMWI0=@0fMWI003>0=WIf@030000003IfMT0fMWI00P0fMWI1000003C0=WIf@00cP3IfMT0
0`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000
fMWI0=WIf@3O0=WIf@00cP3IfMT00`000000fMWI0=WIf@3O0=WIf@00b`3IfMT2000000030=WIf@00
0000fMWI0>00fMWI003=0=WIf@800000h@3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 287.312}, {177.25, 0}} -> {-4.26595, -1.0535, \
0.0293866, 0.0118871}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell["QM: Hydrogen Atom", "Title"],

Cell[CellGroupData[{

Cell[TextData[{
  "Problem 5: The Hydrogen Atom in Spherical Coordinates",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required Packages", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[" Needs[\"Graphics`ParametricPlot3D`\"]", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Clear[\"Global`*\"];", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"eq1", "=", 
      RowBox[{
        RowBox[{
          RowBox[{"0", "\[Equal]", 
            FormBox[
              
              RowBox[{\(\(2\ m\ \(R(
                        r)\)\ \((En - V(r))\)\ r\^2\)\/\[HBar]\^2\), "+", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["R", "\[Prime]\[Prime]",
                      MultilineFunction->None], "(", "r", ")"}], 
                  " ", \(r\^2\)}], "+", 
                RowBox[{"2", " ", 
                  RowBox[{
                    SuperscriptBox["R", "\[Prime]",
                      MultilineFunction->None], "(", "r", ")"}], " ", "r"}], 
                "-", \(\[ScriptL]\ \((\[ScriptL] + 1)\)\ \(R(r)\)\)}],
              "TraditionalForm"]}], "/.", 
          RowBox[{\(V[r]\), "\[Rule]", 
            FormBox[\(-\(e\^2\/\(4\ \[Pi]\ r\ \[Epsilon]0\)\)\),
              "TraditionalForm"]}]}], 
        "/.", \(En \[Rule] \(-Wn\)\)}]}]], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"0", "==", 
        RowBox[{\(\(2\ m\ \((e\^2\/\(4\ \[Pi]\ r\ \[Epsilon]0\) - Wn)\)\ \(R(
                  r)\)\ r\^2\)\/\[HBar]\^2\), "+", 
          RowBox[{
            RowBox[{
              SuperscriptBox["R", "\[Prime]\[Prime]",
                MultilineFunction->None], "(", "r", ")"}], " ", \(r\^2\)}], 
          "+", 
          RowBox[{"2", " ", 
            RowBox[{
              SuperscriptBox["R", "\[Prime]",
                MultilineFunction->None], "(", "r", ")"}], " ", "r"}], 
          "-", \(\[ScriptL]\ \((\[ScriptL] + 1)\)\ \(R(r)\)\)}]}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["eq2=DSolve[eq1,{R[r]},r][[1]] ", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{\(R(r)\), "\[Rule]", 
          RowBox[{
            
            RowBox[{\(\[ExponentialE]\^\(\(\[ScriptL]\ \[HBar]\ \(log(
                            r)\) - \@2\ \@m\ r\ \@Wn\)\/\[HBar]\)\), " ", 
              SubscriptBox[
                TagBox["c",
                  C], "1"], " ", 
              RowBox[{
                TagBox["U",
                  HypergeometricU], 
                "(", \(\(-\(\(\@2\ \@m\ e\^2 - 
                        8\ \[Pi]\ \@Wn\ \[ScriptL]\ \[Epsilon]0\ \[HBar] - 
                        8\ \[Pi]\ \@Wn\ \[Epsilon]0\ \[HBar]\)\/\(8\ \[Pi]\ \
\@Wn\ \[Epsilon]0\ \[HBar]\)\)\), 
                2\ \[ScriptL] + 2, \(2\ \@2\ \@m\ r\ \@Wn\)\/\[HBar]\), 
                ")"}]}], "+", 
            
            RowBox[{\(\[ExponentialE]\^\(\(\[ScriptL]\ \[HBar]\ \(log(
                            r)\) - \@2\ \@m\ r\ \@Wn\)\/\[HBar]\)\), " ", 
              SubscriptBox[
                TagBox["c",
                  C], "2"], 
              " ", \(\(L\_\(\(\@2\ \@m\ e\^2 - 
                          8\ \[Pi]\ \@Wn\ \[ScriptL]\ \[Epsilon]0\ \[HBar] - 
                          8\ \[Pi]\ \@Wn\ \[Epsilon]0\ \[HBar]\)\/\(8\ \[Pi]\ \
\@Wn\ \[Epsilon]0\ \[HBar]\)\)\%\(2\ \[ScriptL] + 
                      1\)\)(\(2\ \@2\ \@m\ r\ \@Wn\)\/\[HBar])\)}]}]}], "}"}],
       TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      RowBox[{"substitutions", "=", 
        FormBox[\({m \[Rule] \(4\ \[Pi]\ \[Epsilon]0\ \[HBar]\^2\)\/\(a0\ \
e\^2\), Wn \[Rule] \(e\^4\ m\)\/\(32\ n\^2\ \[Pi]\^2\ \[Epsilon]0\^2\ \[HBar]\
\^2\)}\),
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq3 = \(eq2 //. substitutions\ \  // PowerExpand\) // 
        Simplify\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{\(R(r)\), "\[Rule]", 
          
          RowBox[{\(\[ExponentialE]\^\(-\(r\/\(a0\ n\)\)\)\), 
            " ", \(r\^\[ScriptL]\), " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SubscriptBox[
                    TagBox["c",
                      C], "1"], " ", 
                  RowBox[{
                    TagBox["U",
                      HypergeometricU], "(", \(\(-n\) + \[ScriptL] + 1, 
                    2\ \[ScriptL] + 2, \(2\ r\)\/\(a0\ n\)\), ")"}]}], "+", 
                RowBox[{
                  SubscriptBox[
                    TagBox["c",
                      C], "2"], 
                  " ", \(\(L\_\(n - \[ScriptL] - 1\)\%\(2\ \[ScriptL] + 
                          1\)\)(\(2\ r\)\/\(a0\ n\))\)}]}], ")"}]}]}], "}"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq4 = eq3 /. {C[1] \[Rule] 0\ }\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{\(R(r)\), "\[Rule]", 
          
          RowBox[{\(\[ExponentialE]\^\(-\(r\/\(a0\ n\)\)\)\), 
            " ", \(r\^\[ScriptL]\), " ", 
            SubscriptBox[
              TagBox["c",
                C], "2"], 
            " ", \(\(L\_\(n - \[ScriptL] - 1\)\%\(2\ \[ScriptL] + 
                    1\)\)(\(2\ r\)\/\(a0\ n\))\)}]}], "}"}], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      RowBox[{"rNorm", "=", 
        FormBox[\(2\^\(\[ScriptL] + 1\)\ \((1\/\(a0\ n\))\)\^\[ScriptL]\ \@\(\
\(\((n - \[ScriptL] - 1)\)!\)\/\(a0\^3\ n\^4\ \(\((n + \[ScriptL])\)!\)\)\)\),
          
          "TraditionalForm"]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rwave[n_, \[ScriptL]_, 
        r_]\  = \(\(R[r] /. eq4[\([1]\)]\) /. C[2] \[Rule] rNorm // 
          PowerExpand\) // Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(2\^\(\[ScriptL] + 1\)\ a0\^\(\(-\[ScriptL]\) - \
3\/2\)\ \[ExponentialE]\^\(-\(r\/\(a0\ n\)\)\)\ n\^\(\(-\[ScriptL]\) - 2\)\ r\
\^\[ScriptL]\ \@\(\((n - \[ScriptL] - 1)\)!\)\ \(\(L\_\(n - \[ScriptL] - \
1\)\%\(2\ \[ScriptL] + 1\)\)(\(2\ r\)\/\(a0\ n\))\)\)\/\@\(\((n + \[ScriptL])\
\)!\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[\ \(r\^2\) {\ \ rwave[1, 0, r\ ], rwave[2, 0, r\ ], rwave[2, \
1, r\ ]}\^2, {r, 0, \[Infinity]}, 
      Assumptions \[Rule] {Re[a0] > 0}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, 1, 1}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq5 = \(\(Table[
          rwave[n, \[ScriptL], r], \ {n, 1, 3}, {\[ScriptL], 0, 
            n - 1}\ ]\)\(//\)\(\ \)\(TableForm[#, \ 
            TableHeadings \[Rule] {{"\<n=1\>", "\<n=2\>", "\<n=3\>"}, {"\<\
\[ScriptL]=0\>", "\<\[ScriptL]=1\>", "\<\[ScriptL]=2\>"}}] &\)\(\ \)\)\)], \
"Input"],

Cell[BoxData[
    FormBox[
      InterpretationBox[GridBox[{
            {
              FormBox["\<\"\"\>",
                "TraditionalForm"], 
              FormBox["\<\"\[ScriptL]=0\"\>",
                "TraditionalForm"], 
              FormBox["\<\"\[ScriptL]=1\"\>",
                "TraditionalForm"], 
              FormBox["\<\"\[ScriptL]=2\"\>",
                "TraditionalForm"]},
            {
              FormBox["\<\"n=1\"\>",
                
                "TraditionalForm"], \(\(2\ \
\[ExponentialE]\^\(-\(r\/a0\)\)\)\/a0\^\(3/2\)\), "\<\"\"\>", "\<\"\"\>"},
            {
              FormBox["\<\"n=2\"\>",
                
                "TraditionalForm"], \(\(\[ExponentialE]\^\(-\(r\/\(2\ \
a0\)\)\)\ \((2 - 
                        r\/a0)\)\)\/\(2\ \@2\ a0\^\(3/2\)\)\), \(\(\
\[ExponentialE]\^\(-\(r\/\(2\ a0\)\)\)\ r\)\/\(2\ \@6\ a0\^\(5/2\)\)\), "\<\"\
\"\>"},
            {
              FormBox["\<\"n=3\"\>",
                
                "TraditionalForm"], \(\(2\ \[ExponentialE]\^\(-\(r\/\(3\ a0\)\
\)\)\ \((27\ a0\^2 - 18\ r\ a0 + 
                        2\ r\^2)\)\)\/\(81\ \@3\ a0\^\(7/2\)\)\), \
\(\(\@\(2\/3\)\ \[ExponentialE]\^\(-\(r\/\(3\ a0\)\)\)\ r\ \((4 - \(2\ \
r\)\/\(3\ a0\))\)\)\/\(27\ a0\^\(5/2\)\)\), \(\(2\ \@\(2\/15\)\ \
\[ExponentialE]\^\(-\(r\/\(3\ a0\)\)\)\ r\^2\)\/\(81\ a0\^\(7/2\)\)\)}
            },
          RowSpacings->1,
          ColumnSpacings->3,
          RowAlignments->Baseline,
          ColumnAlignments->{Left}],
        TableForm[ {{
          Times[ 2, 
            Power[ a0, 
              Rational[ -3, 2]], 
            Power[ E, 
              Times[ -1, 
                Power[ a0, -1], r]]]}, {
          Times[ 
            Rational[ 1, 2], 
            Power[ 2, 
              Rational[ -1, 2]], 
            Power[ a0, 
              Rational[ -3, 2]], 
            Power[ E, 
              Times[ 
                Rational[ -1, 2], 
                Power[ a0, -1], r]], 
            Plus[ 2, 
              Times[ -1, 
                Power[ a0, -1], r]]], 
          Times[ 
            Rational[ 1, 2], 
            Power[ 6, 
              Rational[ -1, 2]], 
            Power[ a0, 
              Rational[ -5, 2]], 
            Power[ E, 
              Times[ 
                Rational[ -1, 2], 
                Power[ a0, -1], r]], r]}, {
          Times[ 
            Rational[ 2, 81], 
            Power[ 3, 
              Rational[ -1, 2]], 
            Power[ a0, 
              Rational[ -7, 2]], 
            Power[ E, 
              Times[ 
                Rational[ -1, 3], 
                Power[ a0, -1], r]], 
            Plus[ 
              Times[ 27, 
                Power[ a0, 2]], 
              Times[ -18, a0, r], 
              Times[ 2, 
                Power[ r, 2]]]], 
          Times[ 
            Rational[ 1, 27], 
            Power[ 
              Rational[ 2, 3], 
              Rational[ 1, 2]], 
            Power[ a0, 
              Rational[ -5, 2]], 
            Power[ E, 
              Times[ 
                Rational[ -1, 3], 
                Power[ a0, -1], r]], r, 
            Plus[ 4, 
              Times[ 
                Rational[ -2, 3], 
                Power[ a0, -1], r]]], 
          Times[ 
            Rational[ 2, 81], 
            Power[ 
              Rational[ 2, 15], 
              Rational[ 1, 2]], 
            Power[ a0, 
              Rational[ -7, 2]], 
            Power[ E, 
              Times[ 
                Rational[ -1, 3], 
                Power[ a0, -1], r]], 
            Power[ r, 2]]}}, TableHeadings -> {{"n=1", "n=2", "n=3"}, {
          "\[ScriptL]=0", "\[ScriptL]=1", "\[ScriptL]=2"}}]], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(plot[n_, \[ScriptL]_, rmax_] := \[IndentingNewLine]Plot[
          r\^2\ rwave[n, \[ScriptL], r]\^2 /. a0 \[Rule] 1 // 
            Evaluate, \[IndentingNewLine]{r, 0.01, 
            rmax}, \[IndentingNewLine]Ticks \[Rule] {{1, 4, 8, 14, 20}, {0.1, 
                0.3, 0.5}}, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[ \
Table[plot[n,\[ScriptL],n*7],{n,1,3},{\[ScriptL],0,n-1}]]];\
\>", "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0147151 0.31746 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.321429 0.198654 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0453515 0.0147151 5.79711 [
[.06916 .00222 -3 -9 ]
[.06916 .00222 3 0 ]
[.20522 .00222 -3 -9 ]
[.20522 .00222 3 0 ]
[.38662 .00222 -3 -9 ]
[.38662 .00222 3 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.93084 .00222 -6 -9 ]
[.93084 .00222 6 0 ]
[.01131 .59443 -18 -4.5 ]
[.01131 .59443 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06916 .01472 m
.06916 .02097 L
s
[(1)] .06916 .00222 0 1 Mshowa
.20522 .01472 m
.20522 .02097 L
s
[(4)] .20522 .00222 0 1 Mshowa
.38662 .01472 m
.38662 .02097 L
s
[(8)] .38662 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(14)] .65873 .00222 0 1 Mshowa
.93084 .01472 m
.93084 .02097 L
s
[(20)] .93084 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
.02381 .59443 m
.03006 .59443 L
s
[(0.1)] .01131 .59443 1 0 Mshowa
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02426 .0148 m
.02544 .01575 L
.02651 .01741 L
.02774 .02013 L
.02891 .02335 L
.03323 .03886 L
.03834 .05962 L
.04306 .07692 L
.04767 .08982 L
.05 .09447 L
.05132 .09653 L
.05256 .0981 L
.05321 .09876 L
.0539 .09936 L
.05513 .10015 L
.05582 .10044 L
.05656 .10064 L
.05726 .10071 L
.05789 .10068 L
.05912 .10038 L
.05982 .10008 L
.06046 .09971 L
.06164 .09883 L
.06288 .09763 L
.0655 .09425 L
.06789 .0903 L
.07326 .07909 L
.08296 .05501 L
.08851 .04164 L
.0944 .02953 L
.09944 .0217 L
.1023 .01847 L
.10359 .01734 L
.10499 .01633 L
.1062 .01565 L
.10733 .01519 L
.10852 .01487 L
.10978 .01472 L
.11097 .01477 L
.11208 .01497 L
.11309 .01529 L
.11417 .01578 L
.11537 .01648 L
.11668 .01745 L
.11932 .02005 L
.12178 .02319 L
.12407 .02673 L
.13407 .04834 L
.14482 .08 L
.16456 .1468 L
Mistroke
.17498 .1795 L
.1807 .19517 L
.18608 .20804 L
.19128 .21851 L
.1969 .22749 L
.19939 .23064 L
.20201 .23343 L
.20446 .23552 L
.2067 .23699 L
.20779 .23756 L
.20898 .23807 L
.21023 .23848 L
.21142 .23875 L
.21253 .2389 L
.21371 .23895 L
.21471 .2389 L
.21582 .23876 L
.21712 .23847 L
.21831 .23809 L
.21961 .23755 L
.22098 .23684 L
.22329 .23533 L
.22582 .23323 L
.23112 .22741 L
.23612 .22028 L
.24546 .20327 L
.26641 .15322 L
.28476 .10497 L
.29518 .07935 L
.30491 .05813 L
.31532 .03939 L
.32482 .02655 L
.33003 .02142 L
.33497 .01787 L
.33768 .01649 L
.34019 .01555 L
.3415 .0152 L
.34225 .01505 L
.34294 .01493 L
.34367 .01483 L
.34445 .01476 L
.34514 .01472 L
.34587 .01472 L
.3471 .01477 L
.34779 .01483 L
.34843 .01492 L
.34961 .01513 L
.35085 .01544 L
.35301 .01617 L
.35539 .01728 L
Mistroke
.35792 .01879 L
.36065 .0208 L
.36557 .02543 L
.37516 .03799 L
.38392 .05334 L
.40291 .0977 L
.42363 .15953 L
.46428 .30043 L
.50341 .43042 L
.52339 .48606 L
.54499 .53485 L
.55514 .55331 L
.56587 .5696 L
.57591 .58188 L
.58506 .59059 L
.59454 .59717 L
.59976 .59975 L
.60216 .6007 L
.6047 .60154 L
.60687 .60213 L
.60927 .60264 L
.61031 .60282 L
.61144 .60298 L
.6125 .6031 L
.61349 .60319 L
.61465 .60327 L
.61591 .60331 L
.61715 .60332 L
.61847 .60329 L
.6197 .60322 L
.62086 .60312 L
.6219 .603 L
.62303 .60285 L
.62539 .60244 L
.62793 .60186 L
.6325 .60044 L
.63794 .59818 L
.64291 .59558 L
.65371 .58828 L
.66395 .57943 L
.7022 .53308 L
.7429 .46872 L
.78208 .40099 L
.82372 .33014 L
.86383 .26752 L
.90244 .21477 L
.9435 .16761 L
.97619 .13653 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.0147151 0.64881 0.198654 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0453515 0.0147151 5.78302 [
[.06916 .00222 -3 -9 ]
[.06916 .00222 3 0 ]
[.20522 .00222 -3 -9 ]
[.20522 .00222 3 0 ]
[.38662 .00222 -3 -9 ]
[.38662 .00222 3 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.93084 .00222 -6 -9 ]
[.93084 .00222 6 0 ]
[.01131 .59302 -18 -4.5 ]
[.01131 .59302 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06916 .01472 m
.06916 .02097 L
s
[(1)] .06916 .00222 0 1 Mshowa
.20522 .01472 m
.20522 .02097 L
s
[(4)] .20522 .00222 0 1 Mshowa
.38662 .01472 m
.38662 .02097 L
s
[(8)] .38662 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(14)] .65873 .00222 0 1 Mshowa
.93084 .01472 m
.93084 .02097 L
s
[(20)] .93084 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
.02381 .59302 m
.03006 .59302 L
s
[(0.1)] .01131 .59302 1 0 Mshowa
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02426 .01472 m
.02544 .01472 L
.02651 .01472 L
.02774 .01472 L
.02891 .01473 L
.02999 .01474 L
.03098 .01476 L
.03208 .01479 L
.03323 .01484 L
.0344 .01491 L
.03565 .01502 L
.03683 .01515 L
.03791 .01529 L
.03917 .01551 L
.04055 .0158 L
.04306 .0165 L
.04567 .01752 L
.04804 .01872 L
.05058 .02035 L
.05334 .02255 L
.05825 .02766 L
.06288 .03396 L
.07355 .05406 L
.08481 .08273 L
.10499 .14441 L
.11519 .17529 L
.12485 .20129 L
.13425 .22187 L
.13838 .22913 L
.14295 .23574 L
.14748 .24078 L
.14996 .24288 L
.15229 .24443 L
.15353 .24509 L
.15484 .24566 L
.15596 .24603 L
.15718 .24634 L
.1585 .24654 L
.15924 .2466 L
.15991 .24661 L
.16122 .24654 L
.16245 .24636 L
.16366 .24607 L
.16498 .24563 L
.16637 .24504 L
.16767 .24436 L
.17248 .2408 L
.17522 .23808 L
.17772 .23517 L
.18335 .22723 L
Mistroke
.19322 .20923 L
.20237 .18885 L
.2231 .13544 L
.24192 .08693 L
.25182 .06445 L
.26226 .04444 L
.26759 .03598 L
.27343 .02823 L
.27875 .02265 L
.2837 .01875 L
.28632 .01721 L
.2888 .01609 L
.29103 .01536 L
.29228 .01507 L
.29344 .01488 L
.29469 .01476 L
.29585 .01472 L
.29713 .01475 L
.29785 .01482 L
.2985 .0149 L
.29975 .01511 L
.30112 .01545 L
.30255 .01591 L
.30387 .01643 L
.30651 .01775 L
.30894 .01929 L
.31442 .02392 L
.31925 .02928 L
.32436 .03622 L
.34295 .07159 L
.36256 .12334 L
.38087 .18122 L
.41973 .31668 L
.46104 .44995 L
.4817 .50385 L
.50083 .54381 L
.51939 .57274 L
.52876 .58364 L
.5338 .58848 L
.53911 .59281 L
.54392 .59607 L
.54919 .59893 L
.55397 .6009 L
.55611 .60159 L
.55843 .6022 L
.55984 .60251 L
.56114 .60275 L
.56236 .60293 L
.5637 .6031 L
.5649 .6032 L
Mistroke
.56603 .60327 L
.56722 .60331 L
.5685 .60332 L
.56921 .6033 L
.56988 .60328 L
.57061 .60324 L
.57138 .60319 L
.57282 .60305 L
.57412 .60288 L
.57677 .60243 L
.57927 .60185 L
.58392 .60041 L
.58903 .5983 L
.59935 .59242 L
.6089 .58519 L
.61782 .57704 L
.65673 .52866 L
.69809 .46253 L
.73794 .3936 L
.77627 .32867 L
.81705 .26531 L
.85632 .2121 L
.89407 .16888 L
.93427 .1312 L
.97296 .10235 L
.97619 .10024 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.0147151 0.97619 0.198654 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0453515 0.0147151 5.49677 [
[.06916 .00222 -3 -9 ]
[.06916 .00222 3 0 ]
[.20522 .00222 -3 -9 ]
[.20522 .00222 3 0 ]
[.38662 .00222 -3 -9 ]
[.38662 .00222 3 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.93084 .00222 -6 -9 ]
[.93084 .00222 6 0 ]
[.01131 .56439 -18 -4.5 ]
[.01131 .56439 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06916 .01472 m
.06916 .02097 L
s
[(1)] .06916 .00222 0 1 Mshowa
.20522 .01472 m
.20522 .02097 L
s
[(4)] .20522 .00222 0 1 Mshowa
.38662 .01472 m
.38662 .02097 L
s
[(8)] .38662 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(14)] .65873 .00222 0 1 Mshowa
.93084 .01472 m
.93084 .02097 L
s
[(20)] .93084 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
.02381 .56439 m
.03006 .56439 L
s
[(0.1)] .01131 .56439 1 0 Mshowa
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02426 .01472 m
.02544 .01472 L
.02651 .01472 L
.02774 .01472 L
.02891 .01472 L
.02999 .01472 L
.03098 .01472 L
.03208 .01472 L
.03323 .01472 L
.0344 .01472 L
.03565 .01472 L
.03683 .01472 L
.03791 .01472 L
.03917 .01472 L
.03989 .01472 L
.04055 .01472 L
.04177 .01472 L
.04306 .01472 L
.0444 .01472 L
.04563 .01472 L
.04699 .01472 L
.04841 .01472 L
.04966 .01473 L
.05082 .01473 L
.05217 .01473 L
.05346 .01474 L
.05583 .01475 L
.058 .01476 L
.06034 .01479 L
.06288 .01482 L
.06548 .01486 L
.06792 .01491 L
.0706 .01499 L
.07349 .01509 L
.07635 .01521 L
.07937 .01538 L
.08476 .01579 L
.08976 .01632 L
.09442 .01697 L
.09953 .0179 L
.10499 .01917 L
.11523 .02254 L
.12101 .02509 L
.12633 .02793 L
.13611 .03449 L
.14647 .04354 L
.16604 .06726 L
.18434 .09772 L
.22315 .18672 L
.2644 .30466 L
Mistroke
.30415 .41926 L
.34237 .51132 L
.36208 .54756 L
.38305 .57636 L
.39336 .58668 L
.39878 .59109 L
.40449 .595 L
.40951 .59779 L
.41501 .60019 L
.41742 .60103 L
.42001 .60177 L
.42222 .6023 L
.42467 .60275 L
.42599 .60294 L
.42724 .60308 L
.42855 .6032 L
.42929 .60324 L
.42997 .60328 L
.43111 .60331 L
.43235 .60332 L
.43365 .60329 L
.43486 .60323 L
.43556 .60319 L
.43631 .60312 L
.43767 .60298 L
.44022 .60261 L
.4432 .60201 L
.44594 .6013 L
.4506 .59976 L
.45572 .59759 L
.46606 .59177 L
.47624 .58425 L
.48554 .57599 L
.50643 .55312 L
.54623 .49723 L
.58451 .43486 L
.62524 .36636 L
.66445 .30334 L
.70215 .24841 L
.7423 .1976 L
.78094 .15662 L
.82203 .12122 L
.8616 .0943 L
.89966 .07409 L
.94017 .05765 L
.97619 .04658 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.217048 0.321429 0.400986 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0680272 0.0147151 3.08222 [
[.09184 .00222 -3 -9 ]
[.09184 .00222 3 0 ]
[.29592 .00222 -3 -9 ]
[.29592 .00222 3 0 ]
[.56803 .00222 -3 -9 ]
[.56803 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .32294 -18 -4.5 ]
[.01131 .32294 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09184 .01472 m
.09184 .02097 L
s
[(1)] .09184 .00222 0 1 Mshowa
.29592 .01472 m
.29592 .02097 L
s
[(4)] .29592 .00222 0 1 Mshowa
.56803 .01472 m
.56803 .02097 L
s
[(8)] .56803 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(14)] .97619 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
.02381 .32294 m
.03006 .32294 L
s
[(0.1)] .01131 .32294 1 0 Mshowa
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02449 .01487 m
.04328 .08436 L
.05286 .12812 L
.05822 .14742 L
.0631 .16066 L
.06566 .16587 L
.06701 .16812 L
.06845 .17014 L
.0697 .1716 L
.07107 .17288 L
.07233 .17375 L
.0735 .17431 L
.07475 .17466 L
.07594 .17474 L
.07701 .17462 L
.07817 .17428 L
.07943 .17368 L
.08077 .17278 L
.08319 .1705 L
.08605 .16681 L
.08914 .16173 L
.09474 .15004 L
.1052 .12235 L
.12474 .06601 L
.13009 .05249 L
.13582 .03985 L
.1412 .03009 L
.14618 .02307 L
.14864 .02035 L
.15125 .01804 L
.15388 .01633 L
.15537 .01562 L
.15604 .01537 L
.15678 .01514 L
.158 .01487 L
.1593 .01473 L
.16049 .01473 L
.16161 .01485 L
.16293 .01514 L
.16413 .01553 L
.16551 .01615 L
.16682 .01689 L
.1691 .01854 L
.17151 .02079 L
.17585 .02608 L
.18051 .03352 L
.18564 .04371 L
.19579 .06953 L
.20507 .09882 L
.22595 .17917 L
Mistroke
.26568 .35136 L
.3039 .49163 L
.32359 .54323 L
.3346 .56504 L
.34457 .58042 L
.34945 .58646 L
.35461 .5918 L
.35907 .59557 L
.36384 .59875 L
.36653 .60016 L
.36898 .60122 L
.37144 .60206 L
.37377 .60266 L
.37508 .60291 L
.3758 .60302 L
.37648 .60311 L
.37767 .60323 L
.37899 .6033 L
.37968 .60332 L
.38041 .60332 L
.38172 .60327 L
.38244 .60322 L
.38312 .60316 L
.38466 .60296 L
.38594 .60274 L
.38729 .60245 L
.38972 .60178 L
.39233 .60086 L
.3952 .59961 L
.40514 .59347 L
.41475 .58507 L
.42372 .57527 L
.46257 .5164 L
.50387 .43738 L
.54366 .35844 L
.58193 .28771 L
.62265 .22238 L
.66185 .17059 L
.69955 .13083 L
.73969 .09809 L
.77832 .07443 L
.81939 .056 L
.85896 .04329 L
.89701 .03457 L
.91658 .03111 L
.93751 .02805 L
.97619 .02376 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.217048 0.64881 0.400986 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0680272 0.0147151 3.01282 [
[.09184 .00222 -3 -9 ]
[.09184 .00222 3 0 ]
[.29592 .00222 -3 -9 ]
[.29592 .00222 3 0 ]
[.56803 .00222 -3 -9 ]
[.56803 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .316 -18 -4.5 ]
[.01131 .316 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09184 .01472 m
.09184 .02097 L
s
[(1)] .09184 .00222 0 1 Mshowa
.29592 .01472 m
.29592 .02097 L
s
[(4)] .29592 .00222 0 1 Mshowa
.56803 .01472 m
.56803 .02097 L
s
[(8)] .56803 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(14)] .97619 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
.02381 .316 m
.03006 .316 L
s
[(0.1)] .01131 .316 1 0 Mshowa
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02449 .01472 m
.02566 .01472 L
.02673 .01472 L
.02797 .01472 L
.02913 .01472 L
.03021 .01472 L
.03121 .01473 L
.0323 .01474 L
.03346 .01476 L
.03462 .01478 L
.03587 .01482 L
.03705 .01486 L
.03813 .01492 L
.0394 .01499 L
.04077 .01509 L
.04328 .01535 L
.04589 .01572 L
.04826 .01618 L
.05099 .01686 L
.05356 .01768 L
.05814 .01963 L
.0631 .02255 L
.06818 .02655 L
.07376 .03223 L
.08503 .04819 L
.09546 .0686 L
.1052 .09247 L
.14408 .22406 L
.18541 .38637 L
.2061 .45864 L
.22523 .51424 L
.2438 .55572 L
.25318 .57171 L
.26353 .58547 L
.26845 .59059 L
.27362 .59501 L
.27804 .59803 L
.28287 .60053 L
.2856 .60159 L
.28809 .60233 L
.28946 .60265 L
.29096 .60292 L
.29164 .60303 L
.29236 .60312 L
.29366 .60324 L
.29485 .6033 L
.29613 .60332 L
.29734 .60329 L
.29845 .60322 L
.29974 .60309 L
Mistroke
.30115 .60289 L
.30248 .60265 L
.30371 .60237 L
.3088 .60077 L
.31166 .59954 L
.3143 .5982 L
.32426 .5915 L
.33331 .58329 L
.34286 .57268 L
.38086 .51532 L
.42131 .43904 L
.46024 .36262 L
.50162 .28676 L
.54149 .22332 L
.57985 .17271 L
.62065 .12984 L
.65994 .0981 L
.69772 .07499 L
.73794 .05679 L
.77666 .04413 L
.79633 .03914 L
.81782 .03459 L
.85747 .0282 L
.8771 .0258 L
.89805 .0237 L
.91799 .02205 L
.93957 .02059 L
.97619 .01873 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.41938 0.321429 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0147151 1.08731 [
[.15986 .00222 -3 -9 ]
[.15986 .00222 3 0 ]
[.56803 .00222 -3 -9 ]
[.56803 .00222 3 0 ]
[.01131 .12345 -18 -4.5 ]
[.01131 .12345 0 4.5 ]
[.01131 .34091 -18 -4.5 ]
[.01131 .34091 0 4.5 ]
[.01131 .55837 -18 -4.5 ]
[.01131 .55837 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 .01472 m
.15986 .02097 L
s
[(1)] .15986 .00222 0 1 Mshowa
.56803 .01472 m
.56803 .02097 L
s
[(4)] .56803 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
.02381 .12345 m
.03006 .12345 L
s
[(0.1)] .01131 .12345 1 0 Mshowa
.02381 .34091 m
.03006 .34091 L
s
[(0.3)] .01131 .34091 1 0 Mshowa
.02381 .55837 m
.03006 .55837 L
s
[(0.5)] .01131 .55837 1 0 Mshowa
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02517 .01514 m
.06375 .22308 L
.08383 .36499 L
.09446 .42982 L
.10582 .48806 L
.11654 .53163 L
.12628 .56174 L
.13098 .57312 L
.13608 .58326 L
.14089 .59082 L
.14534 .59614 L
.14772 .59836 L
.14999 .60007 L
.15124 .60086 L
.1526 .60158 L
.15386 .60214 L
.15499 .60255 L
.15616 .60288 L
.15726 .6031 L
.15843 .60325 L
.15968 .60332 L
.16079 .60329 L
.16195 .60318 L
.16295 .60302 L
.16404 .60278 L
.16542 .60237 L
.16673 .60187 L
.16918 .60069 L
.17182 .59904 L
.17469 .59684 L
.18464 .58615 L
.19402 .5723 L
.20438 .5536 L
.22536 .50793 L
.2655 .40782 L
.30414 .31441 L
.34522 .23009 L
.38479 .16657 L
.42284 .12077 L
.44406 .10083 L
.46334 .08566 L
.50233 .06212 L
.52149 .05341 L
.54226 .04566 L
.56171 .03974 L
.58312 .03447 L
.62246 .0274 L
.64188 .02488 L
.66275 .02271 L
.68247 .02107 L
Mistroke
.70396 .01966 L
.74367 .0178 L
.76335 .01716 L
.78431 .01661 L
.80573 .01618 L
.82588 .01586 L
.84427 .01563 L
.86443 .01543 L
.88438 .01527 L
.90543 .01514 L
.92495 .01505 L
.94585 .01497 L
.97619 .01489 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{674, 416.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:R0001X2000`400?l00000o`00003oo`3ooooo
0?oooj@0oooo003o0?ooool0ooooY03oool00?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo
003o0?ooool0ooooY03oool00?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0
ooooY03oool00?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0ooooY03oool0
0?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo000[0?ooo`@000005`3oool00`000000oooo
0?ooo`0M0?ooo`800000;03oool4000000@0oooo00<000000?ooo`3oool09`3oool4000000<0oooo
0P00000h0?ooo`@000005`3oool00`000000oooo0?ooo`0M0?ooo`800000;03oool4000000@0oooo
00<000000?ooo`3oool09`3oool4000000<0oooo0P00000h0?ooo`@000005`3oool00`000000oooo
0?ooo`0M0?ooo`800000;03oool4000000@0oooo00<000000?ooo`3oool09`3oool4000000<0oooo
0P00000K0?ooo`00;@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01`0oooo00@0
00000?ooo`3oool00000;@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000i0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0703oool010000000oooo0?ooo`00000]0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
000003T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0L0?ooo`040000003oool0
oooo000002d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool000006P3oool002d0oooo00<000000?ooo`3oool04`3o
ool5000001d0oooo00@000000?ooo`3oool00000;@3oool00`000000oooo0?ooo`05000002T0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000i0?ooo`030000003oool0oooo01<0
oooo1@00000M0?ooo`040000003oool0oooo000002d0oooo00<000000?ooo`3oool01@00000Y0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000>@3oool00`000000oooo0?ooo`0C
0?ooo`D000007@3oool010000000oooo0?ooo`00000]0?ooo`030000003oool0oooo00D00000:@3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001X0oooo000]0?ooo`030000003o
ool0oooo01<0oooo00@000000?ooo`3oool000007`3oool2000002h0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0Y0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool000007`3oool2
000002h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Y0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01<0oooo
00@000000?ooo`3oool000007`3oool2000002h0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0Y0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0H
0?ooo`00;@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0000001h0oooo00@000000?oo
o`3oool00000;@3oool01`000000oooo0?ooo`3oool000000?ooo`000000;03oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0503oool00`000000
oooo0000000N0?ooo`040000003oool0oooo000002d0oooo00L000000?ooo`3oool0oooo0000003o
ool0000002`0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`0000007P3oool010000000oooo0?ooo`00000]0?ooo`07
0000003oool0oooo0?ooo`000000oooo0000000/0?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0603oool002/0oooo0`00000G0?ooo`8000007P3oool010000000oooo0?ooo`00
000[0?ooo`<00000103oool2000002T0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`00000g0?ooo`<000005`3oool2000001h0oooo00@000000?ooo`3oool00000:`3oool30000
00@0oooo0P00000Y0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000=`3o
ool3000001L0oooo0P00000N0?ooo`040000003oool0oooo000002/0oooo0`0000040?ooo`800000
:@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001X0oooo000T0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0M0?ooo`80
0000;P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo0P0000040?ooo`80
0000<@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool07@3oool2000002h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`80
0000103oool200000340oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01d0oooo0P00000^0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0:03oool2000000@0oooo0P00000K0?ooo`00903oool00`000000oooo0?ooo`3I0?ooo`030000
003oool0oooo0=T0oooo00<000000?ooo`3oool0``3oool002@0oooo00<000000?ooo`3oool0f@3o
ool00`000000oooo0?ooo`3I0?ooo`030000003oool0oooo0<<0oooo000P0?oookT000008`3oooni
000002<0oooo^@00000A0?ooo`00903oool2000000L0oooo00<000000?ooo`3oool00P3oool20000
0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00X0oooo0P0000030?ooo`8000003@3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo1000000@0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
01`0oooo000T0?ooo`800000303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0:<0
oooo00<000000?ooo`3oool03`3oool200000;80oooo000T0?ooo`8000002`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`2I0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`2_0?ooo`00903oool00`000000oooo0000000:0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09P0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0X@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0:h0oooo000T
0?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2Q
0?ooo`030000003oool0oooo01<0oooo0P00002^0?ooo`00903oool00`000000oooo000000090?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo09L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo09@0oooo0P00000E0?ooo`00903oool010000000oooo0?ooo`0000070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo09H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo0900oooo1000000G0?ooo`00903oool010000000oooo0?ooo`0000070?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo09H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo08`0oooo0`00000K0?ooo`00903oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo09D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo08X0oooo0P00000N0?ooo`00903oool01@000000oooo0?ooo`3oool00000
00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0Q`3oool200000200oooo000T0?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo09h0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`240?ooo`8000008P3oool002@0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0W@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo0840oooo0P00000T0?ooo`00903oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`2M0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0O`3oool2000002H0oooo000T0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`2L0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0O03oool2000002P0oooo000T0?ooo`03
0000003oool0oooo0080oooo1000000?0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo02P0oooo000T0?ooo`030000
003oool0oooo00<0oooo0P00000@0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo06l0oooo0P00000[0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0N03oool2000002/0oooo000T0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0980oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0K03oool2000002d0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`1e0?ooo`800000;@3oool002@0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0TP3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`1[0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo02d0oooo000T0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0980oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0L@3oool200000300oooo000T0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0940
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0I`3oool200000340oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1`0?ooo`030000003oool0oooo0300oooo000T0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0940oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0a0?ooo`00903oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`1U0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?oo
o`0b0?ooo`00903oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0H`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0J`3oool2000003D0oooo000T0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0680oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`1Q0?ooo`800000=P3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo06T0oooo00<000000?ooo`3oool0=@3oool002@0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3o
ool0=P3oool002@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo06H0oooo00<000000?ooo`3oool0=`3oool002@0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0>03o
ool002@0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool0>@3oool002@0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0>P3oool002@0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0680
oooo00<000000?ooo`3oool0>P3oool002@0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0>`3oool002@0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0?03oool002@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0?@3oool002@0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo05`0oooo00<000000?oo
o`3oool0?P3oool002@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool0?`3oool002@0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0
@03oool002@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0@@3oool002@0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0@P3oool0
02@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0540oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool0@P3oool002@0oooo00<000000?ooo`3oool07P3oool01@000000
oooo0?ooo`3oool0000002L0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo05D0oooo00<000000?ooo`3oool0@`3oool002@0oooo00<000000?ooo`3o
ool07P3oool5000002P0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool00`3oool2000002L0oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`140?ooo`00903oool00`000000oooo0?ooo`1;0?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0D0?ooo`800000
00@0oooo0000000000000000:03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo04D0
oooo000T0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0C03oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo01D0oooo0`00000Z0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool0AP3oool002@0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo04L0oooo000T0?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`170?ooo`00903oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo04h0oooo00<000000?ooo`3oool0B03oool002@0oooo00<000000?ooo`3o
ool0C03oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo04T0oooo000T0?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`190?ooo`00903o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0BP3o
ool002@0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo04/0oooo000T0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`1:0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`1<0?ooo`00903oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool0C03oool002@0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`130?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo04d0oooo000T0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`1>0?ooo`00903oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0CP3oool002@0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo04l0oooo000T0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`1?0?ooo`00
903oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
D03oool002@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo0500oooo000T0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`1A0?ooo`00903oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool0DP3oool002@0oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo0580oooo000T0?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1C0?ooo`00903oool00`000000oooo0?oo
o`1B0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0D`3oool002@0oooo00<00000
0?ooo`3oool0DP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo05@0oooo000T0?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`1E0?oo
o`00903oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0E@3oool002@0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo05H0oooo000T0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`1F0?ooo`00903oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0E`3oool002@0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo05L0oooo000T0?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1H0?ooo`00903oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0F@3oool002@0oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo05T0oooo000T
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1J
0?ooo`00903oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0D03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0FP3oool002@0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo0500oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo05/0oooo000T0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`1L0?ooo`00903oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0G03oool002@0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo05d0oooo000T0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
04h0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1N0?ooo`00903oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0G@3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0GP3oool002@0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo05h0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo05l0oooo
000T0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`1N0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`1P0?ooo`00903oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0H03oool002@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo05l0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo0640oooo000T0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`1R0?ooo`00903oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`1A0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0HP3oool002@0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0DP3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06<0oooo000T0?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1I0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1T0?ooo`00903oool00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0F@3oool00`00
0000oooo0?ooo`1B0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0I03oool002@0
oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0680
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06D0
oooo000T0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`1K0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`1V0?ooo`00903oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0H`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0IP3oool002@0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo06L0oooo000T0?ooo`030000003oool0oooo05d0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`1X0?ooo`00903oool00`000000oooo0?ooo`1N0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0J@3oool002@0oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo06T0oooo000T0?ooo`030000003o
ool0oooo05l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1O0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1E0?ooo`800000103o
ool00`000000oooo0?ooo`020?ooo`@000000`3oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0JP3oool002@0oooo00<000000?ooo`3oool0H03oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05D0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`1[0?ooo`00903oool00`000000oooo0?ooo`1P0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0EP3oool010000000oooo0?ooo`00000:0?ooo`030000003o
ool0oooo0080oooo0P00000o0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0K03o
ool002@0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0640oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo05H0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1]0?ooo`00903oool0
0`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0HP3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0E`3oool0
10000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo06h0oooo000T0?ooo`030000003oool0
oooo06<0oooo00<000000?ooo`3oool0303oool2000005<0oooo0P0000040?ooo`030000003oool0
oooo0080oooo100000030?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool03P3oool2
000005X0oooo00@000000?ooo`3oool00000203oool3000000@0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo06h0oooo000B0?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`@000000`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0DP3oool010000000oooo0?ooo`00000:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0;0?ooo`800000G@3o
ool2000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo00`0oooo0P00001a0?ooo`004@3oool010000000oooo0?ooo`00000:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo05<0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`800000
G03oool2000000T0oooo0P00001a0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
2@3oool2000007<0oooo000A0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
0P3oool2000006L0oooo00<000000?ooo`3oool01@3oool2000005H0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo04<0oooo0P0000080?ooo`03
0000003oool0oooo07<0oooo000A0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`1W0?ooo`L00000F03oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0GP3oool7000007@0oooo00<000000?oo
o`3oool0A@3oool8000007H0oooo000A0?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`360?ooo`040000003oool0oooo000000P0oooo0`000004
0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`3oool0``3oool00140oooo00@000000?oo
o`3oool00000203oool3000000@0oooo00<000000?ooo`3oool0a`3oool2000000/0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0oooo0<<0oooo000B0?oo
o`8000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0=T0oooo00<000000?oo
o`3oool0f@3oool00`000000oooo0?ooo`330?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0oooo
Y03oool00?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0ooooY03oool00?l0
ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0ooooY03oool00?l0ooooo`3ooonT
0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0ooooY03oool00?l0ooooo`3ooonT0?ooo`00o`3o
oooo0?oooj@0oooo003o0?ooool0ooooY03oool00?l0ooooo`3ooonT0?ooo`00;`3oool4000002<0
oooo00<000000?ooo`3oool0;@3oool2000004D0oooo100000040?ooo`030000003oool0oooo03<0
oooo1000000S0?ooo`030000003oool0oooo02h0oooo0P0000140?ooo`@00000103oool00`000000
oooo0?ooo`3^0?ooo`00<@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02`0oooo
00@000000?ooo`3oool00000AP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0]0?ooo`040000003oool0oooo0000
04D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3^0?ooo`00<@3oool00`000000
oooo0?ooo`0O0?ooo`D00000;@3oool010000000oooo0?ooo`0000160?ooo`030000003oool0oooo
00D00000=P3oool00`000000oooo0?ooo`0O0?ooo`D00000;P3oool010000000oooo0?ooo`000015
0?ooo`030000003oool0oooo00D00000k`3oool00340oooo00<000000?ooo`3oool07`3oool01000
0000oooo0?ooo`00000_0?ooo`800000A`3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool07`3oool010000000oooo0?ooo`00000`0?ooo`800000
AP3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0>h0oooo000a0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`000000;P3oool010000000oooo0?ooo`0000160?ooo`07
0000003oool0oooo0?ooo`000000oooo0000000g0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`000000;`3oool010000000oooo0?ooo`0000150?ooo`070000003oool0oooo0?ooo`000000
oooo0000003`0?ooo`00;`3oool3000002<0oooo0P00000^0?ooo`040000003oool0oooo000004@0
oooo0`0000040?ooo`800000=@3oool3000002<0oooo0P00000_0?ooo`040000003oool0oooo0000
04<0oooo0`0000040?ooo`800000l03oool00340oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0]0?ooo`800000A`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0^0?ooo`800000AP3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0>h0oooo000T0?ooo`030000003oool0oooo0=T0oooo
00<000000?ooo`3oool0o`3ooonP0?ooo`00903oool00`000000oooo0?ooo`3I0?ooo`030000003o
ool0oooo0?l0ooooX03oool00200oooo]`00000U0?oookL00000k`3oool002@0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`070?ooo`80000000<0oooo0000000000005P3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`04000000H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo04@0oooo1000003c0?ooo`00903oool2000000/0oooo00<000000?ooo`3o
ool01`3oool01@000000oooo0?ooo`3oool0000001H0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`150?ooo`@00000;@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
03<0oooo4@0000030?ooo`030000003oool0oooo0?40oooo000T0?ooo`800000503oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0880oooo2P00000a0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0RP3oool500000?l0oooo2@3oool002@0oooo0P00000D0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0OP3oool3000003/0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`230?ooo`H00000o`3oool>0?ooo`00903oool00`000000oooo0000
000B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0N`3oool3000003h0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1o0?ooo`<00000o`3ooolD0?ooo`00903oool0
0`000000oooo0000000B0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0MP3oool4
00000440oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1l0?ooo`<00000o`3ooolG
0?ooo`00903oool00`000000oooo0000000A0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0LP3oool4000004D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1g0?oo
o`@00000o`3ooolJ0?ooo`00903oool00`000000oooo0000000A0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0KP3oool3000004T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`1c0?ooo`<00000o`3ooolN0?ooo`00903oool010000000oooo0?ooo`00000?0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0K03oool2000004`0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`1`0?ooo`<00000o`3ooolQ0?ooo`00903oool010000000oooo
0?ooo`00000?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0J@3oool2000004h0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1]0?ooo`800000o`3ooolT0?ooo`00
903oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0I`3oool200000500oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1[0?ooo`80
0000o`3ooolV0?ooo`00903oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`1U0?ooo`800000DP3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo06P0oooo0P00003o0?ooobP0oooo000T0?ooo`050000003oool0oooo0?ooo`00
00003@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3o
ool0o`3ooolX0?ooo`00903oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0?l0oooo:@3oool002@0oooo
00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0H03oool2000005H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1S0?ooo`80
0000o`3oool/0?ooo`00903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0?l0oooo
;03oool002@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0G@3oool2000005T0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`1O0?ooo`800000o`3oool_0?ooo`00903oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1N
0?ooo`030000003oool0oooo0?l0oooo;`3oool002@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`1J0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`3o0?oooc00oooo000T0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05P0oooo0P00001M0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0F`3oool200000?l0oooo<`3oool002@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3o0?oooc<0oooo000T0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0o`3ooold0?ooo`00903oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo0?l0oooo=@3oool002@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`1P0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`3o0?ooocH0oooo000T0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3o
ool0o`3ooolf0?ooo`00903oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0?l0oooo
=`3oool002@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1R0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`3o0?ooocP0oooo000T
0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000000G0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0540oooo00<000000?ooo`3oool0o`3oooli0?ooo`00903oool00`000000oooo0?ooo`05
0?ooo`@000006@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0?l0oooo>P3oool0
02@0oooo00<000000?ooo`3oool01P3oool2000001X0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`1U0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`3o0?oooc/0oooo000T0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`3o0?oooc/0oooo000T0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3o0?oooc`0oooo000T0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`1X0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3o0?ooocd0oooo000T
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`1X
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o
0?ooocd0oooo000T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`1Y0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`3o0?oooch0oooo000T0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`3o0?ooocl0oooo000T0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`3o0?oood00oooo000T0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`1/0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3o0?oood00oooo000T
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`1]
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`3o
0?oood40oooo000T0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`1]0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`3o0?oood80oooo000T0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`3o0?oood80oooo000T0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`3o0?oood<0oooo000T0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1_0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`3o0?oood@0oooo000T
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o
0?ooodD0oooo000T0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`1`0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`3o0?ooodD0oooo000T0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`3o0?ooodH0oooo000T0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`3o0?ooodL0oooo000T0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1b0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`3o0?ooodP0oooo000T
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1b
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3o
0?ooodP0oooo000T0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`3o0?ooodT0oooo000T0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`3o0?ooodT0oooo000T0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`3o0?ooodX0oooo000T0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1S0?ooo`800000103o
ool00`000000oooo0?ooo`020?ooo`@000000`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo03T0oooo00<000000?ooo`3oool0o`3ooom:0?ooo`00903oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0HP3oool010000000oooo0?ooo`00
000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo0?l0ooooB`3oool00180oooo0P0000040?ooo`030000003oool0
oooo0080oooo100000030?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`1S0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3o
ool2000001P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`3o0?oood/0oooo000A
0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0H`3oool010000000oooo0?oo
o`00000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo0?l0ooooC03oool00140oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`020?ooo`800000:@3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo06@0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3o0?oood`0
oooo000A0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0I03oool010000000
oooo0?ooo`0000080?ooo`<00000103oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`004@3oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo06H0oooo0P00000;0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0ooooC@3oool00140
oooo00@000000?ooo`3oool00000203oool3000000@0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo0?l0ooooCP3oool00180oooo0P00000;0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo0?l0ooooCP3oool002@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0?l0ooooC`3oool002@0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0?l0ooooC`3oool002@0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo07X0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0?l0ooooD03oool0
02@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
07/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
0?l0ooooD03oool002@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo07/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo0?l0ooooD@3oool002@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo0?l0ooooD@3oool002@0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0ooooDP3oool002@0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo07d0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0ooooDP3oool0
02@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
07d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
0?l0ooooD`3oool002@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo0?l0ooooD`3oool002@0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0?l0ooooE03oool002@0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0?l0ooooE03oool002@0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo07l0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0ooooE@3oool0
02@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
0800oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
0?l0ooooE@3oool002@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo0800oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo0?l0ooooEP3oool002@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo0?l0ooooEP3oool002@0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0?l0ooooE`3oool002@0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0880oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0ooooF03oool0
02@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
0880oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
0?l0ooooF03oool002@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo08<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0?l0ooooF@3oool002@0oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo0?l0ooooF@3oool002@0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0ooooFP3oool002@0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo08@0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0ooooFP3oool0
02@0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
08D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
0?l0ooooF`3oool002@0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo0?l0ooooG03oool002@0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo0?l0ooooG03oool002@0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0ooooG@3oool002@0oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo08L0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0ooooG@3oool0
02@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
08P0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
0?l0ooooGP3oool002@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo0?l0ooooGP3oool002@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0?l0ooooG`3oool002@0oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0?l0ooooH03oool002@0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo08X0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?l0ooooH03oool0
02@0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0?l0ooooH@3oool002@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo0?l0ooooHP3oool002@0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0?l0ooooHP3oool002@0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0ooooH`3oool002@0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooI03oool0
02@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0?l0ooooI@3oool002@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0?l0ooooI@3oool002@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooIP3oool002@0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooIP3oool002@0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0940oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooI`3oool0
02@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0980oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0?l0ooooJ03oool002@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`050?ooo`80
0000U@3oool00`000000oooo0?ooo`0Z0?ooo`8000001`3oool200000?l0ooooJ`3oool002@0oooo
00<000000?ooo`3oool0>`3oool2000000<0oooo0P00002G0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool00P3oool200000?l0ooooK@3oool002@0oooo00<000000?ooo`3oool0?@3o
ool4000009P0oooo00<000000?ooo`3oool0;@3oool400000?l0ooooK`3oool002@0oooo00<00000
0?ooo`3oool0f@3oool00`000000oooo0?ooo`3o0?oooj00oooo000T0?ooo`030000003oool0oooo
0=T0oooo00<000000?ooo`3oool0o`3ooonP0?ooo`00903oool00`000000oooo0?ooo`3I0?ooo`03
0000003oool0oooo0?l0ooooX03oool00?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo003o
0?ooool0ooooY03oool00?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0oooo
Y03oool00?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0ooooY03oool00?l0
ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0ooooY03oool00?l0ooooo`3ooonT
0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0ooooY03oool003/0oooo100000190?ooo`030000
003oool0oooo0?l0ooooo`3ooolI0?ooo`00?@3oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo0?l0ooooo`3ooolI0?ooo`00?@3oool00`000000oooo0?ooo`150?ooo`D00000o`3ooooo
0?oooaX0oooo000m0?ooo`030000003oool0oooo04D0oooo00@000000?ooo`3oool00000o`3ooooo
0?oooa/0oooo000m0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`000000o`3ooooo0?oo
oa/0oooo000k0?ooo`<00000B@3oool200000?l0ooooo`3ooolK0?ooo`00903oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0o`3ooooo0?oooaT0oooo
000T0?ooo`030000003oool0oooo0?l0ooooo`3ooomm0?ooo`00903oool00`000000oooo0?ooo`3o
0?ooool0ooooO@3oool00200oooo^@00003o0?ooolX0oooo000T0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0=0?ooo`d00000o`3oooon0?ooo`00
903oool00`000000oooo0?ooo`1Z0?ooo`L00000o`3ooooo0?ooo``0oooo000T0?ooo`800000I`3o
ool400000?l0ooooo`3ooolC0?ooo`00903oool2000006<0oooo1000003o0?ooool0oooo5`3oool0
02@0oooo0P00001P0?ooo`<00000o`3ooooo0?oooa/0oooo000T0?ooo`800000G03oool400000?l0
ooooo`3ooolN0?ooo`00903oool2000005T0oooo0`00003o0?ooool0oooo8P3oool002@0oooo00<0
00000?ooo`000000EP3oool200000?l0ooooo`3ooolU0?ooo`00903oool00`000000oooo0000001E
0?ooo`030000003oool0oooo0?l0ooooo`3ooolU0?ooo`00903oool00`000000oooo0000001C0?oo
o`800000o`3ooooo0?ooobP0oooo000T0?ooo`030000003oool000000540oooo0P00003o0?ooool0
oooo:P3oool002@0oooo00@000000?ooo`3oool00000CP3oool200000?l0ooooo`3oool/0?ooo`00
903oool010000000oooo0?ooo`00001=0?ooo`030000003oool0oooo0?l0ooooo`3oool/0?ooo`00
903oool010000000oooo0?ooo`00001<0?ooo`030000003oool0oooo0?l0ooooo`3oool]0?ooo`00
903oool010000000oooo0?ooo`00001;0?ooo`030000003oool0oooo0?l0ooooo`3oool^0?ooo`00
903oool010000000oooo0?ooo`00001:0?ooo`030000003oool0oooo0?l0ooooo`3oool_0?ooo`00
903oool01@000000oooo0?ooo`3oool0000004L0oooo0P00003o0?ooool0oooo<P3oool00180oooo
0P0000040?ooo`030000003oool0oooo0080oooo100000030?ooo`050000003oool0oooo0?ooo`00
0000AP3oool00`000000oooo0?ooo`3o0?ooool0oooo<P3oool00140oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000A@3oool00`00
0000oooo0?ooo`3o0?ooool0oooo<`3oool00140oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
0?l0ooooo`3ooold0?ooo`004@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000130?ooo`030000003oool0oooo0?l0ooooo`3ooole
0?ooo`004@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0?l0ooooo`3ooole
0?ooo`004@3oool010000000oooo0?ooo`0000080?ooo`<00000103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0o`3ooooo0?ooocH0oooo000B0?oo
o`8000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`3o0?ooool0oooo=`3oool002@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0?l0ooooo`3ooolh0?ooo`00
903oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
o`3ooooo0?ooocP0oooo000T0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`3o0?ooool0oooo>@3oool002@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?ooo`00903oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oc/0oooo000T0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`3o0?ooool0oooo>`3oool002@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo0?l0ooooo`3oooll0?ooo`00903oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0o`3ooooo0?ooocd0oooo000T
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3o
0?ooool0oooo?@3oool002@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo0?l0ooooo`3oooln0?ooo`00903oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0o`3ooooo0?ooocl0oooo000T0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`3o0?ooool0oooo
?`3oool002@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo0?l0ooooo`3ooom00?ooo`00903oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool0o`3ooooo0?oood40oooo000T0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3o0?ooool0oooo@@3oool002@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0?l0
ooooo`3ooom20?ooo`00903oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0o`3ooooo0?oood80oooo000T0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`3o0?ooool0oooo@`3oool002@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0ooooo`3ooom3
0?ooo`00903oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0o`3ooooo0?oood@0oooo000T0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`3o0?ooool0ooooA03oool002@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0?l0ooooo`3ooom50?ooo`00903o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0o`3o
oooo0?ooodD0oooo000T0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooAP3oool002@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo0?l0ooooo`3ooom60?ooo`00903oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3ooooo0?ooodL0
oooo000T0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`3o0?ooool0ooooA`3oool002@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo0?l0ooooo`3ooom80?ooo`00903oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooodP0oooo000T0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooB@3oool002@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo0?l0ooooo`3ooom90?ooo`00903oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0o`3ooooo0?ooodT0oooo000T0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3o0?ooool0ooooBP3o
ool00180oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3o0?ooool0ooooBP3oool0
0140oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?ooool0ooooB`3o
ool00140oooo00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`3oool2000000T0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3o0?ooool0ooooB`3oool00140oooo00@0
00000?ooo`3oool000002@3oool2000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0?l0ooooo`3ooom;0?ooo`004@3oool010000000oooo0?oo
o`00000;0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0?l0ooooo`3ooom<0?ooo`004@3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0?l0ooooo`3ooom<0?ooo`004P3oool2000000X0oooo0P0000040?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3o0?ooool0
ooooC@3oool002@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo0?l0ooooo`3ooom=0?ooo`00903oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0o`3ooooo0?ooodh0oooo000T0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3o0?ooool0ooooCP3oool0
02@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
0?l0ooooo`3ooom>0?ooo`00903oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0o`3ooooo0?ooodl0oooo000T0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?ooool0ooooC`3oool002@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0ooooo`3o
oom@0?ooo`00903oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooe00oooo000T0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`3o0?ooool0ooooD03oool002@0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0?l0ooooo`3ooomA0?ooo`00
903oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
o`3ooooo0?oooe40oooo000T0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooDP3oool002@0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0ooooo`3ooomB0?ooo`00903oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oe<0oooo000T0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`3o0?ooool0ooooD`3oool002@0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0?l0ooooo`3ooomC0?ooo`00903oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooooo0?oooe@0oooo000T
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3o
0?ooool0ooooE03oool002@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo0?l0ooooo`3ooomE0?ooo`00903oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0o`3ooooo0?oooeD0oooo000T0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?ooool0oooo
E@3oool002@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0?l0ooooo`3ooomF0?ooo`00903oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0o`3ooooo0?oooeH0oooo000T0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?ooool0ooooE`3oool002@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0
ooooo`3ooomG0?ooo`00903oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0o`3ooooo0?oooeP0oooo000T0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`3o0?ooool0ooooF03oool002@0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0ooooo`3ooomH
0?ooo`00903oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0o`3ooooo0?oooeT0oooo000T0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`3o0?ooool0ooooF@3oool002@0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooo`3ooomJ0?ooo`00903o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3o
oooo0?oooeX0oooo000T0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooF`3oool00180oooo0P0000040?ooo`030000003oool0oooo
0080oooo0`0000040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`3o0?ooool0ooooF`3oool00140oooo00@000000?ooo`3oool000002`3oool01@00
0000oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o
0?ooool0ooooG03oool00140oooo00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`3o
ool200000140oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooool0ooooG03o
ool00140oooo00@000000?ooo`3oool00000203oool3000000@0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooo`3ooomL0?ooo`004@3oool0
10000000oooo0?ooo`0000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`004@3oool0
10000000oooo0?ooo`0000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0ooooo`3ooomM0?ooo`004P3oool2
000000T0oooo100000030?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`3o0?ooool0ooooGP3oool002@0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooo`3ooomO0?ooo`00903oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooooo0?ooof00
oooo000T0?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool0oooo0P00003o0?ooool0
ooooH`3oool002@0oooo00<000000?ooo`3oool0503oool500000?l0ooooo`3ooomT0?ooo`00903o
ool00`000000oooo0?ooo`3o0?ooool0ooooO@3oool002@0oooo00<000000?ooo`3oool0o`3ooooo
0?ooogd0oooo000T0?ooo`030000003oool0oooo0?l0ooooo`3ooomm0?ooo`00o`3ooooo0?oooj@0
oooo003o0?ooool0ooooY03oool00?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo003o0?oo
ool0ooooY03oool00?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo003o0?ooool0ooooY03o
ool00?l0ooooo`3ooonT0?ooo`00o`3ooooo0?oooj@0oooo0000\
\>"],
  ImageRangeCache->{{{0, 673}, {415.375, 0}} -> {-0.0771361, -0.0463623, \
0.00468689, 0.00468689}, {{16.4375, 216.438}, {405.438, 281.812}} -> \
{-4.40081, -0.0204221, 0.119785, 0.000937091}, {{236.438, 436.5}, {405.438, \
281.812}} -> {-30.743, -0.0205204, 0.119744, 0.000939051}, {{456.5, 656.5}, \
{405.438, 281.812}} -> {-57.1136, -0.0216149, 0.119785, 0.000988293}, \
{{16.4375, 216.438}, {269.438, 145.875}} -> {-2.95914, -0.281629, 0.0805902, \
0.00177869}, {{236.438, 436.5}, {269.438, 145.875}} -> {-20.6817, -0.287979, \
0.0805616, 0.00181902}, {{16.4375, 216.438}, {133.5, 9.875}} -> {-1.46694, \
-1.46793, 0.0399284, 0.0049962}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection"],

Cell[BoxData[
    \(\(plot[\[ScriptL]_, 
          m_] := \[IndentingNewLine]SphericalPlot3D[\[IndentingNewLine]\(\
SphericalHarmonicY[\[ScriptL], m, \[Theta], \[Phi]]\  // Abs\) // 
            Evaluate, \[IndentingNewLine]{\[Theta], 0, \[Pi]}, {\[Phi], 0, 
            2\ \[Pi]}, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]DisplayFunction \[Rule] 
            Identity];\)\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
pt1=Table[plot[\[ScriptL],m] ,{\[ScriptL],0,2} ,{m,-\[ScriptL],\
\[ScriptL]}];
Show[GraphicsArray[pt1]];
 \
\>", "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .64641 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0153906 0.190476 [
[ 0 0 0 0 ]
[ 1 .64641 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .64641 L
0 .64641 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0153906 0.200176 0.207773 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.22008e-17 1.04992 -0.0702765 1.04992 [
[ 0 0 0 0 ]
[ 1 .80658 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .80658 L
0 .80658 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.46503 .50723 m .45466 .55829 L .54627 .56249 L p .714 .63 .762 r
F P
0 g
s
.54627 .56249 m .54275 .5109 L .46503 .50723 L p .714 .63 .762 r
F P
0 g
s
.54834 .61387 m .54627 .56249 L .45466 .55829 L p .72 .565 .679 r
F P
0 g
s
.54275 .5109 m .54627 .56249 L .63603 .54988 L p .675 .599 .764 r
F P
0 g
s
.54627 .56249 m .54834 .61387 L .64625 .60054 L p .664 .521 .68 r
F P
0 g
s
.64625 .60054 m .63603 .54988 L .54627 .56249 L p .664 .521 .68 r
F P
0 g
s
.39218 .48908 m .36849 .5375 L .45466 .55829 L p .752 .667 .767 r
F P
0 g
s
.45466 .55829 m .46503 .50723 L .39218 .48908 L p .752 .667 .767 r
F P
0 g
s
.44848 .60944 m .45466 .55829 L .36849 .5375 L p .773 .614 .683 r
F P
0 g
s
.45466 .55829 m .44848 .60944 L .54834 .61387 L p .72 .565 .679 r
F P
0 g
s
.54863 .65697 m .54834 .61387 L .44848 .60944 L p .713 .477 .567 r
F P
0 g
s
.54834 .61387 m .54863 .65697 L .64778 .64384 L p .639 .417 .566 r
F P
0 g
s
.64778 .64384 m .64625 .60054 L .54834 .61387 L p .639 .417 .566 r
F P
0 g
s
.36849 .5375 m .35435 .58744 L .44848 .60944 L p .773 .614 .683 r
F P
0 g
s
.44752 .65261 m .44848 .60944 L .35435 .58744 L p .783 .537 .564 r
F P
0 g
s
.44848 .60944 m .44752 .65261 L .54863 .65697 L p .713 .477 .567 r
F P
0 g
s
.47806 .46374 m .46503 .50723 L .54275 .5109 L p .695 .692 .843 r
F P
0 g
s
.54275 .5109 m .53833 .46666 L .47806 .46374 L p .695 .692 .843 r
F P
0 g
s
.53833 .46666 m .54275 .5109 L .61882 .49987 L p .675 .677 .844 r
F P
0 g
s
.63603 .54988 m .61882 .49987 L .54275 .5109 L p .675 .599 .764 r
F P
0 g
s
.61882 .49987 m .63603 .54988 L .71664 .5211 L p .631 .574 .773 r
F P
0 g
s
.63603 .54988 m .64625 .60054 L .7345 .57006 L p .6 .479 .686 r
F P
0 g
s
.7345 .57006 m .71664 .5211 L .63603 .54988 L p .6 .479 .686 r
F P
0 g
s
.42182 .44934 m .39218 .48908 L .46503 .50723 L p .714 .711 .847 r
F P
0 g
s
.46503 .50723 m .47806 .46374 L .42182 .44934 L p .714 .711 .847 r
F P
0 g
s
.64625 .60054 m .64778 .64384 L .73719 .61379 L p .547 .347 .56 r
F P
0 g
s
.73719 .61379 m .7345 .57006 L .64625 .60054 L p .547 .347 .56 r
F P
0 g
s
.61882 .49987 m .59722 .4579 L .53833 .46666 L p .675 .677 .844 r
F P
0 g
s
.59722 .4579 m .61882 .49987 L .68673 .47481 L p .653 .666 .851 r
F P
0 g
s
.71664 .5211 m .68673 .47481 L .61882 .49987 L p .631 .574 .773 r
F P
0 g
s
.33067 .45758 m .2951 .50122 L .36849 .5375 L p .786 .711 .781 r
F P
0 g
s
.36849 .5375 m .39218 .48908 L .33067 .45758 L p .786 .711 .781 r
F P
0 g
s
.35435 .58744 m .36849 .5375 L .2951 .50122 L p .827 .673 .692 r
F P
0 g
s
.54703 .68429 m .54863 .65697 L .44752 .65261 L p .665 .299 .342 r
F P
0 g
s
.54863 .65697 m .54703 .68429 L .64004 .67218 L p .56 .211 .333 r
F P
0 g
s
.64004 .67218 m .64778 .64384 L .54863 .65697 L p .56 .211 .333 r
F P
0 g
s
.35435 .58744 m .35218 .63093 L .44752 .65261 L p .783 .537 .564 r
F P
0 g
s
.45213 .68026 m .44752 .65261 L .35218 .63093 L p .752 .362 .315 r
F P
0 g
s
.44752 .65261 m .45213 .68026 L .54703 .68429 L p .665 .299 .342 r
F P
0 g
s
.37486 .42452 m .33067 .45758 L .39218 .48908 L p .728 .734 .856 r
F P
0 g
s
.39218 .48908 m .42182 .44934 L .37486 .42452 L p .728 .734 .856 r
F P
0 g
s
.2951 .50122 m .27377 .54895 L .35435 .58744 L p .827 .673 .692 r
F P
0 g
s
.35218 .63093 m .35435 .58744 L .27377 .54895 L p .856 .603 .555 r
F P
0 g
s
.49185 .43371 m .47806 .46374 L .53833 .46666 L p .643 .761 .935 r
F P
0 g
s
.53833 .46666 m .53362 .43576 L .49185 .43371 L p .643 .761 .935 r
F P
0 g
s
.53362 .43576 m .53833 .46666 L .59722 .4579 L p .653 .769 .934 r
F P
0 g
s
.45306 .42359 m .42182 .44934 L .47806 .46374 L p .635 .752 .932 r
F P
0 g
s
.47806 .46374 m .49185 .43371 L .45306 .42359 L p .635 .752 .932 r
F P
0 g
s
.64778 .64384 m .64004 .67218 L .72369 .64453 L p .412 .076 .283 r
F P
0 g
s
.72369 .64453 m .73719 .61379 L .64778 .64384 L p .412 .076 .283 r
F P
0 g
s
.68673 .47481 m .71664 .5211 L .78072 .4778 L p .58 .555 .791 r
F P
0 g
s
.71664 .5211 m .7345 .57006 L .80516 .52402 L p .518 .433 .699 r
F P
0 g
s
.80516 .52402 m .78072 .4778 L .71664 .5211 L p .518 .433 .699 r
F P
0 g
s
.59722 .4579 m .57437 .42959 L .53362 .43576 L p .653 .769 .934 r
F P
0 g
s
.57437 .42959 m .59722 .4579 L .6494 .43808 L p .664 .773 .93 r
F P
0 g
s
.68673 .47481 m .6494 .43808 L .59722 .4579 L p .653 .666 .851 r
F P
0 g
s
.6494 .43808 m .68673 .47481 L .74005 .43736 L p .63 .662 .862 r
F P
0 g
s
.78072 .4778 m .74005 .43736 L .68673 .47481 L p .58 .555 .791 r
F P
0 g
s
.7345 .57006 m .73719 .61379 L .80886 .56838 L p .414 .248 .545 r
F P
0 g
s
.80886 .56838 m .80516 .52402 L .7345 .57006 L p .414 .248 .545 r
F P
0 g
s
.42104 .40626 m .37486 .42452 L .42182 .44934 L p .63 .741 .928 r
F P
0 g
s
.42182 .44934 m .45306 .42359 L .42104 .40626 L p .63 .741 .928 r
F P
0 g
s
.27377 .54895 m .2705 .59297 L .35218 .63093 L p .856 .603 .555 r
F P
0 g
s
.36279 .66029 m .35218 .63093 L .2705 .59297 L p .829 .405 .233 r
F P
0 g
s
.35218 .63093 m .36279 .66029 L .45213 .68026 L p .752 .362 .315 r
F P
0 g
s
.54371 .69024 m .54703 .68429 L .45213 .68026 L p .289 0 0 r
F P
0 g
s
.54703 .68429 m .54371 .69024 L .62389 .67984 L p .131 0 0 r
F P
0 g
s
.62389 .67984 m .64004 .67218 L .54703 .68429 L p .131 0 0 r
F P
0 g
s
.28681 .41491 m .24187 .4517 L .2951 .50122 L p .817 .764 .803 r
F P
0 g
s
.2951 .50122 m .33067 .45758 L .28681 .41491 L p .817 .764 .803 r
F P
0 g
s
.27377 .54895 m .2951 .50122 L .24187 .4517 L p .884 .749 .708 r
F P
0 g
s
.34207 .39123 m .28681 .41491 L .33067 .45758 L p .738 .759 .87 r
F P
0 g
s
.33067 .45758 m .37486 .42452 L .34207 .39123 L p .738 .759 .87 r
F P
0 g
s
.46181 .68678 m .45213 .68026 L .36279 .66029 L p .342 0 0 r
F P
0 g
s
.45213 .68026 m .46181 .68678 L .54371 .69024 L p .289 0 0 r
F P
0 g
s
.6494 .43808 m .61019 .4157 L .57437 .42959 L p .664 .773 .93 r
F P
0 g
s
.61019 .4157 m .6494 .43808 L .68975 .4087 L p .675 .774 .925 r
F P
0 g
s
.74005 .43736 m .68975 .4087 L .6494 .43808 L p .63 .662 .862 r
F P
0 g
s
.24187 .4517 m .21473 .49615 L .27377 .54895 L p .884 .749 .708 r
F P
0 g
s
.2705 .59297 m .27377 .54895 L .21473 .49615 L p .938 .685 .528 r
F P
0 g
s
.73719 .61379 m .72369 .64453 L .79037 .60286 L p .148 0 .15 r
F P
0 g
s
.79037 .60286 m .80886 .56838 L .73719 .61379 L p .148 0 .15 r
F P
0 g
s
.50444 .42018 m .49185 .43371 L .53362 .43576 L p .458 .801 .999 r
F P
0 g
s
.55354 .41772 m .52931 .42142 L p .54025 .4234 L .534 .855 .997 r
F P
0 g
s
.57437 .42959 m .55354 .41772 L p .54025 .4234 L .534 .855 .997 r
F P
0 g
s
.55354 .41772 m .57468 .40943 L p .56806 .4115 L .356 .825 .771 r
F P
0 g
s
.52931 .42142 m .55354 .41772 L p .54864 .41863 L 0 0 0 r
F P
0 g
s
.53362 .43576 m .52931 .42142 L p .51155 .42398 L .458 .801 .999 r
F P
0 g
s
.52931 .42142 m .53362 .43576 L .57437 .42959 L p .534 .855 .997 r
F P
0 g
s
.52597 .42285 m .52931 .42142 L p .54864 .41863 L 0 0 0 r
F P
0 g
s
.53747 .42109 m .52597 .42285 L p .53118 .42188 L 0 0 0 r
F P
0 g
s
.55354 .41772 m .53747 .42109 L p .53118 .42188 L 0 0 0 r
F P
0 g
s
.53747 .42109 m .55354 .41772 L p .56806 .4115 L .356 .825 .771 r
F P
0 g
s
.54745 .41717 m .53747 .42109 L p .54449 .41889 L .356 .825 .771 r
F P
0 g
s
.57468 .40943 m .54745 .41717 L p .54449 .41889 L .356 .825 .771 r
F P
0 g
s
.55485 .41149 m .54745 .41717 L p .55555 .41345 L .653 .97 .878 r
F P
0 g
s
.59052 .39734 m .55485 .41149 L p .55555 .41345 L .653 .97 .878 r
F P
0 g
s
.55485 .41149 m .55885 .40463 L p .55414 .40951 L .799 .983 .713 r
F P
0 g
s
.54745 .41717 m .55485 .41149 L p .55046 .41543 L 0 0 0 r
F P
0 g
s
.54745 .41717 m .57468 .40943 L .59052 .39734 L p .653 .97 .878 r
F P
0 g
s
.53083 .43304 m .54745 .41717 L p .55046 .41543 L 0 0 0 r
F P
0 g
s
.53747 .42109 m .54745 .41717 L p .54383 .4203 L .126 0 0 r
F P
0 g
s
.52762 .4343 m .53747 .42109 L p .54383 .4203 L .126 0 0 r
F P
0 g
s
.54745 .41717 m .53083 .43304 L .52762 .4343 L p .126 0 0 r
F P
0 g
s
.53319 .43123 m .53083 .43304 L p .53328 .43084 L 0 0 0 r
F P
0 g
s
.55485 .41149 m .53319 .43123 L p .53328 .43084 L 0 0 0 r
F P
0 g
s
.53319 .43123 m .55485 .41149 L p .55414 .40951 L .799 .983 .713 r
F P
0 g
s
.53445 .42906 m .53319 .43123 L p .5358 .42852 L .799 .983 .713 r
F P
0 g
s
.55885 .40463 m .53445 .42906 L p .5358 .42852 L .799 .983 .713 r
F P
0 g
s
.53445 .42906 m .53446 .42675 L p .53313 .42958 L .965 .929 .605 r
F P
0 g
s
.53319 .43123 m .53445 .42906 L p .5331 .43161 L 0 0 0 r
F P
0 g
s
.52427 .44837 m .53319 .43123 L p .5331 .43161 L 0 0 0 r
F P
0 g
s
.52396 .44861 m .53083 .43304 L .53319 .43123 L p .04 0 .093 r
F P
0 g
s
.53319 .43123 m .52427 .44837 L .52396 .44861 L p .04 0 .093 r
F P
0 g
s
.52443 .44809 m .52427 .44837 L p .52455 .44785 L 0 0 0 r
F P
0 g
s
.53445 .42906 m .52443 .44809 L p .52455 .44785 L 0 0 0 r
F P
0 g
s
.52443 .44809 m .52443 .44779 L .52433 .44832 L p .887 .797 .31 r
F P
0 g
s
.52443 .44809 m .52292 .45534 L .52427 .44837 L closepath p 0 0 .142 r
F P
0 g
s
.52433 .44832 m .52292 .45534 L .52443 .44809 L p .887 .797 .31 r
F P
0 g
s
.52443 .44809 m .53445 .42906 L p .53313 .42958 L .965 .929 .605 r
F P
0 g
s
.52931 .42142 m .50444 .42018 L p .51155 .42398 L .458 .801 .999 r
F P
0 g
s
.64004 .67218 m .62389 .67984 L .69559 .65618 L p 0 0 0 r
F P
0 g
s
.69559 .65618 m .72369 .64453 L .64004 .67218 L p 0 0 0 r
F P
0 g
s
.48144 .41413 m .45306 .42359 L .49185 .43371 L p .42 .746 .993 r
F P
0 g
s
.49185 .43371 m .50444 .42018 L .48144 .41413 L p .42 .746 .993 r
F P
0 g
s
.3992 .38324 m .34207 .39123 L .37486 .42452 L p .629 .731 .921 r
F P
0 g
s
.37486 .42452 m .42104 .40626 L .3992 .38324 L p .629 .731 .921 r
F P
0 g
s
.55354 .41772 m .57437 .42959 L .61019 .4157 L p .628 .892 .987 r
F P
0 g
s
.68975 .4087 m .74005 .43736 L .77276 .3903 L p .607 .663 .878 r
F P
0 g
s
.74005 .43736 m .78072 .4778 L .82102 .42292 L p .52 .542 .819 r
F P
0 g
s
.82102 .42292 m .77276 .3903 L .74005 .43736 L p .52 .542 .819 r
F P
0 g
s
.78072 .4778 m .80516 .52402 L .85027 .46535 L p .4 .377 .718 r
F P
0 g
s
.85027 .46535 m .82102 .42292 L .78072 .4778 L p .4 .377 .718 r
F P
0 g
s
.46266 .40382 m .42104 .40626 L .45306 .42359 L p .423 .697 .978 r
F P
0 g
s
.45306 .42359 m .48144 .41413 L .46266 .40382 L p .423 .697 .978 r
F P
0 g
s
.2705 .59297 m .28655 .6254 L .36279 .66029 L p .829 .405 .233 r
F P
0 g
s
.36279 .66029 m .38497 .66965 L .46181 .68678 L p .342 0 0 r
F P
0 g
s
.38497 .66965 m .36279 .66029 L .28655 .6254 L p 0 .312 .671 r
F P
0 g
s
.61019 .4157 m .57468 .40943 L .55354 .41772 L p .628 .892 .987 r
F P
0 g
s
.57468 .40943 m .61019 .4157 L .63744 .39529 L p .708 .899 .965 r
F P
0 g
s
.68975 .4087 m .63744 .39529 L .61019 .4157 L p .675 .774 .925 r
F P
0 g
s
.63744 .39529 m .68975 .4087 L .71372 .37219 L p .684 .771 .917 r
F P
0 g
s
.77276 .3903 m .71372 .37219 L .68975 .4087 L p .607 .663 .878 r
F P
0 g
s
.21473 .49615 m .21056 .54087 L .2705 .59297 L p .938 .685 .528 r
F P
0 g
s
.28655 .6254 m .2705 .59297 L .21056 .54087 L p .852 .395 .024 r
F P
0 g
s
.80516 .52402 m .80886 .56838 L .85472 .51046 L p .174 .075 .494 r
F P
0 g
s
.85472 .51046 m .85027 .46535 L .80516 .52402 L p .174 .075 .494 r
F P
0 g
s
.53916 .67284 m .54371 .69024 L .46181 .68678 L p .508 .807 .999 r
F P
0 g
s
.54371 .69024 m .53916 .67284 L .60176 .66463 L p .555 .841 .998 r
F P
0 g
s
.60176 .66463 m .62389 .67984 L .54371 .69024 L p .555 .841 .998 r
F P
0 g
s
.45011 .39026 m .3992 .38324 L .42104 .40626 L p .454 .66 .95 r
F P
0 g
s
.42104 .40626 m .46266 .40382 L .45011 .39026 L p .454 .66 .95 r
F P
0 g
s
.72369 .64453 m .69559 .65618 L .7521 .62073 L p .499 .899 .77 r
F P
0 g
s
.7521 .62073 m .79037 .60286 L .72369 .64453 L p .499 .899 .77 r
F P
0 g
s
.47513 .6701 m .46181 .68678 L .38497 .66965 L p .482 .771 .995 r
F P
0 g
s
.46181 .68678 m .47513 .6701 L .53916 .67284 L p .508 .807 .999 r
F P
0 g
s
.32758 .35238 m .26623 .36453 L .28681 .41491 L p .74 .784 .888 r
F P
0 g
s
.28681 .41491 m .34207 .39123 L .32758 .35238 L p .74 .784 .888 r
F P
0 g
s
.24187 .4517 m .28681 .41491 L .26623 .36453 L p .839 .828 .837 r
F P
0 g
s
.39017 .35673 m .32758 .35238 L .34207 .39123 L p .632 .723 .913 r
F P
0 g
s
.34207 .39123 m .3992 .38324 L .39017 .35673 L p .632 .723 .913 r
F P
0 g
s
.26623 .36453 m .21574 .39264 L .24187 .4517 L p .839 .828 .837 r
F P
0 g
s
.21473 .49615 m .24187 .4517 L .21574 .39264 L p .938 .849 .729 r
F P
0 g
s
.63744 .39529 m .59052 .39734 L .57468 .40943 L p .708 .899 .965 r
F P
0 g
s
.59052 .39734 m .63744 .39529 L .65306 .3702 L p .758 .877 .933 r
F P
0 g
s
.71372 .37219 m .65306 .3702 L .63744 .39529 L p .684 .771 .917 r
F P
0 g
s
.62389 .67984 m .60176 .66463 L .65731 .64602 L p .613 .864 .99 r
F P
0 g
s
.65731 .64602 m .69559 .65618 L .62389 .67984 L p .613 .864 .99 r
F P
0 g
s
.51415 .42226 m .50444 .42018 L .52931 .42142 L p .112 0 0 r
F P
0 g
s
.52931 .42142 m .52597 .42285 L .51415 .42226 L p .112 0 0 r
F P
0 g
s
.50325 .41939 m .48144 .41413 L .50444 .42018 L p 0 .43 .705 r
F P
0 g
s
.50444 .42018 m .51415 .42226 L .50325 .41939 L p 0 .43 .705 r
F P
0 g
s
.49442 .41453 m .46266 .40382 L .48144 .41413 L p 0 .447 .833 r
F P
0 g
s
.49639 .41774 m .50325 .41939 L .49442 .41453 L p 0 .447 .833 r
F P
0 g
s
.51376 .4322 m .49442 .41453 L .50325 .41939 L p .64 .081 0 r
F P
0 g
s
.51192 .43018 m .49315 .41245 L p .49442 .41453 L 0 .076 .591 r
F P
0 g
s
.49315 .41245 m .48862 .40818 L .49442 .41453 L p 0 .076 .591 r
F P
0 g
s
.48144 .41413 m .49639 .41774 L p .49442 .41453 L 0 .447 .833 r
F P
0 g
s
.80886 .56838 m .79037 .60286 L .83257 .54993 L p 0 0 0 r
F P
0 g
s
.83257 .54993 m .85472 .51046 L .80886 .56838 L p 0 0 0 r
F P
0 g
s
.44525 .3748 m .39017 .35673 L .3992 .38324 L p .496 .635 .916 r
F P
0 g
s
.3992 .38324 m .45011 .39026 L .44525 .3748 L p .496 .635 .916 r
F P
0 g
s
.28655 .6254 m .31992 .63988 L .38497 .66965 L p 0 .312 .671 r
F P
0 g
s
.41531 .6566 m .38497 .66965 L .31992 .63988 L p .48 .737 .984 r
F P
0 g
s
.38497 .66965 m .41531 .6566 L .47513 .6701 L p .482 .771 .995 r
F P
0 g
s
.21056 .54087 m .23102 .57769 L .28655 .6254 L p .852 .395 .024 r
F P
0 g
s
.31992 .63988 m .28655 .6254 L .23102 .57769 L p 0 .402 .84 r
F P
0 g
s
.21574 .39264 m .18498 .43282 L .21473 .49615 L p .938 .849 .729 r
F P
0 g
s
.21056 .54087 m .21473 .49615 L .18498 .43282 L p .997 .772 .432 r
F P
0 g
s
.65306 .3702 m .71372 .37219 L .7178 .33196 L p .689 .765 .909 r
F P
0 g
s
.71372 .37219 m .77276 .3903 L .77983 .33778 L p .586 .671 .899 r
F P
0 g
s
.77983 .33778 m .7178 .33196 L .71372 .37219 L p .586 .671 .899 r
F P
0 g
s
.77276 .3903 m .82102 .42292 L .83118 .36102 L p .445 .537 .857 r
F P
0 g
s
.83118 .36102 m .77983 .33778 L .77276 .3903 L p .445 .537 .857 r
F P
0 g
s
.48862 .40818 m .45011 .39026 L .46266 .40382 L p .13 .478 .897 r
F P
0 g
s
.46266 .40382 m .49442 .41453 L .48862 .40818 L p .13 .478 .897 r
F P
0 g
s
.65306 .3702 m .59932 .38263 L .59052 .39734 L p .758 .877 .933 r
F P
0 g
s
.59932 .38263 m .65306 .3702 L .65493 .34293 L p .779 .839 .898 r
F P
0 g
s
.7178 .33196 m .65493 .34293 L .65306 .3702 L p .689 .765 .909 r
F P
0 g
s
.55485 .41149 m .59052 .39734 L .59932 .38263 L p .818 .973 .896 r
F P
0 g
s
.82102 .42292 m .85027 .46535 L .86257 .39875 L p .201 .294 .736 r
F P
0 g
s
.86257 .39875 m .83118 .36102 L .82102 .42292 L p .201 .294 .736 r
F P
0 g
s
.69559 .65618 m .65731 .64602 L .70041 .61839 L p .668 .87 .975 r
F P
0 g
s
.70041 .61839 m .7521 .62073 L .69559 .65618 L p .668 .87 .975 r
F P
0 g
s
.53414 .635 m .53916 .67284 L .47513 .6701 L p .667 .741 .905 r
F P
0 g
s
.53916 .67284 m .53414 .635 L .57739 .62918 L p .657 .734 .906 r
F P
0 g
s
.57739 .62918 m .60176 .66463 L .53916 .67284 L p .657 .734 .906 r
F P
0 g
s
.4865 .401 m .44525 .3748 L .45011 .39026 L p .306 .497 .881 r
F P
0 g
s
.45011 .39026 m .48862 .40818 L .4865 .401 L p .306 .497 .881 r
F P
0 g
s
.48983 .63306 m .47513 .6701 L .41531 .6566 L p .675 .75 .907 r
F P
0 g
s
.47513 .6701 m .48983 .63306 L .53414 .635 L p .667 .741 .905 r
F P
0 g
s
.39548 .32943 m .33409 .31185 L .32758 .35238 L p .637 .717 .905 r
F P
0 g
s
.32758 .35238 m .39017 .35673 L .39548 .32943 L p .637 .717 .905 r
F P
0 g
s
.26623 .36453 m .32758 .35238 L .33409 .31185 L p .733 .807 .909 r
F P
0 g
s
.44881 .35907 m .39548 .32943 L .39017 .35673 L p .541 .623 .882 r
F P
0 g
s
.39017 .35673 m .44525 .3748 L .44881 .35907 L p .541 .623 .882 r
F P
0 g
s
.79037 .60286 m .7521 .62073 L .78703 .57608 L p .764 .993 .878 r
F P
0 g
s
.78703 .57608 m .83257 .54993 L .79037 .60286 L p .764 .993 .878 r
F P
0 g
s
.18498 .43282 m .18025 .47832 L .21056 .54087 L p .997 .772 .432 r
F P
0 g
s
.23102 .57769 m .21056 .54087 L .18025 .47832 L p 0 0 .391 r
F P
0 g
s
.60176 .66463 m .57739 .62918 L .61544 .61608 L p .646 .729 .909 r
F P
0 g
s
.61544 .61608 m .65731 .64602 L .60176 .66463 L p .646 .729 .909 r
F P
0 g
s
.59932 .38263 m .55885 .40463 L .55485 .41149 L p .818 .973 .896 r
F P
0 g
s
.55885 .40463 m .59932 .38263 L .59994 .36682 L p .861 .901 .861 r
F P
0 g
s
.65493 .34293 m .59994 .36682 L .59932 .38263 L p .779 .839 .898 r
F P
0 g
s
.5201 .43467 m .51415 .42226 L .52597 .42285 L p .547 .05 .028 r
F P
0 g
s
.52597 .42285 m .52391 .43486 L .5201 .43467 L p .547 .05 .028 r
F P
0 g
s
.52391 .43486 m .52597 .42285 L .53747 .42109 L p .392 0 .003 r
F P
0 g
s
.51659 .43375 m .50325 .41939 L .51415 .42226 L p .639 .109 0 r
F P
0 g
s
.51415 .42226 m .5201 .43467 L .51659 .43375 L p .639 .109 0 r
F P
0 g
s
.33409 .31185 m .27308 .31126 L .26623 .36453 L p .733 .807 .909 r
F P
0 g
s
.21574 .39264 m .26623 .36453 L .27308 .31126 L p .839 .897 .88 r
F P
0 g
s
.53747 .42109 m .52762 .4343 L .52391 .43486 L p .392 0 .003 r
F P
0 g
s
.50325 .41939 m .51659 .43375 L .51376 .4322 L p .64 .081 0 r
F P
0 g
s
.23102 .57769 m .27329 .59945 L .31992 .63988 L p 0 .402 .84 r
F P
0 g
s
.36524 .63328 m .31992 .63988 L .27329 .59945 L p .497 .709 .966 r
F P
0 g
s
.31992 .63988 m .36524 .63328 L .41531 .6566 L p .48 .737 .984 r
F P
0 g
s
.85027 .46535 m .85472 .51046 L .86736 .44464 L p 0 0 .3 r
F P
0 g
s
.86736 .44464 m .86257 .39875 L .85027 .46535 L p 0 0 .3 r
F P
0 g
s
.48832 .39376 m .44881 .35907 L .44525 .3748 L p .433 .513 .84 r
F P
0 g
s
.44525 .3748 m .4865 .401 L .48832 .39376 L p .433 .513 .84 r
F P
0 g
s
.51086 .42955 m .51376 .4322 L .51192 .43018 L p 0 .076 .591 r
F P
0 g
s
.52148 .44824 m .51192 .43018 L .51376 .4322 L p .826 .377 0 r
F P
0 g
s
.51376 .4322 m .52145 .44795 L p .52148 .44824 L .826 .377 0 r
F P
0 g
s
.52145 .44795 m .52172 .4485 L .52148 .44824 L p .826 .377 0 r
F P
0 g
s
.52148 .44824 m .52292 .45534 L .5215 .44846 L p .77 .498 0 r
F P
0 g
s
.5215 .44846 m .5214 .44794 L .52148 .44824 L p .77 .498 0 r
F P
0 g
s
.5214 .44794 m .51263 .43061 L p .51192 .43018 L 0 0 .486 r
F P
0 g
s
.51263 .43061 m .51127 .42791 L .51192 .43018 L p 0 0 .486 r
F P
0 g
s
.49442 .41453 m .51086 .42955 L p .51192 .43018 L 0 .076 .591 r
F P
0 g
s
.44865 .62352 m .41531 .6566 L .36524 .63328 L p .681 .761 .912 r
F P
0 g
s
.41531 .6566 m .44865 .62352 L .48983 .63306 L p .675 .75 .907 r
F P
0 g
s
.59994 .36682 m .65493 .34293 L .64225 .31638 L p .778 .796 .868 r
F P
0 g
s
.65493 .34293 m .7178 .33196 L .70027 .29227 L p .692 .757 .901 r
F P
0 g
s
.70027 .29227 m .64225 .31638 L .65493 .34293 L p .692 .757 .901 r
F P
0 g
s
.7178 .33196 m .77983 .33778 L .75829 .28526 L p .569 .688 .921 r
F P
0 g
s
.75829 .28526 m .70027 .29227 L .7178 .33196 L p .569 .688 .921 r
F P
0 g
s
.51127 .42791 m .4865 .401 L .48862 .40818 L p .017 .265 .766 r
F P
0 g
s
.48862 .40818 m .51192 .43018 L .51127 .42791 L p .017 .265 .766 r
F P
0 g
s
.59994 .36682 m .55898 .39732 L .55885 .40463 L p .861 .901 .861 r
F P
0 g
s
.55898 .39732 m .59994 .36682 L .59214 .35163 L p .848 .82 .821 r
F P
0 g
s
.64225 .31638 m .59214 .35163 L .59994 .36682 L p .778 .796 .868 r
F P
0 g
s
.27308 .31126 m .22224 .3295 L .21574 .39264 L p .839 .897 .88 r
F P
0 g
s
.18498 .43282 m .21574 .39264 L .22224 .3295 L p .942 .961 .73 r
F P
0 g
s
.53445 .42906 m .55885 .40463 L .55898 .39732 L p .933 .942 .778 r
F P
0 g
s
.65731 .64602 m .61544 .61608 L .64445 .59679 L p .635 .728 .915 r
F P
0 g
s
.64445 .59679 m .70041 .61839 L .65731 .64602 L p .635 .728 .915 r
F P
0 g
s
.51188 .42563 m .48832 .39376 L .4865 .401 L p .299 .372 .77 r
F P
0 g
s
.4865 .401 m .51127 .42791 L .51188 .42563 L p .299 .372 .77 r
F P
0 g
s
.49395 .38726 m .4606 .34483 L .44881 .35907 L p .523 .531 .805 r
F P
0 g
s
.44881 .35907 m .48832 .39376 L .49395 .38726 L p .523 .531 .805 r
F P
0 g
s
.39548 .32943 m .44881 .35907 L .4606 .34483 L p .583 .621 .855 r
F P
0 g
s
.4606 .34483 m .41514 .3044 L .39548 .32943 L p .583 .621 .855 r
F P
0 g
s
.33409 .31185 m .39548 .32943 L .41514 .3044 L p .645 .714 .898 r
F P
0 g
s
.52952 .58464 m .53414 .635 L .48983 .63306 L p .703 .679 .823 r
F P
0 g
s
.53414 .635 m .52952 .58464 L .55497 .5811 L p .671 .654 .825 r
F P
0 g
s
.55497 .5811 m .57739 .62918 L .53414 .635 L p .671 .654 .825 r
F P
0 g
s
.55898 .39732 m .53446 .42675 L .53445 .42906 L p .933 .942 .778 r
F P
0 g
s
.53446 .42675 m .55898 .39732 L .55519 .39035 L p .908 .83 .757 r
F P
0 g
s
.59214 .35163 m .55519 .39035 L .55898 .39732 L p .848 .82 .821 r
F P
0 g
s
.18025 .47832 m .20347 .52067 L .23102 .57769 L p 0 0 .391 r
F P
0 g
s
.27329 .59945 m .23102 .57769 L .20347 .52067 L p .201 .467 .885 r
F P
0 g
s
.77983 .33778 m .83118 .36102 L .80691 .29843 L p .35 .544 .903 r
F P
0 g
s
.80691 .29843 m .75829 .28526 L .77983 .33778 L p .35 .544 .903 r
F P
0 g
s
.7521 .62073 m .70041 .61839 L .72618 .58397 L p .708 .86 .954 r
F P
0 g
s
.72618 .58397 m .78703 .57608 L .7521 .62073 L p .708 .86 .954 r
F P
0 g
s
.50341 .58346 m .48983 .63306 L .44865 .62352 L p .732 .709 .829 r
F P
0 g
s
.48983 .63306 m .50341 .58346 L .52952 .58464 L p .703 .679 .823 r
F P
0 g
s
.5137 .4236 m .49395 .38726 L .48832 .39376 L p .458 .434 .745 r
F P
0 g
s
.48832 .39376 m .51188 .42563 L .5137 .4236 L p .458 .434 .745 r
F P
0 g
s
.55519 .39035 m .59214 .35163 L .57657 .33875 L p .816 .751 .791 r
F P
0 g
s
.59214 .35163 m .64225 .31638 L .61587 .29365 L p .765 .755 .844 r
F P
0 g
s
.61587 .29365 m .57657 .33875 L .59214 .35163 L p .765 .755 .844 r
F P
0 g
s
.52255 .44882 m .5201 .43467 L .52391 .43486 L p .665 .295 .333 r
F P
0 g
s
.52391 .43486 m .52305 .44885 L .52255 .44882 L p .665 .295 .333 r
F P
0 g
s
.52305 .44885 m .52391 .43486 L .52762 .4343 L p .547 .195 .323 r
F P
0 g
s
.52209 .4487 m .51659 .43375 L .5201 .43467 L p .762 .365 .301 r
F P
0 g
s
.5201 .43467 m .52255 .44882 L .52209 .4487 L p .762 .365 .301 r
F P
0 g
s
.52762 .4343 m .52354 .44877 L .52305 .44885 L p .547 .195 .323 r
F P
0 g
s
.52354 .44877 m .52762 .4343 L .53083 .43304 L p .37 .036 .262 r
F P
0 g
s
.85472 .51046 m .83257 .54993 L .84354 .49008 L p .903 .937 .567 r
F P
0 g
s
.84354 .49008 m .86736 .44464 L .85472 .51046 L p .903 .937 .567 r
F P
0 g
s
.52172 .4485 m .51376 .4322 L .51659 .43375 L p .844 .411 .199 r
F P
0 g
s
.51659 .43375 m .52209 .4487 L .52172 .4485 L p .844 .411 .199 r
F P
0 g
s
.53083 .43304 m .52396 .44861 L .52354 .44877 L p .37 .036 .262 r
F P
0 g
s
.57739 .62918 m .55497 .5811 L .57719 .57318 L p .635 .636 .834 r
F P
0 g
s
.57719 .57318 m .61544 .61608 L .57739 .62918 L p .635 .636 .834 r
F P
0 g
s
.55519 .39035 m .53322 .42457 L .53446 .42675 L p .908 .83 .757 r
F P
0 g
s
.53322 .42457 m .55519 .39035 L .54784 .3845 L p .855 .738 .733 r
F P
0 g
s
.57657 .33875 m .54784 .3845 L .55519 .39035 L p .816 .751 .791 r
F P
0 g
s
.41514 .3044 m .3622 .27419 L .33409 .31185 L p .645 .714 .898 r
F P
0 g
s
.27308 .31126 m .33409 .31185 L .3622 .27419 L p .715 .823 .932 r
F P
0 g
s
.52172 .4485 m .52292 .45534 L .52148 .44824 L closepath p .952 .604 .288 r
F P
0 g
s
.5214 .44794 m .52292 .45534 L .52158 .44818 L p 0 0 .457 r
F P
0 g
s
.52158 .44818 m .52148 .44765 L .5214 .44794 L p 0 0 .457 r
F P
0 g
s
.51192 .43018 m .52116 .44763 L p .5214 .44794 L 0 0 .486 r
F P
0 g
s
.52116 .44763 m .52148 .44824 L .5214 .44794 L p 0 0 .486 r
F P
0 g
s
.51652 .42203 m .50278 .38221 L .49395 .38726 L p .559 .481 .724 r
F P
0 g
s
.49395 .38726 m .5137 .4236 L .51652 .42203 L p .559 .481 .724 r
F P
0 g
s
.4606 .34483 m .49395 .38726 L .50278 .38221 L p .591 .553 .78 r
F P
0 g
s
.27329 .59945 m .33013 .60193 L .36524 .63328 L p .497 .709 .966 r
F P
0 g
s
.4146 .60716 m .36524 .63328 L .33013 .60193 L p .683 .771 .918 r
F P
0 g
s
.36524 .63328 m .4146 .60716 L .44865 .62352 L p .681 .761 .912 r
F P
0 g
s
.64225 .31638 m .70027 .29227 L .66187 .25786 L p .691 .747 .895 r
F P
0 g
s
.66187 .25786 m .61587 .29365 L .64225 .31638 L p .691 .747 .895 r
F P
0 g
s
.50278 .38221 m .47945 .3337 L .4606 .34483 L p .591 .553 .78 r
F P
0 g
s
.41514 .3044 m .4606 .34483 L .47945 .3337 L p .622 .627 .835 r
F P
0 g
s
.52148 .44765 m .51188 .42563 L .51127 .42791 L p .117 .177 .65 r
F P
0 g
s
.51127 .42791 m .5214 .44794 L .52148 .44765 L p .117 .177 .65 r
F P
0 g
s
.53446 .42675 m .52443 .44779 L .52443 .44809 L p .965 .929 .605 r
F P
0 g
s
.52443 .44779 m .53446 .42675 L .53322 .42457 L p .96 .823 .664 r
F P
0 g
s
.54784 .3845 m .53086 .42274 L .53322 .42457 L p .855 .738 .733 r
F P
0 g
s
.53086 .42274 m .54784 .3845 L .53773 .38042 L p .801 .668 .717 r
F P
0 g
s
.54784 .3845 m .57657 .33875 L .55487 .32973 L p .778 .695 .772 r
F P
0 g
s
.55487 .32973 m .53773 .38042 L .54784 .3845 L p .778 .695 .772 r
F P
0 g
s
.47925 .57767 m .44865 .62352 L .4146 .60716 L p .757 .745 .842 r
F P
0 g
s
.44865 .62352 m .47925 .57767 L .50341 .58346 L p .732 .709 .829 r
F P
0 g
s
.52172 .44739 m .5137 .4236 L .51188 .42563 L p .38 .321 .666 r
F P
0 g
s
.51188 .42563 m .52148 .44765 L .52172 .44739 L p .38 .321 .666 r
F P
0 g
s
.22224 .3295 m .19099 .36465 L .18498 .43282 L p .942 .961 .73 r
F P
0 g
s
.18025 .47832 m .18498 .43282 L .19099 .36465 L p .722 .646 .088 r
F P
0 g
s
.53322 .42457 m .52427 .44751 L .52443 .44779 L p .96 .823 .664 r
F P
0 g
s
.52427 .44751 m .53322 .42457 L .53086 .42274 L p .888 .716 .663 r
F P
0 g
s
.52005 .42109 m .51386 .37921 L .50278 .38221 L p .632 .523 .712 r
F P
0 g
s
.50278 .38221 m .51652 .42203 L .52005 .42109 L p .632 .523 .712 r
F P
0 g
s
.47945 .3337 m .50278 .38221 L .51386 .37921 L p .646 .58 .766 r
F P
0 g
s
.52209 .44718 m .51652 .42203 L .5137 .4236 L p .522 .404 .66 r
F P
0 g
s
.5137 .4236 m .52172 .44739 L .52209 .44718 L p .522 .404 .66 r
F P
0 g
s
.53086 .42274 m .52396 .44727 L .52427 .44751 L p .888 .716 .663 r
F P
0 g
s
.52396 .44727 m .53086 .42274 L .52763 .42147 L p .818 .637 .657 r
F P
0 g
s
.53773 .38042 m .52763 .42147 L .53086 .42274 L p .801 .668 .717 r
F P
0 g
s
.57657 .33875 m .61587 .29365 L .57847 .27759 L p .744 .718 .828 r
F P
0 g
s
.57847 .27759 m .55487 .32973 L .57657 .33875 L p .744 .718 .828 r
F P
0 g
s
.52763 .42147 m .53773 .38042 L .52596 .37859 L p .748 .613 .708 r
F P
0 g
s
.53773 .38042 m .55487 .32973 L .52948 .32566 L p .737 .649 .762 r
F P
0 g
s
.52948 .32566 m .52596 .37859 L .53773 .38042 L p .737 .649 .762 r
F P
0 g
s
.52255 .44706 m .52005 .42109 L .51652 .42203 L p .615 .465 .655 r
F P
0 g
s
.51652 .42203 m .52209 .44718 L .52255 .44706 L p .615 .465 .655 r
F P
0 g
s
.52763 .42147 m .52354 .44711 L .52396 .44727 L p .818 .637 .657 r
F P
0 g
s
.52354 .44711 m .52763 .42147 L .52389 .4209 L p .753 .574 .653 r
F P
0 g
s
.52596 .37859 m .52389 .4209 L .52763 .42147 L p .748 .613 .708 r
F P
0 g
s
.52389 .4209 m .52596 .37859 L .51386 .37921 L p .693 .566 .707 r
F P
0 g
s
.51386 .37921 m .52005 .42109 L .52389 .4209 L p .693 .566 .707 r
F P
0 g
s
.50332 .32704 m .51386 .37921 L .52596 .37859 L p .694 .611 .76 r
F P
0 g
s
.51386 .37921 m .50332 .32704 L .47945 .3337 L p .646 .58 .766 r
F P
0 g
s
.52305 .44704 m .52389 .4209 L .52005 .42109 L p .688 .519 .652 r
F P
0 g
s
.52005 .42109 m .52255 .44706 L .52305 .44704 L p .688 .519 .652 r
F P
0 g
s
.52389 .4209 m .52305 .44704 L .52354 .44711 L p .753 .574 .653 r
F P
0 g
s
.52596 .37859 m .52948 .32566 L .50332 .32704 L p .694 .611 .76 r
F P
0 g
s
.61544 .61608 m .57719 .57318 L .59386 .56163 L p .594 .625 .852 r
F P
0 g
s
.59386 .56163 m .64445 .59679 L .61544 .61608 L p .594 .625 .852 r
F P
0 g
s
.44741 .28467 m .47945 .3337 L .50332 .32704 L p .657 .641 .822 r
F P
0 g
s
.47945 .3337 m .44741 .28467 L .41514 .3044 L p .622 .627 .835 r
F P
0 g
s
.3622 .27419 m .41514 .3044 L .44741 .28467 L p .654 .714 .892 r
F P
0 g
s
.52305 .44885 m .52292 .45534 L .52255 .44882 L closepath p .7 .405 .473 r
F P
0 g
s
.52354 .44877 m .52292 .45534 L .52305 .44885 L closepath p .602 .324 .468 r
F P
0 g
s
.52255 .44882 m .52292 .45534 L .52209 .4487 L closepath p .788 .475 .459 r
F P
0 g
s
.52396 .44861 m .52292 .45534 L .52354 .44877 L closepath p .468 .212 .442 r
F P
0 g
s
.52209 .4487 m .52292 .45534 L .52172 .4485 L closepath p .878 .544 .415 r
F P
0 g
s
.52427 .44837 m .52292 .45534 L .52396 .44861 L closepath p .24 .021 .367 r
F P
0 g
s
.52427 .44751 m .52292 .45534 L .52443 .44779 L closepath p .991 .787 .531 r
F P
0 g
s
.83118 .36102 m .86257 .39875 L .83691 .33094 L p 0 .14 .686 r
F P
0 g
s
.83691 .33094 m .80691 .29843 L .83118 .36102 L p 0 .14 .686 r
F P
0 g
s
.52148 .44765 m .52292 .45534 L .52172 .44739 L closepath p .284 .186 .563 r
F P
0 g
s
.52396 .44727 m .52292 .45534 L .52427 .44751 L closepath p .911 .683 .579 r
F P
0 g
s
.52172 .44739 m .52292 .45534 L .52209 .44718 L closepath p .478 .32 .587 r
F P
0 g
s
.52354 .44711 m .52292 .45534 L .52396 .44727 L closepath p .829 .6 .591 r
F P
0 g
s
.52209 .44718 m .52292 .45534 L .52255 .44706 L closepath p .595 .404 .593 r
F P
0 g
s
.52305 .44704 m .52292 .45534 L .52354 .44711 L closepath p .755 .532 .594 r
F P
0 g
s
.52255 .44706 m .52292 .45534 L .52305 .44704 L closepath p .68 .47 .595 r
F P
0 g
s
.526 .53277 m .52952 .58464 L .50341 .58346 L p .716 .631 .761 r
F P
0 g
s
.52952 .58464 m .526 .53277 L .53789 .53107 L p .67 .595 .763 r
F P
0 g
s
.53789 .53107 m .55497 .5811 L .52952 .58464 L p .67 .595 .763 r
F P
0 g
s
.51378 .5322 m .50341 .58346 L .47925 .57767 L p .759 .673 .767 r
F P
0 g
s
.50341 .58346 m .51378 .5322 L .526 .53277 L p .716 .631 .761 r
F P
0 g
s
.55487 .32973 m .57847 .27759 L .53431 .27029 L p .718 .687 .819 r
F P
0 g
s
.53431 .27029 m .52948 .32566 L .55487 .32973 L p .718 .687 .819 r
F P
0 g
s
.20347 .52067 m .2511 .55157 L .27329 .59945 L p .201 .467 .885 r
F P
0 g
s
.33013 .60193 m .27329 .59945 L .2511 .55157 L p .525 .689 .942 r
F P
0 g
s
.70027 .29227 m .75829 .28526 L .7084 .23915 L p .56 .712 .943 r
F P
0 g
s
.7084 .23915 m .66187 .25786 L .70027 .29227 L p .56 .712 .943 r
F P
0 g
s
.52292 .45534 m .52443 .46292 L .52427 .4632 L closepath p .122 .078 .53 r
F P
0 g
s
.52292 .45534 m .52396 .4621 L .52427 .46234 L closepath p .922 .578 .368 r
F P
0 g
s
.52292 .45534 m .52396 .46343 L .52353 .46359 L closepath p .542 .365 .591 r
F P
0 g
s
.52292 .45534 m .52427 .4632 L .52396 .46343 L closepath p .396 .262 .579 r
F P
0 g
s
.52292 .45534 m .52353 .46194 L .52396 .4621 L closepath p .832 .509 .442 r
F P
0 g
s
.52292 .45534 m .52353 .46359 L .52304 .46367 L closepath p .64 .438 .594 r
F P
0 g
s
.52292 .45534 m .52304 .46187 L .52353 .46194 L closepath p .744 .44 .468 r
F P
0 g
s
.52292 .45534 m .52254 .46364 L .52208 .46352 L closepath p .791 .564 .593 r
F P
0 g
s
.52292 .45534 m .52304 .46367 L .52254 .46364 L closepath p .718 .501 .595 r
F P
0 g
s
.52292 .45534 m .52254 .46189 L .52304 .46187 L closepath p .653 .367 .472 r
F P
0 g
s
.52292 .45534 m .52208 .46352 L .52171 .46332 L closepath p .869 .639 .587 r
F P
0 g
s
.52292 .45534 m .52207 .46201 L .52254 .46189 L closepath p .542 .274 .458 r
F P
0 g
s
.52292 .45534 m .52171 .46332 L .52146 .46306 L closepath p .955 .733 .564 r
F P
0 g
s
.52292 .45534 m .5217 .46221 L .52207 .46201 L closepath p .373 .132 .414 r
F P
0 g
s
.52138 .46277 m .52292 .45534 L .52157 .46252 L p .993 .827 .459 r
F P
0 g
s
.52157 .46252 m .52146 .46306 L .52138 .46277 L p .993 .827 .459 r
F P
0 g
s
.51166 .48099 m .52113 .46309 L p .52138 .46277 L .84 .901 .486 r
F P
0 g
s
.52113 .46309 m .52146 .46247 L .52138 .46277 L p .84 .901 .486 r
F P
0 g
s
.52292 .45534 m .52146 .46247 L .5217 .46221 L closepath p .045 0 .285 r
F P
0 g
s
.51103 .48324 m .52138 .46277 L .52146 .46306 L p .983 .884 .65 r
F P
0 g
s
.52146 .46306 m .5117 .48547 L .51103 .48324 L p .983 .884 .65 r
F P
0 g
s
.52138 .46277 m .51244 .48045 L p .51166 .48099 L .84 .901 .486 r
F P
0 g
s
.51244 .48045 m .51103 .48324 L .51166 .48099 L p .84 .901 .486 r
F P
0 g
s
.49288 .4982 m .51048 .4818 L p .51166 .48099 L .581 .878 .575 r
F P
0 g
s
.52146 .46247 m .51166 .48099 L .51351 .47899 L p 0 0 0 r
F P
0 g
s
.51048 .4818 m .51351 .47899 L .51166 .48099 L p .581 .878 .575 r
F P
0 g
s
.51351 .47899 m .52143 .46277 L p .52146 .46247 L 0 0 0 r
F P
0 g
s
.52143 .46277 m .5217 .46221 L .52146 .46247 L p 0 0 0 r
F P
0 g
s
.52146 .46247 m .52292 .45534 L .52149 .46225 L p 0 0 0 r
F P
0 g
s
.52149 .46225 m .52138 .46277 L .52146 .46247 L p 0 0 0 r
F P
0 g
s
.52443 .46262 m .52443 .46292 L .52433 .46239 L p 0 0 .306 r
F P
0 g
s
.52443 .46262 m .52427 .46234 L p .52454 .46286 L .677 .277 0 r
F P
0 g
s
.53461 .48437 m .52443 .46292 L .52443 .46262 L p 0 .054 .601 r
F P
0 g
s
.53462 .48209 m .53461 .48437 L p .53325 .48146 L 0 .054 .601 r
F P
0 g
s
.52443 .46262 m .53462 .48209 L p .53325 .48146 L 0 .054 .601 r
F P
0 g
s
.53462 .48209 m .52443 .46262 L p .52454 .46286 L .677 .277 0 r
F P
0 g
s
.53336 .47994 m .53462 .48209 L p .53323 .47945 L .677 .277 0 r
F P
0 g
s
.52427 .46234 m .53336 .47994 L p .53323 .47945 L .677 .277 0 r
F P
0 g
s
.52443 .46292 m .53461 .48437 L .53333 .48651 L p .27 .26 .664 r
F P
0 g
s
.53336 .47994 m .53096 .47814 L p .53348 .48045 L .578 .036 0 r
F P
0 g
s
.53462 .48209 m .53336 .47994 L p .53604 .48275 L 0 .165 .7 r
F P
0 g
s
.56014 .50798 m .53462 .48209 L p .53604 .48275 L 0 .165 .7 r
F P
0 g
s
.55622 .50121 m .56014 .50798 L p .55516 .50277 L 0 .165 .7 r
F P
0 g
s
.53336 .47994 m .55622 .50121 L p .55516 .50277 L 0 .165 .7 r
F P
0 g
s
.55622 .50121 m .53336 .47994 L p .53348 .48045 L .578 .036 0 r
F P
0 g
s
.54863 .49552 m .55622 .50121 L p .55152 .49691 L .578 .036 0 r
F P
0 g
s
.53096 .47814 m .54863 .49552 L p .55152 .49691 L .578 .036 0 r
F P
0 g
s
.55586 .52174 m .53333 .48651 L .53461 .48437 L p .383 .403 .757 r
F P
0 g
s
.53461 .48437 m .56 .51508 L .55586 .52174 L p .383 .403 .757 r
F P
0 g
s
.56 .51508 m .53461 .48437 L .53462 .48209 L p .167 .32 .775 r
F P
0 g
s
.53462 .48209 m .56014 .50798 L .56 .51508 L p .167 .32 .775 r
F P
0 g
s
.52396 .46343 m .53093 .48829 L .52767 .48953 L p .572 .436 .657 r
F P
0 g
s
.53093 .48829 m .52396 .46343 L .52427 .4632 L p .459 .366 .663 r
F P
0 g
s
.52427 .4632 m .53333 .48651 L .53093 .48829 L p .459 .366 .663 r
F P
0 g
s
.53333 .48651 m .52427 .4632 L .52443 .46292 L p .27 .26 .664 r
F P
0 g
s
.53817 .49156 m .54863 .49552 L p .54472 .49204 L .666 .122 0 r
F P
0 g
s
.52768 .47689 m .53817 .49156 L p .54472 .49204 L .666 .122 0 r
F P
0 g
s
.526 .53277 m .52389 .49008 L .52767 .48953 L p .663 .544 .708 r
F P
0 g
s
.52767 .48953 m .53789 .53107 L .526 .53277 L p .663 .544 .708 r
F P
0 g
s
.53789 .53107 m .52767 .48953 L .53093 .48829 L p .597 .501 .717 r
F P
0 g
s
.53093 .48829 m .54822 .52726 L .53789 .53107 L p .597 .501 .717 r
F P
0 g
s
.54822 .52726 m .53093 .48829 L .53333 .48651 L p .51 .457 .733 r
F P
0 g
s
.53333 .48651 m .55586 .52174 L .54822 .52726 L p .51 .457 .733 r
F P
0 g
s
.53817 .49156 m .526 .48978 L p .53157 .49107 L .211 0 0 r
F P
0 g
s
.54863 .49552 m .53817 .49156 L p .54572 .49412 L 0 .388 .718 r
F P
0 g
s
.54863 .49552 m .53096 .47814 L .52768 .47689 L p .666 .122 0 r
F P
0 g
s
.57928 .50552 m .54863 .49552 L p .54572 .49412 L 0 .388 .718 r
F P
0 g
s
.55645 .49686 m .57928 .50552 L p .57177 .50297 L 0 .388 .718 r
F P
0 g
s
.53817 .49156 m .55645 .49686 L p .57177 .50297 L 0 .388 .718 r
F P
0 g
s
.55645 .49686 m .53817 .49156 L p .53157 .49107 L .211 0 0 r
F P
0 g
s
.55622 .50121 m .54863 .49552 L p .55729 .49964 L 0 .435 .853 r
F P
0 g
s
.54863 .49552 m .57928 .50552 L .59564 .51786 L p 0 .435 .853 r
F P
0 g
s
.52972 .49295 m .55645 .49686 L p .55087 .49556 L .211 0 0 r
F P
0 g
s
.526 .48978 m .52972 .49295 L p .55087 .49556 L .211 0 0 r
F P
0 g
s
.52389 .49008 m .526 .53277 L .51378 .5322 L p .721 .589 .707 r
F P
0 g
s
.51378 .5322 m .52001 .4899 L .52389 .49008 L p .721 .589 .707 r
F P
0 g
s
.50251 .52941 m .51644 .48899 L .52001 .4899 L p .775 .64 .712 r
F P
0 g
s
.52001 .4899 m .51378 .5322 L .50251 .52941 L p .775 .64 .712 r
F P
0 g
s
.49339 .52469 m .51357 .48746 L .51644 .48899 L p .829 .702 .724 r
F P
0 g
s
.51644 .48899 m .50251 .52941 L .49339 .52469 L p .829 .702 .724 r
F P
0 g
s
.48739 .51853 m .5117 .48547 L .51357 .48746 L p .884 .783 .744 r
F P
0 g
s
.51357 .48746 m .49339 .52469 L .48739 .51853 L p .884 .783 .744 r
F P
0 g
s
.48519 .51155 m .51103 .48324 L .5117 .48547 L p .93 .888 .77 r
F P
0 g
s
.5117 .48547 m .48739 .51853 L .48519 .51155 L p .93 .888 .77 r
F P
0 g
s
.51357 .48746 m .52171 .46332 L .52208 .46352 L p .852 .674 .66 r
F P
0 g
s
.52208 .46352 m .51644 .48899 L .51357 .48746 L p .852 .674 .66 r
F P
0 g
s
.5117 .48547 m .52146 .46306 L .52171 .46332 L p .925 .766 .666 r
F P
0 g
s
.52171 .46332 m .51357 .48746 L .5117 .48547 L p .925 .766 .666 r
F P
0 g
s
.51638 .47744 m .50201 .4933 L .51348 .49038 L p .291 0 0 r
F P
0 g
s
.50217 .49428 m .51348 .49038 L .50201 .4933 L p 0 0 0 r
F P
0 g
s
.51348 .49038 m .50217 .49428 L .52972 .49295 L p .098 0 0 r
F P
0 g
s
.52972 .49295 m .50217 .49428 L p .50985 .4905 L .433 .821 .987 r
F P
0 g
s
.52001 .4899 m .52254 .46364 L .52304 .46367 L p .721 .546 .652 r
F P
0 g
s
.52304 .46367 m .52389 .49008 L .52001 .4899 L p .721 .546 .652 r
F P
0 g
s
.52389 .49008 m .52304 .46367 L .52353 .46359 L p .653 .492 .653 r
F P
0 g
s
.51644 .48899 m .52208 .46352 L .52254 .46364 L p .786 .604 .654 r
F P
0 g
s
.52254 .46364 m .52001 .4899 L .51644 .48899 L p .786 .604 .654 r
F P
0 g
s
.52353 .46359 m .52767 .48953 L .52389 .49008 L p .653 .492 .653 r
F P
0 g
s
.52767 .48953 m .52353 .46359 L .52396 .46343 L p .572 .436 .657 r
F P
0 g
s
.53336 .47994 m .52427 .46234 L .52396 .4621 L p .863 .414 .099 r
F P
0 g
s
.52396 .4621 m .53096 .47814 L .53336 .47994 L p .863 .414 .099 r
F P
0 g
s
.51348 .49038 m .51997 .47652 L .51638 .47744 L p .291 0 0 r
F P
0 g
s
.53817 .49156 m .52768 .47689 L .52388 .47633 L p .607 .1 .02 r
F P
0 g
s
.526 .48978 m .52388 .47633 L .51997 .47652 L p .486 .007 .042 r
F P
0 g
s
.51997 .47652 m .51348 .49038 L .526 .48978 L p .486 .007 .042 r
F P
0 g
s
.52388 .47633 m .526 .48978 L .53817 .49156 L p .607 .1 .02 r
F P
0 g
s
.52972 .49295 m .526 .48978 L .51348 .49038 L p .098 0 0 r
F P
0 g
s
.53494 .47815 m .52972 .49295 L p .50985 .4905 L .433 .821 .987 r
F P
0 g
s
.55645 .49686 m .52972 .49295 L p .54202 .49111 L .37 .761 .987 r
F P
0 g
s
.58203 .4851 m .55645 .49686 L p .54202 .49111 L .37 .761 .987 r
F P
0 g
s
.59564 .51786 m .55622 .50121 L p .55729 .49964 L 0 .435 .853 r
F P
0 g
s
.52433 .46239 m .52292 .45534 L .52443 .46262 L p 0 0 .306 r
F P
0 g
s
.52292 .45534 m .52427 .46234 L .52443 .46262 L closepath p .929 .595 .146 r
F P
0 g
s
.70041 .61839 m .64445 .59679 L .66117 .57307 L p .624 .729 .922 r
F P
0 g
s
.66117 .57307 m .72618 .58397 L .70041 .61839 L p .624 .729 .922 r
F P
0 g
s
.3622 .27419 m .3089 .2611 L .27308 .31126 L p .715 .823 .932 r
F P
0 g
s
.22224 .3295 m .27308 .31126 L .3089 .2611 L p .79 .955 .923 r
F P
0 g
s
.55497 .5811 m .53789 .53107 L .54822 .52726 L p .617 .565 .774 r
F P
0 g
s
.54822 .52726 m .57719 .57318 L .55497 .5811 L p .617 .565 .774 r
F P
0 g
s
.48877 .27277 m .50332 .32704 L .52948 .32566 L p .689 .661 .817 r
F P
0 g
s
.50332 .32704 m .48877 .27277 L .44741 .28467 L p .657 .641 .822 r
F P
0 g
s
.52948 .32566 m .53431 .27029 L .48877 .27277 L p .689 .661 .817 r
F P
0 g
s
.83257 .54993 m .78703 .57608 L .79496 .52609 L p .856 .942 .876 r
F P
0 g
s
.79496 .52609 m .84354 .49008 L .83257 .54993 L p .856 .942 .876 r
F P
0 g
s
.51638 .47744 m .52207 .46201 L .5217 .46221 L p .236 0 .2 r
F P
0 g
s
.5217 .46221 m .51351 .47899 L .51638 .47744 L p .236 0 .2 r
F P
0 g
s
.53096 .47814 m .52396 .4621 L .52353 .46194 L p .806 .393 .265 r
F P
0 g
s
.51997 .47652 m .52254 .46189 L .52207 .46201 L p .47 .127 .302 r
F P
0 g
s
.52207 .46201 m .51638 .47744 L .51997 .47652 L p .47 .127 .302 r
F P
0 g
s
.52353 .46194 m .52768 .47689 L .53096 .47814 L p .806 .393 .265 r
F P
0 g
s
.52768 .47689 m .52353 .46194 L .52304 .46187 L p .715 .333 .325 r
F P
0 g
s
.52388 .47633 m .52304 .46187 L .52254 .46189 L p .61 .251 .334 r
F P
0 g
s
.52254 .46189 m .51997 .47652 L .52388 .47633 L p .61 .251 .334 r
F P
0 g
s
.33013 .60193 m .3913 .58541 L .4146 .60716 L p .683 .771 .918 r
F P
0 g
s
.4595 .56782 m .4146 .60716 L .3913 .58541 L p .775 .788 .863 r
F P
0 g
s
.4146 .60716 m .4595 .56782 L .47925 .57767 L p .757 .745 .842 r
F P
0 g
s
.52304 .46187 m .52388 .47633 L .52768 .47689 L p .715 .333 .325 r
F P
0 g
s
.50251 .52941 m .47925 .57767 L .4595 .56782 L p .8 .725 .782 r
F P
0 g
s
.47925 .57767 m .50251 .52941 L .51378 .5322 L p .759 .673 .767 r
F P
0 g
s
.61587 .29365 m .66187 .25786 L .60628 .23329 L p .687 .738 .89 r
F P
0 g
s
.60628 .23329 m .57847 .27759 L .61587 .29365 L p .687 .738 .89 r
F P
0 g
s
.57719 .57318 m .54822 .52726 L .55586 .52174 L p .554 .54 .793 r
F P
0 g
s
.55586 .52174 m .59386 .56163 L .57719 .57318 L p .554 .54 .793 r
F P
0 g
s
.4595 .56782 m .49339 .52469 L .50251 .52941 L p .8 .725 .782 r
F P
0 g
s
.19099 .36465 m .18616 .41093 L .18025 .47832 L p .722 .646 .088 r
F P
0 g
s
.20347 .52067 m .18025 .47832 L .18616 .41093 L p .006 .135 .65 r
F P
0 g
s
.40974 .24415 m .44741 .28467 L .48877 .27277 L p .664 .717 .888 r
F P
0 g
s
.44741 .28467 m .40974 .24415 L .3622 .27419 L p .654 .714 .892 r
F P
0 g
s
.48707 .50452 m .51166 .48099 L .51103 .48324 L p .898 .987 .762 r
F P
0 g
s
.51103 .48324 m .48519 .51155 L .48707 .50452 L p .898 .987 .762 r
F P
0 g
s
.3913 .58541 m .44629 .55485 L .4595 .56782 L p .775 .788 .863 r
F P
0 g
s
.49339 .52469 m .4595 .56782 L .44629 .55485 L p .836 .79 .807 r
F P
0 g
s
.64445 .59679 m .59386 .56163 L .60313 .54756 L p .548 .621 .877 r
F P
0 g
s
.60313 .54756 m .66117 .57307 L .64445 .59679 L p .548 .621 .877 r
F P
0 g
s
.3089 .2611 m .3622 .27419 L .40974 .24415 L p .685 .829 .952 r
F P
0 g
s
.44629 .55485 m .48739 .51853 L .49339 .52469 L p .836 .79 .807 r
F P
0 g
s
.47705 .50067 m .49438 .49556 L p .49288 .4982 L .468 .888 .795 r
F P
0 g
s
.51166 .48099 m .49193 .49986 L p .49288 .4982 L .581 .878 .575 r
F P
0 g
s
.51351 .47899 m .49288 .4982 L .50201 .4933 L p 0 0 0 r
F P
0 g
s
.49438 .49556 m .50201 .4933 L .49288 .4982 L p .468 .888 .795 r
F P
0 g
s
.49193 .49986 m .48707 .50452 L .49288 .4982 L p .581 .878 .575 r
F P
0 g
s
.2511 .55157 m .3144 .56526 L .33013 .60193 L p .525 .689 .942 r
F P
0 g
s
.3913 .58541 m .33013 .60193 L .3144 .56526 L p .681 .781 .926 r
F P
0 g
s
.50201 .4933 m .51638 .47744 L .51351 .47899 L p 0 0 0 r
F P
0 g
s
.59386 .56163 m .55586 .52174 L .56 .51508 L p .472 .518 .824 r
F P
0 g
s
.57847 .27759 m .60628 .23329 L .54003 .22207 L p .681 .729 .887 r
F P
0 g
s
.54003 .22207 m .53431 .27029 L .57847 .27759 L p .681 .729 .887 r
F P
0 g
s
.86257 .39875 m .86736 .44464 L .8415 .37757 L p .917 .644 .153 r
F P
0 g
s
.8415 .37757 m .83691 .33094 L .86257 .39875 L p .917 .644 .153 r
F P
0 g
s
.56 .51508 m .60313 .54756 L .59386 .56163 L p .472 .518 .824 r
F P
0 g
s
.44115 .54006 m .48519 .51155 L .48739 .51853 L p .861 .868 .843 r
F P
0 g
s
.48739 .51853 m .44629 .55485 L .44115 .54006 L p .861 .868 .843 r
F P
0 g
s
.47156 .22588 m .48877 .27277 L .53431 .27029 L p .673 .722 .886 r
F P
0 g
s
.48877 .27277 m .47156 .22588 L .40974 .24415 L p .664 .717 .888 r
F P
0 g
s
.75829 .28526 m .80691 .29843 L .74782 .2429 L p .24 .563 .936 r
F P
0 g
s
.74782 .2429 m .7084 .23915 L .75829 .28526 L p .24 .563 .936 r
F P
0 g
s
.78703 .57608 m .72618 .58397 L .73083 .54594 L p .731 .837 .93 r
F P
0 g
s
.73083 .54594 m .79496 .52609 L .78703 .57608 L p .731 .837 .93 r
F P
0 g
s
.3089 .2611 m .26397 .26939 L .22224 .3295 L p .79 .955 .923 r
F P
0 g
s
.19099 .36465 m .22224 .3295 L .26397 .26939 L p .688 .914 .58 r
F P
0 g
s
.53431 .27029 m .54003 .22207 L .47156 .22588 L p .673 .722 .886 r
F P
0 g
s
.60313 .54756 m .56 .51508 L .56014 .50798 L p .357 .498 .863 r
F P
0 g
s
.3144 .56526 m .38157 .5603 L .3913 .58541 L p .681 .781 .926 r
F P
0 g
s
.44629 .55485 m .3913 .58541 L .38157 .5603 L p .782 .834 .892 r
F P
0 g
s
.38157 .5603 m .44115 .54006 L .44629 .55485 L p .782 .834 .892 r
F P
0 g
s
.44486 .525 m .48707 .50452 L .48519 .51155 L p .849 .951 .881 r
F P
0 g
s
.48519 .51155 m .44115 .54006 L .44486 .525 L p .849 .951 .881 r
F P
0 g
s
.66187 .25786 m .7084 .23915 L .63466 .2059 L p .562 .741 .96 r
F P
0 g
s
.63466 .2059 m .60628 .23329 L .66187 .25786 L p .562 .741 .96 r
F P
0 g
s
.56014 .50798 m .60382 .53243 L .60313 .54756 L p .357 .498 .863 r
F P
0 g
s
.60382 .53243 m .56014 .50798 L .55622 .50121 L p .19 .475 .892 r
F P
0 g
s
.18616 .41093 m .2098 .45953 L .20347 .52067 L p .006 .135 .65 r
F P
0 g
s
.2511 .55157 m .20347 .52067 L .2098 .45953 L p .377 .503 .859 r
F P
0 g
s
.66117 .57307 m .60313 .54756 L .60382 .53243 L p .497 .627 .909 r
F P
0 g
s
.45723 .51134 m .49288 .4982 L .48707 .50452 L p .738 .989 .886 r
F P
0 g
s
.48707 .50452 m .44486 .525 L .45723 .51134 L p .738 .989 .886 r
F P
0 g
s
.72618 .58397 m .66117 .57307 L .66329 .54722 L p .615 .734 .931 r
F P
0 g
s
.66329 .54722 m .73083 .54594 L .72618 .58397 L p .615 .734 .931 r
F P
0 g
s
.55622 .50121 m .59564 .51786 L .60382 .53243 L p .19 .475 .892 r
F P
0 g
s
.60382 .53243 m .66329 .54722 L .66117 .57307 L p .497 .627 .909 r
F P
0 g
s
.37142 .22063 m .40974 .24415 L .47156 .22588 L p .648 .821 .967 r
F P
0 g
s
.40974 .24415 m .37142 .22063 L .3089 .2611 L p .685 .829 .952 r
F P
0 g
s
.49288 .4982 m .45723 .51134 L .47705 .50067 L p .468 .888 .795 r
F P
0 g
s
.38709 .53441 m .44486 .525 L .44115 .54006 L p .769 .878 .926 r
F P
0 g
s
.44115 .54006 m .38157 .5603 L .38709 .53441 L p .769 .878 .926 r
F P
0 g
s
.86736 .44464 m .84354 .49008 L .8187 .42939 L p .97 .868 .68 r
F P
0 g
s
.8187 .42939 m .8415 .37757 L .86736 .44464 L p .97 .868 .68 r
F P
0 g
s
.26397 .26939 m .3089 .2611 L .37142 .22063 L p .655 .957 .94 r
F P
0 g
s
.50201 .4933 m .47705 .50067 L .50217 .49428 L p 0 0 0 r
F P
0 g
s
.2098 .45953 m .25791 .50078 L .2511 .55157 L p .377 .503 .859 r
F P
0 g
s
.3144 .56526 m .2511 .55157 L .25791 .50078 L p .557 .677 .919 r
F P
0 g
s
.66329 .54722 m .60382 .53243 L .59564 .51786 L p .442 .644 .943 r
F P
0 g
s
.60628 .23329 m .63466 .2059 L .54587 .19062 L p .579 .773 .971 r
F P
0 g
s
.54587 .19062 m .54003 .22207 L .60628 .23329 L p .579 .773 .971 r
F P
0 g
s
.26397 .26939 m .2361 .29933 L .19099 .36465 L p .688 .914 .58 r
F P
0 g
s
.18616 .41093 m .19099 .36465 L .2361 .29933 L p 0 0 .311 r
F P
0 g
s
.80691 .29843 m .83691 .33094 L .77233 .27039 L p .587 .076 0 r
F P
0 g
s
.77233 .27039 m .74782 .2429 L .80691 .29843 L p .587 .076 0 r
F P
0 g
s
.32105 .52689 m .38709 .53441 L .38157 .5603 L p .675 .789 .935 r
F P
0 g
s
.38157 .5603 m .3144 .56526 L .32105 .52689 L p .675 .789 .935 r
F P
0 g
s
.25791 .50078 m .32105 .52689 L .3144 .56526 L p .557 .677 .919 r
F P
0 g
s
.45394 .19582 m .47156 .22588 L .54003 .22207 L p .61 .802 .973 r
F P
0 g
s
.47156 .22588 m .45394 .19582 L .37142 .22063 L p .648 .821 .967 r
F P
0 g
s
.40793 .51063 m .45723 .51134 L .44486 .525 L p .725 .909 .959 r
F P
0 g
s
.44486 .525 m .38709 .53441 L .40793 .51063 L p .725 .909 .959 r
F P
0 g
s
.54003 .22207 m .54587 .19062 L .45394 .19582 L p .61 .802 .973 r
F P
0 g
s
.7084 .23915 m .74782 .2429 L .65888 .2025 L p .149 .595 .931 r
F P
0 g
s
.65888 .2025 m .63466 .2059 L .7084 .23915 L p .149 .595 .931 r
F P
0 g
s
.84354 .49008 m .79496 .52609 L .77255 .47593 L p .855 .855 .841 r
F P
0 g
s
.77255 .47593 m .8187 .42939 L .84354 .49008 L p .855 .855 .841 r
F P
0 g
s
.59564 .51786 m .6499 .52201 L .66329 .54722 L p .442 .644 .943 r
F P
0 g
s
.6499 .52201 m .59564 .51786 L .57928 .50552 L p .39 .672 .972 r
F P
0 g
s
.73083 .54594 m .66329 .54722 L .6499 .52201 L p .609 .742 .939 r
F P
0 g
s
.44226 .49185 m .47705 .50067 L .45723 .51134 L p .644 .912 .981 r
F P
0 g
s
.45723 .51134 m .40793 .51063 L .44226 .49185 L p .644 .912 .981 r
F P
0 g
s
.79496 .52609 m .73083 .54594 L .71238 .50832 L p .737 .807 .907 r
F P
0 g
s
.71238 .50832 m .77255 .47593 L .79496 .52609 L p .737 .807 .907 r
F P
0 g
s
.6499 .52201 m .71238 .50832 L .73083 .54594 L p .609 .742 .939 r
F P
0 g
s
.2361 .29933 m .23177 .34628 L .18616 .41093 L p 0 0 .311 r
F P
0 g
s
.2098 .45953 m .18616 .41093 L .23177 .34628 L p .334 .312 .686 r
F P
0 g
s
.57928 .50552 m .62188 .5004 L .6499 .52201 L p .39 .672 .972 r
F P
0 g
s
.62188 .5004 m .57928 .50552 L .55645 .49686 L p .359 .711 .986 r
F P
0 g
s
.37142 .22063 m .3388 .22043 L .26397 .26939 L p .655 .957 .94 r
F P
0 g
s
.2361 .29933 m .26397 .26939 L .3388 .22043 L p 0 0 0 r
F P
0 g
s
.3388 .22043 m .37142 .22063 L .45394 .19582 L p .443 .874 .914 r
F P
0 g
s
.35084 .49114 m .40793 .51063 L .38709 .53441 L p .665 .794 .943 r
F P
0 g
s
.38709 .53441 m .32105 .52689 L .35084 .49114 L p .665 .794 .943 r
F P
0 g
s
.83691 .33094 m .8415 .37757 L .77609 .31762 L p .949 .634 .402 r
F P
0 g
s
.77609 .31762 m .77233 .27039 L .83691 .33094 L p .949 .634 .402 r
F P
0 g
s
.48635 .48051 m .50217 .49428 L .47705 .50067 L p .535 .879 .988 r
F P
0 g
s
.47705 .50067 m .44226 .49185 L .48635 .48051 L p .535 .879 .988 r
F P
0 g
s
.55645 .49686 m .58203 .4851 L .62188 .5004 L p .359 .711 .986 r
F P
0 g
s
.50217 .49428 m .48635 .48051 L .53494 .47815 L p .433 .821 .987 r
F P
0 g
s
.52972 .49295 m .53494 .47815 L .58203 .4851 L p .37 .761 .987 r
F P
0 g
s
.63466 .2059 m .65888 .2025 L .55087 .18384 L p .138 .651 .895 r
F P
0 g
s
.55087 .18384 m .54587 .19062 L .63466 .2059 L p .138 .651 .895 r
F P
0 g
s
.71238 .50832 m .6499 .52201 L .62188 .5004 L p .606 .752 .947 r
F P
0 g
s
.23177 .34628 m .25289 .40119 L .2098 .45953 L p .334 .312 .686 r
F P
0 g
s
.25791 .50078 m .2098 .45953 L .25289 .40119 L p .493 .53 .824 r
F P
0 g
s
.29553 .4528 m .35084 .49114 L .32105 .52689 L p .59 .673 .897 r
F P
0 g
s
.32105 .52689 m .25791 .50078 L .29553 .4528 L p .59 .673 .897 r
F P
0 g
s
.25289 .40119 m .29553 .4528 L .25791 .50078 L p .493 .53 .824 r
F P
0 g
s
.43884 .1902 m .45394 .19582 L .54587 .19062 L p .244 .749 .884 r
F P
0 g
s
.45394 .19582 m .43884 .1902 L .3388 .22043 L p .443 .874 .914 r
F P
0 g
s
.74782 .2429 m .77233 .27039 L .67401 .22611 L p .703 .168 0 r
F P
0 g
s
.67401 .22611 m .65888 .2025 L .74782 .2429 L p .703 .168 0 r
F P
0 g
s
.40157 .46256 m .44226 .49185 L .40793 .51063 L p .653 .795 .951 r
F P
0 g
s
.40793 .51063 m .35084 .49114 L .40157 .46256 L p .653 .795 .951 r
F P
0 g
s
.54587 .19062 m .55087 .18384 L .43884 .1902 L p .244 .749 .884 r
F P
0 g
s
.8415 .37757 m .8187 .42939 L .75741 .37541 L p .902 .751 .684 r
F P
0 g
s
.75741 .37541 m .77609 .31762 L .8415 .37757 L p .902 .751 .684 r
F P
0 g
s
.3388 .22043 m .31843 .24579 L .2361 .29933 L p 0 0 0 r
F P
0 g
s
.23177 .34628 m .2361 .29933 L .31843 .24579 L p .35 .141 .449 r
F P
0 g
s
.77255 .47593 m .71238 .50832 L .6715 .47561 L p .732 .777 .888 r
F P
0 g
s
.62188 .5004 m .6715 .47561 L .71238 .50832 L p .606 .752 .947 r
F P
0 g
s
.6715 .47561 m .62188 .5004 L .58203 .4851 L p .608 .763 .953 r
F P
0 g
s
.31843 .24579 m .3388 .22043 L .43884 .1902 L p .279 0 0 r
F P
0 g
s
.46773 .44514 m .48635 .48051 L .44226 .49185 L p .639 .792 .956 r
F P
0 g
s
.44226 .49185 m .40157 .46256 L .46773 .44514 L p .639 .792 .956 r
F P
0 g
s
.8187 .42939 m .77255 .47593 L .71989 .43176 L p .823 .777 .809 r
F P
0 g
s
.71989 .43176 m .75741 .37541 L .8187 .42939 L p .823 .777 .809 r
F P
0 g
s
.6715 .47561 m .71989 .43176 L .77255 .47593 L p .732 .777 .888 r
F P
0 g
s
.58203 .4851 m .61208 .45221 L .6715 .47561 L p .608 .763 .953 r
F P
0 g
s
.61208 .45221 m .58203 .4851 L .53494 .47815 L p .615 .775 .957 r
F P
0 g
s
.36171 .41398 m .40157 .46256 L .35084 .49114 L p .622 .676 .881 r
F P
0 g
s
.35084 .49114 m .29553 .4528 L .36171 .41398 L p .622 .676 .881 r
F P
0 g
s
.54111 .44151 m .53494 .47815 L .48635 .48051 L p .625 .785 .958 r
F P
0 g
s
.48635 .48051 m .46773 .44514 L .54111 .44151 L p .625 .785 .958 r
F P
0 g
s
.65888 .2025 m .67401 .22611 L .55399 .20559 L p .634 .138 .054 r
F P
0 g
s
.55399 .20559 m .55087 .18384 L .65888 .2025 L p .634 .138 .054 r
F P
0 g
s
.53494 .47815 m .54111 .44151 L .61208 .45221 L p .615 .775 .957 r
F P
0 g
s
.31843 .24579 m .31525 .29324 L .23177 .34628 L p .35 .141 .449 r
F P
0 g
s
.25289 .40119 m .23177 .34628 L .31525 .29324 L p .503 .408 .68 r
F P
0 g
s
.77233 .27039 m .77609 .31762 L .67633 .27373 L p .852 .55 .477 r
F P
0 g
s
.67633 .27373 m .67401 .22611 L .77233 .27039 L p .852 .55 .477 r
F P
0 g
s
.71989 .43176 m .6715 .47561 L .61208 .45221 L p .719 .748 .875 r
F P
0 g
s
.42937 .21258 m .43884 .1902 L .55087 .18384 L p .499 .033 .078 r
F P
0 g
s
.43884 .1902 m .42937 .21258 L .31843 .24579 L p .279 0 0 r
F P
0 g
s
.3307 .35354 m .36171 .41398 L .29553 .4528 L p .575 .557 .797 r
F P
0 g
s
.29553 .4528 m .25289 .40119 L .3307 .35354 L p .575 .557 .797 r
F P
0 g
s
.31525 .29324 m .3307 .35354 L .25289 .40119 L p .503 .408 .68 r
F P
0 g
s
.55087 .18384 m .55399 .20559 L .42937 .21258 L p .499 .033 .078 r
F P
0 g
s
.31525 .29324 m .31843 .24579 L .42937 .21258 L p .538 .293 .492 r
F P
0 g
s
.44938 .39013 m .46773 .44514 L .40157 .46256 L p .651 .686 .87 r
F P
0 g
s
.40157 .46256 m .36171 .41398 L .44938 .39013 L p .651 .686 .87 r
F P
0 g
s
.77609 .31762 m .75741 .37541 L .66476 .33606 L p .828 .661 .676 r
F P
0 g
s
.66476 .33606 m .67633 .27373 L .77609 .31762 L p .828 .661 .676 r
F P
0 g
s
.75741 .37541 m .71989 .43176 L .64165 .39982 L p .783 .714 .788 r
F P
0 g
s
.61208 .45221 m .64165 .39982 L .71989 .43176 L p .719 .748 .875 r
F P
0 g
s
.64165 .39982 m .61208 .45221 L .54111 .44151 L p .7 .723 .867 r
F P
0 g
s
.64165 .39982 m .66476 .33606 L .75741 .37541 L p .783 .714 .788 r
F P
0 g
s
.67401 .22611 m .67633 .27373 L .55444 .25339 L p .756 .471 .501 r
F P
0 g
s
.55444 .25339 m .55399 .20559 L .67401 .22611 L p .756 .471 .501 r
F P
0 g
s
.54722 .38513 m .54111 .44151 L .46773 .44514 L p .677 .702 .865 r
F P
0 g
s
.46773 .44514 m .44938 .39013 L .54722 .38513 L p .677 .702 .865 r
F P
0 g
s
.54111 .44151 m .54722 .38513 L .64165 .39982 L p .7 .723 .867 r
F P
0 g
s
.42937 .21258 m .42787 .26033 L .31525 .29324 L p .538 .293 .492 r
F P
0 g
s
.3307 .35354 m .31525 .29324 L .42787 .26033 L p .608 .474 .673 r
F P
0 g
s
.43503 .32407 m .44938 .39013 L .36171 .41398 L p .638 .587 .781 r
F P
0 g
s
.36171 .41398 m .3307 .35354 L .43503 .32407 L p .638 .587 .781 r
F P
0 g
s
.42787 .26033 m .42937 .21258 L .55399 .20559 L p .658 .391 .505 r
F P
0 g
s
.55399 .20559 m .55444 .25339 L .42787 .26033 L p .658 .391 .505 r
F P
0 g
s
.42787 .26033 m .43503 .32407 L .3307 .35354 L p .608 .474 .673 r
F P
0 g
s
.66476 .33606 m .64165 .39982 L .54722 .38513 L p .739 .664 .776 r
F P
0 g
s
.67633 .27373 m .66476 .33606 L .55202 .31787 L p .758 .592 .671 r
F P
0 g
s
.55202 .31787 m .55444 .25339 L .67633 .27373 L p .758 .592 .671 r
F P
0 g
s
.55202 .31787 m .54722 .38513 L .44938 .39013 L p .691 .622 .774 r
F P
0 g
s
.44938 .39013 m .43503 .32407 L .55202 .31787 L p .691 .622 .774 r
F P
0 g
s
.54722 .38513 m .55202 .31787 L .66476 .33606 L p .739 .664 .776 r
F P
0 g
s
.43503 .32407 m .42787 .26033 L .55444 .25339 L p .688 .532 .67 r
F P
0 g
s
.55444 .25339 m .55202 .31787 L .43503 .32407 L p .688 .532 .67 r
F P
0 g
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.0153906 0.39418 0.207773 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0577037 1.16819 -8.61941e-17 1.16819 [
[ 0 0 0 0 ]
[ 1 1.08786 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.08786 L
0 1.08786 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.47239 .48567 m .46084 .54041 L .54634 .54468 L p .713 .635 .769 r
F P
0 g
s
.54634 .54468 m .54242 .48928 L .47239 .48567 L p .713 .635 .769 r
F P
0 g
s
.54757 .60169 m .54634 .54468 L .46084 .54041 L p .718 .517 .618 r
F P
0 g
s
.54242 .48928 m .54634 .54468 L .63011 .53185 L p .678 .608 .771 r
F P
0 g
s
.54634 .54468 m .54757 .60169 L .63626 .58856 L p .652 .465 .618 r
F P
0 g
s
.63626 .58856 m .63011 .53185 L .54634 .54468 L p .652 .465 .618 r
F P
0 g
s
.4068 .46783 m .38044 .51926 L .46084 .54041 L p .745 .667 .774 r
F P
0 g
s
.46084 .54041 m .47239 .48567 L .4068 .46783 L p .745 .667 .774 r
F P
0 g
s
.45709 .59732 m .46084 .54041 L .38044 .51926 L p .78 .572 .618 r
F P
0 g
s
.46084 .54041 m .45709 .59732 L .54757 .60169 L p .718 .517 .618 r
F P
0 g
s
.63011 .53185 m .61095 .47844 L .54242 .48928 L p .678 .608 .771 r
F P
0 g
s
.61095 .47844 m .63011 .53185 L .7053 .50258 L p .64 .587 .779 r
F P
0 g
s
.63011 .53185 m .63626 .58856 L .71604 .55857 L p .574 .408 .619 r
F P
0 g
s
.71604 .55857 m .7053 .50258 L .63011 .53185 L p .574 .408 .619 r
F P
0 g
s
.48869 .44988 m .47239 .48567 L .54242 .48928 L p .643 .758 .933 r
F P
0 g
s
.54242 .48928 m .53686 .45242 L .48869 .44988 L p .643 .758 .933 r
F P
0 g
s
.53686 .45242 m .54242 .48928 L .61095 .47844 L p .659 .77 .932 r
F P
0 g
s
.44384 .43741 m .4068 .46783 L .47239 .48567 L p .63 .743 .929 r
F P
0 g
s
.47239 .48567 m .48869 .44988 L .44384 .43741 L p .63 .743 .929 r
F P
0 g
s
.54539 .64334 m .54757 .60169 L .45709 .59732 L p .672 .316 .363 r
F P
0 g
s
.54757 .60169 m .54539 .64334 L .62574 .63174 L p .566 .228 .355 r
F P
0 g
s
.62574 .63174 m .63626 .58856 L .54757 .60169 L p .566 .228 .355 r
F P
0 g
s
.38044 .51926 m .3719 .57567 L .45709 .59732 L p .78 .572 .618 r
F P
0 g
s
.46336 .63948 m .45709 .59732 L .3719 .57567 L p .761 .382 .338 r
F P
0 g
s
.45709 .59732 m .46336 .63948 L .54539 .64334 L p .672 .316 .363 r
F P
0 g
s
.35156 .43691 m .31202 .48237 L .38044 .51926 L p .774 .705 .786 r
F P
0 g
s
.38044 .51926 m .4068 .46783 L .35156 .43691 L p .774 .705 .786 r
F P
0 g
s
.3719 .57567 m .38044 .51926 L .31202 .48237 L p .845 .636 .62 r
F P
0 g
s
.61095 .47844 m .5839 .44482 L .53686 .45242 L p .659 .77 .932 r
F P
0 g
s
.5839 .44482 m .61095 .47844 L .67202 .45382 L p .676 .777 .926 r
F P
0 g
s
.7053 .50258 m .67202 .45382 L .61095 .47844 L p .64 .587 .779 r
F P
0 g
s
.63626 .58856 m .62574 .63174 L .69774 .60531 L p .416 .093 .307 r
F P
0 g
s
.69774 .60531 m .71604 .55857 L .63626 .58856 L p .416 .093 .307 r
F P
0 g
s
.40662 .41597 m .35156 .43691 L .4068 .46783 L p .623 .727 .922 r
F P
0 g
s
.4068 .46783 m .44384 .43741 L .40662 .41597 L p .623 .727 .922 r
F P
0 g
s
.67202 .45382 m .7053 .50258 L .765 .45857 L p .598 .572 .796 r
F P
0 g
s
.7053 .50258 m .71604 .55857 L .77969 .51336 L p .468 .338 .619 r
F P
0 g
s
.77969 .51336 m .765 .45857 L .7053 .50258 L p .468 .338 .619 r
F P
0 g
s
.31202 .48237 m .29916 .53782 L .3719 .57567 L p .845 .636 .62 r
F P
0 g
s
.38629 .62037 m .3719 .57567 L .29916 .53782 L p .842 .431 .26 r
F P
0 g
s
.3719 .57567 m .38629 .62037 L .46336 .63948 L p .761 .382 .338 r
F P
0 g
s
.67202 .45382 m .62541 .42766 L .5839 .44482 L p .676 .777 .926 r
F P
0 g
s
.62541 .42766 m .67202 .45382 L .71983 .41709 L p .692 .777 .917 r
F P
0 g
s
.765 .45857 m .71983 .41709 L .67202 .45382 L p .598 .572 .796 r
F P
0 g
s
.31235 .39512 m .26247 .43205 L .31202 .48237 L p .8 .75 .807 r
F P
0 g
s
.31202 .48237 m .35156 .43691 L .31235 .39512 L p .8 .75 .807 r
F P
0 g
s
.29916 .53782 m .31202 .48237 L .26247 .43205 L p .917 .718 .618 r
F P
0 g
s
.53097 .44993 m .53686 .45242 L .5839 .44482 L p .201 .729 .786 r
F P
0 g
s
.55545 .44597 m .53097 .44993 L p .5398 .44908 L .201 .729 .786 r
F P
0 g
s
.5839 .44482 m .55545 .44597 L p .5398 .44908 L .201 .729 .786 r
F P
0 g
s
.55545 .44597 m .5839 .44482 L .62541 .42766 L p .465 .891 .865 r
F P
0 g
s
.57683 .43709 m .55545 .44597 L p .56706 .44294 L .465 .891 .865 r
F P
0 g
s
.62541 .42766 m .57683 .43709 L p .56706 .44294 L .465 .891 .865 r
F P
0 g
s
.59287 .42412 m .57683 .43709 L p .59007 .43137 L .704 .977 .915 r
F P
0 g
s
.65725 .40234 m .59287 .42412 L p .59007 .43137 L .704 .977 .915 r
F P
0 g
s
.59287 .42412 m .60181 .40833 L p .59594 .41619 L .747 .922 .562 r
F P
0 g
s
.57683 .43709 m .59287 .42412 L p .5875 .4307 L 0 0 0 r
F P
0 g
s
.57683 .43709 m .62541 .42766 L .65725 .40234 L p .704 .977 .915 r
F P
0 g
s
.53912 .48997 m .57683 .43709 L p .5875 .4307 L 0 0 0 r
F P
0 g
s
.54351 .48647 m .53912 .48997 L p .5421 .48633 L 0 0 0 r
F P
0 g
s
.59287 .42412 m .54351 .48647 L p .5421 .48633 L 0 0 0 r
F P
0 g
s
.54351 .48647 m .59287 .42412 L p .59594 .41619 L .747 .922 .562 r
F P
0 g
s
.54586 .48226 m .54351 .48647 L p .54671 .48218 L .747 .922 .562 r
F P
0 g
s
.60181 .40833 m .54586 .48226 L p .54671 .48218 L .747 .922 .562 r
F P
0 g
s
.57683 .43709 m .53912 .48997 L .53318 .49239 L p .253 0 .074 r
F P
0 g
s
.54586 .48226 m .54591 .47778 L .54499 .48234 L p .887 .797 .31 r
F P
0 g
s
.54351 .48647 m .54586 .48226 L .54495 .48661 L p 0 0 .142 r
F P
0 g
s
.54495 .48661 m .52446 .58471 L .54351 .48647 L p 0 0 .142 r
F P
0 g
s
.54499 .48234 m .52446 .58471 L .54586 .48226 L p .887 .797 .31 r
F P
0 g
s
.55545 .44597 m .57683 .43709 L p .57249 .44259 L .253 0 .074 r
F P
0 g
s
.53318 .49239 m .55545 .44597 L p .57249 .44259 L .253 0 .074 r
F P
0 g
s
.53097 .44993 m .55545 .44597 L p .55257 .45068 L .479 .064 .175 r
F P
0 g
s
.48869 .44988 m .53686 .45242 L p .51105 .44925 L .025 .595 .765 r
F P
0 g
s
.53686 .45242 m .53097 .44993 L .50585 .44861 L p .025 .595 .765 r
F P
0 g
s
.52632 .49347 m .53097 .44993 L p .55257 .45068 L .479 .064 .175 r
F P
0 g
s
.50585 .44861 m .50163 .44892 L p .51105 .44925 L .025 .595 .765 r
F P
0 g
s
.50163 .44892 m .48869 .44988 L p .51105 .44925 L .025 .595 .765 r
F P
0 g
s
.71604 .55857 m .69774 .60531 L .75474 .56564 L p .148 0 .179 r
F P
0 g
s
.75474 .56564 m .77969 .51336 L .71604 .55857 L p .148 0 .179 r
F P
0 g
s
.38093 .38735 m .31235 .39512 L .35156 .43691 L p .621 .712 .911 r
F P
0 g
s
.35156 .43691 m .40662 .41597 L .38093 .38735 L p .621 .712 .911 r
F P
0 g
s
.48261 .44212 m .44384 .43741 L .48869 .44988 L p 0 .531 .822 r
F P
0 g
s
.48869 .44988 m .50585 .44861 L .48261 .44212 L p 0 .531 .822 r
F P
0 g
s
.53945 .65351 m .54539 .64334 L .46336 .63948 L p .283 0 0 r
F P
0 g
s
.54539 .64334 m .53945 .65351 L .59691 .64527 L p .111 0 0 r
F P
0 g
s
.59691 .64527 m .62574 .63174 L .54539 .64334 L p .111 0 0 r
F P
0 g
s
.46361 .43107 m .40662 .41597 L .44384 .43741 L p .067 .518 .898 r
F P
0 g
s
.44384 .43741 m .47308 .44096 L p .46361 .43107 L .067 .518 .898 r
F P
0 g
s
.40662 .41597 m .44966 .42737 L p .45089 .41652 L .217 .517 .914 r
F P
0 g
s
.44966 .42737 m .46361 .43107 L .45089 .41652 L p .217 .517 .914 r
F P
0 g
s
.50411 .48444 m .45636 .42351 L p .46361 .43107 L .616 .137 0 r
F P
0 g
s
.45636 .42351 m .45089 .41652 L .46361 .43107 L p .616 .137 0 r
F P
0 g
s
.47308 .44096 m .48261 .44212 L .46361 .43107 L p .067 .518 .898 r
F P
0 g
s
.50753 .48834 m .46361 .43107 L .48261 .44212 L p .768 .261 0 r
F P
0 g
s
.46361 .43107 m .50449 .48437 L p .50411 .48444 L .616 .137 0 r
F P
0 g
s
.50449 .48437 m .50753 .48834 L .50411 .48444 L p .616 .137 0 r
F P
0 g
s
.50411 .48444 m .52446 .58471 L .50379 .48449 L p .77 .498 0 r
F P
0 g
s
.45089 .41652 m .50044 .47976 L p .50288 .48003 L 0 .123 .671 r
F P
0 g
s
.50044 .47976 m .50411 .48444 L .50288 .48003 L p 0 .123 .671 r
F P
0 g
s
.50379 .48449 m .50288 .48003 L .50411 .48444 L p .77 .498 0 r
F P
0 g
s
.48261 .44212 m .51278 .49134 L .50753 .48834 L p .768 .261 0 r
F P
0 g
s
.50753 .48834 m .52446 .58471 L .50411 .48444 L closepath p .952 .604 .288 r
F P
0 g
s
.50288 .48003 m .52446 .58471 L .50486 .48026 L p 0 0 .457 r
F P
0 g
s
.51278 .49134 m .48261 .44212 L .50585 .44861 L p .718 .25 .139 r
F P
0 g
s
.50486 .48026 m .50399 .47561 L .50288 .48003 L p 0 0 .457 r
F P
0 g
s
.50288 .48003 m .45183 .40821 L p .45089 .41652 L 0 .123 .671 r
F P
0 g
s
.45183 .40821 m .44594 .39991 L .45089 .41652 L p 0 .123 .671 r
F P
0 g
s
.48067 .65077 m .46336 .63948 L .38629 .62037 L p .339 0 0 r
F P
0 g
s
.46336 .63948 m .48067 .65077 L .53945 .65351 L p .283 0 0 r
F P
0 g
s
.71983 .41709 m .65725 .40234 L .62541 .42766 L p .692 .777 .917 r
F P
0 g
s
.65725 .40234 m .71983 .41709 L .74895 .37105 L p .704 .772 .905 r
F P
0 g
s
.71983 .41709 m .765 .45857 L .80248 .40283 L p .552 .565 .821 r
F P
0 g
s
.80248 .40283 m .74895 .37105 L .71983 .41709 L p .552 .565 .821 r
F P
0 g
s
.765 .45857 m .77969 .51336 L .82003 .4559 L p .295 .23 .612 r
F P
0 g
s
.82003 .4559 m .80248 .40283 L .765 .45857 L p .295 .23 .612 r
F P
0 g
s
.26247 .43205 m .24613 .48604 L .29916 .53782 L p .917 .718 .618 r
F P
0 g
s
.32086 .58708 m .29916 .53782 L .24613 .48604 L p .87 .43 .054 r
F P
0 g
s
.29916 .53782 m .32086 .58708 L .38629 .62037 L p .842 .431 .26 r
F P
0 g
s
.62574 .63174 m .59691 .64527 L .64786 .6266 L p 0 0 0 r
F P
0 g
s
.64786 .6266 m .69774 .60531 L .62574 .63174 L p 0 0 0 r
F P
0 g
s
.45089 .41652 m .38093 .38735 L .40662 .41597 L p .217 .517 .914 r
F P
0 g
s
.38629 .62037 m .42578 .63721 L .48067 .65077 L p .339 0 0 r
F P
0 g
s
.42578 .63721 m .38629 .62037 L .32086 .58708 L p 0 .313 .694 r
F P
0 g
s
.36995 .35418 m .29417 .34589 L .31235 .39512 L p .625 .7 .899 r
F P
0 g
s
.31235 .39512 m .38093 .38735 L .36995 .35418 L p .625 .7 .899 r
F P
0 g
s
.26247 .43205 m .31235 .39512 L .29417 .34589 L p .817 .802 .837 r
F P
0 g
s
.29417 .34589 m .23823 .37209 L .26247 .43205 L p .817 .802 .837 r
F P
0 g
s
.24613 .48604 m .26247 .43205 L .23823 .37209 L p .987 .825 .596 r
F P
0 g
s
.77969 .51336 m .75474 .56564 L .79027 .51552 L p 0 0 0 r
F P
0 g
s
.79027 .51552 m .82003 .4559 L .77969 .51336 L p 0 0 0 r
F P
0 g
s
.59287 .42412 m .65725 .40234 L .67582 .37106 L p .825 .953 .9 r
F P
0 g
s
.74895 .37105 m .67582 .37106 L .65725 .40234 L p .704 .772 .905 r
F P
0 g
s
.69774 .60531 m .64786 .6266 L .68732 .5989 L p .558 .928 .787 r
F P
0 g
s
.68732 .5989 m .75474 .56564 L .69774 .60531 L p .558 .928 .787 r
F P
0 g
s
.44594 .39991 m .36995 .35418 L .38093 .38735 L p .355 .518 .88 r
F P
0 g
s
.38093 .38735 m .45089 .41652 L .44594 .39991 L p .355 .518 .88 r
F P
0 g
s
.67582 .37106 m .74895 .37105 L .75498 .31981 L p .711 .762 .893 r
F P
0 g
s
.74895 .37105 m .80248 .40283 L .81181 .34002 L p .499 .568 .856 r
F P
0 g
s
.81181 .34002 m .75498 .31981 L .74895 .37105 L p .499 .568 .856 r
F P
0 g
s
.24613 .48604 m .27367 .54177 L .32086 .58708 L p .87 .43 .054 r
F P
0 g
s
.37989 .61383 m .32086 .58708 L .27367 .54177 L p 0 .398 .847 r
F P
0 g
s
.32086 .58708 m .37989 .61383 L .42578 .63721 L p 0 .313 .694 r
F P
0 g
s
.51927 .49311 m .50585 .44861 L .53097 .44993 L p .618 .183 .192 r
F P
0 g
s
.53097 .44993 m .52632 .49347 L .51927 .49311 L p .618 .183 .192 r
F P
0 g
s
.50585 .44861 m .51927 .49311 L .51278 .49134 L p .718 .25 .139 r
F P
0 g
s
.23823 .37209 m .21977 .42412 L .24613 .48604 L p .987 .825 .596 r
F P
0 g
s
.27367 .54177 m .24613 .48604 L .21977 .42412 L p 0 0 .366 r
F P
0 g
s
.80248 .40283 m .82003 .4559 L .8306 .39089 L p 0 .025 .551 r
F P
0 g
s
.8306 .39089 m .81181 .34002 L .80248 .40283 L p 0 .025 .551 r
F P
0 g
s
.55545 .44597 m .53318 .49239 L .52632 .49347 L p .479 .064 .175 r
F P
0 g
s
.67582 .37106 m .60181 .40833 L .59287 .42412 L p .825 .953 .9 r
F P
0 g
s
.60181 .40833 m .67582 .37106 L .67852 .33682 L p .854 .881 .858 r
F P
0 g
s
.75498 .31981 m .67852 .33682 L .67582 .37106 L p .711 .762 .893 r
F P
0 g
s
.37563 .3198 m .30065 .29398 L .29417 .34589 L p .633 .692 .887 r
F P
0 g
s
.29417 .34589 m .36995 .35418 L .37563 .3198 L p .633 .692 .887 r
F P
0 g
s
.23823 .37209 m .29417 .34589 L .30065 .29398 L p .819 .858 .877 r
F P
0 g
s
.53007 .6197 m .53945 .65351 L .48067 .65077 L p .486 .805 1 r
F P
0 g
s
.53945 .65351 m .53007 .6197 L .55151 .61656 L p .549 .849 .998 r
F P
0 g
s
.55151 .61656 m .59691 .64527 L .53945 .65351 L p .549 .849 .998 r
F P
0 g
s
.44949 .383 m .37563 .3198 L .36995 .35418 L p .459 .524 .837 r
F P
0 g
s
.36995 .35418 m .44594 .39991 L .44949 .383 L p .459 .524 .837 r
F P
0 g
s
.75474 .56564 m .68732 .5989 L .71084 .56444 L p .803 .993 .873 r
F P
0 g
s
.71084 .56444 m .79027 .51552 L .75474 .56564 L p .803 .993 .873 r
F P
0 g
s
.50807 .61865 m .48067 .65077 L .42578 .63721 L p .453 .757 .994 r
F P
0 g
s
.48772 .61351 m .50807 .61865 L p .50323 .61974 L .453 .757 .994 r
F P
0 g
s
.42578 .63721 m .48772 .61351 L p .50323 .61974 L .453 .757 .994 r
F P
0 g
s
.47112 .60475 m .48772 .61351 L p .48145 .61352 L .452 .714 .98 r
F P
0 g
s
.37989 .61383 m .47112 .60475 L p .48145 .61352 L .452 .714 .98 r
F P
0 g
s
.46005 .59324 m .47112 .60475 L p .46404 .60347 L .476 .68 .955 r
F P
0 g
s
.34778 .58242 m .46005 .59324 L p .46404 .60347 L .476 .68 .955 r
F P
0 g
s
.4558 .58013 m .46005 .59324 L p .45289 .59055 L .511 .657 .925 r
F P
0 g
s
.33349 .54573 m .4558 .58013 L p .45289 .59055 L .511 .657 .925 r
F P
0 g
s
.4558 .58013 m .45898 .56682 L p .45835 .571 L 0 0 .167 r
F P
0 g
s
.46005 .59324 m .4558 .58013 L p .45655 .58427 L .959 .734 .284 r
F P
0 g
s
.46005 .59324 m .34778 .58242 L .33349 .54573 L p .511 .657 .925 r
F P
0 g
s
.45559 .58933 m .45986 .6024 L p .45911 .5983 L .959 .734 .284 r
F P
0 g
s
.4558 .58013 m .45559 .58933 L p .45911 .5983 L .959 .734 .284 r
F P
0 g
s
.45559 .58933 m .4558 .58013 L p .45835 .571 L 0 0 .167 r
F P
0 g
s
.45986 .6024 m .46005 .59324 L p .45655 .58427 L .959 .734 .284 r
F P
0 g
s
.4558 .58013 m .33349 .54573 L .33972 .50739 L p .55 .644 .895 r
F P
0 g
s
.33972 .50739 m .45898 .56682 L .4558 .58013 L p .55 .644 .895 r
F P
0 g
s
.45878 .57605 m .45559 .58933 L p .45622 .58518 L 0 0 .167 r
F P
0 g
s
.45898 .56682 m .45878 .57605 L p .45622 .58518 L 0 0 .167 r
F P
0 g
s
.45878 .57605 m .45898 .56682 L .46941 .55477 L p .148 .013 .428 r
F P
0 g
s
.46924 .56402 m .45878 .57605 L p .46074 .57212 L .148 .013 .428 r
F P
0 g
s
.46941 .55477 m .46924 .56402 L p .46074 .57212 L .148 .013 .428 r
F P
0 g
s
.48594 .55465 m .46924 .56402 L p .47235 .56058 L .42 .221 .503 r
F P
0 g
s
.48607 .54536 m .48594 .55465 L p .47235 .56058 L .42 .221 .503 r
F P
0 g
s
.50707 .54903 m .48594 .55465 L p .48986 .55189 L .567 .337 .527 r
F P
0 g
s
.50713 .53974 m .50707 .54903 L p .48986 .55189 L .567 .337 .527 r
F P
0 g
s
.52632 .49347 m .52446 .58471 L .51927 .49311 L closepath p .7 .405 .473 r
F P
0 g
s
.53318 .49239 m .52446 .58471 L .52632 .49347 L closepath p .602 .324 .468 r
F P
0 g
s
.51927 .49311 m .52446 .58471 L .51278 .49134 L closepath p .788 .475 .459 r
F P
0 g
s
.53912 .48997 m .52446 .58471 L .53318 .49239 L closepath p .468 .212 .442 r
F P
0 g
s
.51278 .49134 m .52446 .58471 L .50753 .48834 L closepath p .878 .544 .415 r
F P
0 g
s
.54351 .48647 m .52446 .58471 L .53912 .48997 L closepath p .24 .021 .367 r
F P
0 g
s
.50399 .47561 m .52446 .58471 L .50735 .47164 L closepath p .284 .186 .563 r
F P
0 g
s
.53926 .46997 m .52446 .58471 L .54363 .47353 L closepath p .911 .683 .579 r
F P
0 g
s
.50735 .47164 m .52446 .58471 L .51259 .46858 L closepath p .478 .32 .587 r
F P
0 g
s
.53326 .46749 m .52446 .58471 L .53926 .46997 L closepath p .829 .6 .591 r
F P
0 g
s
.51259 .46858 m .52446 .58471 L .51915 .46675 L closepath p .595 .404 .593 r
F P
0 g
s
.52631 .46638 m .52446 .58471 L .53326 .46749 L closepath p .755 .532 .594 r
F P
0 g
s
.51915 .46675 m .52446 .58471 L .52631 .46638 L closepath p .68 .47 .595 r
F P
0 g
s
.5302 .53857 m .53021 .54787 L .50707 .54903 L p .668 .419 .535 r
F P
0 g
s
.50707 .54903 m .53021 .54787 L p .52713 .5457 L .527 .827 .999 r
F P
0 g
s
.50399 .47561 m .44949 .383 L .44594 .39991 L p .234 .295 .722 r
F P
0 g
s
.44594 .39991 m .50288 .48003 L .50399 .47561 L p .234 .295 .722 r
F P
0 g
s
.4741 .4259 m .50713 .53974 L .48607 .54536 L p .656 .657 .839 r
F P
0 g
s
.48607 .54536 m .41358 .44324 L .4741 .4259 L p .656 .657 .839 r
F P
0 g
s
.48594 .55465 m .48607 .54536 L .50713 .53974 L p .567 .337 .527 r
F P
0 g
s
.55692 .35139 m .53326 .46749 L .53926 .46997 L p .808 .652 .689 r
F P
0 g
s
.53326 .46749 m .55692 .35139 L .53117 .34699 L p .75 .594 .682 r
F P
0 g
s
.53117 .34699 m .52631 .46638 L .53326 .46749 L p .75 .594 .682 r
F P
0 g
s
.54118 .42228 m .5302 .53857 L .50713 .53974 L p .686 .676 .834 r
F P
0 g
s
.50735 .47164 m .46139 .36766 L .44949 .383 L p .429 .386 .709 r
F P
0 g
s
.44949 .383 m .50399 .47561 L .50735 .47164 L p .429 .386 .709 r
F P
0 g
s
.51259 .46858 m .48047 .35567 L .46139 .36766 L p .545 .447 .694 r
F P
0 g
s
.46139 .36766 m .50735 .47164 L .51259 .46858 L p .545 .447 .694 r
F P
0 g
s
.51915 .46675 m .50466 .34848 L .48047 .35567 L p .626 .496 .684 r
F P
0 g
s
.48047 .35567 m .51259 .46858 L .51915 .46675 L p .626 .496 .684 r
F P
0 g
s
.52631 .46638 m .53117 .34699 L .50466 .34848 L p .691 .543 .681 r
F P
0 g
s
.50466 .34848 m .51915 .46675 L .52631 .46638 L p .691 .543 .681 r
F P
0 g
s
.50713 .53974 m .4741 .4259 L .54118 .42228 L p .686 .676 .834 r
F P
0 g
s
.50707 .54903 m .50713 .53974 L .5302 .53857 L p .668 .419 .535 r
F P
0 g
s
.47266 .50734 m .50707 .54903 L p .52713 .5457 L .527 .827 .999 r
F P
0 g
s
.48594 .55465 m .50707 .54903 L p .50186 .5477 L .597 .865 .993 r
F P
0 g
s
.36711 .47172 m .46941 .55477 L .45898 .56682 L p .588 .64 .87 r
F P
0 g
s
.45898 .56682 m .33972 .50739 L .36711 .47172 L p .588 .64 .87 r
F P
0 g
s
.41358 .44324 m .48607 .54536 L .46941 .55477 L p .623 .645 .851 r
F P
0 g
s
.46941 .55477 m .36711 .47172 L .41358 .44324 L p .623 .645 .851 r
F P
0 g
s
.46924 .56402 m .46941 .55477 L .48607 .54536 L p .42 .221 .503 r
F P
0 g
s
.4105 .52436 m .48594 .55465 L p .50186 .5477 L .597 .865 .993 r
F P
0 g
s
.46924 .56402 m .48594 .55465 L p .47922 .55452 L .668 .881 .977 r
F P
0 g
s
.36283 .5523 m .46924 .56402 L p .47922 .55452 L .668 .881 .977 r
F P
0 g
s
.45878 .57605 m .46924 .56402 L p .46179 .56531 L .723 .874 .952 r
F P
0 g
s
.27367 .54177 m .34778 .58242 L .37989 .61383 L p 0 .398 .847 r
F P
0 g
s
.47112 .60475 m .37989 .61383 L .34778 .58242 L p .476 .68 .955 r
F P
0 g
s
.33481 .58725 m .45878 .57605 L p .46179 .56531 L .723 .874 .952 r
F P
0 g
s
.45559 .58933 m .45878 .57605 L p .45146 .57879 L .754 .849 .922 r
F P
0 g
s
.32853 .62478 m .45559 .58933 L p .45146 .57879 L .754 .849 .922 r
F P
0 g
s
.47112 .60475 m .46005 .59324 L p .46208 .59707 L .961 .688 .472 r
F P
0 g
s
.48772 .61351 m .42578 .63721 L .37989 .61383 L p .452 .714 .98 r
F P
0 g
s
.47096 .61388 m .47112 .60475 L p .46208 .59707 L .961 .688 .472 r
F P
0 g
s
.48772 .61351 m .47112 .60475 L p .47418 .60806 L .873 .601 .525 r
F P
0 g
s
.48761 .62261 m .48772 .61351 L p .47418 .60806 L .873 .601 .525 r
F P
0 g
s
.50807 .61865 m .48772 .61351 L p .49147 .61614 L .79 .529 .542 r
F P
0 g
s
.48067 .65077 m .50807 .61865 L p .52715 .62154 L .486 .805 1 r
F P
0 g
s
.50801 .62775 m .50807 .61865 L p .49147 .61614 L .79 .529 .542 r
F P
0 g
s
.50807 .61865 m .53007 .6197 L p .52715 .62154 L .486 .805 1 r
F P
0 g
s
.59691 .64527 m .55151 .61656 L .57021 .60951 L p .626 .879 .988 r
F P
0 g
s
.57021 .60951 m .64786 .6266 L .59691 .64527 L p .626 .879 .988 r
F P
0 g
s
.30065 .29398 m .24444 .30805 L .23823 .37209 L p .819 .858 .877 r
F P
0 g
s
.21977 .42412 m .23823 .37209 L .24444 .30805 L p .917 .878 .451 r
F P
0 g
s
.82003 .4559 m .79027 .51552 L .79879 .45918 L p .919 .923 .543 r
F P
0 g
s
.79879 .45918 m .8306 .39089 L .82003 .4559 L p .919 .923 .543 r
F P
0 g
s
.67852 .33682 m .60249 .39134 L .60181 .40833 L p .854 .881 .858 r
F P
0 g
s
.60249 .39134 m .67852 .33682 L .66419 .30328 L p .84 .806 .818 r
F P
0 g
s
.67852 .33682 m .75498 .31981 L .73536 .26871 L p .712 .75 .881 r
F P
0 g
s
.73536 .26871 m .66419 .30328 L .67852 .33682 L p .712 .75 .881 r
F P
0 g
s
.75498 .31981 m .81181 .34002 L .78907 .27656 L p .441 .584 .9 r
F P
0 g
s
.78907 .27656 m .73536 .26871 L .75498 .31981 L p .441 .584 .9 r
F P
0 g
s
.54586 .48226 m .60181 .40833 L .60249 .39134 L p .958 .941 .715 r
F P
0 g
s
.47956 .72737 m .45956 .83054 L .54653 .83415 L p .716 .624 .753 r
F P
0 g
s
.54653 .83415 m .53977 .73005 L .47956 .72737 L p .716 .624 .753 r
F P
0 g
s
.54975 .92341 m .54653 .83415 L .45956 .83054 L p .72 .555 .665 r
F P
0 g
s
.53977 .73005 m .54653 .83415 L .63176 .8233 L p .671 .589 .755 r
F P
0 g
s
.54653 .83415 m .54975 .92341 L .64765 .91174 L p .66 .507 .666 r
F P
0 g
s
.64765 .91174 m .63176 .8233 L .54653 .83415 L p .66 .507 .666 r
F P
0 g
s
.42333 .71415 m .37773 .81266 L .45956 .83054 L p .759 .665 .759 r
F P
0 g
s
.45956 .83054 m .47956 .72737 L .42333 .71415 L p .759 .665 .759 r
F P
0 g
s
.44995 .91954 m .45956 .83054 L .37773 .81266 L p .778 .607 .668 r
F P
0 g
s
.45956 .83054 m .44995 .91954 L .54975 .92341 L p .72 .555 .665 r
F P
0 g
s
.21977 .42412 m .25087 .48793 L .27367 .54177 L p 0 0 .366 r
F P
0 g
s
.34778 .58242 m .27367 .54177 L .25087 .48793 L p .225 .455 .872 r
F P
0 g
s
.64786 .6266 m .57021 .60951 L .5842 .59925 L p .694 .885 .968 r
F P
0 g
s
.5842 .59925 m .68732 .5989 L .64786 .6266 L p .694 .885 .968 r
F P
0 g
s
.46139 .36766 m .39821 .28807 L .37563 .3198 L p .537 .538 .803 r
F P
0 g
s
.37563 .3198 m .44949 .383 L .46139 .36766 L p .537 .538 .803 r
F P
0 g
s
.30065 .29398 m .37563 .3198 L .39821 .28807 L p .644 .688 .876 r
F P
0 g
s
.63176 .8233 m .59862 .72201 L .53977 .73005 L p .671 .589 .755 r
F P
0 g
s
.59862 .72201 m .63176 .8233 L .70831 .79856 L p .62 .56 .765 r
F P
0 g
s
.63176 .8233 m .64765 .91174 L .73611 .88501 L p .589 .459 .671 r
F P
0 g
s
.73611 .88501 m .70831 .79856 L .63176 .8233 L p .589 .459 .671 r
F P
0 g
s
.54916 .98014 m .54975 .92341 L .44995 .91954 L p .704 .43 .508 r
F P
0 g
s
.54975 .92341 m .54916 .98014 L .64493 .96921 L p .622 .363 .505 r
F P
0 g
s
.64493 .96921 m .64765 .91174 L .54975 .92341 L p .622 .363 .505 r
F P
0 g
s
.60249 .39134 m .54591 .47778 L .54586 .48226 L p .958 .941 .715 r
F P
0 g
s
.54591 .47778 m .60249 .39134 L .59463 .37498 L p .931 .824 .718 r
F P
0 g
s
.66419 .30328 m .59463 .37498 L .60249 .39134 L p .84 .806 .818 r
F P
0 g
s
.37773 .81266 m .35574 .90026 L .44995 .91954 L p .778 .607 .668 r
F P
0 g
s
.45152 .9765 m .44995 .91954 L .35574 .90026 L p .779 .492 .5 r
F P
0 g
s
.44995 .91954 m .45152 .9765 L .54916 .98014 L p .704 .43 .508 r
F P
0 g
s
.50801 .62775 m .47956 .72737 L .53977 .73005 L p .7 .685 .832 r
F P
0 g
s
.53977 .73005 m .53008 .62879 L .50801 .62775 L p .7 .685 .832 r
F P
0 g
s
.53008 .62879 m .53977 .73005 L .59862 .72201 L p .672 .664 .834 r
F P
0 g
s
.81181 .34002 m .8306 .39089 L .80699 .32493 L p 0 0 .255 r
F P
0 g
s
.80699 .32493 m .78907 .27656 L .81181 .34002 L p 0 0 .255 r
F P
0 g
s
.39821 .28807 m .33302 .24525 L .30065 .29398 L p .644 .688 .876 r
F P
0 g
s
.24444 .30805 m .30065 .29398 L .33302 .24525 L p .79 .907 .922 r
F P
0 g
s
.24444 .30805 m .22572 .35769 L .21977 .42412 L p .917 .878 .451 r
F P
0 g
s
.25087 .48793 m .21977 .42412 L .22572 .35769 L p .01 .114 .626 r
F P
0 g
s
.48761 .62261 m .42333 .71415 L .47956 .72737 L p .725 .711 .837 r
F P
0 g
s
.47956 .72737 m .50801 .62775 L .48761 .62261 L p .725 .711 .837 r
F P
0 g
s
.59463 .37498 m .66419 .30328 L .63363 .27438 L p .81 .742 .789 r
F P
0 g
s
.66419 .30328 m .73536 .26871 L .69047 .22397 L p .71 .736 .872 r
F P
0 g
s
.69047 .22397 m .63363 .27438 L .66419 .30328 L p .71 .736 .872 r
F P
0 g
s
.37628 .69132 m .30803 .78146 L .37773 .81266 L p .798 .716 .773 r
F P
0 g
s
.37773 .81266 m .42333 .71415 L .37628 .69132 L p .798 .716 .773 r
F P
0 g
s
.35574 .90026 m .37773 .81266 L .30803 .78146 L p .837 .67 .676 r
F P
0 g
s
.59862 .72201 m .55158 .62566 L .53008 .62879 L p .672 .664 .834 r
F P
0 g
s
.55158 .62566 m .59862 .72201 L .65083 .7038 L p .642 .65 .842 r
F P
0 g
s
.70831 .79856 m .65083 .7038 L .59862 .72201 L p .62 .56 .765 r
F P
0 g
s
.64765 .91174 m .64493 .96921 L .73137 .94419 L p .518 .278 .49 r
F P
0 g
s
.73137 .94419 m .73611 .88501 L .64765 .91174 L p .518 .278 .49 r
F P
0 g
s
.59463 .37498 m .54363 .47353 L .54591 .47778 L p .931 .824 .718 r
F P
0 g
s
.54363 .47353 m .59463 .37498 L .57889 .36112 L p .869 .726 .701 r
F P
0 g
s
.63363 .27438 m .57889 .36112 L .59463 .37498 L p .81 .742 .789 r
F P
0 g
s
.79027 .51552 m .71084 .56444 L .71497 .52642 L p .873 .926 .857 r
F P
0 g
s
.71497 .52642 m .79879 .45918 L .79027 .51552 L p .873 .926 .857 r
F P
0 g
s
.68732 .5989 m .5842 .59925 L .59194 .58677 L p .74 .869 .94 r
F P
0 g
s
.59194 .58677 m .71084 .56444 L .68732 .5989 L p .74 .869 .94 r
F P
0 g
s
.39821 .28807 m .46139 .36766 L .48047 .35567 L p .599 .557 .779 r
F P
0 g
s
.47096 .61388 m .37628 .69132 L .42333 .71415 L p .745 .742 .849 r
F P
0 g
s
.42333 .71415 m .48761 .62261 L .47096 .61388 L p .745 .742 .849 r
F P
0 g
s
.48047 .35567 m .43581 .26292 L .39821 .28807 L p .599 .557 .779 r
F P
0 g
s
.33302 .24525 m .39821 .28807 L .43581 .26292 L p .657 .688 .868 r
F P
0 g
s
.65083 .7038 m .70831 .79856 L .76918 .76132 L p .56 .535 .784 r
F P
0 g
s
.70831 .79856 m .73611 .88501 L .80728 .84453 L p .496 .405 .682 r
F P
0 g
s
.80728 .84453 m .76918 .76132 L .70831 .79856 L p .496 .405 .682 r
F P
0 g
s
.57889 .36112 m .53926 .46997 L .54363 .47353 L p .869 .726 .701 r
F P
0 g
s
.53926 .46997 m .57889 .36112 L .55692 .35139 L p .808 .652 .689 r
F P
0 g
s
.57889 .36112 m .63363 .27438 L .58986 .25386 L p .774 .69 .771 r
F P
0 g
s
.58986 .25386 m .55692 .35139 L .57889 .36112 L p .774 .69 .771 r
F P
0 g
s
.73536 .26871 m .78907 .27656 L .73394 .22032 L p .385 .619 .944 r
F P
0 g
s
.73394 .22032 m .69047 .22397 L .73536 .26871 L p .385 .619 .944 r
F P
0 g
s
.30803 .78146 m .27479 .86646 L .35574 .90026 L p .837 .67 .676 r
F P
0 g
s
.3594 .95846 m .35574 .90026 L .27479 .86646 L p .858 .555 .476 r
F P
0 g
s
.35574 .90026 m .3594 .95846 L .45152 .9765 L p .779 .492 .5 r
F P
0 g
s
.43581 .26292 m .48047 .35567 L .50466 .34848 L p .65 .582 .765 r
F P
0 g
s
.33302 .24525 m .28343 .24715 L .24444 .30805 L p .79 .907 .922 r
F P
0 g
s
.22572 .35769 m .24444 .30805 L .28343 .24715 L p 0 0 0 r
F P
0 g
s
.65083 .7038 m .57033 .61863 L .55158 .62566 L p .642 .65 .842 r
F P
0 g
s
.57033 .61863 m .65083 .7038 L .69133 .67675 L p .609 .641 .858 r
F P
0 g
s
.76918 .76132 m .69133 .67675 L .65083 .7038 L p .56 .535 .784 r
F P
0 g
s
.63363 .27438 m .69047 .22397 L .62442 .19177 L p .703 .722 .865 r
F P
0 g
s
.62442 .19177 m .58986 .25386 L .63363 .27438 L p .703 .722 .865 r
F P
0 g
s
.55692 .35139 m .58986 .25386 L .53795 .24451 L p .735 .647 .761 r
F P
0 g
s
.53795 .24451 m .53117 .34699 L .55692 .35139 L p .735 .647 .761 r
F P
0 g
s
.8306 .39089 m .79879 .45918 L .7767 .40245 L p .974 .851 .658 r
F P
0 g
s
.7767 .40245 m .80699 .32493 L .8306 .39089 L p .974 .851 .658 r
F P
0 g
s
.54508 .98846 m .54916 .98014 L .45152 .9765 L p .312 0 0 r
F P
0 g
s
.54916 .98014 m .54508 .98846 L .62504 .97939 L p .17 0 0 r
F P
0 g
s
.62504 .97939 m .64493 .96921 L .54916 .98014 L p .17 0 0 r
F P
0 g
s
.25087 .48793 m .33349 .54573 L .34778 .58242 L p .225 .455 .872 r
F P
0 g
s
.48435 .24768 m .50466 .34848 L .53117 .34699 L p .694 .611 .759 r
F P
0 g
s
.50466 .34848 m .48435 .24768 L .43581 .26292 L p .65 .582 .765 r
F P
0 g
s
.53117 .34699 m .53795 .24451 L .48435 .24768 L p .694 .611 .759 r
F P
0 g
s
.54363 .47353 m .52446 .58471 L .54591 .47778 L closepath p .991 .787 .531 r
F P
0 g
s
.22572 .35769 m .2572 .43058 L .25087 .48793 L p .01 .114 .626 r
F P
0 g
s
.33349 .54573 m .25087 .48793 L .2572 .43058 L p .391 .489 .839 r
F P
0 g
s
.46343 .98544 m .45152 .9765 L .3594 .95846 L p .362 0 0 r
F P
0 g
s
.45152 .9765 m .46343 .98544 L .54508 .98846 L p .312 0 0 r
F P
0 g
s
.38912 .20603 m .43581 .26292 L .48435 .24768 L p .67 .692 .862 r
F P
0 g
s
.43581 .26292 m .38912 .20603 L .33302 .24525 L p .657 .688 .868 r
F P
0 g
s
.45986 .6024 m .34329 .66065 L .37628 .69132 L p .759 .777 .867 r
F P
0 g
s
.37628 .69132 m .47096 .61388 L .45986 .6024 L p .759 .777 .867 r
F P
0 g
s
.30803 .78146 m .37628 .69132 L .34329 .66065 L p .835 .778 .797 r
F P
0 g
s
.34329 .66065 m .25744 .73886 L .30803 .78146 L p .835 .778 .797 r
F P
0 g
s
.27479 .86646 m .30803 .78146 L .25744 .73886 L p .9 .752 .688 r
F P
0 g
s
.73611 .88501 m .73137 .94419 L .80079 .90634 L p .357 .146 .451 r
F P
0 g
s
.80079 .90634 m .80728 .84453 L .73611 .88501 L p .357 .146 .451 r
F P
0 g
s
.28343 .24715 m .33302 .24525 L .38912 .20603 L p .712 .928 .963 r
F P
0 g
s
.64493 .96921 m .62504 .97939 L .69669 .95872 L p 0 0 0 r
F P
0 g
s
.69669 .95872 m .73137 .94419 L .64493 .96921 L p 0 0 0 r
F P
0 g
s
.58986 .25386 m .62442 .19177 L .54507 .177 L p .694 .71 .861 r
F P
0 g
s
.54507 .177 m .53795 .24451 L .58986 .25386 L p .694 .71 .861 r
F P
0 g
s
.53008 .62879 m .53007 .6197 L .50807 .61865 L p .712 .464 .548 r
F P
0 g
s
.53007 .6197 m .53008 .62879 L .55158 .62566 L p .628 .395 .546 r
F P
0 g
s
.55158 .62566 m .55151 .61656 L .53007 .6197 L p .628 .395 .546 r
F P
0 g
s
.50807 .61865 m .50801 .62775 L .53008 .62879 L p .712 .464 .548 r
F P
0 g
s
.71084 .56444 m .59194 .58677 L .59245 .57338 L p .761 .837 .91 r
F P
0 g
s
.59245 .57338 m .71497 .52642 L .71084 .56444 L p .761 .837 .91 r
F P
0 g
s
.55151 .61656 m .55158 .62566 L .57033 .61863 L p .521 .311 .535 r
F P
0 g
s
.57033 .61863 m .57021 .60951 L .55151 .61656 L p .521 .311 .535 r
F P
0 g
s
.46294 .18202 m .48435 .24768 L .53795 .24451 L p .682 .7 .86 r
F P
0 g
s
.48435 .24768 m .46294 .18202 L .38912 .20603 L p .67 .692 .862 r
F P
0 g
s
.48772 .61351 m .48761 .62261 L .50801 .62775 L p .79 .529 .542 r
F P
0 g
s
.78907 .27656 m .80699 .32493 L .74855 .26622 L p .906 .495 .148 r
F P
0 g
s
.74855 .26622 m .73394 .22032 L .78907 .27656 L p .906 .495 .148 r
F P
0 g
s
.53795 .24451 m .54507 .177 L .46294 .18202 L p .682 .7 .86 r
F P
0 g
s
.69133 .67675 m .58437 .60839 L .57033 .61863 L p .609 .641 .858 r
F P
0 g
s
.58437 .60839 m .69133 .67675 L .71553 .64308 L p .573 .64 .879 r
F P
0 g
s
.69133 .67675 m .76918 .76132 L .8075 .71411 L p .483 .514 .813 r
F P
0 g
s
.8075 .71411 m .71553 .64308 L .69133 .67675 L p .483 .514 .813 r
F P
0 g
s
.57021 .60951 m .57033 .61863 L .58437 .60839 L p .353 .182 .505 r
F P
0 g
s
.58437 .60839 m .5842 .59925 L .57021 .60951 L p .353 .182 .505 r
F P
0 g
s
.47112 .60475 m .47096 .61388 L .48761 .62261 L p .873 .601 .525 r
F P
0 g
s
.69047 .22397 m .73394 .22032 L .6511 .17944 L p .351 .674 .976 r
F P
0 g
s
.6511 .17944 m .62442 .19177 L .69047 .22397 L p .351 .674 .976 r
F P
0 g
s
.27479 .86646 m .28036 .92684 L .3594 .95846 L p .858 .555 .476 r
F P
0 g
s
.38673 .97049 m .3594 .95846 L .28036 .92684 L p .298 0 0 r
F P
0 g
s
.3594 .95846 m .38673 .97049 L .46343 .98544 L p .362 0 0 r
F P
0 g
s
.28343 .24715 m .26677 .29426 L .22572 .35769 L p 0 0 0 r
F P
0 g
s
.2572 .43058 m .22572 .35769 L .26677 .29426 L p .336 .297 .666 r
F P
0 g
s
.79879 .45918 m .71497 .52642 L .69795 .48885 L p .862 .837 .82 r
F P
0 g
s
.69795 .48885 m .7767 .40245 L .79879 .45918 L p .862 .837 .82 r
F P
0 g
s
.25744 .73886 m .21508 .81996 L .27479 .86646 L p .9 .752 .688 r
F P
0 g
s
.28036 .92684 m .27479 .86646 L .21508 .81996 L p .941 .625 .411 r
F P
0 g
s
.76918 .76132 m .80728 .84453 L .85319 .79275 L p .355 .331 .695 r
F P
0 g
s
.85319 .79275 m .8075 .71411 L .76918 .76132 L p .355 .331 .695 r
F P
0 g
s
.46005 .59324 m .45986 .6024 L .47096 .61388 L p .961 .688 .472 r
F P
0 g
s
.5842 .59925 m .58437 .60839 L .59213 .59595 L p .019 0 .406 r
F P
0 g
s
.59213 .59595 m .59194 .58677 L .5842 .59925 L p .019 0 .406 r
F P
0 g
s
.2572 .43058 m .33972 .50739 L .33349 .54573 L p .391 .489 .839 r
F P
0 g
s
.71553 .64308 m .59213 .59595 L .58437 .60839 L p .573 .64 .879 r
F P
0 g
s
.45559 .58933 m .32853 .62478 L .34329 .66065 L p .764 .814 .892 r
F P
0 g
s
.34329 .66065 m .45986 .6024 L .45559 .58933 L p .764 .814 .892 r
F P
0 g
s
.25744 .73886 m .34329 .66065 L .32853 .62478 L p .862 .854 .832 r
F P
0 g
s
.35318 .19758 m .38912 .20603 L .46294 .18202 L p .588 .9 .985 r
F P
0 g
s
.38912 .20603 m .35318 .19758 L .28343 .24715 L p .712 .928 .963 r
F P
0 g
s
.73137 .94419 m .69669 .95872 L .75337 .9277 L p .416 .85 .729 r
F P
0 g
s
.75337 .9277 m .80079 .90634 L .73137 .94419 L p .416 .85 .729 r
F P
0 g
s
.26677 .29426 m .28343 .24715 L .35318 .19758 L p .21 0 .255 r
F P
0 g
s
.59194 .58677 m .59213 .59595 L .59265 .58259 L p 0 0 .068 r
F P
0 g
s
.59265 .58259 m .59245 .57338 L .59194 .58677 L p 0 0 .068 r
F P
0 g
s
.53858 .93958 m .54508 .98846 L .46343 .98544 L p .669 .743 .906 r
F P
0 g
s
.54508 .98846 m .53858 .93958 L .59335 .93313 L p .652 .731 .907 r
F P
0 g
s
.59335 .93313 m .62504 .97939 L .54508 .98846 L p .652 .731 .907 r
F P
0 g
s
.59213 .59595 m .71553 .64308 L .71988 .60588 L p .536 .648 .907 r
F P
0 g
s
.71988 .60588 m .59265 .58259 L .59213 .59595 L p .536 .648 .907 r
F P
0 g
s
.48252 .93743 m .46343 .98544 L .38673 .97049 L p .682 .759 .909 r
F P
0 g
s
.46343 .98544 m .48252 .93743 L .53858 .93958 L p .669 .743 .906 r
F P
0 g
s
.62442 .19177 m .6511 .17944 L .55058 .16056 L p .369 .747 .989 r
F P
0 g
s
.55058 .16056 m .54507 .177 L .62442 .19177 L p .369 .747 .989 r
F P
0 g
s
.71497 .52642 m .59245 .57338 L .58553 .56052 L p .764 .799 .882 r
F P
0 g
s
.58553 .56052 m .69795 .48885 L .71497 .52642 L p .764 .799 .882 r
F P
0 g
s
.32853 .62478 m .23258 .68805 L .25744 .73886 L p .862 .854 .832 r
F P
0 g
s
.21508 .81996 m .25744 .73886 L .23258 .68805 L p .959 .86 .699 r
F P
0 g
s
.80699 .32493 m .7767 .40245 L .72387 .3523 L p .902 .735 .666 r
F P
0 g
s
.72387 .3523 m .74855 .26622 L .80699 .32493 L p .902 .735 .666 r
F P
0 g
s
.52446 .58471 m .54474 .703 L .54004 .70629 L closepath p .396 .262 .579 r
F P
0 g
s
.52446 .58471 m .54726 .69904 L .54474 .703 L closepath p .122 .078 .53 r
F P
0 g
s
.52446 .58471 m .54019 .68747 L .54488 .69082 L closepath p .922 .578 .368 r
F P
0 g
s
.52446 .58471 m .54004 .70629 L .53367 .70857 L closepath p .542 .365 .591 r
F P
0 g
s
.52446 .58471 m .53376 .68513 L .54019 .68747 L closepath p .832 .509 .442 r
F P
0 g
s
.52446 .58471 m .53367 .70857 L .52632 .70959 L closepath p .64 .438 .594 r
F P
0 g
s
.52446 .58471 m .5263 .68409 L .53376 .68513 L closepath p .744 .44 .468 r
F P
0 g
s
.52446 .58471 m .51876 .70925 L .5118 .70758 L closepath p .791 .564 .593 r
F P
0 g
s
.52446 .58471 m .52632 .70959 L .51876 .70925 L closepath p .718 .501 .595 r
F P
0 g
s
.52446 .58471 m .51862 .68444 L .5263 .68409 L closepath p .653 .367 .472 r
F P
0 g
s
.52446 .58471 m .5118 .70758 L .50618 .70476 L closepath p .869 .639 .587 r
F P
0 g
s
.52446 .58471 m .51159 .68616 L .51862 .68444 L closepath p .542 .274 .458 r
F P
0 g
s
.52446 .58471 m .50618 .70476 L .5025 .70109 L closepath p .955 .733 .564 r
F P
0 g
s
.52446 .58471 m .50597 .68905 L .51159 .68616 L closepath p .373 .132 .414 r
F P
0 g
s
.50118 .69695 m .52446 .58471 L .5035 .69581 L p .993 .827 .459 r
F P
0 g
s
.5035 .69581 m .5025 .70109 L .50118 .69695 L p .993 .827 .459 r
F P
0 g
s
.43902 .77933 m .49828 .69836 L p .50118 .69695 L .875 .962 .627 r
F P
0 g
s
.50237 .69278 m .52446 .58471 L .50224 .69184 L p 0 0 0 r
F P
0 g
s
.50224 .69184 m .50118 .69695 L .50237 .69278 L p 0 0 0 r
F P
0 g
s
.49828 .69836 m .50237 .69278 L .50118 .69695 L p .875 .962 .627 r
F P
0 g
s
.50118 .69695 m .44229 .78384 L p .43902 .77933 L .875 .962 .627 r
F P
0 g
s
.44229 .78384 m .43509 .79446 L .43902 .77933 L p .875 .962 .627 r
F P
0 g
s
.375 .79795 m .43449 .77308 L p .43902 .77933 L .695 .982 .859 r
F P
0 g
s
.50237 .69278 m .44597 .76984 L p .45245 .76557 L 0 0 0 r
F P
0 g
s
.44597 .76984 m .43902 .77933 L .45245 .76557 L p 0 0 0 r
F P
0 g
s
.45245 .76557 m .50253 .69395 L p .50237 .69278 L 0 0 0 r
F P
0 g
s
.43509 .79446 m .50118 .69695 L .5025 .70109 L p .962 .897 .713 r
F P
0 g
s
.5025 .70109 m .44081 .80927 L .43509 .79446 L p .962 .897 .713 r
F P
0 g
s
.44081 .80927 m .5025 .70109 L .50618 .70476 L p .909 .78 .707 r
F P
0 g
s
.50597 .68905 m .45245 .76557 L .47411 .7548 L p .144 0 .047 r
F P
0 g
s
.41916 .77589 m .46144 .75966 L p .45245 .76557 L .378 .829 .718 r
F P
0 g
s
.46144 .75966 m .47411 .7548 L .45245 .76557 L p .378 .829 .718 r
F P
0 g
s
.43449 .77308 m .45245 .76557 L .43902 .77933 L p .695 .982 .859 r
F P
0 g
s
.50253 .69395 m .50597 .68905 L .50237 .69278 L p 0 0 0 r
F P
0 g
s
.52446 .58471 m .50237 .69278 L .50597 .68905 L closepath p .045 0 .285 r
F P
0 g
s
.54623 .69385 m .52446 .58471 L .54732 .69483 L p 0 0 .306 r
F P
0 g
s
.54488 .69082 m .54732 .69483 L .54627 .68981 L p .929 .595 .146 r
F P
0 g
s
.54627 .68981 m .52446 .58471 L .54488 .69082 L p .929 .595 .146 r
F P
0 g
s
.54488 .69082 m .54019 .68747 L p .54348 .69183 L .781 .28 0 r
F P
0 g
s
.54732 .69483 m .54488 .69082 L p .5484 .69581 L 0 0 .477 r
F P
0 g
s
.6128 .78679 m .54732 .69483 L p .5484 .69581 L 0 0 .477 r
F P
0 g
s
.54732 .69483 m .54726 .69904 L .54623 .69385 L p 0 0 .306 r
F P
0 g
s
.61192 .80197 m .54726 .69904 L .54732 .69483 L p .011 .181 .693 r
F P
0 g
s
.54732 .69483 m .6128 .78679 L .61192 .80197 L p .011 .181 .693 r
F P
0 g
s
.60397 .77214 m .6128 .78679 L p .6056 .77662 L 0 0 .477 r
F P
0 g
s
.54488 .69082 m .60397 .77214 L p .6056 .77662 L 0 0 .477 r
F P
0 g
s
.60397 .77214 m .54488 .69082 L p .54348 .69183 L .781 .28 0 r
F P
0 g
s
.58614 .7597 m .60397 .77214 L p .59716 .7631 L .781 .28 0 r
F P
0 g
s
.54019 .68747 m .58614 .7597 L p .59716 .7631 L .781 .28 0 r
F P
0 g
s
.54474 .703 m .6017 .81604 L .58347 .82758 L p .48 .409 .699 r
F P
0 g
s
.6017 .81604 m .54474 .703 L .54726 .69904 L p .318 .328 .713 r
F P
0 g
s
.54726 .69904 m .61192 .80197 L .6017 .81604 L p .318 .328 .713 r
F P
0 g
s
.58614 .7597 m .56115 .75095 L p .57558 .75644 L .282 0 0 r
F P
0 g
s
.60397 .77214 m .58614 .7597 L p .60241 .76786 L 0 .382 .801 r
F P
0 g
s
.65321 .78596 m .68892 .81123 L p .68392 .80872 L 0 .382 .801 r
F P
0 g
s
.58614 .7597 m .65321 .78596 L p .68392 .80872 L 0 .382 .801 r
F P
0 g
s
.65321 .78596 m .58614 .7597 L p .57558 .75644 L .282 0 0 r
F P
0 g
s
.68892 .81123 m .60397 .77214 L p .60241 .76786 L 0 .382 .801 r
F P
0 g
s
.60159 .76792 m .65321 .78596 L p .64868 .78423 L .282 0 0 r
F P
0 g
s
.56115 .75095 m .60159 .76792 L p .64868 .78423 L .282 0 0 r
F P
0 g
s
.53367 .70857 m .55926 .83547 L .53157 .83898 L p .658 .517 .681 r
F P
0 g
s
.55926 .83547 m .53367 .70857 L .54004 .70629 L p .582 .467 .687 r
F P
0 g
s
.54004 .70629 m .58347 .82758 L .55926 .83547 L p .582 .467 .687 r
F P
0 g
s
.58347 .82758 m .54004 .70629 L .54474 .703 L p .48 .409 .699 r
F P
0 g
s
.53157 .83898 m .52632 .70959 L .53367 .70857 L p .658 .517 .681 r
F P
0 g
s
.60159 .76792 m .56115 .75095 L .53184 .747 L p .296 0 0 r
F P
0 g
s
.5401 .75968 m .60159 .76792 L p .59813 .76688 L .296 0 0 r
F P
0 g
s
.53184 .747 m .5401 .75968 L p .59813 .76688 L .296 0 0 r
F P
0 g
s
.50317 .83781 m .51876 .70925 L .52632 .70959 L p .722 .567 .679 r
F P
0 g
s
.52632 .70959 m .53157 .83898 L .50317 .83781 L p .722 .567 .679 r
F P
0 g
s
.47686 .83205 m .5118 .70758 L .51876 .70925 L p .782 .623 .683 r
F P
0 g
s
.51876 .70925 m .50317 .83781 L .47686 .83205 L p .782 .623 .683 r
F P
0 g
s
.45531 .82223 m .50618 .70476 L .5118 .70758 L p .844 .691 .693 r
F P
0 g
s
.5118 .70758 m .47686 .83205 L .45531 .82223 L p .844 .691 .693 r
F P
0 g
s
.50618 .70476 m .45531 .82223 L .44081 .80927 L p .909 .78 .707 r
F P
0 g
s
.47655 .76248 m .50163 .74834 L .47411 .7548 L p 0 0 0 r
F P
0 g
s
.50163 .74834 m .47655 .76248 L .5401 .75968 L p .186 0 0 r
F P
0 g
s
.5401 .75968 m .47655 .76248 L p .49142 .75365 L .569 .814 .991 r
F P
0 g
s
.50163 .74834 m .51862 .68444 L .51159 .68616 L p .416 .026 .189 r
F P
0 g
s
.51159 .68616 m .47411 .7548 L .50163 .74834 L p .416 .026 .189 r
F P
0 g
s
.53376 .68513 m .56115 .75095 L .58614 .7597 L p .767 .301 .136 r
F P
0 g
s
.56115 .75095 m .53376 .68513 L .5263 .68409 L p .684 .253 .221 r
F P
0 g
s
.53184 .747 m .5263 .68409 L .51862 .68444 L p .573 .167 .235 r
F P
0 g
s
.51862 .68444 m .50163 .74834 L .53184 .747 L p .573 .167 .235 r
F P
0 g
s
.5263 .68409 m .53184 .747 L .56115 .75095 L p .684 .253 .221 r
F P
0 g
s
.5401 .75968 m .53184 .747 L .50163 .74834 L p .186 0 0 r
F P
0 g
s
.54882 .71955 m .5401 .75968 L p .49142 .75365 L .569 .814 .991 r
F P
0 g
s
.60159 .76792 m .5401 .75968 L p .56163 .75407 L .548 .794 .99 r
F P
0 g
s
.58614 .7597 m .54019 .68747 L .53376 .68513 L p .767 .301 .136 r
F P
0 g
s
.64392 .73263 m .60159 .76792 L p .56163 .75407 L .548 .794 .99 r
F P
0 g
s
.65321 .78596 m .60159 .76792 L p .62694 .76647 L .538 .773 .985 r
F P
0 g
s
.7225 .76103 m .65321 .78596 L p .62694 .76647 L .538 .773 .985 r
F P
0 g
s
.26677 .29426 m .29473 .3762 L .2572 .43058 L p .336 .297 .666 r
F P
0 g
s
.33972 .50739 m .2572 .43058 L .29473 .3762 L p .501 .515 .803 r
F P
0 g
s
.80728 .84453 m .80079 .90634 L .84537 .85799 L p .043 0 .338 r
F P
0 g
s
.84537 .85799 m .85319 .79275 L .80728 .84453 L p .043 0 .338 r
F P
0 g
s
.71553 .64308 m .8075 .71411 L .81718 .66084 L p .377 .497 .853 r
F P
0 g
s
.81718 .66084 m .71988 .60588 L .71553 .64308 L p .377 .497 .853 r
F P
0 g
s
.62504 .97939 m .59335 .93313 L .64186 .91852 L p .632 .722 .912 r
F P
0 g
s
.64186 .91852 m .69669 .95872 L .62504 .97939 L p .632 .722 .912 r
F P
0 g
s
.44632 .16699 m .46294 .18202 L .54507 .177 L p .455 .83 .991 r
F P
0 g
s
.46294 .18202 m .44632 .16699 L .35318 .19758 L p .588 .9 .985 r
F P
0 g
s
.59245 .57338 m .59265 .58259 L .5857 .56976 L p .984 .715 .339 r
F P
0 g
s
.5857 .56976 m .58553 .56052 L .59245 .57338 L p .984 .715 .339 r
F P
0 g
s
.54507 .177 m .55058 .16056 L .44632 .16699 L p .455 .83 .991 r
F P
0 g
s
.59265 .58259 m .71988 .60588 L .70251 .56909 L p .5 .667 .937 r
F P
0 g
s
.70251 .56909 m .5857 .56976 L .59265 .58259 L p .5 .667 .937 r
F P
0 g
s
.21508 .81996 m .22221 .88339 L .28036 .92684 L p .941 .625 .411 r
F P
0 g
s
.28036 .92684 m .32163 .94447 L .38673 .97049 L p .298 0 0 r
F P
0 g
s
.32163 .94447 m .28036 .92684 L .22221 .88339 L p 0 .391 .815 r
F P
0 g
s
.73394 .22032 m .74855 .26622 L .6601 .22341 L p .841 .456 .32 r
F P
0 g
s
.6601 .22341 m .6511 .17944 L .73394 .22032 L p .841 .456 .32 r
F P
0 g
s
.43022 .92682 m .38673 .97049 L .32163 .94447 L p .692 .777 .917 r
F P
0 g
s
.38673 .97049 m .43022 .92682 L .48252 .93743 L p .682 .759 .909 r
F P
0 g
s
.45878 .57605 m .33481 .58725 L .32853 .62478 L p .754 .849 .922 r
F P
0 g
s
.29473 .3762 m .36711 .47172 L .33972 .50739 L p .501 .515 .803 r
F P
0 g
s
.69795 .48885 m .58553 .56052 L .57176 .54963 L p .753 .762 .86 r
F P
0 g
s
.58553 .56052 m .5857 .56976 L .5719 .5589 L p .929 .642 .477 r
F P
0 g
s
.5719 .5589 m .57176 .54963 L .58553 .56052 L p .929 .642 .477 r
F P
0 g
s
.23258 .68805 m .32853 .62478 L .33481 .58725 L p .858 .937 .874 r
F P
0 g
s
.5857 .56976 m .70251 .56909 L .66409 .53712 L p .472 .696 .966 r
F P
0 g
s
.66409 .53712 m .5719 .5589 L .5857 .56976 L p .472 .696 .966 r
F P
0 g
s
.35318 .19758 m .34102 .24242 L .26677 .29426 L p .21 0 .255 r
F P
0 g
s
.29473 .3762 m .26677 .29426 L .34102 .24242 L p .503 .395 .664 r
F P
0 g
s
.7767 .40245 m .69795 .48885 L .66046 .45624 L p .826 .76 .789 r
F P
0 g
s
.66046 .45624 m .72387 .3523 L .7767 .40245 L p .826 .76 .789 r
F P
0 g
s
.8075 .71411 m .85319 .79275 L .86634 .7337 L p .096 .207 .691 r
F P
0 g
s
.86634 .7337 m .81718 .66084 L .8075 .71411 L p .096 .207 .691 r
F P
0 g
s
.46924 .56402 m .36283 .5523 L .33481 .58725 L p .723 .874 .952 r
F P
0 g
s
.57176 .54963 m .66046 .45624 L .69795 .48885 L p .753 .762 .86 r
F P
0 g
s
.66046 .45624 m .57176 .54963 L .55261 .54201 L p .736 .728 .844 r
F P
0 g
s
.57176 .54963 m .5719 .5589 L .55269 .5513 L p .837 .56 .518 r
F P
0 g
s
.55269 .5513 m .55261 .54201 L .57176 .54963 L p .837 .56 .518 r
F P
0 g
s
.23258 .68805 m .18446 .76394 L .21508 .81996 L p .959 .86 .699 r
F P
0 g
s
.22221 .88339 m .21508 .81996 L .18446 .76394 L p .95 .654 .211 r
F P
0 g
s
.34102 .24242 m .35318 .19758 L .44632 .16699 L p .472 .16 .356 r
F P
0 g
s
.69669 .95872 m .64186 .91852 L .67934 .89688 L p .611 .719 .922 r
F P
0 g
s
.67934 .89688 m .75337 .9277 L .69669 .95872 L p .611 .719 .922 r
F P
0 g
s
.5719 .5589 m .66409 .53712 L .60826 .51424 L p .461 .735 .987 r
F P
0 g
s
.60826 .51424 m .55269 .5513 L .5719 .5589 L p .461 .735 .987 r
F P
0 g
s
.55261 .54201 m .60607 .43293 L .66046 .45624 L p .736 .728 .844 r
F P
0 g
s
.60607 .43293 m .55261 .54201 L .5302 .53857 L p .713 .699 .836 r
F P
0 g
s
.55261 .54201 m .55269 .5513 L .53021 .54787 L p .753 .489 .532 r
F P
0 g
s
.53021 .54787 m .5302 .53857 L .55261 .54201 L p .753 .489 .532 r
F P
0 g
s
.53157 .83898 m .53858 .93958 L .48252 .93743 L p .716 .635 .766 r
F P
0 g
s
.53858 .93958 m .53157 .83898 L .55926 .83547 L p .667 .598 .768 r
F P
0 g
s
.55926 .83547 m .59335 .93313 L .53858 .93958 L p .667 .598 .768 r
F P
0 g
s
.80079 .90634 m .75337 .9277 L .78869 .88852 L p .707 .985 .872 r
F P
0 g
s
.78869 .88852 m .84537 .85799 L .80079 .90634 L p .707 .985 .872 r
F P
0 g
s
.48594 .55465 m .4105 .52436 L .36283 .5523 L p .668 .881 .977 r
F P
0 g
s
.50317 .83781 m .48252 .93743 L .43022 .92682 L p .761 .679 .772 r
F P
0 g
s
.48252 .93743 m .50317 .83781 L .53157 .83898 L p .716 .635 .766 r
F P
0 g
s
.5302 .53857 m .54118 .42228 L .60607 .43293 L p .713 .699 .836 r
F P
0 g
s
.55269 .5513 m .60826 .51424 L .54159 .50379 L p .478 .781 .997 r
F P
0 g
s
.54159 .50379 m .53021 .54787 L .55269 .5513 L p .478 .781 .997 r
F P
0 g
s
.71988 .60588 m .81718 .66084 L .79417 .60696 L p .225 .48 .89 r
F P
0 g
s
.79417 .60696 m .70251 .56909 L .71988 .60588 L p .225 .48 .89 r
F P
0 g
s
.50707 .54903 m .47266 .50734 L .4105 .52436 L p .597 .865 .993 r
F P
0 g
s
.53021 .54787 m .54159 .50379 L .47266 .50734 L p .527 .827 .999 r
F P
0 g
s
.59335 .93313 m .55926 .83547 L .58347 .82758 L p .612 .566 .779 r
F P
0 g
s
.58347 .82758 m .64186 .91852 L .59335 .93313 L p .612 .566 .779 r
F P
0 g
s
.6511 .17944 m .6601 .22341 L .55241 .2036 L p .738 .382 .377 r
F P
0 g
s
.55241 .2036 m .55058 .16056 L .6511 .17944 L p .738 .382 .377 r
F P
0 g
s
.22221 .88339 m .2747 .90905 L .32163 .94447 L p 0 .391 .815 r
F P
0 g
s
.38657 .90853 m .32163 .94447 L .2747 .90905 L p .695 .796 .927 r
F P
0 g
s
.32163 .94447 m .38657 .90853 L .43022 .92682 L p .692 .777 .917 r
F P
0 g
s
.34102 .24242 m .36138 .33206 L .29473 .3762 L p .503 .395 .664 r
F P
0 g
s
.36711 .47172 m .29473 .3762 L .36138 .33206 L p .58 .543 .778 r
F P
0 g
s
.74855 .26622 m .72387 .3523 L .64486 .31593 L p .827 .648 .661 r
F P
0 g
s
.64486 .31593 m .6601 .22341 L .74855 .26622 L p .827 .648 .661 r
F P
0 g
s
.36138 .33206 m .41358 .44324 L .36711 .47172 L p .58 .543 .778 r
F P
0 g
s
.47686 .83205 m .43022 .92682 L .38657 .90853 L p .803 .734 .788 r
F P
0 g
s
.43022 .92682 m .47686 .83205 L .50317 .83781 L p .761 .679 .772 r
F P
0 g
s
.44066 .21035 m .44632 .16699 L .55058 .16056 L p .624 .291 .386 r
F P
0 g
s
.44632 .16699 m .44066 .21035 L .34102 .24242 L p .472 .16 .356 r
F P
0 g
s
.33481 .58725 m .23871 .6337 L .23258 .68805 L p .858 .937 .874 r
F P
0 g
s
.18446 .76394 m .23258 .68805 L .23871 .6337 L p .933 .959 .653 r
F P
0 g
s
.23871 .6337 m .33481 .58725 L .36283 .5523 L p .768 .989 .893 r
F P
0 g
s
.55058 .16056 m .55241 .2036 L .44066 .21035 L p .624 .291 .386 r
F P
0 g
s
.85319 .79275 m .84537 .85799 L .8579 .80297 L p 0 0 0 r
F P
0 g
s
.8579 .80297 m .86634 .7337 L .85319 .79275 L p 0 0 0 r
F P
0 g
s
.64186 .91852 m .58347 .82758 L .6017 .81604 L p .544 .539 .799 r
F P
0 g
s
.6017 .81604 m .67934 .89688 L .64186 .91852 L p .544 .539 .799 r
F P
0 g
s
.72387 .3523 m .66046 .45624 L .60607 .43293 L p .784 .698 .769 r
F P
0 g
s
.18446 .76394 m .19261 .83114 L .22221 .88339 L p .95 .654 .211 r
F P
0 g
s
.2747 .90905 m .22221 .88339 L .19261 .83114 L p .158 .472 .894 r
F P
0 g
s
.38657 .90853 m .45531 .82223 L .47686 .83205 L p .803 .734 .788 r
F P
0 g
s
.47411 .7548 m .51159 .68616 L .50597 .68905 L p .144 0 .047 r
F P
0 g
s
.36138 .33206 m .34102 .24242 L .44066 .21035 L p .608 .463 .658 r
F P
0 g
s
.75337 .9277 m .67934 .89688 L .70155 .87 L p .589 .72 .934 r
F P
0 g
s
.70155 .87 m .78869 .88852 L .75337 .9277 L p .589 .72 .934 r
F P
0 g
s
.60607 .43293 m .64486 .31593 L .72387 .3523 L p .784 .698 .769 r
F P
0 g
s
.2747 .90905 m .35614 .88402 L .38657 .90853 L p .695 .796 .927 r
F P
0 g
s
.45531 .82223 m .38657 .90853 L .35614 .88402 L p .841 .802 .814 r
F P
0 g
s
.45008 .30487 m .4741 .4259 L .41358 .44324 L p .641 .573 .763 r
F P
0 g
s
.41358 .44324 m .36138 .33206 L .45008 .30487 L p .641 .573 .763 r
F P
0 g
s
.35614 .88402 m .44081 .80927 L .45531 .82223 L p .841 .802 .814 r
F P
0 g
s
.70251 .56909 m .79417 .60696 L .73805 .55914 L p .029 .455 .875 r
F P
0 g
s
.73805 .55914 m .66409 .53712 L .70251 .56909 L p .029 .455 .875 r
F P
0 g
s
.81718 .66084 m .86634 .7337 L .84126 .6733 L p 0 0 .547 r
F P
0 g
s
.84126 .6733 m .79417 .60696 L .81718 .66084 L p 0 0 .547 r
F P
0 g
s
.67934 .89688 m .6017 .81604 L .61192 .80197 L p .453 .514 .831 r
F P
0 g
s
.6601 .22341 m .64486 .31593 L .54922 .29916 L p .757 .58 .657 r
F P
0 g
s
.54922 .29916 m .55241 .2036 L .6601 .22341 L p .757 .58 .657 r
F P
0 g
s
.64486 .31593 m .60607 .43293 L .54118 .42228 L p .74 .649 .759 r
F P
0 g
s
.44066 .21035 m .45008 .30487 L .36138 .33206 L p .608 .463 .658 r
F P
0 g
s
.61192 .80197 m .70155 .87 L .67934 .89688 L p .453 .514 .831 r
F P
0 g
s
.34273 .85543 m .43509 .79446 L .44081 .80927 L p .865 .885 .849 r
F P
0 g
s
.44081 .80927 m .35614 .88402 L .34273 .85543 L p .865 .885 .849 r
F P
0 g
s
.54922 .29916 m .54118 .42228 L .4741 .4259 L p .693 .608 .757 r
F P
0 g
s
.4741 .4259 m .45008 .30487 L .54922 .29916 L p .693 .608 .757 r
F P
0 g
s
.23871 .6337 m .18969 .70337 L .18446 .76394 L p .933 .959 .653 r
F P
0 g
s
.19261 .83114 m .18446 .76394 L .18969 .70337 L p 0 0 .24 r
F P
0 g
s
.19261 .83114 m .25205 .86697 L .2747 .90905 L p .158 .472 .894 r
F P
0 g
s
.35614 .88402 m .2747 .90905 L .25205 .86697 L p .691 .814 .941 r
F P
0 g
s
.27831 .58196 m .36283 .5523 L .4105 .52436 L p .527 .92 .832 r
F P
0 g
s
.36283 .5523 m .27831 .58196 L .23871 .6337 L p .768 .989 .893 r
F P
0 g
s
.84537 .85799 m .78869 .88852 L .79711 .84451 L p .832 .961 .893 r
F P
0 g
s
.79711 .84451 m .8579 .80297 L .84537 .85799 L p .832 .961 .893 r
F P
0 g
s
.54118 .42228 m .54922 .29916 L .64486 .31593 L p .74 .649 .759 r
F P
0 g
s
.45008 .30487 m .44066 .21035 L .55241 .2036 L p .687 .521 .656 r
F P
0 g
s
.70155 .87 m .61192 .80197 L .6128 .78679 L p .322 .488 .868 r
F P
0 g
s
.55241 .2036 m .54922 .29916 L .45008 .30487 L p .687 .521 .656 r
F P
0 g
s
.25205 .86697 m .34273 .85543 L .35614 .88402 L p .691 .814 .941 r
F P
0 g
s
.66409 .53712 m .73805 .55914 L .65355 .52435 L p 0 .424 .767 r
F P
0 g
s
.65355 .52435 m .60826 .51424 L .66409 .53712 L p 0 .424 .767 r
F P
0 g
s
.34884 .82562 m .43902 .77933 L .43509 .79446 L p .842 .968 .882 r
F P
0 g
s
.43509 .79446 m .34273 .85543 L .34884 .82562 L p .842 .968 .882 r
F P
0 g
s
.18969 .70337 m .23871 .6337 L .27831 .58196 L p 0 0 0 r
F P
0 g
s
.6128 .78679 m .70527 .84041 L .70155 .87 L p .322 .488 .868 r
F P
0 g
s
.70527 .84041 m .6128 .78679 L .60397 .77214 L p .125 .449 .882 r
F P
0 g
s
.78869 .88852 m .70155 .87 L .70527 .84041 L p .569 .726 .948 r
F P
0 g
s
.70527 .84041 m .79711 .84451 L .78869 .88852 L p .569 .726 .948 r
F P
0 g
s
.34939 .53979 m .4105 .52436 L .47266 .50734 L p .204 .724 .702 r
F P
0 g
s
.4105 .52436 m .34939 .53979 L .27831 .58196 L p .527 .92 .832 r
F P
0 g
s
.43902 .77933 m .34884 .82562 L .375 .79795 L p .695 .982 .859 r
F P
0 g
s
.86634 .7337 m .8579 .80297 L .83313 .74679 L p .992 .791 .412 r
F P
0 g
s
.83313 .74679 m .84126 .6733 L .86634 .7337 L p .992 .791 .412 r
F P
0 g
s
.18969 .70337 m .19803 .77474 L .19261 .83114 L p 0 0 .24 r
F P
0 g
s
.25205 .86697 m .19261 .83114 L .19803 .77474 L p .351 .517 .881 r
F P
0 g
s
.60826 .51424 m .65355 .52435 L .55091 .50828 L p .161 0 0 r
F P
0 g
s
.55091 .50828 m .54159 .50379 L .60826 .51424 L p .161 0 0 r
F P
0 g
s
.60397 .77214 m .68892 .81123 L .70527 .84041 L p .125 .449 .882 r
F P
0 g
s
.47266 .50734 m .44445 .51375 L .34939 .53979 L p .204 .724 .702 r
F P
0 g
s
.44445 .51375 m .47266 .50734 L .54159 .50379 L p .044 0 0 r
F P
0 g
s
.79417 .60696 m .84126 .6733 L .77661 .61911 L p .757 .259 0 r
F P
0 g
s
.77661 .61911 m .73805 .55914 L .79417 .60696 L p .757 .259 0 r
F P
0 g
s
.25838 .82216 m .34884 .82562 L .34273 .85543 L p .679 .829 .955 r
F P
0 g
s
.34273 .85543 m .25205 .86697 L .25838 .82216 L p .679 .829 .955 r
F P
0 g
s
.54159 .50379 m .55091 .50828 L .44445 .51375 L p .044 0 0 r
F P
0 g
s
.45024 .724 m .46858 .75082 L p .41916 .77589 L .598 .829 .988 r
F P
0 g
s
.45245 .76557 m .37891 .79631 L p .41916 .77589 L .378 .829 .718 r
F P
0 g
s
.47411 .7548 m .41916 .77589 L .47655 .76248 L p 0 0 0 r
F P
0 g
s
.46858 .75082 m .47655 .76248 L .41916 .77589 L p .598 .829 .988 r
F P
0 g
s
.37891 .79631 m .375 .79795 L .41916 .77589 L p .378 .829 .718 r
F P
0 g
s
.19803 .77474 m .25838 .82216 L .25205 .86697 L p .351 .517 .881 r
F P
0 g
s
.79711 .84451 m .70527 .84041 L .68892 .81123 L p .551 .738 .963 r
F P
0 g
s
.8579 .80297 m .79711 .84451 L .77508 .80019 L p .846 .879 .864 r
F P
0 g
s
.77508 .80019 m .83313 .74679 L .8579 .80297 L p .846 .879 .864 r
F P
0 g
s
.27831 .58196 m .23449 .64504 L .18969 .70337 L p 0 0 0 r
F P
0 g
s
.19803 .77474 m .18969 .70337 L .23449 .64504 L p .13 .055 .496 r
F P
0 g
s
.23449 .64504 m .27831 .58196 L .34939 .53979 L p .057 0 0 r
F P
0 g
s
.68892 .81123 m .77508 .80019 L .79711 .84451 L p .551 .738 .963 r
F P
0 g
s
.29574 .77969 m .375 .79795 L .34884 .82562 L p .658 .837 .969 r
F P
0 g
s
.34884 .82562 m .25838 .82216 L .29574 .77969 L p .658 .837 .969 r
F P
0 g
s
.73805 .55914 m .77661 .61911 L .67741 .57934 L p .775 .297 .101 r
F P
0 g
s
.67741 .57934 m .65355 .52435 L .73805 .55914 L p .775 .297 .101 r
F P
0 g
s
.77508 .80019 m .68892 .81123 L .65321 .78596 L p .54 .754 .975 r
F P
0 g
s
.84126 .6733 m .83313 .74679 L .76992 .69649 L p .946 .702 .538 r
F P
0 g
s
.76992 .69649 m .77661 .61911 L .84126 .6733 L p .946 .702 .538 r
F P
0 g
s
.23449 .64504 m .24197 .72054 L .19803 .77474 L p .13 .055 .496 r
F P
0 g
s
.25838 .82216 m .19803 .77474 L .24197 .72054 L p .478 .546 .848 r
F P
0 g
s
.24197 .72054 m .29574 .77969 L .25838 .82216 L p .478 .546 .848 r
F P
0 g
s
.31728 .59703 m .34939 .53979 L .44445 .51375 L p .383 0 .164 r
F P
0 g
s
.34939 .53979 m .31728 .59703 L .23449 .64504 L p .057 0 0 r
F P
0 g
s
.36204 .74523 m .41916 .77589 L .375 .79795 L p .629 .838 .98 r
F P
0 g
s
.375 .79795 m .29574 .77969 L .36204 .74523 L p .629 .838 .98 r
F P
0 g
s
.65321 .78596 m .7225 .76103 L .77508 .80019 L p .54 .754 .975 r
F P
0 g
s
.65355 .52435 m .67741 .57934 L .55582 .56087 L p .686 .247 .202 r
F P
0 g
s
.55582 .56087 m .55091 .50828 L .65355 .52435 L p .686 .247 .202 r
F P
0 g
s
.24197 .72054 m .23449 .64504 L .31728 .59703 L p .417 .259 .558 r
F P
0 g
s
.83313 .74679 m .77508 .80019 L .7225 .76103 L p .82 .799 .832 r
F P
0 g
s
.7225 .76103 m .76992 .69649 L .83313 .74679 L p .82 .799 .832 r
F P
0 g
s
.42949 .56717 m .44445 .51375 L .55091 .50828 L p .564 .151 .218 r
F P
0 g
s
.44445 .51375 m .42949 .56717 L .31728 .59703 L p .383 0 .164 r
F P
0 g
s
.41916 .77589 m .36204 .74523 L .45024 .724 L p .598 .829 .988 r
F P
0 g
s
.55091 .50828 m .55582 .56087 L .42949 .56717 L p .564 .151 .218 r
F P
0 g
s
.60159 .76792 m .64392 .73263 L .7225 .76103 L p .538 .773 .985 r
F P
0 g
s
.47655 .76248 m .45024 .724 L .54882 .71955 L p .569 .814 .991 r
F P
0 g
s
.32277 .67601 m .36204 .74523 L .29574 .77969 L p .566 .573 .82 r
F P
0 g
s
.29574 .77969 m .24197 .72054 L .32277 .67601 L p .566 .573 .82 r
F P
0 g
s
.77661 .61911 m .76992 .69649 L .67323 .65962 L p .85 .606 .569 r
F P
0 g
s
.67323 .65962 m .67741 .57934 L .77661 .61911 L p .85 .606 .569 r
F P
0 g
s
.5401 .75968 m .54882 .71955 L .64392 .73263 L p .548 .794 .99 r
F P
0 g
s
.31728 .59703 m .32277 .67601 L .24197 .72054 L p .417 .259 .558 r
F P
0 g
s
.76992 .69649 m .7225 .76103 L .64392 .73263 L p .781 .734 .81 r
F P
0 g
s
.32277 .67601 m .31728 .59703 L .42949 .56717 L p .57 .373 .574 r
F P
0 g
s
.64392 .73263 m .67323 .65962 L .76992 .69649 L p .781 .734 .81 r
F P
0 g
s
.43202 .64834 m .45024 .724 L .36204 .74523 L p .633 .604 .802 r
F P
0 g
s
.36204 .74523 m .32277 .67601 L .43202 .64834 L p .633 .604 .802 r
F P
0 g
s
.67741 .57934 m .67323 .65962 L .55491 .64251 L p .762 .527 .577 r
F P
0 g
s
.55491 .64251 m .55582 .56087 L .67741 .57934 L p .762 .527 .577 r
F P
0 g
s
.67323 .65962 m .64392 .73263 L .54882 .71955 L p .737 .682 .798 r
F P
0 g
s
.42949 .56717 m .43202 .64834 L .32277 .67601 L p .57 .373 .574 r
F P
0 g
s
.43202 .64834 m .42949 .56717 L .55582 .56087 L p .674 .454 .579 r
F P
0 g
s
.55582 .56087 m .55491 .64251 L .43202 .64834 L p .674 .454 .579 r
F P
0 g
s
.55491 .64251 m .54882 .71955 L .45024 .724 L p .688 .639 .795 r
F P
0 g
s
.45024 .724 m .43202 .64834 L .55491 .64251 L p .688 .639 .795 r
F P
0 g
s
.54882 .71955 m .55491 .64251 L .67323 .65962 L p .737 .682 .798 r
F P
0 g
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.0153906 0.588183 0.207773 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.323448 1.6726 -0.0146511 1.6726 [
[ 0 0 0 0 ]
[ 1 1.65795 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.65795 L
0 1.65795 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.48778 .41708 m .47075 .52985 L .52473 .5327 L p .719 .59 .711 r
F P
0 g
s
.52473 .5327 m .51898 .41878 L .48778 .41708 L p .719 .59 .711 r
F P
0 g
s
.52694 .64972 m .52473 .5327 L .47075 .52985 L p .718 .51 .608 r
F P
0 g
s
.51898 .41878 m .52473 .5327 L .57735 .52415 L p .668 .55 .712 r
F P
0 g
s
.52473 .5327 m .52694 .64972 L .5882 .64008 L p .646 .452 .607 r
F P
0 g
s
.5882 .64008 m .57735 .52415 L .52473 .5327 L p .646 .452 .607 r
F P
0 g
s
.51898 .41878 m .51107 .33072 L .48778 .41708 L closepath p .702 .674 .819 r
F P
0 g
s
.54935 .41369 m .51107 .33072 L .51898 .41878 L closepath p .678 .656 .821 r
F P
0 g
s
.57735 .52415 m .54935 .41369 L .51898 .41878 L p .668 .55 .712 r
F P
0 g
s
.459 .40876 m .42079 .51585 L .47075 .52985 L p .768 .636 .715 r
F P
0 g
s
.47075 .52985 m .48778 .41708 L .459 .40876 L p .768 .636 .715 r
F P
0 g
s
.46412 .6465 m .47075 .52985 L .42079 .51585 L p .786 .57 .607 r
F P
0 g
s
.47075 .52985 m .46412 .6465 L .52694 .64972 L p .718 .51 .608 r
F P
0 g
s
.48778 .41708 m .51107 .33072 L .459 .40876 L closepath p .723 .696 .824 r
F P
0 g
s
.57576 .40232 m .51107 .33072 L .54935 .41369 L closepath p .653 .643 .828 r
F P
0 g
s
.54935 .41369 m .57735 .52415 L .62332 .50499 L p .61 .514 .72 r
F P
0 g
s
.62332 .50499 m .57576 .40232 L .54935 .41369 L p .61 .514 .72 r
F P
0 g
s
.57735 .52415 m .5882 .64008 L .64183 .61844 L p .558 .388 .607 r
F P
0 g
s
.64183 .61844 m .62332 .50499 L .57735 .52415 L p .558 .388 .607 r
F P
0 g
s
.459 .40876 m .51107 .33072 L .43563 .39465 L closepath p .741 .722 .834 r
F P
0 g
s
.42079 .51585 m .459 .40876 L .43563 .39465 L p .816 .692 .728 r
F P
0 g
s
.43563 .39465 m .37993 .49201 L .42079 .51585 L p .816 .692 .728 r
F P
0 g
s
.40591 .63071 m .42079 .51585 L .37993 .49201 L p .858 .64 .605 r
F P
0 g
s
.42079 .51585 m .40591 .63071 L .46412 .6465 L p .786 .57 .607 r
F P
0 g
s
.5954 .3858 m .51107 .33072 L .57576 .40232 L closepath p .626 .637 .841 r
F P
0 g
s
.57576 .40232 m .62332 .50499 L .65788 .47699 L p .538 .479 .737 r
F P
0 g
s
.65788 .47699 m .5954 .3858 L .57576 .40232 L p .538 .479 .737 r
F P
0 g
s
.43563 .39465 m .51107 .33072 L .42019 .37617 L closepath p .755 .752 .85 r
F P
0 g
s
.37993 .49201 m .43563 .39465 L .42019 .37617 L p .864 .762 .748 r
F P
0 g
s
.62332 .50499 m .64183 .61844 L .6823 .58677 L p .431 .301 .602 r
F P
0 g
s
.6823 .58677 m .65788 .47699 L .62332 .50499 L p .431 .301 .602 r
F P
0 g
s
.60611 .36582 m .51107 .33072 L .5954 .3858 L closepath p .599 .637 .86 r
F P
0 g
s
.5954 .3858 m .65788 .47699 L .67717 .44289 L p .441 .441 .763 r
F P
0 g
s
.67717 .44289 m .60611 .36582 L .5954 .3858 L p .441 .441 .763 r
F P
0 g
s
.42019 .37617 m .35254 .46058 L .37993 .49201 L p .864 .762 .748 r
F P
0 g
s
.35817 .60377 m .37993 .49201 L .35254 .46058 L p .939 .73 .594 r
F P
0 g
s
.37993 .49201 m .35817 .60377 L .40591 .63071 L p .858 .64 .605 r
F P
0 g
s
.42019 .37617 m .51107 .33072 L .41445 .35522 L closepath p .76 .782 .871 r
F P
0 g
s
.35254 .46058 m .42019 .37617 L .41445 .35522 L p .906 .852 .779 r
F P
0 g
s
.52482 .74787 m .52694 .64972 L .46412 .6465 L p .698 .4 .466 r
F P
0 g
s
.52694 .64972 m .52482 .74787 L .57801 .73973 L p .601 .32 .462 r
F P
0 g
s
.57801 .73973 m .5882 .64008 L .52694 .64972 L p .601 .32 .462 r
F P
0 g
s
.60661 .34447 m .51107 .33072 L .60611 .36582 L closepath p .574 .646 .884 r
F P
0 g
s
.57726 .30687 m .51107 .33072 L .59668 .32406 L closepath p .539 .693 .939 r
F P
0 g
s
.55041 .29488 m .51107 .33072 L .57726 .30687 L closepath p .541 .73 .962 r
F P
0 g
s
.51911 .28947 m .51107 .33072 L .55041 .29488 L closepath p .562 .771 .976 r
F P
0 g
s
.48689 .2913 m .51107 .33072 L .51911 .28947 L closepath p .602 .808 .979 r
F P
0 g
s
.45742 .30015 m .51107 .33072 L .48689 .2913 L closepath p .652 .834 .97 r
F P
0 g
s
.43399 .31497 m .51107 .33072 L .45742 .30015 L closepath p .7 .843 .951 r
F P
0 g
s
.41916 .33405 m .51107 .33072 L .43399 .31497 L closepath p .736 .833 .925 r
F P
0 g
s
.41445 .35522 m .51107 .33072 L .41916 .33405 L closepath p .755 .811 .897 r
F P
0 g
s
.59668 .32406 m .51107 .33072 L .60661 .34447 L closepath p .552 .664 .911 r
F P
0 g
s
.47025 .74515 m .46412 .6465 L .40591 .63071 L p .785 .468 .452 r
F P
0 g
s
.46412 .6465 m .47025 .74515 L .52482 .74787 L p .698 .4 .466 r
F P
0 g
s
.60611 .36582 m .67717 .44289 L .67873 .40616 L p .292 .394 .796 r
F P
0 g
s
.67873 .40616 m .60661 .34447 L .60611 .36582 L p .292 .394 .796 r
F P
0 g
s
.65788 .47699 m .6823 .58677 L .70509 .54809 L p .208 .156 .576 r
F P
0 g
s
.70509 .54809 m .67717 .44289 L .65788 .47699 L p .208 .156 .576 r
F P
0 g
s
.5882 .64008 m .57801 .73973 L .62449 .72147 L p .47 .209 .435 r
F P
0 g
s
.62449 .72147 m .64183 .61844 L .5882 .64008 L p .47 .209 .435 r
F P
0 g
s
.34184 .4247 m .41445 .35522 L .41916 .33405 L p .911 .957 .809 r
F P
0 g
s
.41445 .35522 m .34184 .4247 L .35254 .46058 L p .906 .852 .779 r
F P
0 g
s
.41974 .73182 m .40591 .63071 L .35817 .60377 L p .873 .536 .408 r
F P
0 g
s
.40591 .63071 m .41974 .73182 L .47025 .74515 L p .785 .468 .452 r
F P
0 g
s
.32598 .56817 m .35254 .46058 L .34184 .4247 L p .999 .837 .536 r
F P
0 g
s
.35254 .46058 m .32598 .56817 L .35817 .60377 L p .939 .73 .594 r
F P
0 g
s
.60661 .34447 m .67873 .40616 L .66189 .37077 L p .043 .322 .806 r
F P
0 g
s
.66189 .37077 m .59668 .32406 L .60661 .34447 L p .043 .322 .806 r
F P
0 g
s
.64183 .61844 m .62449 .72147 L .65944 .6948 L p .248 .022 .361 r
F P
0 g
s
.65944 .6948 m .6823 .58677 L .64183 .61844 L p .248 .022 .361 r
F P
0 g
s
.34944 .38813 m .41916 .33405 L .43399 .31497 L p .763 .989 .769 r
F P
0 g
s
.41916 .33405 m .34944 .38813 L .34184 .4247 L p .911 .957 .809 r
F P
0 g
s
.67717 .44289 m .70509 .54809 L .70723 .5063 L p 0 0 .44 r
F P
0 g
s
.70723 .5063 m .67873 .40616 L .67717 .44289 L p 0 0 .44 r
F P
0 g
s
.37842 .70911 m .35817 .60377 L .32598 .56817 L p .947 .592 .282 r
F P
0 g
s
.35817 .60377 m .37842 .70911 L .41974 .73182 L p .873 .536 .408 r
F P
0 g
s
.59668 .32406 m .66189 .37077 L .62806 .34075 L p 0 .199 .68 r
F P
0 g
s
.62806 .34075 m .57726 .30687 L .59668 .32406 L p 0 .199 .68 r
F P
0 g
s
.43399 .31497 m .37501 .35492 L .34944 .38813 L p .763 .989 .769 r
F P
0 g
s
.37501 .35492 m .43399 .31497 L .45742 .30015 L p 0 0 0 r
F P
0 g
s
.31318 .52741 m .34184 .4247 L .34944 .38813 L p .768 .766 .258 r
F P
0 g
s
.34184 .4247 m .31318 .52741 L .32598 .56817 L p .999 .837 .536 r
F P
0 g
s
.57726 .30687 m .62806 .34075 L .58076 .31967 L p .495 0 0 r
F P
0 g
s
.58076 .31967 m .55041 .29488 L .57726 .30687 L p .495 0 0 r
F P
0 g
s
.6823 .58677 m .65944 .6948 L .67896 .6623 L p 0 0 .141 r
F P
0 g
s
.67896 .6623 m .70509 .54809 L .6823 .58677 L p 0 0 .141 r
F P
0 g
s
.41608 .32895 m .45742 .30015 L .48689 .2913 L p .086 0 0 r
F P
0 g
s
.45742 .30015 m .41608 .32895 L .37501 .35492 L p 0 0 0 r
F P
0 g
s
.55041 .29488 m .58076 .31967 L .52531 .31015 L p .482 0 0 r
F P
0 g
s
.52531 .31015 m .51911 .28947 L .55041 .29488 L p .482 0 0 r
F P
0 g
s
.46818 .31338 m .48689 .2913 L .51911 .28947 L p .346 0 0 r
F P
0 g
s
.48689 .2913 m .46818 .31338 L .41608 .32895 L p .086 0 0 r
F P
0 g
s
.67873 .40616 m .70723 .5063 L .6878 .4659 L p .846 .503 0 r
F P
0 g
s
.6878 .4659 m .66189 .37077 L .67873 .40616 L p .846 .503 0 r
F P
0 g
s
.51911 .28947 m .52531 .31015 L .46818 .31338 L p .346 0 0 r
F P
0 g
s
.35071 .67916 m .32598 .56817 L .31318 .52741 L p .78 .493 0 r
F P
0 g
s
.32598 .56817 m .35071 .67916 L .37842 .70911 L p .947 .592 .282 r
F P
0 g
s
.51835 .80859 m .52482 .74787 L .47025 .74515 L p .616 .18 .19 r
F P
0 g
s
.52482 .74787 m .51835 .80859 L .54679 .80431 L p .48 .065 .173 r
F P
0 g
s
.54679 .80431 m .57801 .73973 L .52482 .74787 L p .48 .065 .173 r
F P
0 g
s
.44996 .9141 m .43633 .9765 L .53627 .98114 L p .713 .641 .776 r
F P
0 g
s
.53627 .98114 m .53166 .91797 L .44996 .9141 L p .713 .641 .776 r
F P
0 g
s
.53642 1.02311 m .53627 .98114 L .43633 .9765 L p .712 .469 .555 r
F P
0 g
s
.53166 .91797 m .53627 .98114 L .63389 .9672 L p .673 .611 .778 r
F P
0 g
s
.53627 .98114 m .53642 1.02311 L .63467 1.00925 L p .632 .404 .553 r
F P
0 g
s
.63467 1.00925 m .63389 .9672 L .53627 .98114 L p .632 .404 .553 r
F P
0 g
s
.48915 .80716 m .47025 .74515 L .41974 .73182 L p .714 .246 .138 r
F P
0 g
s
.47025 .74515 m .48915 .80716 L .51835 .80859 L p .616 .18 .19 r
F P
0 g
s
.37407 .89506 m .34326 .95361 L .43633 .9765 L p .75 .678 .782 r
F P
0 g
s
.43633 .9765 m .44996 .9141 L .37407 .89506 L p .75 .678 .782 r
F P
0 g
s
.43584 1.01849 m .43633 .9765 L .34326 .95361 L p .787 .532 .55 r
F P
0 g
s
.43633 .9765 m .43584 1.01849 L .53642 1.02311 L p .712 .469 .555 r
F P
0 g
s
.57801 .73973 m .54679 .80431 L .5715 .79475 L p .262 0 .075 r
F P
0 g
s
.5715 .79475 m .62449 .72147 L .57801 .73973 L p .262 0 .075 r
F P
0 g
s
.34944 .38813 m .32176 .48573 L .31318 .52741 L p .768 .766 .258 r
F P
0 g
s
.32176 .48573 m .34944 .38813 L .37501 .35492 L p 0 0 .169 r
F P
0 g
s
.70509 .54809 m .67896 .6623 L .68055 .62729 L p .872 .799 .309 r
F P
0 g
s
.68055 .62729 m .70723 .5063 L .70509 .54809 L p .872 .799 .309 r
F P
0 g
s
.63389 .9672 m .61139 .90636 L .53166 .91797 L p .673 .611 .778 r
F P
0 g
s
.61139 .90636 m .63389 .9672 L .72006 .93574 L p .629 .587 .788 r
F P
0 g
s
.63389 .9672 m .63467 1.00925 L .7214 .97799 L p .531 .324 .545 r
F P
0 g
s
.7214 .97799 m .72006 .93574 L .63389 .9672 L p .531 .324 .545 r
F P
0 g
s
.4622 .80016 m .41974 .73182 L .37842 .70911 L p .764 .256 0 r
F P
0 g
s
.41974 .73182 m .4622 .80016 L .48915 .80716 L p .714 .246 .138 r
F P
0 g
s
.47405 .85528 m .44996 .9141 L .53166 .91797 L p .662 .745 .911 r
F P
0 g
s
.53166 .91797 m .52348 .85767 L .47405 .85528 L p .662 .745 .911 r
F P
0 g
s
.52348 .85767 m .53166 .91797 L .61139 .90636 L p .66 .743 .912 r
F P
0 g
s
.42832 .84359 m .37407 .89506 L .44996 .9141 L p .664 .747 .912 r
F P
0 g
s
.44996 .9141 m .47405 .85528 L .42832 .84359 L p .664 .747 .912 r
F P
0 g
s
.53196 1.02281 m .53642 1.02311 L .43584 1.01849 L p 0 .553 .71 r
F P
0 g
s
.53642 1.02311 m .53196 1.02281 L .61299 1.01138 L p .13 .677 .733 r
F P
0 g
s
.61299 1.01138 m .63467 1.00925 L .53642 1.02311 L p .13 .677 .733 r
F P
0 g
s
.66189 .37077 m .6878 .4659 L .64834 .43153 L p .922 .549 .288 r
F P
0 g
s
.64834 .43153 m .62806 .34075 L .66189 .37077 L p .922 .549 .288 r
F P
0 g
s
.62449 .72147 m .5715 .79475 L .58986 .78087 L p 0 0 0 r
F P
0 g
s
.58986 .78087 m .65944 .6948 L .62449 .72147 L p 0 0 0 r
F P
0 g
s
.34326 .95361 m .34217 .99575 L .43584 1.01849 L p .787 .532 .55 r
F P
0 g
s
.44894 1.019 m .43584 1.01849 L .34217 .99575 L p 0 .503 .773 r
F P
0 g
s
.43584 1.01849 m .44894 1.019 L .53196 1.02281 L p 0 .553 .71 r
F P
0 g
s
.31144 .86245 m .26601 .91428 L .34326 .95361 L p .783 .723 .796 r
F P
0 g
s
.34326 .95361 m .37407 .89506 L .31144 .86245 L p .783 .723 .796 r
F P
0 g
s
.34217 .99575 m .34326 .95361 L .26601 .91428 L p .867 .602 .536 r
F P
0 g
s
.61139 .90636 m .57166 .85052 L .52348 .85767 L p .66 .743 .912 r
F P
0 g
s
.57166 .85052 m .61139 .90636 L .68149 .88023 L p .658 .742 .912 r
F P
0 g
s
.72006 .93574 m .68149 .88023 L .61139 .90636 L p .629 .587 .788 r
F P
0 g
s
.31318 .52741 m .33987 .64496 L .35071 .67916 L p .78 .493 0 r
F P
0 g
s
.33987 .64496 m .31318 .52741 L .32176 .48573 L p 0 0 .462 r
F P
0 g
s
.63467 1.00925 m .61299 1.01138 L .68424 .98566 L p .381 .845 .824 r
F P
0 g
s
.68424 .98566 m .7214 .97799 L .63467 1.00925 L p .381 .845 .824 r
F P
0 g
s
.35147 .44776 m .37501 .35492 L .41608 .32895 L p .316 .058 .355 r
F P
0 g
s
.37501 .35492 m .35147 .44776 L .32176 .48573 L p 0 0 .169 r
F P
0 g
s
.44035 .7883 m .37842 .70911 L .35071 .67916 L p .625 .138 0 r
F P
0 g
s
.37842 .70911 m .44035 .7883 L .4622 .80016 L p .764 .256 0 r
F P
0 g
s
.39098 .82368 m .31144 .86245 L .37407 .89506 L p .665 .749 .913 r
F P
0 g
s
.37407 .89506 m .42832 .84359 L .39098 .82368 L p .665 .749 .913 r
F P
0 g
s
.68149 .88023 m .72006 .93574 L .78618 .88929 L p .578 .568 .806 r
F P
0 g
s
.72006 .93574 m .7214 .97799 L .78797 .93183 L p .377 .207 .521 r
F P
0 g
s
.78797 .93183 m .78618 .88929 L .72006 .93574 L p .377 .207 .521 r
F P
0 g
s
.62806 .34075 m .64834 .43153 L .59291 .40735 L p .836 .488 .395 r
F P
0 g
s
.59291 .40735 m .58076 .31967 L .62806 .34075 L p .836 .488 .395 r
F P
0 g
s
.26601 .91428 m .2644 .95666 L .34217 .99575 L p .867 .602 .536 r
F P
0 g
s
.37181 1.00026 m .34217 .99575 L .2644 .95666 L p .016 .507 .871 r
F P
0 g
s
.34217 .99575 m .37181 1.00026 L .44894 1.019 L p 0 .503 .773 r
F P
0 g
s
.65944 .6948 m .58986 .78087 L .59986 .76408 L p .72 .912 .553 r
F P
0 g
s
.59986 .76408 m .67896 .6623 L .65944 .6948 L p .72 .912 .553 r
F P
0 g
s
.70723 .5063 m .68055 .62729 L .66354 .59356 L p .993 .798 .538 r
F P
0 g
s
.66354 .59356 m .6878 .4659 L .70723 .5063 L p .993 .798 .538 r
F P
0 g
s
.68149 .88023 m .6137 .83451 L .57166 .85052 L p .658 .742 .912 r
F P
0 g
s
.6137 .83451 m .68149 .88023 L .73484 .84181 L p .655 .742 .913 r
F P
0 g
s
.78618 .88929 m .73484 .84181 L .68149 .88023 L p .578 .568 .806 r
F P
0 g
s
.39951 .418 m .41608 .32895 L .46818 .31338 L p .517 .23 .418 r
F P
0 g
s
.41608 .32895 m .39951 .418 L .35147 .44776 L p .316 .058 .355 r
F P
0 g
s
.35071 .67916 m .42592 .77277 L .44035 .7883 L p .625 .138 0 r
F P
0 g
s
.42592 .77277 m .35071 .67916 L .33987 .64496 L p 0 .121 .671 r
F P
0 g
s
.58076 .31967 m .59291 .40735 L .52778 .39641 L p .742 .417 .432 r
F P
0 g
s
.52778 .39641 m .52531 .31015 L .58076 .31967 L p .742 .417 .432 r
F P
0 g
s
.2687 .81914 m .21268 .86177 L .26601 .91428 L p .813 .776 .819 r
F P
0 g
s
.26601 .91428 m .31144 .86245 L .2687 .81914 L p .813 .776 .819 r
F P
0 g
s
.2644 .95666 m .26601 .91428 L .21268 .86177 L p .953 .687 .494 r
F P
0 g
s
.7214 .97799 m .68424 .98566 L .7385 .94782 L p .637 .962 .906 r
F P
0 g
s
.7385 .94782 m .78797 .93183 L .7214 .97799 L p .637 .962 .906 r
F P
0 g
s
.34754 .6101 m .32176 .48573 L .35147 .44776 L p .278 .188 .571 r
F P
0 g
s
.32176 .48573 m .34754 .6101 L .33987 .64496 L p 0 0 .462 r
F P
0 g
s
.52366 .96665 m .53196 1.02281 L .44894 1.019 L p .649 .758 .929 r
F P
0 g
s
.53196 1.02281 m .52366 .96665 L .57265 .95961 L p .651 .76 .929 r
F P
0 g
s
.57265 .95961 m .61299 1.01138 L .53196 1.02281 L p .651 .76 .929 r
F P
0 g
s
.46065 .40012 m .46818 .31338 L .52531 .31015 L p .642 .336 .438 r
F P
0 g
s
.46818 .31338 m .46065 .40012 L .39951 .418 L p .517 .23 .418 r
F P
0 g
s
.36602 .79748 m .2687 .81914 L .31144 .86245 L p .665 .751 .914 r
F P
0 g
s
.31144 .86245 m .39098 .82368 L .36602 .79748 L p .665 .751 .914 r
F P
0 g
s
.50404 .82356 m .47405 .85528 L .52348 .85767 L p .454 .801 .998 r
F P
0 g
s
.52348 .85767 m .51327 .82401 L .50404 .82356 L p .454 .801 .998 r
F P
0 g
s
.51327 .82401 m .52348 .85767 L .57166 .85052 L p .528 .854 .997 r
F P
0 g
s
.47339 .9643 m .44894 1.019 L .37181 1.00026 L p .647 .756 .929 r
F P
0 g
s
.44894 1.019 m .47339 .9643 L .52366 .96665 L p .649 .758 .929 r
F P
0 g
s
.52531 .31015 m .52778 .39641 L .46065 .40012 L p .642 .336 .438 r
F P
0 g
s
.49555 .82136 m .42832 .84359 L .47405 .85528 L p .417 .748 .994 r
F P
0 g
s
.47405 .85528 m .50404 .82356 L .49555 .82136 L p .417 .748 .994 r
F P
0 g
s
.67896 .6623 m .59986 .76408 L .60029 .74616 L p .953 .949 .719 r
F P
0 g
s
.60029 .74616 m .68055 .62729 L .67896 .6623 L p .953 .949 .719 r
F P
0 g
s
.57166 .85052 m .52225 .82266 L .51327 .82401 L p .528 .854 .997 r
F P
0 g
s
.52225 .82266 m .57166 .85052 L .6137 .83451 L p .619 .89 .988 r
F P
0 g
s
.61299 1.01138 m .57265 .95961 L .61542 .94385 L p .654 .761 .928 r
F P
0 g
s
.61542 .94385 m .68424 .98566 L .61299 1.01138 L p .654 .761 .928 r
F P
0 g
s
.6878 .4659 m .66354 .59356 L .62934 .56493 L p .914 .692 .586 r
F P
0 g
s
.62934 .56493 m .64834 .43153 L .6878 .4659 L p .914 .692 .586 r
F P
0 g
s
.4887 .81765 m .39098 .82368 L .42832 .84359 L p .421 .702 .98 r
F P
0 g
s
.42832 .84359 m .49555 .82136 L .4887 .81765 L p .421 .702 .98 r
F P
0 g
s
.21268 .86177 m .21069 .90448 L .2644 .95666 L p .953 .687 .494 r
F P
0 g
s
.30813 .96815 m .2644 .95666 L .21069 .90448 L p .173 .524 .92 r
F P
0 g
s
.2644 .95666 m .30813 .96815 L .37181 1.00026 L p .016 .507 .871 r
F P
0 g
s
.73484 .84181 m .64524 .81116 L .6137 .83451 L p .655 .742 .913 r
F P
0 g
s
.64524 .81116 m .73484 .84181 L .76545 .7946 L p .653 .742 .915 r
F P
0 g
s
.73484 .84181 m .78618 .88929 L .82481 .83188 L p .517 .556 .835 r
F P
0 g
s
.82481 .83188 m .76545 .7946 L .73484 .84181 L p .517 .556 .835 r
F P
0 g
s
.78618 .88929 m .78797 .93183 L .82689 .87476 L p .08 0 .442 r
F P
0 g
s
.82689 .87476 m .82481 .83188 L .78618 .88929 L p .08 0 .442 r
F P
0 g
s
.42688 .95279 m .37181 1.00026 L .30813 .96815 L p .646 .754 .928 r
F P
0 g
s
.37181 1.00026 m .42688 .95279 L .47339 .9643 L p .647 .756 .929 r
F P
0 g
s
.42058 .75518 m .33987 .64496 L .34754 .6101 L p .225 .297 .729 r
F P
0 g
s
.33987 .64496 m .42058 .75518 L .42592 .77277 L p 0 .121 .671 r
F P
0 g
s
.6137 .83451 m .53001 .81966 L .52225 .82266 L p .619 .89 .988 r
F P
0 g
s
.53001 .81966 m .6137 .83451 L .64524 .81116 L p .699 .899 .968 r
F P
0 g
s
.37339 .57844 m .35147 .44776 L .39951 .418 L p .476 .323 .594 r
F P
0 g
s
.35147 .44776 m .37339 .57844 L .34754 .6101 L p .278 .188 .571 r
F P
0 g
s
.51327 .82401 m .51835 .80859 L .48915 .80716 L p .407 0 0 r
F P
0 g
s
.51835 .80859 m .51327 .82401 L .52225 .82266 L p .233 0 0 r
F P
0 g
s
.52225 .82266 m .54679 .80431 L .51835 .80859 L p .233 0 0 r
F P
0 g
s
.50404 .82356 m .48915 .80716 L .4622 .80016 L p .479 0 0 r
F P
0 g
s
.48915 .80716 m .50404 .82356 L .51327 .82401 L p .407 0 0 r
F P
0 g
s
.49555 .82136 m .4622 .80016 L .44035 .7883 L p .409 0 0 r
F P
0 g
s
.4622 .80016 m .49555 .82136 L .50404 .82356 L p .479 0 0 r
F P
0 g
s
.44035 .7883 m .4887 .81765 L .49555 .82136 L p .409 0 0 r
F P
0 g
s
.4887 .81765 m .44035 .7883 L .42592 .77277 L p 0 .292 .776 r
F P
0 g
s
.42592 .77277 m .48424 .81282 L .4887 .81765 L p 0 .292 .776 r
F P
0 g
s
.48424 .81282 m .36602 .79748 L .39098 .82368 L p .452 .666 .954 r
F P
0 g
s
.39098 .82368 m .4887 .81765 L .48424 .81282 L p .452 .666 .954 r
F P
0 g
s
.54679 .80431 m .52225 .82266 L .53001 .81966 L p 0 0 0 r
F P
0 g
s
.53001 .81966 m .5715 .79475 L .54679 .80431 L p 0 0 0 r
F P
0 g
s
.68424 .98566 m .61542 .94385 L .64752 .92085 L p .656 .761 .927 r
F P
0 g
s
.64752 .92085 m .7385 .94782 L .68424 .98566 L p .656 .761 .927 r
F P
0 g
s
.68055 .62729 m .60029 .74616 L .59098 .72904 L p .932 .833 .724 r
F P
0 g
s
.59098 .72904 m .66354 .59356 L .68055 .62729 L p .932 .833 .724 r
F P
0 g
s
.35636 .7676 m .25105 .76923 L .2687 .81914 L p .665 .753 .916 r
F P
0 g
s
.2687 .81914 m .36602 .79748 L .35636 .7676 L p .665 .753 .916 r
F P
0 g
s
.21268 .86177 m .2687 .81914 L .25105 .76923 L p .831 .839 .853 r
F P
0 g
s
.78797 .93183 m .7385 .94782 L .76968 .90131 L p .789 .967 .917 r
F P
0 g
s
.76968 .90131 m .82689 .87476 L .78797 .93183 L p .789 .967 .917 r
F P
0 g
s
.5715 .79475 m .53001 .81966 L .53573 .81533 L p .509 .883 .681 r
F P
0 g
s
.53573 .81533 m .58986 .78087 L .5715 .79475 L p .509 .883 .681 r
F P
0 g
s
.64834 .43153 m .62934 .56493 L .5815 .54483 L p .831 .606 .597 r
F P
0 g
s
.5815 .54483 m .59291 .40735 L .64834 .43153 L p .831 .606 .597 r
F P
0 g
s
.25105 .76923 m .18987 .80088 L .21268 .86177 L p .831 .839 .853 r
F P
0 g
s
.21069 .90448 m .21268 .86177 L .18987 .80088 L p .98 .754 .343 r
F P
0 g
s
.64524 .81116 m .53573 .81533 L .53001 .81966 L p .699 .899 .968 r
F P
0 g
s
.53573 .81533 m .64524 .81116 L .66277 .78274 L p .75 .879 .938 r
F P
0 g
s
.76545 .7946 m .66277 .78274 L .64524 .81116 L p .653 .742 .915 r
F P
0 g
s
.21069 .90448 m .26465 .9255 L .30813 .96815 L p .173 .524 .92 r
F P
0 g
s
.38889 .93319 m .30813 .96815 L .26465 .9255 L p .646 .752 .926 r
F P
0 g
s
.30813 .96815 m .38889 .93319 L .42688 .95279 L p .646 .754 .928 r
F P
0 g
s
.42502 .73741 m .34754 .6101 L .37339 .57844 L p .425 .39 .716 r
F P
0 g
s
.34754 .6101 m .42502 .73741 L .42058 .75518 L p .225 .297 .729 r
F P
0 g
s
.41492 .55368 m .39951 .418 L .46065 .40012 L p .594 .408 .599 r
F P
0 g
s
.39951 .418 m .41492 .55368 L .37339 .57844 L p .476 .323 .594 r
F P
0 g
s
.51327 .8538 m .52366 .96665 L .47339 .9643 L p .702 .679 .825 r
F P
0 g
s
.52366 .96665 m .51327 .8538 L .52229 .85246 L p .672 .657 .826 r
F P
0 g
s
.52229 .85246 m .57265 .95961 L .52366 .96665 L p .672 .657 .826 r
F P
0 g
s
.58986 .78087 m .53573 .81533 L .53878 .81012 L p .821 1 .826 r
F P
0 g
s
.53878 .81012 m .59986 .76408 L .58986 .78087 L p .821 1 .826 r
F P
0 g
s
.504 .85335 m .47339 .9643 L .42688 .95279 L p .73 .708 .83 r
F P
0 g
s
.47339 .9643 m .504 .85335 L .51327 .8538 L p .702 .679 .825 r
F P
0 g
s
.48424 .81282 m .42592 .77277 L .42058 .75518 L p .164 .39 .836 r
F P
0 g
s
.42058 .75518 m .48266 .80738 L .48424 .81282 L p .164 .39 .836 r
F P
0 g
s
.48266 .80738 m .35636 .7676 L .36602 .79748 L p .495 .642 .921 r
F P
0 g
s
.36602 .79748 m .48424 .81282 L .48266 .80738 L p .495 .642 .921 r
F P
0 g
s
.57265 .95961 m .52229 .85246 L .53009 .84948 L p .638 .64 .835 r
F P
0 g
s
.53009 .84948 m .61542 .94385 L .57265 .95961 L p .638 .64 .835 r
F P
0 g
s
.66277 .78274 m .76545 .7946 L .76916 .74326 L p .652 .743 .917 r
F P
0 g
s
.76545 .7946 m .82481 .83188 L .83049 .76902 L p .44 .553 .873 r
F P
0 g
s
.83049 .76902 m .76916 .74326 L .76545 .7946 L p .44 .553 .873 r
F P
0 g
s
.59291 .40735 m .5815 .54483 L .52541 .53575 L p .756 .537 .6 r
F P
0 g
s
.52541 .53575 m .52778 .39641 L .59291 .40735 L p .756 .537 .6 r
F P
0 g
s
.18987 .80088 m .18769 .84395 L .21069 .90448 L p .98 .754 .343 r
F P
0 g
s
.26465 .9255 m .21069 .90448 L .18769 .84395 L p .326 .534 .903 r
F P
0 g
s
.66354 .59356 m .59098 .72904 L .5728 .71463 L p .871 .733 .707 r
F P
0 g
s
.5728 .71463 m .62934 .56493 L .66354 .59356 L p .871 .733 .707 r
F P
0 g
s
.49547 .85117 m .42688 .95279 L .38889 .93319 L p .753 .742 .842 r
F P
0 g
s
.42688 .95279 m .49547 .85117 L .504 .85335 L p .73 .708 .83 r
F P
0 g
s
.46762 .53883 m .46065 .40012 L .52778 .39641 L p .681 .474 .6 r
F P
0 g
s
.46065 .40012 m .46762 .53883 L .41492 .55368 L p .594 .408 .599 r
F P
0 g
s
.59986 .76408 m .53878 .81012 L .53882 .8046 L p .9 .929 .827 r
F P
0 g
s
.53882 .8046 m .60029 .74616 L .59986 .76408 L p .9 .929 .827 r
F P
0 g
s
.7385 .94782 m .64752 .92085 L .66536 .89287 L p .658 .761 .926 r
F P
0 g
s
.66536 .89287 m .76968 .90131 L .7385 .94782 L p .658 .761 .926 r
F P
0 g
s
.66277 .78274 m .53878 .81012 L .53573 .81533 L p .75 .879 .938 r
F P
0 g
s
.53878 .81012 m .66277 .78274 L .66406 .75219 L p .773 .843 .905 r
F P
0 g
s
.76916 .74326 m .66406 .75219 L .66277 .78274 L p .652 .743 .917 r
F P
0 g
s
.52778 .39641 m .52541 .53575 L .46762 .53883 L p .681 .474 .6 r
F P
0 g
s
.82481 .83188 m .82689 .87476 L .83265 .81227 L p 0 0 .157 r
F P
0 g
s
.83265 .81227 m .83049 .76902 L .82481 .83188 L p 0 0 .157 r
F P
0 g
s
.61542 .94385 m .53009 .84948 L .53584 .84516 L p .601 .63 .852 r
F P
0 g
s
.53584 .84516 m .64752 .92085 L .61542 .94385 L p .601 .63 .852 r
F P
0 g
s
.48266 .80738 m .42058 .75518 L .42502 .73741 L p .364 .444 .81 r
F P
0 g
s
.43891 .72142 m .37339 .57844 L .41492 .55368 L p .543 .45 .7 r
F P
0 g
s
.37339 .57844 m .43891 .72142 L .42502 .73741 L p .425 .39 .716 r
F P
0 g
s
.42502 .73741 m .48414 .80192 L .48266 .80738 L p .364 .444 .81 r
F P
0 g
s
.48414 .80192 m .36342 .73721 L .35636 .7676 L p .54 .63 .889 r
F P
0 g
s
.35636 .7676 m .48266 .80738 L .48414 .80192 L p .54 .63 .889 r
F P
0 g
s
.25105 .76923 m .35636 .7676 L .36342 .73721 L p .664 .754 .918 r
F P
0 g
s
.36342 .73721 m .26145 .71785 L .25105 .76923 L p .664 .754 .918 r
F P
0 g
s
.18987 .80088 m .25105 .76923 L .26145 .71785 L p .826 .906 .895 r
F P
0 g
s
.60029 .74616 m .53882 .8046 L .53583 .79936 L p .881 .83 .792 r
F P
0 g
s
.53583 .79936 m .59098 .72904 L .60029 .74616 L p .881 .83 .792 r
F P
0 g
s
.26465 .9255 m .36349 .90738 L .38889 .93319 L p .646 .752 .926 r
F P
0 g
s
.48859 .84747 m .38889 .93319 L .36349 .90738 L p .769 .781 .862 r
F P
0 g
s
.38889 .93319 m .48859 .84747 L .49547 .85117 L p .753 .742 .842 r
F P
0 g
s
.18769 .84395 m .24663 .87632 L .26465 .9255 L p .326 .534 .903 r
F P
0 g
s
.36349 .90738 m .26465 .9255 L .24663 .87632 L p .646 .75 .925 r
F P
0 g
s
.62934 .56493 m .5728 .71463 L .5477 .70458 L p .809 .657 .694 r
F P
0 g
s
.5477 .70458 m .5815 .54483 L .62934 .56493 L p .809 .657 .694 r
F P
0 g
s
.82689 .87476 m .76968 .90131 L .77352 .85071 L p .838 .905 .884 r
F P
0 g
s
.77352 .85071 m .83265 .81227 L .82689 .87476 L p .838 .905 .884 r
F P
0 g
s
.48414 .80192 m .42502 .73741 L .43891 .72142 L p .488 .482 .777 r
F P
0 g
s
.504 .85335 m .48865 .94185 L .51847 .94325 L p .719 .609 .733 r
F P
0 g
s
.51847 .94325 m .51327 .8538 L .504 .85335 L p .719 .609 .733 r
F P
0 g
s
.5255 1.10783 m .51847 .94325 L .48865 .94185 L p .721 .572 .686 r
F P
0 g
s
.51327 .8538 m .51847 .94325 L .5475 .93906 L p .667 .569 .735 r
F P
0 g
s
.51847 .94325 m .5255 1.10783 L .58173 1.1001 L p .66 .524 .687 r
F P
0 g
s
.58173 1.1001 m .5475 .93906 L .51847 .94325 L p .66 .524 .687 r
F P
0 g
s
.49547 .85117 m .46113 .93499 L .48865 .94185 L p .767 .656 .739 r
F P
0 g
s
.48865 .94185 m .504 .85335 L .49547 .85117 L p .767 .656 .739 r
F P
0 g
s
.46782 1.10525 m .48865 .94185 L .46113 .93499 L p .779 .626 .69 r
F P
0 g
s
.48865 .94185 m .46782 1.10525 L .5255 1.10783 L p .721 .572 .686 r
F P
0 g
s
.66406 .75219 m .53882 .8046 L .53878 .81012 L p .773 .843 .905 r
F P
0 g
s
.53882 .8046 m .66406 .75219 L .64858 .7228 L p .774 .801 .875 r
F P
0 g
s
.66406 .75219 m .76916 .74326 L .74439 .69328 L p .651 .745 .919 r
F P
0 g
s
.74439 .69328 m .64858 .7228 L .66406 .75219 L p .651 .745 .919 r
F P
0 g
s
.64752 .92085 m .53584 .84516 L .53891 .83998 L p .561 .628 .875 r
F P
0 g
s
.53891 .83998 m .66536 .89287 L .64752 .92085 L p .561 .628 .875 r
F P
0 g
s
.5475 .93906 m .52229 .85246 L .51327 .8538 L p .667 .569 .735 r
F P
0 g
s
.52229 .85246 m .5475 .93906 L .57274 .92967 L p .608 .533 .745 r
F P
0 g
s
.5475 .93906 m .58173 1.1001 L .6309 1.08278 L p .589 .478 .694 r
F P
0 g
s
.6309 1.08278 m .57274 .92967 L .5475 .93906 L p .589 .478 .694 r
F P
0 g
s
.26145 .71785 m .20165 .73776 L .18987 .80088 L p .826 .906 .895 r
F P
0 g
s
.18769 .84395 m .18987 .80088 L .20165 .73776 L p 0 0 .084 r
F P
0 g
s
.46081 .70899 m .41492 .55368 L .46762 .53883 L p .625 .5 .69 r
F P
0 g
s
.41492 .55368 m .46081 .70899 L .43891 .72142 L p .543 .45 .7 r
F P
0 g
s
.59098 .72904 m .53583 .79936 L .53012 .79498 L p .838 .747 .764 r
F P
0 g
s
.53012 .79498 m .5728 .71463 L .59098 .72904 L p .838 .747 .764 r
F P
0 g
s
.48859 .84747 m .43881 .92334 L .46113 .93499 L p .814 .713 .753 r
F P
0 g
s
.46113 .93499 m .49547 .85117 L .48859 .84747 L p .814 .713 .753 r
F P
0 g
s
.41441 1.0926 m .46113 .93499 L .43881 .92334 L p .838 .691 .7 r
F P
0 g
s
.46113 .93499 m .41441 1.0926 L .46782 1.10525 L p .779 .626 .69 r
F P
0 g
s
.57274 .92967 m .53009 .84948 L .52229 .85246 L p .608 .533 .745 r
F P
0 g
s
.52832 1.25912 m .5255 1.10783 L .46782 1.10525 L p .719 .51 .607 r
F P
0 g
s
.5255 1.10783 m .52832 1.25912 L .59559 1.25032 L p .644 .451 .607 r
F P
0 g
s
.59559 1.25032 m .58173 1.1001 L .5255 1.10783 L p .644 .451 .607 r
F P
0 g
s
.64858 .7228 m .53583 .79936 L .53882 .8046 L p .774 .801 .875 r
F P
0 g
s
.53009 .84948 m .57274 .92967 L .5915 .91604 L p .535 .5 .763 r
F P
0 g
s
.5915 .91604 m .53584 .84516 L .53009 .84948 L p .535 .5 .763 r
F P
0 g
s
.57274 .92967 m .6309 1.08278 L .66791 1.05744 L p .495 .425 .708 r
F P
0 g
s
.66791 1.05744 m .5915 .91604 L .57274 .92967 L p .495 .425 .708 r
F P
0 g
s
.48854 .79704 m .43891 .72142 L .46081 .70899 L p .573 .516 .753 r
F P
0 g
s
.43891 .72142 m .48854 .79704 L .48414 .80192 L p .488 .482 .777 r
F P
0 g
s
.76916 .74326 m .83049 .76902 L .80081 .70742 L p .344 .559 .916 r
F P
0 g
s
.80081 .70742 m .74439 .69328 L .76916 .74326 L p .344 .559 .916 r
F P
0 g
s
.45935 1.25618 m .46782 1.10525 L .41441 1.0926 L p .789 .571 .606 r
F P
0 g
s
.46782 1.10525 m .45935 1.25618 L .52832 1.25912 L p .719 .51 .607 r
F P
0 g
s
.5815 .54483 m .5477 .70458 L .51846 .70005 L p .751 .598 .687 r
F P
0 g
s
.51846 .70005 m .52541 .53575 L .5815 .54483 L p .751 .598 .687 r
F P
0 g
s
.36342 .73721 m .48414 .80192 L .48854 .79704 L p .582 .628 .862 r
F P
0 g
s
.36349 .90738 m .48411 .84266 L .48859 .84747 L p .769 .781 .862 r
F P
0 g
s
.43881 .92334 m .48859 .84747 L .48411 .84266 L p .86 .785 .777 r
F P
0 g
s
.24663 .87632 m .35364 .87795 L .36349 .90738 L p .646 .75 .925 r
F P
0 g
s
.48411 .84266 m .36349 .90738 L .35364 .87795 L p .776 .823 .89 r
F P
0 g
s
.53583 .79936 m .64858 .7228 L .61764 .6979 L p .762 .76 .851 r
F P
0 g
s
.61764 .6979 m .53012 .79498 L .53583 .79936 L p .762 .76 .851 r
F P
0 g
s
.53584 .84516 m .5915 .91604 L .60171 .89957 L p .434 .465 .792 r
F P
0 g
s
.60171 .89957 m .53891 .83998 L .53584 .84516 L p .434 .465 .792 r
F P
0 g
s
.48854 .79704 m .38686 .70965 L .36342 .73721 L p .582 .628 .862 r
F P
0 g
s
.26145 .71785 m .36342 .73721 L .38686 .70965 L p .662 .755 .919 r
F P
0 g
s
.46081 .70899 m .49539 .79327 L .48854 .79704 L p .573 .516 .753 r
F P
0 g
s
.38686 .70965 m .48854 .79704 L .49539 .79327 L p .621 .634 .842 r
F P
0 g
s
.35364 .87795 m .48252 .83724 L .48411 .84266 L p .776 .823 .89 r
F P
0 g
s
.42407 .9081 m .48411 .84266 L .48252 .83724 L p .895 .877 .81 r
F P
0 g
s
.48411 .84266 m .42407 .9081 L .43881 .92334 L p .86 .785 .777 r
F P
0 g
s
.58173 1.1001 m .59559 1.25032 L .65457 1.23056 L p .553 .383 .605 r
F P
0 g
s
.65457 1.23056 m .6309 1.08278 L .58173 1.1001 L p .553 .383 .605 r
F P
0 g
s
.48836 .70158 m .46762 .53883 L .52541 .53575 L p .691 .547 .686 r
F P
0 g
s
.46762 .53883 m .48836 .70158 L .46081 .70899 L p .625 .5 .69 r
F P
0 g
s
.37068 1.07103 m .43881 .92334 L .42407 .9081 L p .899 .776 .717 r
F P
0 g
s
.43881 .92334 m .37068 1.07103 L .41441 1.0926 L p .838 .691 .7 r
F P
0 g
s
.76968 .90131 m .66536 .89287 L .66671 .86277 L p .66 .76 .924 r
F P
0 g
s
.66671 .86277 m .77352 .85071 L .76968 .90131 L p .66 .76 .924 r
F P
0 g
s
.5728 .71463 m .53012 .79498 L .52231 .79194 L p .791 .683 .745 r
F P
0 g
s
.52231 .79194 m .5477 .70458 L .5728 .71463 L p .791 .683 .745 r
F P
0 g
s
.53012 .79498 m .61764 .6979 L .57448 .68044 L p .742 .724 .835 r
F P
0 g
s
.57448 .68044 m .52231 .79194 L .53012 .79498 L p .742 .724 .835 r
F P
0 g
s
.66536 .89287 m .53891 .83998 L .53894 .83448 L p .516 .635 .905 r
F P
0 g
s
.53891 .83998 m .60171 .89957 L .60217 .88197 L p .279 .422 .827 r
F P
0 g
s
.60217 .88197 m .53894 .83448 L .53891 .83998 L p .279 .422 .827 r
F P
0 g
s
.52541 .53575 m .51846 .70005 L .48836 .70158 L p .691 .547 .686 r
F P
0 g
s
.48836 .70158 m .50393 .79104 L .49539 .79327 L p .639 .551 .739 r
F P
0 g
s
.49539 .79327 m .46081 .70899 L .48836 .70158 L p .639 .551 .739 r
F P
0 g
s
.42437 .68813 m .49539 .79327 L .50393 .79104 L p .656 .647 .83 r
F P
0 g
s
.49539 .79327 m .42437 .68813 L .38686 .70965 L p .621 .634 .842 r
F P
0 g
s
.5477 .70458 m .52231 .79194 L .51325 .79057 L p .744 .631 .735 r
F P
0 g
s
.51325 .79057 m .51846 .70005 L .5477 .70458 L p .744 .631 .735 r
F P
0 g
s
.52231 .79194 m .57448 .68044 L .52394 .67256 L p .716 .693 .826 r
F P
0 g
s
.52394 .67256 m .51325 .79057 L .52231 .79194 L p .716 .693 .826 r
F P
0 g
s
.3608 .848 m .48401 .83181 L .48252 .83724 L p .765 .863 .922 r
F P
0 g
s
.48252 .83724 m .35364 .87795 L .3608 .848 L p .765 .863 .922 r
F P
0 g
s
.4186 .89083 m .48252 .83724 L .48401 .83181 L p .882 .974 .837 r
F P
0 g
s
.48252 .83724 m .4186 .89083 L .42407 .9081 L p .895 .877 .81 r
F P
0 g
s
.51846 .70005 m .51325 .79057 L .50393 .79104 L p .694 .588 .733 r
F P
0 g
s
.50393 .79104 m .48836 .70158 L .51846 .70005 L p .694 .588 .733 r
F P
0 g
s
.47188 .67523 m .50393 .79104 L .51325 .79057 L p .688 .667 .824 r
F P
0 g
s
.50393 .79104 m .47188 .67523 L .42437 .68813 L p .656 .647 .83 r
F P
0 g
s
.51325 .79057 m .52394 .67256 L .47188 .67523 L p .688 .667 .824 r
F P
0 g
s
.5915 .91604 m .66791 1.05744 L .68865 1.02655 L p .35 .356 .726 r
F P
0 g
s
.68865 1.02655 m .60171 .89957 L .5915 .91604 L p .35 .356 .726 r
F P
0 g
s
.53894 .83448 m .66671 .86277 L .66536 .89287 L p .516 .635 .905 r
F P
0 g
s
.66671 .86277 m .53894 .83448 L .53594 .82926 L p .471 .653 .939 r
F P
0 g
s
.53894 .83448 m .60217 .88197 L .59266 .86516 L p .029 .351 .827 r
F P
0 g
s
.59266 .86516 m .53594 .82926 L .53894 .83448 L p .029 .351 .827 r
F P
0 g
s
.39539 1.24177 m .41441 1.0926 L .37068 1.07103 L p .863 .643 .604 r
F P
0 g
s
.41441 1.0926 m .39539 1.24177 L .45935 1.25618 L p .789 .571 .606 r
F P
0 g
s
.20165 .73776 m .19951 .78118 L .18769 .84395 L p 0 0 .084 r
F P
0 g
s
.24663 .87632 m .18769 .84395 L .19951 .78118 L p .442 .543 .864 r
F P
0 g
s
.38463 .82084 m .48843 .82695 L .48401 .83181 L p .728 .893 .955 r
F P
0 g
s
.48401 .83181 m .3608 .848 L .38463 .82084 L p .728 .893 .955 r
F P
0 g
s
.42313 .87338 m .48401 .83181 L .48843 .82695 L p .703 .978 .781 r
F P
0 g
s
.48401 .83181 m .42313 .87338 L .4186 .89083 L p .882 .974 .837 r
F P
0 g
s
.64858 .7228 m .74439 .69328 L .6928 .65049 L p .651 .747 .92 r
F P
0 g
s
.6928 .65049 m .61764 .6979 L .64858 .7228 L p .651 .747 .92 r
F P
0 g
s
.53594 .82926 m .65097 .8338 L .66671 .86277 L p .471 .653 .939 r
F P
0 g
s
.65097 .8338 m .53594 .82926 L .5302 .82489 L p .432 .683 .969 r
F P
0 g
s
.53594 .82926 m .59266 .86516 L .5741 .851 L p 0 .233 .686 r
F P
0 g
s
.5741 .851 m .5302 .82489 L .53594 .82926 L p 0 .233 .686 r
F P
0 g
s
.4228 .79962 m .4953 .82319 L .48843 .82695 L p .661 .899 .98 r
F P
0 g
s
.48843 .82695 m .38463 .82084 L .4228 .79962 L p .661 .899 .98 r
F P
0 g
s
.48843 .82695 m .43731 .85767 L .42313 .87338 L p .703 .978 .781 r
F P
0 g
s
.43731 .85767 m .48843 .82695 L .4953 .82319 L p 0 0 0 r
F P
0 g
s
.3413 1.04258 m .42407 .9081 L .4186 .89083 L p .951 .887 .732 r
F P
0 g
s
.42407 .9081 m .3413 1.04258 L .37068 1.07103 L p .899 .776 .717 r
F P
0 g
s
.83049 .76902 m .83265 .81227 L .80281 .75101 L p .971 .698 .283 r
F P
0 g
s
.80281 .75101 m .80081 .70742 L .83049 .76902 L p .971 .698 .283 r
F P
0 g
s
.5302 .82489 m .6195 .80926 L .65097 .8338 L p .432 .683 .969 r
F P
0 g
s
.6195 .80926 m .5302 .82489 L .52236 .82186 L p .412 .724 .989 r
F P
0 g
s
.5302 .82489 m .5741 .851 L .54846 .84113 L p .462 0 0 r
F P
0 g
s
.54846 .84113 m .52236 .82186 L .5302 .82489 L p .462 0 0 r
F P
0 g
s
.6309 1.08278 m .65457 1.23056 L .69919 1.20159 L p .42 .292 .599 r
F P
0 g
s
.69919 1.20159 m .66791 1.05744 L .6309 1.08278 L p .42 .292 .599 r
F P
0 g
s
.38686 .70965 m .29994 .67073 L .26145 .71785 L p .662 .755 .919 r
F P
0 g
s
.20165 .73776 m .26145 .71785 L .29994 .67073 L p .768 .957 .933 r
F P
0 g
s
.47115 .78691 m .50389 .82096 L .4953 .82319 L p .571 .875 .994 r
F P
0 g
s
.4953 .82319 m .4228 .79962 L .47115 .78691 L p .571 .875 .994 r
F P
0 g
s
.45968 .84547 m .4953 .82319 L .50389 .82096 L p .092 0 0 r
F P
0 g
s
.4953 .82319 m .45968 .84547 L .43731 .85767 L p 0 0 0 r
F P
0 g
s
.52236 .82186 m .57558 .79205 L .6195 .80926 L p .412 .724 .989 r
F P
0 g
s
.57558 .79205 m .52236 .82186 L .51325 .8205 L p .427 .774 .997 r
F P
0 g
s
.52236 .82186 m .54846 .84113 L .51858 .83668 L p .451 0 0 r
F P
0 g
s
.51858 .83668 m .51325 .8205 L .52236 .82186 L p .451 0 0 r
F P
0 g
s
.52414 .78427 m .51325 .8205 L .50389 .82096 L p .484 .828 .998 r
F P
0 g
s
.50389 .82096 m .47115 .78691 L .52414 .78427 L p .484 .828 .998 r
F P
0 g
s
.48782 .83819 m .50389 .82096 L .51325 .8205 L p .328 0 0 r
F P
0 g
s
.50389 .82096 m .48782 .83819 L .45968 .84547 L p .092 0 0 r
F P
0 g
s
.51325 .8205 m .52414 .78427 L .57558 .79205 L p .427 .774 .997 r
F P
0 g
s
.51325 .8205 m .51858 .83668 L .48782 .83819 L p .328 0 0 r
F P
0 g
s
.29994 .67073 m .38686 .70965 L .42437 .68813 L p .66 .755 .921 r
F P
0 g
s
.60171 .89957 m .68865 1.02655 L .69044 .99323 L p .088 .239 .726 r
F P
0 g
s
.69044 .99323 m .60217 .88197 L .60171 .89957 L p .088 .239 .726 r
F P
0 g
s
.19951 .78118 m .25714 .82565 L .24663 .87632 L p .442 .543 .864 r
F P
0 g
s
.35364 .87795 m .24663 .87632 L .25714 .82565 L p .648 .748 .923 r
F P
0 g
s
.25714 .82565 m .3608 .848 L .35364 .87795 L p .648 .748 .923 r
F P
0 g
s
.34283 1.21714 m .37068 1.07103 L .3413 1.04258 L p .945 .736 .59 r
F P
0 g
s
.37068 1.07103 m .34283 1.21714 L .39539 1.24177 L p .863 .643 .604 r
F P
0 g
s
.32972 1.01005 m .4186 .89083 L .42313 .87338 L p .901 .977 .687 r
F P
0 g
s
.4186 .89083 m .32972 1.01005 L .3413 1.04258 L p .951 .887 .732 r
F P
0 g
s
.61764 .6979 m .6928 .65049 L .61961 .62023 L p .652 .749 .921 r
F P
0 g
s
.61961 .62023 m .57448 .68044 L .61764 .6979 L p .652 .749 .921 r
F P
0 g
s
.83265 .81227 m .77352 .85071 L .74838 .80142 L p .833 .831 .845 r
F P
0 g
s
.74838 .80142 m .80281 .75101 L .83265 .81227 L p .833 .831 .845 r
F P
0 g
s
.52636 1.37186 m .52832 1.25912 L .45935 1.25618 L p .701 .411 .481 r
F P
0 g
s
.52832 1.25912 m .52636 1.37186 L .58623 1.36432 L p .608 .335 .478 r
F P
0 g
s
.58623 1.36432 m .59559 1.25032 L .52832 1.25912 L p .608 .335 .478 r
F P
0 g
s
.77352 .85071 m .66671 .86277 L .65097 .8338 L p .661 .758 .922 r
F P
0 g
s
.74439 .69328 m .80081 .70742 L .73741 .65434 L p .234 .576 .942 r
F P
0 g
s
.73741 .65434 m .6928 .65049 L .74439 .69328 L p .234 .576 .942 r
F P
0 g
s
.60217 .88197 m .69044 .99323 L .67251 .96109 L p 0 .018 .579 r
F P
0 g
s
.67251 .96109 m .59266 .86516 L .60217 .88197 L p 0 .018 .579 r
F P
0 g
s
.46497 1.36934 m .45935 1.25618 L .39539 1.24177 L p .784 .478 .47 r
F P
0 g
s
.45935 1.25618 m .46497 1.36934 L .52636 1.37186 L p .701 .411 .481 r
F P
0 g
s
.3631 .63357 m .42437 .68813 L .47188 .67523 L p .657 .755 .922 r
F P
0 g
s
.42437 .68813 m .3631 .63357 L .29994 .67073 L p .66 .755 .921 r
F P
0 g
s
.66791 1.05744 m .69919 1.20159 L .72447 1.16613 L p .181 .136 .568 r
F P
0 g
s
.72447 1.16613 m .68865 1.02655 L .66791 1.05744 L p .181 .136 .568 r
F P
0 g
s
.29994 .67073 m .24853 .67949 L .20165 .73776 L p .768 .957 .933 r
F P
0 g
s
.19951 .78118 m .20165 .73776 L .24853 .67949 L p .094 0 .394 r
F P
0 g
s
.59559 1.25032 m .58623 1.36432 L .63862 1.34741 L p .486 .233 .455 r
F P
0 g
s
.63862 1.34741 m .65457 1.23056 L .59559 1.25032 L p .486 .233 .455 r
F P
0 g
s
.42313 .87338 m .33775 .97686 L .32972 1.01005 L p .901 .977 .687 r
F P
0 g
s
.33775 .97686 m .42313 .87338 L .43731 .85767 L p 0 0 0 r
F P
0 g
s
.65097 .8338 m .74838 .80142 L .77352 .85071 L p .661 .758 .922 r
F P
0 g
s
.57448 .68044 m .61961 .62023 L .53321 .6065 L p .653 .752 .922 r
F P
0 g
s
.53321 .6065 m .52394 .67256 L .57448 .68044 L p .653 .752 .922 r
F P
0 g
s
.29625 .77918 m .38463 .82084 L .3608 .848 L p .65 .747 .921 r
F P
0 g
s
.3608 .848 m .25714 .82565 L .29625 .77918 L p .65 .747 .921 r
F P
0 g
s
.44406 .61116 m .47188 .67523 L .52394 .67256 L p .655 .753 .922 r
F P
0 g
s
.47188 .67523 m .44406 .61116 L .3631 .63357 L p .657 .755 .922 r
F P
0 g
s
.59266 .86516 m .67251 .96109 L .63633 .93379 L p .718 .197 0 r
F P
0 g
s
.63633 .93379 m .5741 .851 L .59266 .86516 L p .718 .197 0 r
F P
0 g
s
.52394 .67256 m .53321 .6065 L .44406 .61116 L p .655 .753 .922 r
F P
0 g
s
.40809 1.357 m .39539 1.24177 L .34283 1.21714 L p .87 .545 .433 r
F P
0 g
s
.39539 1.24177 m .40809 1.357 L .46497 1.36934 L p .784 .478 .47 r
F P
0 g
s
.30725 1.18455 m .3413 1.04258 L .32972 1.01005 L p .999 .841 .519 r
F P
0 g
s
.3413 1.04258 m .30725 1.18455 L .34283 1.21714 L p .945 .736 .59 r
F P
0 g
s
.24853 .67949 m .29994 .67073 L .3631 .63357 L p .626 .949 .941 r
F P
0 g
s
.36505 .94668 m .43731 .85767 L .45968 .84547 L p .063 0 0 r
F P
0 g
s
.43731 .85767 m .36505 .94668 L .33775 .97686 L p 0 0 0 r
F P
0 g
s
.24853 .67949 m .24668 .72323 L .19951 .78118 L p .094 0 .394 r
F P
0 g
s
.25714 .82565 m .19951 .78118 L .24668 .72323 L p .527 .556 .829 r
F P
0 g
s
.74838 .80142 m .65097 .8338 L .6195 .80926 L p .661 .756 .92 r
F P
0 g
s
.65457 1.23056 m .63862 1.34741 L .67813 1.32267 L p .284 .064 .394 r
F P
0 g
s
.67813 1.32267 m .69919 1.20159 L .65457 1.23056 L p .284 .064 .394 r
F P
0 g
s
.5741 .851 m .63633 .93379 L .58564 .9146 L p .742 .245 .051 r
F P
0 g
s
.58564 .9146 m .54846 .84113 L .5741 .851 L p .742 .245 .051 r
F P
0 g
s
.24668 .72323 m .29625 .77918 L .25714 .82565 L p .527 .556 .829 r
F P
0 g
s
.80081 .70742 m .80281 .75101 L .73899 .69822 L p .937 .641 .455 r
F P
0 g
s
.73899 .69822 m .73741 .65434 L .80081 .70742 L p .937 .641 .455 r
F P
0 g
s
.68865 1.02655 m .72447 1.16613 L .72707 1.12775 L p 0 0 .406 r
F P
0 g
s
.72707 1.12775 m .69044 .99323 L .68865 1.02655 L p 0 0 .406 r
F P
0 g
s
.40902 .92305 m .45968 .84547 L .48782 .83819 L p .373 0 .116 r
F P
0 g
s
.45968 .84547 m .40902 .92305 L .36505 .94668 L p .063 0 0 r
F P
0 g
s
.6928 .65049 m .73741 .65434 L .64655 .61663 L p .144 .602 .928 r
F P
0 g
s
.64655 .61663 m .61961 .62023 L .6928 .65049 L p .144 .602 .928 r
F P
0 g
s
.54846 .84113 m .58564 .9146 L .52617 .90593 L p .663 .205 .155 r
F P
0 g
s
.52617 .90593 m .51858 .83668 L .54846 .84113 L p .663 .205 .155 r
F P
0 g
s
.36048 .74251 m .4228 .79962 L .38463 .82084 L p .652 .747 .92 r
F P
0 g
s
.38463 .82084 m .29625 .77918 L .36048 .74251 L p .652 .747 .92 r
F P
0 g
s
.46488 .90887 m .48782 .83819 L .51858 .83668 L p .547 .115 .173 r
F P
0 g
s
.48782 .83819 m .46488 .90887 L .40902 .92305 L p .373 0 .116 r
F P
0 g
s
.51858 .83668 m .52617 .90593 L .46488 .90887 L p .547 .115 .173 r
F P
0 g
s
.36145 1.33595 m .34283 1.21714 L .30725 1.18455 L p .95 .608 .329 r
F P
0 g
s
.34283 1.21714 m .36145 1.33595 L .40809 1.357 L p .87 .545 .433 r
F P
0 g
s
.6195 .80926 m .69594 .75921 L .74838 .80142 L p .661 .756 .92 r
F P
0 g
s
.69594 .75921 m .6195 .80926 L .57558 .79205 L p .66 .753 .919 r
F P
0 g
s
.29291 1.14715 m .32972 1.01005 L .33775 .97686 L p .712 .726 .206 r
F P
0 g
s
.32972 1.01005 m .29291 1.14715 L .30725 1.18455 L p .999 .841 .519 r
F P
0 g
s
.32661 .63327 m .3631 .63357 L .44406 .61116 L p .418 .861 .908 r
F P
0 g
s
.3631 .63357 m .32661 .63327 L .24853 .67949 L p .626 .949 .941 r
F P
0 g
s
.80281 .75101 m .74838 .80142 L .69594 .75921 L p .806 .765 .815 r
F P
0 g
s
.69594 .75921 m .73899 .69822 L .80281 .75101 L p .806 .765 .815 r
F P
0 g
s
.24668 .72323 m .24853 .67949 L .32661 .63327 L p .399 .197 .487 r
F P
0 g
s
.44285 .72039 m .47115 .78691 L .4228 .79962 L p .654 .748 .919 r
F P
0 g
s
.4228 .79962 m .36048 .74251 L .44285 .72039 L p .654 .748 .919 r
F P
0 g
s
.69919 1.20159 m .67813 1.32267 L .70034 1.29246 L p 0 0 .211 r
F P
0 g
s
.70034 1.29246 m .72447 1.16613 L .69919 1.20159 L p 0 0 .211 r
F P
0 g
s
.61961 .62023 m .64655 .61663 L .53874 .59946 L p .132 .65 .888 r
F P
0 g
s
.53874 .59946 m .53321 .6065 L .61961 .62023 L p .132 .65 .888 r
F P
0 g
s
.57558 .79205 m .62149 .72934 L .69594 .75921 L p .66 .753 .919 r
F P
0 g
s
.62149 .72934 m .57558 .79205 L .52414 .78427 L p .659 .751 .918 r
F P
0 g
s
.69044 .99323 m .72707 1.12775 L .70588 1.09056 L p .877 .53 .033 r
F P
0 g
s
.70588 1.09056 m .67251 .96109 L .69044 .99323 L p .877 .53 .033 r
F P
0 g
s
.53357 .71579 m .52414 .78427 L .47115 .78691 L p .657 .749 .918 r
F P
0 g
s
.47115 .78691 m .44285 .72039 L .53357 .71579 L p .657 .749 .918 r
F P
0 g
s
.52 1.42408 m .52636 1.37186 L .46497 1.36934 L p .596 .143 .147 r
F P
0 g
s
.52636 1.37186 m .52 1.42408 L .55548 1.4197 L p .468 .033 .129 r
F P
0 g
s
.55548 1.4197 m .58623 1.36432 L .52636 1.37186 L p .468 .033 .129 r
F P
0 g
s
.42742 .60528 m .44406 .61116 L .53321 .6065 L p .23 .741 .876 r
F P
0 g
s
.44406 .61116 m .42742 .60528 L .32661 .63327 L p .418 .861 .908 r
F P
0 g
s
.52414 .78427 m .53357 .71579 L .62149 .72934 L p .659 .751 .918 r
F P
0 g
s
.32529 .67726 m .36048 .74251 L .29625 .77918 L p .592 .575 .803 r
F P
0 g
s
.29625 .77918 m .24668 .72323 L .32529 .67726 L p .592 .575 .803 r
F P
0 g
s
.48358 1.42262 m .46497 1.36934 L .40809 1.357 L p .686 .201 .094 r
F P
0 g
s
.46497 1.36934 m .48358 1.42262 L .52 1.42408 L p .596 .143 .147 r
F P
0 g
s
.53321 .6065 m .53874 .59946 L .42742 .60528 L p .23 .741 .876 r
F P
0 g
s
.33005 1.30814 m .30725 1.18455 L .29291 1.14715 L p .847 .556 .019 r
F P
0 g
s
.30725 1.18455 m .33005 1.30814 L .36145 1.33595 L p .95 .608 .329 r
F P
0 g
s
.32661 .63327 m .32529 .67726 L .24668 .72323 L p .399 .197 .487 r
F P
0 g
s
.73741 .65434 m .73899 .69822 L .6475 .66069 L p .842 .557 .506 r
F P
0 g
s
.6475 .66069 m .64655 .61663 L .73741 .65434 L p .842 .557 .506 r
F P
0 g
s
.58623 1.36432 m .55548 1.4197 L .58635 1.40989 L p .263 0 .031 r
F P
0 g
s
.58635 1.40989 m .63862 1.34741 L .58623 1.36432 L p .263 0 .031 r
F P
0 g
s
.33775 .97686 m .30213 1.10882 L .29291 1.14715 L p .712 .726 .206 r
F P
0 g
s
.30213 1.10882 m .33775 .97686 L .36505 .94668 L p 0 0 .205 r
F P
0 g
s
.44995 1.41544 m .40809 1.357 L .36145 1.33595 L p .727 .201 0 r
F P
0 g
s
.40809 1.357 m .44995 1.41544 L .48358 1.42262 L p .686 .201 .094 r
F P
0 g
s
.73899 .69822 m .69594 .75921 L .62149 .72934 L p .772 .711 .795 r
F P
0 g
s
.72447 1.16613 m .70034 1.29246 L .70238 1.25984 L p .811 .747 .226 r
F P
0 g
s
.70238 1.25984 m .72707 1.12775 L .72447 1.16613 L p .811 .747 .226 r
F P
0 g
s
.67251 .96109 m .70588 1.09056 L .66248 1.05885 L p .92 .553 .311 r
F P
0 g
s
.66248 1.05885 m .63633 .93379 L .67251 .96109 L p .92 .553 .311 r
F P
0 g
s
.32529 .67726 m .32661 .63327 L .42742 .60528 L p .558 .323 .516 r
F P
0 g
s
.63862 1.34741 m .58635 1.40989 L .60937 1.39562 L p 0 0 0 r
F P
0 g
s
.60937 1.39562 m .67813 1.32267 L .63862 1.34741 L p 0 0 0 r
F P
0 g
s
.62149 .72934 m .6475 .66069 L .73899 .69822 L p .772 .711 .795 r
F P
0 g
s
.42681 .64941 m .44285 .72039 L .36048 .74251 L p .646 .6 .788 r
F P
0 g
s
.36048 .74251 m .32529 .67726 L .42681 .64941 L p .646 .6 .788 r
F P
0 g
s
.33471 1.07383 m .36505 .94668 L .40902 .92305 L p .337 .081 .371 r
F P
0 g
s
.36505 .94668 m .33471 1.07383 L .30213 1.10882 L p 0 0 .205 r
F P
0 g
s
.42259 1.40326 m .36145 1.33595 L .33005 1.30814 L p .601 .084 0 r
F P
0 g
s
.36145 1.33595 m .42259 1.40326 L .44995 1.41544 L p .727 .201 0 r
F P
0 g
s
.64655 .61663 m .6475 .66069 L .53893 .64361 L p .754 .483 .522 r
F P
0 g
s
.53893 .64361 m .53874 .59946 L .64655 .61663 L p .754 .483 .522 r
F P
0 g
s
.29291 1.14715 m .31758 1.27631 L .33005 1.30814 L p .847 .556 .019 r
F P
0 g
s
.31758 1.27631 m .29291 1.14715 L .30213 1.10882 L p 0 0 .409 r
F P
0 g
s
.6475 .66069 m .62149 .72934 L .53357 .71579 L p .734 .666 .784 r
F P
0 g
s
.42742 .60528 m .42681 .64941 L .32529 .67726 L p .558 .323 .516 r
F P
0 g
s
.42681 .64941 m .42742 .60528 L .53874 .59946 L p .665 .41 .525 r
F P
0 g
s
.63633 .93379 m .66248 1.05885 L .60132 1.03651 L p .833 .491 .407 r
F P
0 g
s
.60132 1.03651 m .58564 .9146 L .63633 .93379 L p .833 .491 .407 r
F P
0 g
s
.67813 1.32267 m .60937 1.39562 L .62199 1.37833 L p .653 .901 .573 r
F P
0 g
s
.62199 1.37833 m .70034 1.29246 L .67813 1.32267 L p .653 .901 .573 r
F P
0 g
s
.53874 .59946 m .53893 .64361 L .42681 .64941 L p .665 .41 .525 r
F P
0 g
s
.53893 .64361 m .53357 .71579 L .44285 .72039 L p .692 .63 .782 r
F P
0 g
s
.44285 .72039 m .42681 .64941 L .53893 .64361 L p .692 .63 .782 r
F P
0 g
s
.53357 .71579 m .53893 .64361 L .6475 .66069 L p .734 .666 .784 r
F P
0 g
s
.38764 1.04635 m .40902 .92305 L .46488 .90887 L p .525 .242 .428 r
F P
0 g
s
.40902 .92305 m .38764 1.04635 L .33471 1.07383 L p .337 .081 .371 r
F P
0 g
s
.72707 1.12775 m .70238 1.25984 L .68337 1.22832 L p .998 .798 .508 r
F P
0 g
s
.68337 1.22832 m .70588 1.09056 L .72707 1.12775 L p .998 .798 .508 r
F P
0 g
s
.33005 1.30814 m .40446 1.38729 L .42259 1.40326 L p .601 .084 0 r
F P
0 g
s
.40446 1.38729 m .33005 1.30814 L .31758 1.27631 L p 0 .156 .698 r
F P
0 g
s
.58564 .9146 m .60132 1.03651 L .52935 1.02639 L p .741 .421 .44 r
F P
0 g
s
.52935 1.02639 m .52617 .90593 L .58564 .9146 L p .741 .421 .44 r
F P
0 g
s
.45515 1.02982 m .46488 .90887 L .52617 .90593 L p .645 .344 .446 r
F P
0 g
s
.46488 .90887 m .45515 1.02982 L .38764 1.04635 L p .525 .242 .428 r
F P
0 g
s
.52617 .90593 m .52935 1.02639 L .45515 1.02982 L p .645 .344 .446 r
F P
0 g
s
.32601 1.24378 m .30213 1.10882 L .33471 1.07383 L p .244 .155 .552 r
F P
0 g
s
.30213 1.10882 m .32601 1.24378 L .31758 1.27631 L p 0 0 .409 r
F P
0 g
s
.51075 1.40299 m .52 1.42408 L .48358 1.42262 L closepath p .337 .775 .966 r
F P
0 g
s
.51075 1.40299 m .55548 1.4197 L .52 1.42408 L closepath p .418 .833 .969 r
F P
0 g
s
.70034 1.29246 m .62199 1.37833 L .62268 1.35983 L p .924 .974 .753 r
F P
0 g
s
.62268 1.35983 m .70238 1.25984 L .70034 1.29246 L p .924 .974 .753 r
F P
0 g
s
.51075 1.40299 m .48358 1.42262 L .44995 1.41544 L closepath p .308 .729 .974 \
r
F P
0 g
s
.51075 1.40299 m .58635 1.40989 L .55548 1.4197 L closepath p .528 .887 .979 \
r
F P
0 g
s
.51075 1.40299 m .44995 1.41544 L .42259 1.40326 L closepath p .328 .696 .981 \
r
F P
0 g
s
.70588 1.09056 m .68337 1.22832 L .64481 1.20152 L p .922 .693 .573 r
F P
0 g
s
.64481 1.20152 m .66248 1.05885 L .70588 1.09056 L p .922 .693 .573 r
F P
0 g
s
.51075 1.40299 m .60937 1.39562 L .58635 1.40989 L closepath p .636 .916 .98 \
r
F P
0 g
s
.39764 1.36915 m .31758 1.27631 L .32601 1.24378 L p .208 .326 .765 r
F P
0 g
s
.31758 1.27631 m .39764 1.36915 L .40446 1.38729 L p 0 .156 .698 r
F P
0 g
s
.51075 1.40299 m .42259 1.40326 L .40446 1.38729 L closepath p .38 .673 .974 \
r
F P
0 g
s
.51075 1.40299 m .62199 1.37833 L .60937 1.39562 L closepath p .712 .91 .964 \
r
F P
0 g
s
.35505 1.21417 m .33471 1.07383 L .38764 1.04635 L p .462 .306 .583 r
F P
0 g
s
.33471 1.07383 m .35505 1.21417 L .32601 1.24378 L p .244 .155 .552 r
F P
0 g
s
.70238 1.25984 m .62268 1.35983 L .61113 1.34211 L p .925 .864 .76 r
F P
0 g
s
.61113 1.34211 m .68337 1.22832 L .70238 1.25984 L p .925 .864 .76 r
F P
0 g
s
.51075 1.40299 m .40446 1.38729 L .39764 1.36915 L closepath p .443 .657 .951 \
r
F P
0 g
s
.66248 1.05885 m .64481 1.20152 L .59069 1.18267 L p .836 .604 .588 r
F P
0 g
s
.59069 1.18267 m .60132 1.03651 L .66248 1.05885 L p .836 .604 .588 r
F P
0 g
s
.51075 1.40299 m .62268 1.35983 L .62199 1.37833 L closepath p .752 .878 .937 \
r
F P
0 g
s
.40306 1.35078 m .32601 1.24378 L .35505 1.21417 L p .417 .415 .749 r
F P
0 g
s
.32601 1.24378 m .40306 1.35078 L .39764 1.36915 L p .208 .326 .765 r
F P
0 g
s
.40197 1.19097 m .38764 1.04635 L .45515 1.02982 L p .588 .398 .591 r
F P
0 g
s
.38764 1.04635 m .40197 1.19097 L .35505 1.21417 L p .462 .306 .583 r
F P
0 g
s
.51075 1.40299 m .39764 1.36915 L .40306 1.35078 L closepath p .504 .649 .923 \
r
F P
0 g
s
.60132 1.03651 m .59069 1.18267 L .52714 1.17414 L p .757 .533 .593 r
F P
0 g
s
.52714 1.17414 m .52935 1.02639 L .60132 1.03651 L p .757 .533 .593 r
F P
0 g
s
.68337 1.22832 m .61113 1.34211 L .58842 1.32716 L p .87 .76 .738 r
F P
0 g
s
.58842 1.32716 m .64481 1.20152 L .68337 1.22832 L p .87 .76 .738 r
F P
0 g
s
.51075 1.40299 m .61113 1.34211 L .62268 1.35983 L closepath p .762 .836 .908 \
r
F P
0 g
s
.46163 1.17703 m .45515 1.02982 L .52935 1.02639 L p .679 .468 .593 r
F P
0 g
s
.45515 1.02982 m .46163 1.17703 L .40197 1.19097 L p .588 .398 .591 r
F P
0 g
s
.51075 1.40299 m .58842 1.32716 L .61113 1.34211 L closepath p .754 .792 .884 \
r
F P
0 g
s
.51075 1.40299 m .55694 1.31671 L .58842 1.32716 L closepath p .735 .753 .867 \
r
F P
0 g
s
.51075 1.40299 m .5202 1.312 L .55694 1.31671 L closepath p .709 .719 .857 r
F P
0 g
s
.51075 1.40299 m .48237 1.3136 L .5202 1.312 L closepath p .679 .692 .855 r
F P
0 g
s
.51075 1.40299 m .44779 1.32131 L .48237 1.3136 L closepath p .644 .67 .861 r
F P
0 g
s
.51075 1.40299 m .42036 1.3342 L .44779 1.32131 L closepath p .603 .656 .874 \
r
F P
0 g
s
.51075 1.40299 m .40306 1.35078 L .42036 1.3342 L closepath p .557 .648 .895 \
r
F P
0 g
s
.52935 1.02639 m .52714 1.17414 L .46163 1.17703 L p .679 .468 .593 r
F P
0 g
s
.35505 1.21417 m .42036 1.3342 L .40306 1.35078 L p .417 .415 .749 r
F P
0 g
s
.42036 1.3342 m .35505 1.21417 L .40197 1.19097 L p .539 .473 .729 r
F P
0 g
s
.64481 1.20152 m .58842 1.32716 L .55694 1.31671 L p .81 .681 .722 r
F P
0 g
s
.55694 1.31671 m .59069 1.18267 L .64481 1.20152 L p .81 .681 .722 r
F P
0 g
s
.40197 1.19097 m .44779 1.32131 L .42036 1.3342 L p .539 .473 .729 r
F P
0 g
s
.44779 1.32131 m .40197 1.19097 L .46163 1.17703 L p .624 .521 .716 r
F P
0 g
s
.46163 1.17703 m .48237 1.3136 L .44779 1.32131 L p .624 .521 .716 r
F P
0 g
s
.59069 1.18267 m .55694 1.31671 L .5202 1.312 L p .752 .62 .713 r
F P
0 g
s
.5202 1.312 m .52714 1.17414 L .59069 1.18267 L p .752 .62 .713 r
F P
0 g
s
.52714 1.17414 m .5202 1.312 L .48237 1.3136 L p .692 .568 .711 r
F P
0 g
s
.48237 1.3136 m .46163 1.17703 L .52714 1.17414 L p .692 .568 .711 r
F P
0 g
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.0153906 0.782187 0.207773 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0577037 1.16819 -8.61941e-17 1.16819 [
[ 0 0 0 0 ]
[ 1 1.08786 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.08786 L
0 1.08786 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.47239 .48567 m .46084 .54041 L .54634 .54468 L p .713 .635 .769 r
F P
0 g
s
.54634 .54468 m .54242 .48928 L .47239 .48567 L p .713 .635 .769 r
F P
0 g
s
.54757 .60169 m .54634 .54468 L .46084 .54041 L p .718 .517 .618 r
F P
0 g
s
.54242 .48928 m .54634 .54468 L .63011 .53185 L p .678 .608 .771 r
F P
0 g
s
.54634 .54468 m .54757 .60169 L .63626 .58856 L p .652 .465 .618 r
F P
0 g
s
.63626 .58856 m .63011 .53185 L .54634 .54468 L p .652 .465 .618 r
F P
0 g
s
.4068 .46783 m .38044 .51926 L .46084 .54041 L p .745 .667 .774 r
F P
0 g
s
.46084 .54041 m .47239 .48567 L .4068 .46783 L p .745 .667 .774 r
F P
0 g
s
.45709 .59732 m .46084 .54041 L .38044 .51926 L p .78 .572 .618 r
F P
0 g
s
.46084 .54041 m .45709 .59732 L .54757 .60169 L p .718 .517 .618 r
F P
0 g
s
.63011 .53185 m .61095 .47844 L .54242 .48928 L p .678 .608 .771 r
F P
0 g
s
.61095 .47844 m .63011 .53185 L .7053 .50258 L p .64 .587 .779 r
F P
0 g
s
.63011 .53185 m .63626 .58856 L .71604 .55857 L p .574 .408 .619 r
F P
0 g
s
.71604 .55857 m .7053 .50258 L .63011 .53185 L p .574 .408 .619 r
F P
0 g
s
.48869 .44988 m .47239 .48567 L .54242 .48928 L p .643 .758 .933 r
F P
0 g
s
.54242 .48928 m .53686 .45242 L .48869 .44988 L p .643 .758 .933 r
F P
0 g
s
.53686 .45242 m .54242 .48928 L .61095 .47844 L p .659 .77 .932 r
F P
0 g
s
.44384 .43741 m .4068 .46783 L .47239 .48567 L p .63 .743 .929 r
F P
0 g
s
.47239 .48567 m .48869 .44988 L .44384 .43741 L p .63 .743 .929 r
F P
0 g
s
.54539 .64334 m .54757 .60169 L .45709 .59732 L p .672 .316 .363 r
F P
0 g
s
.54757 .60169 m .54539 .64334 L .62574 .63174 L p .566 .228 .355 r
F P
0 g
s
.62574 .63174 m .63626 .58856 L .54757 .60169 L p .566 .228 .355 r
F P
0 g
s
.38044 .51926 m .3719 .57567 L .45709 .59732 L p .78 .572 .618 r
F P
0 g
s
.46336 .63948 m .45709 .59732 L .3719 .57567 L p .761 .382 .338 r
F P
0 g
s
.45709 .59732 m .46336 .63948 L .54539 .64334 L p .672 .316 .363 r
F P
0 g
s
.35156 .43691 m .31202 .48237 L .38044 .51926 L p .774 .705 .786 r
F P
0 g
s
.38044 .51926 m .4068 .46783 L .35156 .43691 L p .774 .705 .786 r
F P
0 g
s
.3719 .57567 m .38044 .51926 L .31202 .48237 L p .845 .636 .62 r
F P
0 g
s
.61095 .47844 m .5839 .44482 L .53686 .45242 L p .659 .77 .932 r
F P
0 g
s
.5839 .44482 m .61095 .47844 L .67202 .45382 L p .676 .777 .926 r
F P
0 g
s
.7053 .50258 m .67202 .45382 L .61095 .47844 L p .64 .587 .779 r
F P
0 g
s
.63626 .58856 m .62574 .63174 L .69774 .60531 L p .416 .093 .307 r
F P
0 g
s
.69774 .60531 m .71604 .55857 L .63626 .58856 L p .416 .093 .307 r
F P
0 g
s
.40662 .41597 m .35156 .43691 L .4068 .46783 L p .623 .727 .922 r
F P
0 g
s
.4068 .46783 m .44384 .43741 L .40662 .41597 L p .623 .727 .922 r
F P
0 g
s
.67202 .45382 m .7053 .50258 L .765 .45857 L p .598 .572 .796 r
F P
0 g
s
.7053 .50258 m .71604 .55857 L .77969 .51336 L p .468 .338 .619 r
F P
0 g
s
.77969 .51336 m .765 .45857 L .7053 .50258 L p .468 .338 .619 r
F P
0 g
s
.31202 .48237 m .29916 .53782 L .3719 .57567 L p .845 .636 .62 r
F P
0 g
s
.38629 .62037 m .3719 .57567 L .29916 .53782 L p .842 .431 .26 r
F P
0 g
s
.3719 .57567 m .38629 .62037 L .46336 .63948 L p .761 .382 .338 r
F P
0 g
s
.67202 .45382 m .62541 .42766 L .5839 .44482 L p .676 .777 .926 r
F P
0 g
s
.62541 .42766 m .67202 .45382 L .71983 .41709 L p .692 .777 .917 r
F P
0 g
s
.765 .45857 m .71983 .41709 L .67202 .45382 L p .598 .572 .796 r
F P
0 g
s
.31235 .39512 m .26247 .43205 L .31202 .48237 L p .8 .75 .807 r
F P
0 g
s
.31202 .48237 m .35156 .43691 L .31235 .39512 L p .8 .75 .807 r
F P
0 g
s
.29916 .53782 m .31202 .48237 L .26247 .43205 L p .917 .718 .618 r
F P
0 g
s
.53097 .44993 m .53686 .45242 L .5839 .44482 L p .201 .729 .786 r
F P
0 g
s
.55545 .44597 m .53097 .44993 L p .5398 .44908 L .201 .729 .786 r
F P
0 g
s
.5839 .44482 m .55545 .44597 L p .5398 .44908 L .201 .729 .786 r
F P
0 g
s
.55545 .44597 m .5839 .44482 L .62541 .42766 L p .465 .891 .865 r
F P
0 g
s
.57683 .43709 m .55545 .44597 L p .56706 .44294 L .465 .891 .865 r
F P
0 g
s
.62541 .42766 m .57683 .43709 L p .56706 .44294 L .465 .891 .865 r
F P
0 g
s
.59287 .42412 m .57683 .43709 L p .59007 .43137 L .704 .977 .915 r
F P
0 g
s
.65725 .40234 m .59287 .42412 L p .59007 .43137 L .704 .977 .915 r
F P
0 g
s
.59287 .42412 m .60181 .40833 L p .59594 .41619 L .747 .922 .562 r
F P
0 g
s
.57683 .43709 m .59287 .42412 L p .5875 .4307 L 0 0 0 r
F P
0 g
s
.57683 .43709 m .62541 .42766 L .65725 .40234 L p .704 .977 .915 r
F P
0 g
s
.53912 .48997 m .57683 .43709 L p .5875 .4307 L 0 0 0 r
F P
0 g
s
.54351 .48647 m .53912 .48997 L p .5421 .48633 L 0 0 0 r
F P
0 g
s
.59287 .42412 m .54351 .48647 L p .5421 .48633 L 0 0 0 r
F P
0 g
s
.54351 .48647 m .59287 .42412 L p .59594 .41619 L .747 .922 .562 r
F P
0 g
s
.54586 .48226 m .54351 .48647 L p .54671 .48218 L .747 .922 .562 r
F P
0 g
s
.60181 .40833 m .54586 .48226 L p .54671 .48218 L .747 .922 .562 r
F P
0 g
s
.57683 .43709 m .53912 .48997 L .53318 .49239 L p .253 0 .074 r
F P
0 g
s
.54586 .48226 m .54591 .47778 L .54499 .48234 L p .887 .797 .31 r
F P
0 g
s
.54351 .48647 m .54586 .48226 L .54495 .48661 L p 0 0 .142 r
F P
0 g
s
.54495 .48661 m .52446 .58471 L .54351 .48647 L p 0 0 .142 r
F P
0 g
s
.54499 .48234 m .52446 .58471 L .54586 .48226 L p .887 .797 .31 r
F P
0 g
s
.55545 .44597 m .57683 .43709 L p .57249 .44259 L .253 0 .074 r
F P
0 g
s
.53318 .49239 m .55545 .44597 L p .57249 .44259 L .253 0 .074 r
F P
0 g
s
.53097 .44993 m .55545 .44597 L p .55257 .45068 L .479 .064 .175 r
F P
0 g
s
.48869 .44988 m .53686 .45242 L p .51105 .44925 L .025 .595 .765 r
F P
0 g
s
.53686 .45242 m .53097 .44993 L .50585 .44861 L p .025 .595 .765 r
F P
0 g
s
.52632 .49347 m .53097 .44993 L p .55257 .45068 L .479 .064 .175 r
F P
0 g
s
.50585 .44861 m .50163 .44892 L p .51105 .44925 L .025 .595 .765 r
F P
0 g
s
.50163 .44892 m .48869 .44988 L p .51105 .44925 L .025 .595 .765 r
F P
0 g
s
.71604 .55857 m .69774 .60531 L .75474 .56564 L p .148 0 .179 r
F P
0 g
s
.75474 .56564 m .77969 .51336 L .71604 .55857 L p .148 0 .179 r
F P
0 g
s
.38093 .38735 m .31235 .39512 L .35156 .43691 L p .621 .712 .911 r
F P
0 g
s
.35156 .43691 m .40662 .41597 L .38093 .38735 L p .621 .712 .911 r
F P
0 g
s
.48261 .44212 m .44384 .43741 L .48869 .44988 L p 0 .531 .822 r
F P
0 g
s
.48869 .44988 m .50585 .44861 L .48261 .44212 L p 0 .531 .822 r
F P
0 g
s
.53945 .65351 m .54539 .64334 L .46336 .63948 L p .283 0 0 r
F P
0 g
s
.54539 .64334 m .53945 .65351 L .59691 .64527 L p .111 0 0 r
F P
0 g
s
.59691 .64527 m .62574 .63174 L .54539 .64334 L p .111 0 0 r
F P
0 g
s
.46361 .43107 m .40662 .41597 L .44384 .43741 L p .067 .518 .898 r
F P
0 g
s
.44384 .43741 m .47308 .44096 L p .46361 .43107 L .067 .518 .898 r
F P
0 g
s
.40662 .41597 m .44966 .42737 L p .45089 .41652 L .217 .517 .914 r
F P
0 g
s
.44966 .42737 m .46361 .43107 L .45089 .41652 L p .217 .517 .914 r
F P
0 g
s
.50411 .48444 m .45636 .42351 L p .46361 .43107 L .616 .137 0 r
F P
0 g
s
.45636 .42351 m .45089 .41652 L .46361 .43107 L p .616 .137 0 r
F P
0 g
s
.47308 .44096 m .48261 .44212 L .46361 .43107 L p .067 .518 .898 r
F P
0 g
s
.50753 .48834 m .46361 .43107 L .48261 .44212 L p .768 .261 0 r
F P
0 g
s
.46361 .43107 m .50449 .48437 L p .50411 .48444 L .616 .137 0 r
F P
0 g
s
.50449 .48437 m .50753 .48834 L .50411 .48444 L p .616 .137 0 r
F P
0 g
s
.50411 .48444 m .52446 .58471 L .50379 .48449 L p .77 .498 0 r
F P
0 g
s
.45089 .41652 m .50044 .47976 L p .50288 .48003 L 0 .123 .671 r
F P
0 g
s
.50044 .47976 m .50411 .48444 L .50288 .48003 L p 0 .123 .671 r
F P
0 g
s
.50379 .48449 m .50288 .48003 L .50411 .48444 L p .77 .498 0 r
F P
0 g
s
.48261 .44212 m .51278 .49134 L .50753 .48834 L p .768 .261 0 r
F P
0 g
s
.50753 .48834 m .52446 .58471 L .50411 .48444 L closepath p .952 .604 .288 r
F P
0 g
s
.50288 .48003 m .52446 .58471 L .50486 .48026 L p 0 0 .457 r
F P
0 g
s
.51278 .49134 m .48261 .44212 L .50585 .44861 L p .718 .25 .139 r
F P
0 g
s
.50486 .48026 m .50399 .47561 L .50288 .48003 L p 0 0 .457 r
F P
0 g
s
.50288 .48003 m .45183 .40821 L p .45089 .41652 L 0 .123 .671 r
F P
0 g
s
.45183 .40821 m .44594 .39991 L .45089 .41652 L p 0 .123 .671 r
F P
0 g
s
.48067 .65077 m .46336 .63948 L .38629 .62037 L p .339 0 0 r
F P
0 g
s
.46336 .63948 m .48067 .65077 L .53945 .65351 L p .283 0 0 r
F P
0 g
s
.71983 .41709 m .65725 .40234 L .62541 .42766 L p .692 .777 .917 r
F P
0 g
s
.65725 .40234 m .71983 .41709 L .74895 .37105 L p .704 .772 .905 r
F P
0 g
s
.71983 .41709 m .765 .45857 L .80248 .40283 L p .552 .565 .821 r
F P
0 g
s
.80248 .40283 m .74895 .37105 L .71983 .41709 L p .552 .565 .821 r
F P
0 g
s
.765 .45857 m .77969 .51336 L .82003 .4559 L p .295 .23 .612 r
F P
0 g
s
.82003 .4559 m .80248 .40283 L .765 .45857 L p .295 .23 .612 r
F P
0 g
s
.26247 .43205 m .24613 .48604 L .29916 .53782 L p .917 .718 .618 r
F P
0 g
s
.32086 .58708 m .29916 .53782 L .24613 .48604 L p .87 .43 .054 r
F P
0 g
s
.29916 .53782 m .32086 .58708 L .38629 .62037 L p .842 .431 .26 r
F P
0 g
s
.62574 .63174 m .59691 .64527 L .64786 .6266 L p 0 0 0 r
F P
0 g
s
.64786 .6266 m .69774 .60531 L .62574 .63174 L p 0 0 0 r
F P
0 g
s
.45089 .41652 m .38093 .38735 L .40662 .41597 L p .217 .517 .914 r
F P
0 g
s
.38629 .62037 m .42578 .63721 L .48067 .65077 L p .339 0 0 r
F P
0 g
s
.42578 .63721 m .38629 .62037 L .32086 .58708 L p 0 .313 .694 r
F P
0 g
s
.36995 .35418 m .29417 .34589 L .31235 .39512 L p .625 .7 .899 r
F P
0 g
s
.31235 .39512 m .38093 .38735 L .36995 .35418 L p .625 .7 .899 r
F P
0 g
s
.26247 .43205 m .31235 .39512 L .29417 .34589 L p .817 .802 .837 r
F P
0 g
s
.29417 .34589 m .23823 .37209 L .26247 .43205 L p .817 .802 .837 r
F P
0 g
s
.24613 .48604 m .26247 .43205 L .23823 .37209 L p .987 .825 .596 r
F P
0 g
s
.77969 .51336 m .75474 .56564 L .79027 .51552 L p 0 0 0 r
F P
0 g
s
.79027 .51552 m .82003 .4559 L .77969 .51336 L p 0 0 0 r
F P
0 g
s
.59287 .42412 m .65725 .40234 L .67582 .37106 L p .825 .953 .9 r
F P
0 g
s
.74895 .37105 m .67582 .37106 L .65725 .40234 L p .704 .772 .905 r
F P
0 g
s
.69774 .60531 m .64786 .6266 L .68732 .5989 L p .558 .928 .787 r
F P
0 g
s
.68732 .5989 m .75474 .56564 L .69774 .60531 L p .558 .928 .787 r
F P
0 g
s
.44594 .39991 m .36995 .35418 L .38093 .38735 L p .355 .518 .88 r
F P
0 g
s
.38093 .38735 m .45089 .41652 L .44594 .39991 L p .355 .518 .88 r
F P
0 g
s
.67582 .37106 m .74895 .37105 L .75498 .31981 L p .711 .762 .893 r
F P
0 g
s
.74895 .37105 m .80248 .40283 L .81181 .34002 L p .499 .568 .856 r
F P
0 g
s
.81181 .34002 m .75498 .31981 L .74895 .37105 L p .499 .568 .856 r
F P
0 g
s
.24613 .48604 m .27367 .54177 L .32086 .58708 L p .87 .43 .054 r
F P
0 g
s
.37989 .61383 m .32086 .58708 L .27367 .54177 L p 0 .398 .847 r
F P
0 g
s
.32086 .58708 m .37989 .61383 L .42578 .63721 L p 0 .313 .694 r
F P
0 g
s
.51927 .49311 m .50585 .44861 L .53097 .44993 L p .618 .183 .192 r
F P
0 g
s
.53097 .44993 m .52632 .49347 L .51927 .49311 L p .618 .183 .192 r
F P
0 g
s
.50585 .44861 m .51927 .49311 L .51278 .49134 L p .718 .25 .139 r
F P
0 g
s
.23823 .37209 m .21977 .42412 L .24613 .48604 L p .987 .825 .596 r
F P
0 g
s
.27367 .54177 m .24613 .48604 L .21977 .42412 L p 0 0 .366 r
F P
0 g
s
.80248 .40283 m .82003 .4559 L .8306 .39089 L p 0 .025 .551 r
F P
0 g
s
.8306 .39089 m .81181 .34002 L .80248 .40283 L p 0 .025 .551 r
F P
0 g
s
.55545 .44597 m .53318 .49239 L .52632 .49347 L p .479 .064 .175 r
F P
0 g
s
.67582 .37106 m .60181 .40833 L .59287 .42412 L p .825 .953 .9 r
F P
0 g
s
.60181 .40833 m .67582 .37106 L .67852 .33682 L p .854 .881 .858 r
F P
0 g
s
.75498 .31981 m .67852 .33682 L .67582 .37106 L p .711 .762 .893 r
F P
0 g
s
.37563 .3198 m .30065 .29398 L .29417 .34589 L p .633 .692 .887 r
F P
0 g
s
.29417 .34589 m .36995 .35418 L .37563 .3198 L p .633 .692 .887 r
F P
0 g
s
.23823 .37209 m .29417 .34589 L .30065 .29398 L p .819 .858 .877 r
F P
0 g
s
.53007 .6197 m .53945 .65351 L .48067 .65077 L p .486 .805 1 r
F P
0 g
s
.53945 .65351 m .53007 .6197 L .55151 .61656 L p .549 .849 .998 r
F P
0 g
s
.55151 .61656 m .59691 .64527 L .53945 .65351 L p .549 .849 .998 r
F P
0 g
s
.44949 .383 m .37563 .3198 L .36995 .35418 L p .459 .524 .837 r
F P
0 g
s
.36995 .35418 m .44594 .39991 L .44949 .383 L p .459 .524 .837 r
F P
0 g
s
.75474 .56564 m .68732 .5989 L .71084 .56444 L p .803 .993 .873 r
F P
0 g
s
.71084 .56444 m .79027 .51552 L .75474 .56564 L p .803 .993 .873 r
F P
0 g
s
.50807 .61865 m .48067 .65077 L .42578 .63721 L p .453 .757 .994 r
F P
0 g
s
.48772 .61351 m .50807 .61865 L p .50323 .61974 L .453 .757 .994 r
F P
0 g
s
.42578 .63721 m .48772 .61351 L p .50323 .61974 L .453 .757 .994 r
F P
0 g
s
.47112 .60475 m .48772 .61351 L p .48145 .61352 L .452 .714 .98 r
F P
0 g
s
.37989 .61383 m .47112 .60475 L p .48145 .61352 L .452 .714 .98 r
F P
0 g
s
.46005 .59324 m .47112 .60475 L p .46404 .60347 L .476 .68 .955 r
F P
0 g
s
.34778 .58242 m .46005 .59324 L p .46404 .60347 L .476 .68 .955 r
F P
0 g
s
.4558 .58013 m .46005 .59324 L p .45289 .59055 L .511 .657 .925 r
F P
0 g
s
.33349 .54573 m .4558 .58013 L p .45289 .59055 L .511 .657 .925 r
F P
0 g
s
.4558 .58013 m .45898 .56682 L p .45835 .571 L 0 0 .167 r
F P
0 g
s
.46005 .59324 m .4558 .58013 L p .45655 .58427 L .959 .734 .284 r
F P
0 g
s
.46005 .59324 m .34778 .58242 L .33349 .54573 L p .511 .657 .925 r
F P
0 g
s
.45559 .58933 m .45986 .6024 L p .45911 .5983 L .959 .734 .284 r
F P
0 g
s
.4558 .58013 m .45559 .58933 L p .45911 .5983 L .959 .734 .284 r
F P
0 g
s
.45559 .58933 m .4558 .58013 L p .45835 .571 L 0 0 .167 r
F P
0 g
s
.45986 .6024 m .46005 .59324 L p .45655 .58427 L .959 .734 .284 r
F P
0 g
s
.4558 .58013 m .33349 .54573 L .33972 .50739 L p .55 .644 .895 r
F P
0 g
s
.33972 .50739 m .45898 .56682 L .4558 .58013 L p .55 .644 .895 r
F P
0 g
s
.45878 .57605 m .45559 .58933 L p .45622 .58518 L 0 0 .167 r
F P
0 g
s
.45898 .56682 m .45878 .57605 L p .45622 .58518 L 0 0 .167 r
F P
0 g
s
.45878 .57605 m .45898 .56682 L .46941 .55477 L p .148 .013 .428 r
F P
0 g
s
.46924 .56402 m .45878 .57605 L p .46074 .57212 L .148 .013 .428 r
F P
0 g
s
.46941 .55477 m .46924 .56402 L p .46074 .57212 L .148 .013 .428 r
F P
0 g
s
.48594 .55465 m .46924 .56402 L p .47235 .56058 L .42 .221 .503 r
F P
0 g
s
.48607 .54536 m .48594 .55465 L p .47235 .56058 L .42 .221 .503 r
F P
0 g
s
.50707 .54903 m .48594 .55465 L p .48986 .55189 L .567 .337 .527 r
F P
0 g
s
.50713 .53974 m .50707 .54903 L p .48986 .55189 L .567 .337 .527 r
F P
0 g
s
.52632 .49347 m .52446 .58471 L .51927 .49311 L closepath p .7 .405 .473 r
F P
0 g
s
.53318 .49239 m .52446 .58471 L .52632 .49347 L closepath p .602 .324 .468 r
F P
0 g
s
.51927 .49311 m .52446 .58471 L .51278 .49134 L closepath p .788 .475 .459 r
F P
0 g
s
.53912 .48997 m .52446 .58471 L .53318 .49239 L closepath p .468 .212 .442 r
F P
0 g
s
.51278 .49134 m .52446 .58471 L .50753 .48834 L closepath p .878 .544 .415 r
F P
0 g
s
.54351 .48647 m .52446 .58471 L .53912 .48997 L closepath p .24 .021 .367 r
F P
0 g
s
.50399 .47561 m .52446 .58471 L .50735 .47164 L closepath p .284 .186 .563 r
F P
0 g
s
.53926 .46997 m .52446 .58471 L .54363 .47353 L closepath p .911 .683 .579 r
F P
0 g
s
.50735 .47164 m .52446 .58471 L .51259 .46858 L closepath p .478 .32 .587 r
F P
0 g
s
.53326 .46749 m .52446 .58471 L .53926 .46997 L closepath p .829 .6 .591 r
F P
0 g
s
.51259 .46858 m .52446 .58471 L .51915 .46675 L closepath p .595 .404 .593 r
F P
0 g
s
.52631 .46638 m .52446 .58471 L .53326 .46749 L closepath p .755 .532 .594 r
F P
0 g
s
.51915 .46675 m .52446 .58471 L .52631 .46638 L closepath p .68 .47 .595 r
F P
0 g
s
.5302 .53857 m .53021 .54787 L .50707 .54903 L p .668 .419 .535 r
F P
0 g
s
.50707 .54903 m .53021 .54787 L p .52713 .5457 L .527 .827 .999 r
F P
0 g
s
.50399 .47561 m .44949 .383 L .44594 .39991 L p .234 .295 .722 r
F P
0 g
s
.44594 .39991 m .50288 .48003 L .50399 .47561 L p .234 .295 .722 r
F P
0 g
s
.4741 .4259 m .50713 .53974 L .48607 .54536 L p .656 .657 .839 r
F P
0 g
s
.48607 .54536 m .41358 .44324 L .4741 .4259 L p .656 .657 .839 r
F P
0 g
s
.48594 .55465 m .48607 .54536 L .50713 .53974 L p .567 .337 .527 r
F P
0 g
s
.55692 .35139 m .53326 .46749 L .53926 .46997 L p .808 .652 .689 r
F P
0 g
s
.53326 .46749 m .55692 .35139 L .53117 .34699 L p .75 .594 .682 r
F P
0 g
s
.53117 .34699 m .52631 .46638 L .53326 .46749 L p .75 .594 .682 r
F P
0 g
s
.54118 .42228 m .5302 .53857 L .50713 .53974 L p .686 .676 .834 r
F P
0 g
s
.50735 .47164 m .46139 .36766 L .44949 .383 L p .429 .386 .709 r
F P
0 g
s
.44949 .383 m .50399 .47561 L .50735 .47164 L p .429 .386 .709 r
F P
0 g
s
.51259 .46858 m .48047 .35567 L .46139 .36766 L p .545 .447 .694 r
F P
0 g
s
.46139 .36766 m .50735 .47164 L .51259 .46858 L p .545 .447 .694 r
F P
0 g
s
.51915 .46675 m .50466 .34848 L .48047 .35567 L p .626 .496 .684 r
F P
0 g
s
.48047 .35567 m .51259 .46858 L .51915 .46675 L p .626 .496 .684 r
F P
0 g
s
.52631 .46638 m .53117 .34699 L .50466 .34848 L p .691 .543 .681 r
F P
0 g
s
.50466 .34848 m .51915 .46675 L .52631 .46638 L p .691 .543 .681 r
F P
0 g
s
.50713 .53974 m .4741 .4259 L .54118 .42228 L p .686 .676 .834 r
F P
0 g
s
.50707 .54903 m .50713 .53974 L .5302 .53857 L p .668 .419 .535 r
F P
0 g
s
.47266 .50734 m .50707 .54903 L p .52713 .5457 L .527 .827 .999 r
F P
0 g
s
.48594 .55465 m .50707 .54903 L p .50186 .5477 L .597 .865 .993 r
F P
0 g
s
.36711 .47172 m .46941 .55477 L .45898 .56682 L p .588 .64 .87 r
F P
0 g
s
.45898 .56682 m .33972 .50739 L .36711 .47172 L p .588 .64 .87 r
F P
0 g
s
.41358 .44324 m .48607 .54536 L .46941 .55477 L p .623 .645 .851 r
F P
0 g
s
.46941 .55477 m .36711 .47172 L .41358 .44324 L p .623 .645 .851 r
F P
0 g
s
.46924 .56402 m .46941 .55477 L .48607 .54536 L p .42 .221 .503 r
F P
0 g
s
.4105 .52436 m .48594 .55465 L p .50186 .5477 L .597 .865 .993 r
F P
0 g
s
.46924 .56402 m .48594 .55465 L p .47922 .55452 L .668 .881 .977 r
F P
0 g
s
.36283 .5523 m .46924 .56402 L p .47922 .55452 L .668 .881 .977 r
F P
0 g
s
.45878 .57605 m .46924 .56402 L p .46179 .56531 L .723 .874 .952 r
F P
0 g
s
.27367 .54177 m .34778 .58242 L .37989 .61383 L p 0 .398 .847 r
F P
0 g
s
.47112 .60475 m .37989 .61383 L .34778 .58242 L p .476 .68 .955 r
F P
0 g
s
.33481 .58725 m .45878 .57605 L p .46179 .56531 L .723 .874 .952 r
F P
0 g
s
.45559 .58933 m .45878 .57605 L p .45146 .57879 L .754 .849 .922 r
F P
0 g
s
.32853 .62478 m .45559 .58933 L p .45146 .57879 L .754 .849 .922 r
F P
0 g
s
.47112 .60475 m .46005 .59324 L p .46208 .59707 L .961 .688 .472 r
F P
0 g
s
.48772 .61351 m .42578 .63721 L .37989 .61383 L p .452 .714 .98 r
F P
0 g
s
.47096 .61388 m .47112 .60475 L p .46208 .59707 L .961 .688 .472 r
F P
0 g
s
.48772 .61351 m .47112 .60475 L p .47418 .60806 L .873 .601 .525 r
F P
0 g
s
.48761 .62261 m .48772 .61351 L p .47418 .60806 L .873 .601 .525 r
F P
0 g
s
.50807 .61865 m .48772 .61351 L p .49147 .61614 L .79 .529 .542 r
F P
0 g
s
.48067 .65077 m .50807 .61865 L p .52715 .62154 L .486 .805 1 r
F P
0 g
s
.50801 .62775 m .50807 .61865 L p .49147 .61614 L .79 .529 .542 r
F P
0 g
s
.50807 .61865 m .53007 .6197 L p .52715 .62154 L .486 .805 1 r
F P
0 g
s
.59691 .64527 m .55151 .61656 L .57021 .60951 L p .626 .879 .988 r
F P
0 g
s
.57021 .60951 m .64786 .6266 L .59691 .64527 L p .626 .879 .988 r
F P
0 g
s
.30065 .29398 m .24444 .30805 L .23823 .37209 L p .819 .858 .877 r
F P
0 g
s
.21977 .42412 m .23823 .37209 L .24444 .30805 L p .917 .878 .451 r
F P
0 g
s
.82003 .4559 m .79027 .51552 L .79879 .45918 L p .919 .923 .543 r
F P
0 g
s
.79879 .45918 m .8306 .39089 L .82003 .4559 L p .919 .923 .543 r
F P
0 g
s
.67852 .33682 m .60249 .39134 L .60181 .40833 L p .854 .881 .858 r
F P
0 g
s
.60249 .39134 m .67852 .33682 L .66419 .30328 L p .84 .806 .818 r
F P
0 g
s
.67852 .33682 m .75498 .31981 L .73536 .26871 L p .712 .75 .881 r
F P
0 g
s
.73536 .26871 m .66419 .30328 L .67852 .33682 L p .712 .75 .881 r
F P
0 g
s
.75498 .31981 m .81181 .34002 L .78907 .27656 L p .441 .584 .9 r
F P
0 g
s
.78907 .27656 m .73536 .26871 L .75498 .31981 L p .441 .584 .9 r
F P
0 g
s
.54586 .48226 m .60181 .40833 L .60249 .39134 L p .958 .941 .715 r
F P
0 g
s
.47956 .72737 m .45956 .83054 L .54653 .83415 L p .716 .624 .753 r
F P
0 g
s
.54653 .83415 m .53977 .73005 L .47956 .72737 L p .716 .624 .753 r
F P
0 g
s
.54975 .92341 m .54653 .83415 L .45956 .83054 L p .72 .555 .665 r
F P
0 g
s
.53977 .73005 m .54653 .83415 L .63176 .8233 L p .671 .589 .755 r
F P
0 g
s
.54653 .83415 m .54975 .92341 L .64765 .91174 L p .66 .507 .666 r
F P
0 g
s
.64765 .91174 m .63176 .8233 L .54653 .83415 L p .66 .507 .666 r
F P
0 g
s
.42333 .71415 m .37773 .81266 L .45956 .83054 L p .759 .665 .759 r
F P
0 g
s
.45956 .83054 m .47956 .72737 L .42333 .71415 L p .759 .665 .759 r
F P
0 g
s
.44995 .91954 m .45956 .83054 L .37773 .81266 L p .778 .607 .668 r
F P
0 g
s
.45956 .83054 m .44995 .91954 L .54975 .92341 L p .72 .555 .665 r
F P
0 g
s
.21977 .42412 m .25087 .48793 L .27367 .54177 L p 0 0 .366 r
F P
0 g
s
.34778 .58242 m .27367 .54177 L .25087 .48793 L p .225 .455 .872 r
F P
0 g
s
.64786 .6266 m .57021 .60951 L .5842 .59925 L p .694 .885 .968 r
F P
0 g
s
.5842 .59925 m .68732 .5989 L .64786 .6266 L p .694 .885 .968 r
F P
0 g
s
.46139 .36766 m .39821 .28807 L .37563 .3198 L p .537 .538 .803 r
F P
0 g
s
.37563 .3198 m .44949 .383 L .46139 .36766 L p .537 .538 .803 r
F P
0 g
s
.30065 .29398 m .37563 .3198 L .39821 .28807 L p .644 .688 .876 r
F P
0 g
s
.63176 .8233 m .59862 .72201 L .53977 .73005 L p .671 .589 .755 r
F P
0 g
s
.59862 .72201 m .63176 .8233 L .70831 .79856 L p .62 .56 .765 r
F P
0 g
s
.63176 .8233 m .64765 .91174 L .73611 .88501 L p .589 .459 .671 r
F P
0 g
s
.73611 .88501 m .70831 .79856 L .63176 .8233 L p .589 .459 .671 r
F P
0 g
s
.54916 .98014 m .54975 .92341 L .44995 .91954 L p .704 .43 .508 r
F P
0 g
s
.54975 .92341 m .54916 .98014 L .64493 .96921 L p .622 .363 .505 r
F P
0 g
s
.64493 .96921 m .64765 .91174 L .54975 .92341 L p .622 .363 .505 r
F P
0 g
s
.60249 .39134 m .54591 .47778 L .54586 .48226 L p .958 .941 .715 r
F P
0 g
s
.54591 .47778 m .60249 .39134 L .59463 .37498 L p .931 .824 .718 r
F P
0 g
s
.66419 .30328 m .59463 .37498 L .60249 .39134 L p .84 .806 .818 r
F P
0 g
s
.37773 .81266 m .35574 .90026 L .44995 .91954 L p .778 .607 .668 r
F P
0 g
s
.45152 .9765 m .44995 .91954 L .35574 .90026 L p .779 .492 .5 r
F P
0 g
s
.44995 .91954 m .45152 .9765 L .54916 .98014 L p .704 .43 .508 r
F P
0 g
s
.50801 .62775 m .47956 .72737 L .53977 .73005 L p .7 .685 .832 r
F P
0 g
s
.53977 .73005 m .53008 .62879 L .50801 .62775 L p .7 .685 .832 r
F P
0 g
s
.53008 .62879 m .53977 .73005 L .59862 .72201 L p .672 .664 .834 r
F P
0 g
s
.81181 .34002 m .8306 .39089 L .80699 .32493 L p 0 0 .255 r
F P
0 g
s
.80699 .32493 m .78907 .27656 L .81181 .34002 L p 0 0 .255 r
F P
0 g
s
.39821 .28807 m .33302 .24525 L .30065 .29398 L p .644 .688 .876 r
F P
0 g
s
.24444 .30805 m .30065 .29398 L .33302 .24525 L p .79 .907 .922 r
F P
0 g
s
.24444 .30805 m .22572 .35769 L .21977 .42412 L p .917 .878 .451 r
F P
0 g
s
.25087 .48793 m .21977 .42412 L .22572 .35769 L p .01 .114 .626 r
F P
0 g
s
.48761 .62261 m .42333 .71415 L .47956 .72737 L p .725 .711 .837 r
F P
0 g
s
.47956 .72737 m .50801 .62775 L .48761 .62261 L p .725 .711 .837 r
F P
0 g
s
.59463 .37498 m .66419 .30328 L .63363 .27438 L p .81 .742 .789 r
F P
0 g
s
.66419 .30328 m .73536 .26871 L .69047 .22397 L p .71 .736 .872 r
F P
0 g
s
.69047 .22397 m .63363 .27438 L .66419 .30328 L p .71 .736 .872 r
F P
0 g
s
.37628 .69132 m .30803 .78146 L .37773 .81266 L p .798 .716 .773 r
F P
0 g
s
.37773 .81266 m .42333 .71415 L .37628 .69132 L p .798 .716 .773 r
F P
0 g
s
.35574 .90026 m .37773 .81266 L .30803 .78146 L p .837 .67 .676 r
F P
0 g
s
.59862 .72201 m .55158 .62566 L .53008 .62879 L p .672 .664 .834 r
F P
0 g
s
.55158 .62566 m .59862 .72201 L .65083 .7038 L p .642 .65 .842 r
F P
0 g
s
.70831 .79856 m .65083 .7038 L .59862 .72201 L p .62 .56 .765 r
F P
0 g
s
.64765 .91174 m .64493 .96921 L .73137 .94419 L p .518 .278 .49 r
F P
0 g
s
.73137 .94419 m .73611 .88501 L .64765 .91174 L p .518 .278 .49 r
F P
0 g
s
.59463 .37498 m .54363 .47353 L .54591 .47778 L p .931 .824 .718 r
F P
0 g
s
.54363 .47353 m .59463 .37498 L .57889 .36112 L p .869 .726 .701 r
F P
0 g
s
.63363 .27438 m .57889 .36112 L .59463 .37498 L p .81 .742 .789 r
F P
0 g
s
.79027 .51552 m .71084 .56444 L .71497 .52642 L p .873 .926 .857 r
F P
0 g
s
.71497 .52642 m .79879 .45918 L .79027 .51552 L p .873 .926 .857 r
F P
0 g
s
.68732 .5989 m .5842 .59925 L .59194 .58677 L p .74 .869 .94 r
F P
0 g
s
.59194 .58677 m .71084 .56444 L .68732 .5989 L p .74 .869 .94 r
F P
0 g
s
.39821 .28807 m .46139 .36766 L .48047 .35567 L p .599 .557 .779 r
F P
0 g
s
.47096 .61388 m .37628 .69132 L .42333 .71415 L p .745 .742 .849 r
F P
0 g
s
.42333 .71415 m .48761 .62261 L .47096 .61388 L p .745 .742 .849 r
F P
0 g
s
.48047 .35567 m .43581 .26292 L .39821 .28807 L p .599 .557 .779 r
F P
0 g
s
.33302 .24525 m .39821 .28807 L .43581 .26292 L p .657 .688 .868 r
F P
0 g
s
.65083 .7038 m .70831 .79856 L .76918 .76132 L p .56 .535 .784 r
F P
0 g
s
.70831 .79856 m .73611 .88501 L .80728 .84453 L p .496 .405 .682 r
F P
0 g
s
.80728 .84453 m .76918 .76132 L .70831 .79856 L p .496 .405 .682 r
F P
0 g
s
.57889 .36112 m .53926 .46997 L .54363 .47353 L p .869 .726 .701 r
F P
0 g
s
.53926 .46997 m .57889 .36112 L .55692 .35139 L p .808 .652 .689 r
F P
0 g
s
.57889 .36112 m .63363 .27438 L .58986 .25386 L p .774 .69 .771 r
F P
0 g
s
.58986 .25386 m .55692 .35139 L .57889 .36112 L p .774 .69 .771 r
F P
0 g
s
.73536 .26871 m .78907 .27656 L .73394 .22032 L p .385 .619 .944 r
F P
0 g
s
.73394 .22032 m .69047 .22397 L .73536 .26871 L p .385 .619 .944 r
F P
0 g
s
.30803 .78146 m .27479 .86646 L .35574 .90026 L p .837 .67 .676 r
F P
0 g
s
.3594 .95846 m .35574 .90026 L .27479 .86646 L p .858 .555 .476 r
F P
0 g
s
.35574 .90026 m .3594 .95846 L .45152 .9765 L p .779 .492 .5 r
F P
0 g
s
.43581 .26292 m .48047 .35567 L .50466 .34848 L p .65 .582 .765 r
F P
0 g
s
.33302 .24525 m .28343 .24715 L .24444 .30805 L p .79 .907 .922 r
F P
0 g
s
.22572 .35769 m .24444 .30805 L .28343 .24715 L p 0 0 0 r
F P
0 g
s
.65083 .7038 m .57033 .61863 L .55158 .62566 L p .642 .65 .842 r
F P
0 g
s
.57033 .61863 m .65083 .7038 L .69133 .67675 L p .609 .641 .858 r
F P
0 g
s
.76918 .76132 m .69133 .67675 L .65083 .7038 L p .56 .535 .784 r
F P
0 g
s
.63363 .27438 m .69047 .22397 L .62442 .19177 L p .703 .722 .865 r
F P
0 g
s
.62442 .19177 m .58986 .25386 L .63363 .27438 L p .703 .722 .865 r
F P
0 g
s
.55692 .35139 m .58986 .25386 L .53795 .24451 L p .735 .647 .761 r
F P
0 g
s
.53795 .24451 m .53117 .34699 L .55692 .35139 L p .735 .647 .761 r
F P
0 g
s
.8306 .39089 m .79879 .45918 L .7767 .40245 L p .974 .851 .658 r
F P
0 g
s
.7767 .40245 m .80699 .32493 L .8306 .39089 L p .974 .851 .658 r
F P
0 g
s
.54508 .98846 m .54916 .98014 L .45152 .9765 L p .312 0 0 r
F P
0 g
s
.54916 .98014 m .54508 .98846 L .62504 .97939 L p .17 0 0 r
F P
0 g
s
.62504 .97939 m .64493 .96921 L .54916 .98014 L p .17 0 0 r
F P
0 g
s
.25087 .48793 m .33349 .54573 L .34778 .58242 L p .225 .455 .872 r
F P
0 g
s
.48435 .24768 m .50466 .34848 L .53117 .34699 L p .694 .611 .759 r
F P
0 g
s
.50466 .34848 m .48435 .24768 L .43581 .26292 L p .65 .582 .765 r
F P
0 g
s
.53117 .34699 m .53795 .24451 L .48435 .24768 L p .694 .611 .759 r
F P
0 g
s
.54363 .47353 m .52446 .58471 L .54591 .47778 L closepath p .991 .787 .531 r
F P
0 g
s
.22572 .35769 m .2572 .43058 L .25087 .48793 L p .01 .114 .626 r
F P
0 g
s
.33349 .54573 m .25087 .48793 L .2572 .43058 L p .391 .489 .839 r
F P
0 g
s
.46343 .98544 m .45152 .9765 L .3594 .95846 L p .362 0 0 r
F P
0 g
s
.45152 .9765 m .46343 .98544 L .54508 .98846 L p .312 0 0 r
F P
0 g
s
.38912 .20603 m .43581 .26292 L .48435 .24768 L p .67 .692 .862 r
F P
0 g
s
.43581 .26292 m .38912 .20603 L .33302 .24525 L p .657 .688 .868 r
F P
0 g
s
.45986 .6024 m .34329 .66065 L .37628 .69132 L p .759 .777 .867 r
F P
0 g
s
.37628 .69132 m .47096 .61388 L .45986 .6024 L p .759 .777 .867 r
F P
0 g
s
.30803 .78146 m .37628 .69132 L .34329 .66065 L p .835 .778 .797 r
F P
0 g
s
.34329 .66065 m .25744 .73886 L .30803 .78146 L p .835 .778 .797 r
F P
0 g
s
.27479 .86646 m .30803 .78146 L .25744 .73886 L p .9 .752 .688 r
F P
0 g
s
.73611 .88501 m .73137 .94419 L .80079 .90634 L p .357 .146 .451 r
F P
0 g
s
.80079 .90634 m .80728 .84453 L .73611 .88501 L p .357 .146 .451 r
F P
0 g
s
.28343 .24715 m .33302 .24525 L .38912 .20603 L p .712 .928 .963 r
F P
0 g
s
.64493 .96921 m .62504 .97939 L .69669 .95872 L p 0 0 0 r
F P
0 g
s
.69669 .95872 m .73137 .94419 L .64493 .96921 L p 0 0 0 r
F P
0 g
s
.58986 .25386 m .62442 .19177 L .54507 .177 L p .694 .71 .861 r
F P
0 g
s
.54507 .177 m .53795 .24451 L .58986 .25386 L p .694 .71 .861 r
F P
0 g
s
.53008 .62879 m .53007 .6197 L .50807 .61865 L p .712 .464 .548 r
F P
0 g
s
.53007 .6197 m .53008 .62879 L .55158 .62566 L p .628 .395 .546 r
F P
0 g
s
.55158 .62566 m .55151 .61656 L .53007 .6197 L p .628 .395 .546 r
F P
0 g
s
.50807 .61865 m .50801 .62775 L .53008 .62879 L p .712 .464 .548 r
F P
0 g
s
.71084 .56444 m .59194 .58677 L .59245 .57338 L p .761 .837 .91 r
F P
0 g
s
.59245 .57338 m .71497 .52642 L .71084 .56444 L p .761 .837 .91 r
F P
0 g
s
.55151 .61656 m .55158 .62566 L .57033 .61863 L p .521 .311 .535 r
F P
0 g
s
.57033 .61863 m .57021 .60951 L .55151 .61656 L p .521 .311 .535 r
F P
0 g
s
.46294 .18202 m .48435 .24768 L .53795 .24451 L p .682 .7 .86 r
F P
0 g
s
.48435 .24768 m .46294 .18202 L .38912 .20603 L p .67 .692 .862 r
F P
0 g
s
.48772 .61351 m .48761 .62261 L .50801 .62775 L p .79 .529 .542 r
F P
0 g
s
.78907 .27656 m .80699 .32493 L .74855 .26622 L p .906 .495 .148 r
F P
0 g
s
.74855 .26622 m .73394 .22032 L .78907 .27656 L p .906 .495 .148 r
F P
0 g
s
.53795 .24451 m .54507 .177 L .46294 .18202 L p .682 .7 .86 r
F P
0 g
s
.69133 .67675 m .58437 .60839 L .57033 .61863 L p .609 .641 .858 r
F P
0 g
s
.58437 .60839 m .69133 .67675 L .71553 .64308 L p .573 .64 .879 r
F P
0 g
s
.69133 .67675 m .76918 .76132 L .8075 .71411 L p .483 .514 .813 r
F P
0 g
s
.8075 .71411 m .71553 .64308 L .69133 .67675 L p .483 .514 .813 r
F P
0 g
s
.57021 .60951 m .57033 .61863 L .58437 .60839 L p .353 .182 .505 r
F P
0 g
s
.58437 .60839 m .5842 .59925 L .57021 .60951 L p .353 .182 .505 r
F P
0 g
s
.47112 .60475 m .47096 .61388 L .48761 .62261 L p .873 .601 .525 r
F P
0 g
s
.69047 .22397 m .73394 .22032 L .6511 .17944 L p .351 .674 .976 r
F P
0 g
s
.6511 .17944 m .62442 .19177 L .69047 .22397 L p .351 .674 .976 r
F P
0 g
s
.27479 .86646 m .28036 .92684 L .3594 .95846 L p .858 .555 .476 r
F P
0 g
s
.38673 .97049 m .3594 .95846 L .28036 .92684 L p .298 0 0 r
F P
0 g
s
.3594 .95846 m .38673 .97049 L .46343 .98544 L p .362 0 0 r
F P
0 g
s
.28343 .24715 m .26677 .29426 L .22572 .35769 L p 0 0 0 r
F P
0 g
s
.2572 .43058 m .22572 .35769 L .26677 .29426 L p .336 .297 .666 r
F P
0 g
s
.79879 .45918 m .71497 .52642 L .69795 .48885 L p .862 .837 .82 r
F P
0 g
s
.69795 .48885 m .7767 .40245 L .79879 .45918 L p .862 .837 .82 r
F P
0 g
s
.25744 .73886 m .21508 .81996 L .27479 .86646 L p .9 .752 .688 r
F P
0 g
s
.28036 .92684 m .27479 .86646 L .21508 .81996 L p .941 .625 .411 r
F P
0 g
s
.76918 .76132 m .80728 .84453 L .85319 .79275 L p .355 .331 .695 r
F P
0 g
s
.85319 .79275 m .8075 .71411 L .76918 .76132 L p .355 .331 .695 r
F P
0 g
s
.46005 .59324 m .45986 .6024 L .47096 .61388 L p .961 .688 .472 r
F P
0 g
s
.5842 .59925 m .58437 .60839 L .59213 .59595 L p .019 0 .406 r
F P
0 g
s
.59213 .59595 m .59194 .58677 L .5842 .59925 L p .019 0 .406 r
F P
0 g
s
.2572 .43058 m .33972 .50739 L .33349 .54573 L p .391 .489 .839 r
F P
0 g
s
.71553 .64308 m .59213 .59595 L .58437 .60839 L p .573 .64 .879 r
F P
0 g
s
.45559 .58933 m .32853 .62478 L .34329 .66065 L p .764 .814 .892 r
F P
0 g
s
.34329 .66065 m .45986 .6024 L .45559 .58933 L p .764 .814 .892 r
F P
0 g
s
.25744 .73886 m .34329 .66065 L .32853 .62478 L p .862 .854 .832 r
F P
0 g
s
.35318 .19758 m .38912 .20603 L .46294 .18202 L p .588 .9 .985 r
F P
0 g
s
.38912 .20603 m .35318 .19758 L .28343 .24715 L p .712 .928 .963 r
F P
0 g
s
.73137 .94419 m .69669 .95872 L .75337 .9277 L p .416 .85 .729 r
F P
0 g
s
.75337 .9277 m .80079 .90634 L .73137 .94419 L p .416 .85 .729 r
F P
0 g
s
.26677 .29426 m .28343 .24715 L .35318 .19758 L p .21 0 .255 r
F P
0 g
s
.59194 .58677 m .59213 .59595 L .59265 .58259 L p 0 0 .068 r
F P
0 g
s
.59265 .58259 m .59245 .57338 L .59194 .58677 L p 0 0 .068 r
F P
0 g
s
.53858 .93958 m .54508 .98846 L .46343 .98544 L p .669 .743 .906 r
F P
0 g
s
.54508 .98846 m .53858 .93958 L .59335 .93313 L p .652 .731 .907 r
F P
0 g
s
.59335 .93313 m .62504 .97939 L .54508 .98846 L p .652 .731 .907 r
F P
0 g
s
.59213 .59595 m .71553 .64308 L .71988 .60588 L p .536 .648 .907 r
F P
0 g
s
.71988 .60588 m .59265 .58259 L .59213 .59595 L p .536 .648 .907 r
F P
0 g
s
.48252 .93743 m .46343 .98544 L .38673 .97049 L p .682 .759 .909 r
F P
0 g
s
.46343 .98544 m .48252 .93743 L .53858 .93958 L p .669 .743 .906 r
F P
0 g
s
.62442 .19177 m .6511 .17944 L .55058 .16056 L p .369 .747 .989 r
F P
0 g
s
.55058 .16056 m .54507 .177 L .62442 .19177 L p .369 .747 .989 r
F P
0 g
s
.71497 .52642 m .59245 .57338 L .58553 .56052 L p .764 .799 .882 r
F P
0 g
s
.58553 .56052 m .69795 .48885 L .71497 .52642 L p .764 .799 .882 r
F P
0 g
s
.32853 .62478 m .23258 .68805 L .25744 .73886 L p .862 .854 .832 r
F P
0 g
s
.21508 .81996 m .25744 .73886 L .23258 .68805 L p .959 .86 .699 r
F P
0 g
s
.80699 .32493 m .7767 .40245 L .72387 .3523 L p .902 .735 .666 r
F P
0 g
s
.72387 .3523 m .74855 .26622 L .80699 .32493 L p .902 .735 .666 r
F P
0 g
s
.52446 .58471 m .54474 .703 L .54004 .70629 L closepath p .396 .262 .579 r
F P
0 g
s
.52446 .58471 m .54726 .69904 L .54474 .703 L closepath p .122 .078 .53 r
F P
0 g
s
.52446 .58471 m .54019 .68747 L .54488 .69082 L closepath p .922 .578 .368 r
F P
0 g
s
.52446 .58471 m .54004 .70629 L .53367 .70857 L closepath p .542 .365 .591 r
F P
0 g
s
.52446 .58471 m .53376 .68513 L .54019 .68747 L closepath p .832 .509 .442 r
F P
0 g
s
.52446 .58471 m .53367 .70857 L .52632 .70959 L closepath p .64 .438 .594 r
F P
0 g
s
.52446 .58471 m .5263 .68409 L .53376 .68513 L closepath p .744 .44 .468 r
F P
0 g
s
.52446 .58471 m .51876 .70925 L .5118 .70758 L closepath p .791 .564 .593 r
F P
0 g
s
.52446 .58471 m .52632 .70959 L .51876 .70925 L closepath p .718 .501 .595 r
F P
0 g
s
.52446 .58471 m .51862 .68444 L .5263 .68409 L closepath p .653 .367 .472 r
F P
0 g
s
.52446 .58471 m .5118 .70758 L .50618 .70476 L closepath p .869 .639 .587 r
F P
0 g
s
.52446 .58471 m .51159 .68616 L .51862 .68444 L closepath p .542 .274 .458 r
F P
0 g
s
.52446 .58471 m .50618 .70476 L .5025 .70109 L closepath p .955 .733 .564 r
F P
0 g
s
.52446 .58471 m .50597 .68905 L .51159 .68616 L closepath p .373 .132 .414 r
F P
0 g
s
.50118 .69695 m .52446 .58471 L .5035 .69581 L p .993 .827 .459 r
F P
0 g
s
.5035 .69581 m .5025 .70109 L .50118 .69695 L p .993 .827 .459 r
F P
0 g
s
.43902 .77933 m .49828 .69836 L p .50118 .69695 L .875 .962 .627 r
F P
0 g
s
.50237 .69278 m .52446 .58471 L .50224 .69184 L p 0 0 0 r
F P
0 g
s
.50224 .69184 m .50118 .69695 L .50237 .69278 L p 0 0 0 r
F P
0 g
s
.49828 .69836 m .50237 .69278 L .50118 .69695 L p .875 .962 .627 r
F P
0 g
s
.50118 .69695 m .44229 .78384 L p .43902 .77933 L .875 .962 .627 r
F P
0 g
s
.44229 .78384 m .43509 .79446 L .43902 .77933 L p .875 .962 .627 r
F P
0 g
s
.375 .79795 m .43449 .77308 L p .43902 .77933 L .695 .982 .859 r
F P
0 g
s
.50237 .69278 m .44597 .76984 L p .45245 .76557 L 0 0 0 r
F P
0 g
s
.44597 .76984 m .43902 .77933 L .45245 .76557 L p 0 0 0 r
F P
0 g
s
.45245 .76557 m .50253 .69395 L p .50237 .69278 L 0 0 0 r
F P
0 g
s
.43509 .79446 m .50118 .69695 L .5025 .70109 L p .962 .897 .713 r
F P
0 g
s
.5025 .70109 m .44081 .80927 L .43509 .79446 L p .962 .897 .713 r
F P
0 g
s
.44081 .80927 m .5025 .70109 L .50618 .70476 L p .909 .78 .707 r
F P
0 g
s
.50597 .68905 m .45245 .76557 L .47411 .7548 L p .144 0 .047 r
F P
0 g
s
.41916 .77589 m .46144 .75966 L p .45245 .76557 L .378 .829 .718 r
F P
0 g
s
.46144 .75966 m .47411 .7548 L .45245 .76557 L p .378 .829 .718 r
F P
0 g
s
.43449 .77308 m .45245 .76557 L .43902 .77933 L p .695 .982 .859 r
F P
0 g
s
.50253 .69395 m .50597 .68905 L .50237 .69278 L p 0 0 0 r
F P
0 g
s
.52446 .58471 m .50237 .69278 L .50597 .68905 L closepath p .045 0 .285 r
F P
0 g
s
.54623 .69385 m .52446 .58471 L .54732 .69483 L p 0 0 .306 r
F P
0 g
s
.54488 .69082 m .54732 .69483 L .54627 .68981 L p .929 .595 .146 r
F P
0 g
s
.54627 .68981 m .52446 .58471 L .54488 .69082 L p .929 .595 .146 r
F P
0 g
s
.54488 .69082 m .54019 .68747 L p .54348 .69183 L .781 .28 0 r
F P
0 g
s
.54732 .69483 m .54488 .69082 L p .5484 .69581 L 0 0 .477 r
F P
0 g
s
.6128 .78679 m .54732 .69483 L p .5484 .69581 L 0 0 .477 r
F P
0 g
s
.54732 .69483 m .54726 .69904 L .54623 .69385 L p 0 0 .306 r
F P
0 g
s
.61192 .80197 m .54726 .69904 L .54732 .69483 L p .011 .181 .693 r
F P
0 g
s
.54732 .69483 m .6128 .78679 L .61192 .80197 L p .011 .181 .693 r
F P
0 g
s
.60397 .77214 m .6128 .78679 L p .6056 .77662 L 0 0 .477 r
F P
0 g
s
.54488 .69082 m .60397 .77214 L p .6056 .77662 L 0 0 .477 r
F P
0 g
s
.60397 .77214 m .54488 .69082 L p .54348 .69183 L .781 .28 0 r
F P
0 g
s
.58614 .7597 m .60397 .77214 L p .59716 .7631 L .781 .28 0 r
F P
0 g
s
.54019 .68747 m .58614 .7597 L p .59716 .7631 L .781 .28 0 r
F P
0 g
s
.54474 .703 m .6017 .81604 L .58347 .82758 L p .48 .409 .699 r
F P
0 g
s
.6017 .81604 m .54474 .703 L .54726 .69904 L p .318 .328 .713 r
F P
0 g
s
.54726 .69904 m .61192 .80197 L .6017 .81604 L p .318 .328 .713 r
F P
0 g
s
.58614 .7597 m .56115 .75095 L p .57558 .75644 L .282 0 0 r
F P
0 g
s
.60397 .77214 m .58614 .7597 L p .60241 .76786 L 0 .382 .801 r
F P
0 g
s
.65321 .78596 m .68892 .81123 L p .68392 .80872 L 0 .382 .801 r
F P
0 g
s
.58614 .7597 m .65321 .78596 L p .68392 .80872 L 0 .382 .801 r
F P
0 g
s
.65321 .78596 m .58614 .7597 L p .57558 .75644 L .282 0 0 r
F P
0 g
s
.68892 .81123 m .60397 .77214 L p .60241 .76786 L 0 .382 .801 r
F P
0 g
s
.60159 .76792 m .65321 .78596 L p .64868 .78423 L .282 0 0 r
F P
0 g
s
.56115 .75095 m .60159 .76792 L p .64868 .78423 L .282 0 0 r
F P
0 g
s
.53367 .70857 m .55926 .83547 L .53157 .83898 L p .658 .517 .681 r
F P
0 g
s
.55926 .83547 m .53367 .70857 L .54004 .70629 L p .582 .467 .687 r
F P
0 g
s
.54004 .70629 m .58347 .82758 L .55926 .83547 L p .582 .467 .687 r
F P
0 g
s
.58347 .82758 m .54004 .70629 L .54474 .703 L p .48 .409 .699 r
F P
0 g
s
.53157 .83898 m .52632 .70959 L .53367 .70857 L p .658 .517 .681 r
F P
0 g
s
.60159 .76792 m .56115 .75095 L .53184 .747 L p .296 0 0 r
F P
0 g
s
.5401 .75968 m .60159 .76792 L p .59813 .76688 L .296 0 0 r
F P
0 g
s
.53184 .747 m .5401 .75968 L p .59813 .76688 L .296 0 0 r
F P
0 g
s
.50317 .83781 m .51876 .70925 L .52632 .70959 L p .722 .567 .679 r
F P
0 g
s
.52632 .70959 m .53157 .83898 L .50317 .83781 L p .722 .567 .679 r
F P
0 g
s
.47686 .83205 m .5118 .70758 L .51876 .70925 L p .782 .623 .683 r
F P
0 g
s
.51876 .70925 m .50317 .83781 L .47686 .83205 L p .782 .623 .683 r
F P
0 g
s
.45531 .82223 m .50618 .70476 L .5118 .70758 L p .844 .691 .693 r
F P
0 g
s
.5118 .70758 m .47686 .83205 L .45531 .82223 L p .844 .691 .693 r
F P
0 g
s
.50618 .70476 m .45531 .82223 L .44081 .80927 L p .909 .78 .707 r
F P
0 g
s
.47655 .76248 m .50163 .74834 L .47411 .7548 L p 0 0 0 r
F P
0 g
s
.50163 .74834 m .47655 .76248 L .5401 .75968 L p .186 0 0 r
F P
0 g
s
.5401 .75968 m .47655 .76248 L p .49142 .75365 L .569 .814 .991 r
F P
0 g
s
.50163 .74834 m .51862 .68444 L .51159 .68616 L p .416 .026 .189 r
F P
0 g
s
.51159 .68616 m .47411 .7548 L .50163 .74834 L p .416 .026 .189 r
F P
0 g
s
.53376 .68513 m .56115 .75095 L .58614 .7597 L p .767 .301 .136 r
F P
0 g
s
.56115 .75095 m .53376 .68513 L .5263 .68409 L p .684 .253 .221 r
F P
0 g
s
.53184 .747 m .5263 .68409 L .51862 .68444 L p .573 .167 .235 r
F P
0 g
s
.51862 .68444 m .50163 .74834 L .53184 .747 L p .573 .167 .235 r
F P
0 g
s
.5263 .68409 m .53184 .747 L .56115 .75095 L p .684 .253 .221 r
F P
0 g
s
.5401 .75968 m .53184 .747 L .50163 .74834 L p .186 0 0 r
F P
0 g
s
.54882 .71955 m .5401 .75968 L p .49142 .75365 L .569 .814 .991 r
F P
0 g
s
.60159 .76792 m .5401 .75968 L p .56163 .75407 L .548 .794 .99 r
F P
0 g
s
.58614 .7597 m .54019 .68747 L .53376 .68513 L p .767 .301 .136 r
F P
0 g
s
.64392 .73263 m .60159 .76792 L p .56163 .75407 L .548 .794 .99 r
F P
0 g
s
.65321 .78596 m .60159 .76792 L p .62694 .76647 L .538 .773 .985 r
F P
0 g
s
.7225 .76103 m .65321 .78596 L p .62694 .76647 L .538 .773 .985 r
F P
0 g
s
.26677 .29426 m .29473 .3762 L .2572 .43058 L p .336 .297 .666 r
F P
0 g
s
.33972 .50739 m .2572 .43058 L .29473 .3762 L p .501 .515 .803 r
F P
0 g
s
.80728 .84453 m .80079 .90634 L .84537 .85799 L p .043 0 .338 r
F P
0 g
s
.84537 .85799 m .85319 .79275 L .80728 .84453 L p .043 0 .338 r
F P
0 g
s
.71553 .64308 m .8075 .71411 L .81718 .66084 L p .377 .497 .853 r
F P
0 g
s
.81718 .66084 m .71988 .60588 L .71553 .64308 L p .377 .497 .853 r
F P
0 g
s
.62504 .97939 m .59335 .93313 L .64186 .91852 L p .632 .722 .912 r
F P
0 g
s
.64186 .91852 m .69669 .95872 L .62504 .97939 L p .632 .722 .912 r
F P
0 g
s
.44632 .16699 m .46294 .18202 L .54507 .177 L p .455 .83 .991 r
F P
0 g
s
.46294 .18202 m .44632 .16699 L .35318 .19758 L p .588 .9 .985 r
F P
0 g
s
.59245 .57338 m .59265 .58259 L .5857 .56976 L p .984 .715 .339 r
F P
0 g
s
.5857 .56976 m .58553 .56052 L .59245 .57338 L p .984 .715 .339 r
F P
0 g
s
.54507 .177 m .55058 .16056 L .44632 .16699 L p .455 .83 .991 r
F P
0 g
s
.59265 .58259 m .71988 .60588 L .70251 .56909 L p .5 .667 .937 r
F P
0 g
s
.70251 .56909 m .5857 .56976 L .59265 .58259 L p .5 .667 .937 r
F P
0 g
s
.21508 .81996 m .22221 .88339 L .28036 .92684 L p .941 .625 .411 r
F P
0 g
s
.28036 .92684 m .32163 .94447 L .38673 .97049 L p .298 0 0 r
F P
0 g
s
.32163 .94447 m .28036 .92684 L .22221 .88339 L p 0 .391 .815 r
F P
0 g
s
.73394 .22032 m .74855 .26622 L .6601 .22341 L p .841 .456 .32 r
F P
0 g
s
.6601 .22341 m .6511 .17944 L .73394 .22032 L p .841 .456 .32 r
F P
0 g
s
.43022 .92682 m .38673 .97049 L .32163 .94447 L p .692 .777 .917 r
F P
0 g
s
.38673 .97049 m .43022 .92682 L .48252 .93743 L p .682 .759 .909 r
F P
0 g
s
.45878 .57605 m .33481 .58725 L .32853 .62478 L p .754 .849 .922 r
F P
0 g
s
.29473 .3762 m .36711 .47172 L .33972 .50739 L p .501 .515 .803 r
F P
0 g
s
.69795 .48885 m .58553 .56052 L .57176 .54963 L p .753 .762 .86 r
F P
0 g
s
.58553 .56052 m .5857 .56976 L .5719 .5589 L p .929 .642 .477 r
F P
0 g
s
.5719 .5589 m .57176 .54963 L .58553 .56052 L p .929 .642 .477 r
F P
0 g
s
.23258 .68805 m .32853 .62478 L .33481 .58725 L p .858 .937 .874 r
F P
0 g
s
.5857 .56976 m .70251 .56909 L .66409 .53712 L p .472 .696 .966 r
F P
0 g
s
.66409 .53712 m .5719 .5589 L .5857 .56976 L p .472 .696 .966 r
F P
0 g
s
.35318 .19758 m .34102 .24242 L .26677 .29426 L p .21 0 .255 r
F P
0 g
s
.29473 .3762 m .26677 .29426 L .34102 .24242 L p .503 .395 .664 r
F P
0 g
s
.7767 .40245 m .69795 .48885 L .66046 .45624 L p .826 .76 .789 r
F P
0 g
s
.66046 .45624 m .72387 .3523 L .7767 .40245 L p .826 .76 .789 r
F P
0 g
s
.8075 .71411 m .85319 .79275 L .86634 .7337 L p .096 .207 .691 r
F P
0 g
s
.86634 .7337 m .81718 .66084 L .8075 .71411 L p .096 .207 .691 r
F P
0 g
s
.46924 .56402 m .36283 .5523 L .33481 .58725 L p .723 .874 .952 r
F P
0 g
s
.57176 .54963 m .66046 .45624 L .69795 .48885 L p .753 .762 .86 r
F P
0 g
s
.66046 .45624 m .57176 .54963 L .55261 .54201 L p .736 .728 .844 r
F P
0 g
s
.57176 .54963 m .5719 .5589 L .55269 .5513 L p .837 .56 .518 r
F P
0 g
s
.55269 .5513 m .55261 .54201 L .57176 .54963 L p .837 .56 .518 r
F P
0 g
s
.23258 .68805 m .18446 .76394 L .21508 .81996 L p .959 .86 .699 r
F P
0 g
s
.22221 .88339 m .21508 .81996 L .18446 .76394 L p .95 .654 .211 r
F P
0 g
s
.34102 .24242 m .35318 .19758 L .44632 .16699 L p .472 .16 .356 r
F P
0 g
s
.69669 .95872 m .64186 .91852 L .67934 .89688 L p .611 .719 .922 r
F P
0 g
s
.67934 .89688 m .75337 .9277 L .69669 .95872 L p .611 .719 .922 r
F P
0 g
s
.5719 .5589 m .66409 .53712 L .60826 .51424 L p .461 .735 .987 r
F P
0 g
s
.60826 .51424 m .55269 .5513 L .5719 .5589 L p .461 .735 .987 r
F P
0 g
s
.55261 .54201 m .60607 .43293 L .66046 .45624 L p .736 .728 .844 r
F P
0 g
s
.60607 .43293 m .55261 .54201 L .5302 .53857 L p .713 .699 .836 r
F P
0 g
s
.55261 .54201 m .55269 .5513 L .53021 .54787 L p .753 .489 .532 r
F P
0 g
s
.53021 .54787 m .5302 .53857 L .55261 .54201 L p .753 .489 .532 r
F P
0 g
s
.53157 .83898 m .53858 .93958 L .48252 .93743 L p .716 .635 .766 r
F P
0 g
s
.53858 .93958 m .53157 .83898 L .55926 .83547 L p .667 .598 .768 r
F P
0 g
s
.55926 .83547 m .59335 .93313 L .53858 .93958 L p .667 .598 .768 r
F P
0 g
s
.80079 .90634 m .75337 .9277 L .78869 .88852 L p .707 .985 .872 r
F P
0 g
s
.78869 .88852 m .84537 .85799 L .80079 .90634 L p .707 .985 .872 r
F P
0 g
s
.48594 .55465 m .4105 .52436 L .36283 .5523 L p .668 .881 .977 r
F P
0 g
s
.50317 .83781 m .48252 .93743 L .43022 .92682 L p .761 .679 .772 r
F P
0 g
s
.48252 .93743 m .50317 .83781 L .53157 .83898 L p .716 .635 .766 r
F P
0 g
s
.5302 .53857 m .54118 .42228 L .60607 .43293 L p .713 .699 .836 r
F P
0 g
s
.55269 .5513 m .60826 .51424 L .54159 .50379 L p .478 .781 .997 r
F P
0 g
s
.54159 .50379 m .53021 .54787 L .55269 .5513 L p .478 .781 .997 r
F P
0 g
s
.71988 .60588 m .81718 .66084 L .79417 .60696 L p .225 .48 .89 r
F P
0 g
s
.79417 .60696 m .70251 .56909 L .71988 .60588 L p .225 .48 .89 r
F P
0 g
s
.50707 .54903 m .47266 .50734 L .4105 .52436 L p .597 .865 .993 r
F P
0 g
s
.53021 .54787 m .54159 .50379 L .47266 .50734 L p .527 .827 .999 r
F P
0 g
s
.59335 .93313 m .55926 .83547 L .58347 .82758 L p .612 .566 .779 r
F P
0 g
s
.58347 .82758 m .64186 .91852 L .59335 .93313 L p .612 .566 .779 r
F P
0 g
s
.6511 .17944 m .6601 .22341 L .55241 .2036 L p .738 .382 .377 r
F P
0 g
s
.55241 .2036 m .55058 .16056 L .6511 .17944 L p .738 .382 .377 r
F P
0 g
s
.22221 .88339 m .2747 .90905 L .32163 .94447 L p 0 .391 .815 r
F P
0 g
s
.38657 .90853 m .32163 .94447 L .2747 .90905 L p .695 .796 .927 r
F P
0 g
s
.32163 .94447 m .38657 .90853 L .43022 .92682 L p .692 .777 .917 r
F P
0 g
s
.34102 .24242 m .36138 .33206 L .29473 .3762 L p .503 .395 .664 r
F P
0 g
s
.36711 .47172 m .29473 .3762 L .36138 .33206 L p .58 .543 .778 r
F P
0 g
s
.74855 .26622 m .72387 .3523 L .64486 .31593 L p .827 .648 .661 r
F P
0 g
s
.64486 .31593 m .6601 .22341 L .74855 .26622 L p .827 .648 .661 r
F P
0 g
s
.36138 .33206 m .41358 .44324 L .36711 .47172 L p .58 .543 .778 r
F P
0 g
s
.47686 .83205 m .43022 .92682 L .38657 .90853 L p .803 .734 .788 r
F P
0 g
s
.43022 .92682 m .47686 .83205 L .50317 .83781 L p .761 .679 .772 r
F P
0 g
s
.44066 .21035 m .44632 .16699 L .55058 .16056 L p .624 .291 .386 r
F P
0 g
s
.44632 .16699 m .44066 .21035 L .34102 .24242 L p .472 .16 .356 r
F P
0 g
s
.33481 .58725 m .23871 .6337 L .23258 .68805 L p .858 .937 .874 r
F P
0 g
s
.18446 .76394 m .23258 .68805 L .23871 .6337 L p .933 .959 .653 r
F P
0 g
s
.23871 .6337 m .33481 .58725 L .36283 .5523 L p .768 .989 .893 r
F P
0 g
s
.55058 .16056 m .55241 .2036 L .44066 .21035 L p .624 .291 .386 r
F P
0 g
s
.85319 .79275 m .84537 .85799 L .8579 .80297 L p 0 0 0 r
F P
0 g
s
.8579 .80297 m .86634 .7337 L .85319 .79275 L p 0 0 0 r
F P
0 g
s
.64186 .91852 m .58347 .82758 L .6017 .81604 L p .544 .539 .799 r
F P
0 g
s
.6017 .81604 m .67934 .89688 L .64186 .91852 L p .544 .539 .799 r
F P
0 g
s
.72387 .3523 m .66046 .45624 L .60607 .43293 L p .784 .698 .769 r
F P
0 g
s
.18446 .76394 m .19261 .83114 L .22221 .88339 L p .95 .654 .211 r
F P
0 g
s
.2747 .90905 m .22221 .88339 L .19261 .83114 L p .158 .472 .894 r
F P
0 g
s
.38657 .90853 m .45531 .82223 L .47686 .83205 L p .803 .734 .788 r
F P
0 g
s
.47411 .7548 m .51159 .68616 L .50597 .68905 L p .144 0 .047 r
F P
0 g
s
.36138 .33206 m .34102 .24242 L .44066 .21035 L p .608 .463 .658 r
F P
0 g
s
.75337 .9277 m .67934 .89688 L .70155 .87 L p .589 .72 .934 r
F P
0 g
s
.70155 .87 m .78869 .88852 L .75337 .9277 L p .589 .72 .934 r
F P
0 g
s
.60607 .43293 m .64486 .31593 L .72387 .3523 L p .784 .698 .769 r
F P
0 g
s
.2747 .90905 m .35614 .88402 L .38657 .90853 L p .695 .796 .927 r
F P
0 g
s
.45531 .82223 m .38657 .90853 L .35614 .88402 L p .841 .802 .814 r
F P
0 g
s
.45008 .30487 m .4741 .4259 L .41358 .44324 L p .641 .573 .763 r
F P
0 g
s
.41358 .44324 m .36138 .33206 L .45008 .30487 L p .641 .573 .763 r
F P
0 g
s
.35614 .88402 m .44081 .80927 L .45531 .82223 L p .841 .802 .814 r
F P
0 g
s
.70251 .56909 m .79417 .60696 L .73805 .55914 L p .029 .455 .875 r
F P
0 g
s
.73805 .55914 m .66409 .53712 L .70251 .56909 L p .029 .455 .875 r
F P
0 g
s
.81718 .66084 m .86634 .7337 L .84126 .6733 L p 0 0 .547 r
F P
0 g
s
.84126 .6733 m .79417 .60696 L .81718 .66084 L p 0 0 .547 r
F P
0 g
s
.67934 .89688 m .6017 .81604 L .61192 .80197 L p .453 .514 .831 r
F P
0 g
s
.6601 .22341 m .64486 .31593 L .54922 .29916 L p .757 .58 .657 r
F P
0 g
s
.54922 .29916 m .55241 .2036 L .6601 .22341 L p .757 .58 .657 r
F P
0 g
s
.64486 .31593 m .60607 .43293 L .54118 .42228 L p .74 .649 .759 r
F P
0 g
s
.44066 .21035 m .45008 .30487 L .36138 .33206 L p .608 .463 .658 r
F P
0 g
s
.61192 .80197 m .70155 .87 L .67934 .89688 L p .453 .514 .831 r
F P
0 g
s
.34273 .85543 m .43509 .79446 L .44081 .80927 L p .865 .885 .849 r
F P
0 g
s
.44081 .80927 m .35614 .88402 L .34273 .85543 L p .865 .885 .849 r
F P
0 g
s
.54922 .29916 m .54118 .42228 L .4741 .4259 L p .693 .608 .757 r
F P
0 g
s
.4741 .4259 m .45008 .30487 L .54922 .29916 L p .693 .608 .757 r
F P
0 g
s
.23871 .6337 m .18969 .70337 L .18446 .76394 L p .933 .959 .653 r
F P
0 g
s
.19261 .83114 m .18446 .76394 L .18969 .70337 L p 0 0 .24 r
F P
0 g
s
.19261 .83114 m .25205 .86697 L .2747 .90905 L p .158 .472 .894 r
F P
0 g
s
.35614 .88402 m .2747 .90905 L .25205 .86697 L p .691 .814 .941 r
F P
0 g
s
.27831 .58196 m .36283 .5523 L .4105 .52436 L p .527 .92 .832 r
F P
0 g
s
.36283 .5523 m .27831 .58196 L .23871 .6337 L p .768 .989 .893 r
F P
0 g
s
.84537 .85799 m .78869 .88852 L .79711 .84451 L p .832 .961 .893 r
F P
0 g
s
.79711 .84451 m .8579 .80297 L .84537 .85799 L p .832 .961 .893 r
F P
0 g
s
.54118 .42228 m .54922 .29916 L .64486 .31593 L p .74 .649 .759 r
F P
0 g
s
.45008 .30487 m .44066 .21035 L .55241 .2036 L p .687 .521 .656 r
F P
0 g
s
.70155 .87 m .61192 .80197 L .6128 .78679 L p .322 .488 .868 r
F P
0 g
s
.55241 .2036 m .54922 .29916 L .45008 .30487 L p .687 .521 .656 r
F P
0 g
s
.25205 .86697 m .34273 .85543 L .35614 .88402 L p .691 .814 .941 r
F P
0 g
s
.66409 .53712 m .73805 .55914 L .65355 .52435 L p 0 .424 .767 r
F P
0 g
s
.65355 .52435 m .60826 .51424 L .66409 .53712 L p 0 .424 .767 r
F P
0 g
s
.34884 .82562 m .43902 .77933 L .43509 .79446 L p .842 .968 .882 r
F P
0 g
s
.43509 .79446 m .34273 .85543 L .34884 .82562 L p .842 .968 .882 r
F P
0 g
s
.18969 .70337 m .23871 .6337 L .27831 .58196 L p 0 0 0 r
F P
0 g
s
.6128 .78679 m .70527 .84041 L .70155 .87 L p .322 .488 .868 r
F P
0 g
s
.70527 .84041 m .6128 .78679 L .60397 .77214 L p .125 .449 .882 r
F P
0 g
s
.78869 .88852 m .70155 .87 L .70527 .84041 L p .569 .726 .948 r
F P
0 g
s
.70527 .84041 m .79711 .84451 L .78869 .88852 L p .569 .726 .948 r
F P
0 g
s
.34939 .53979 m .4105 .52436 L .47266 .50734 L p .204 .724 .702 r
F P
0 g
s
.4105 .52436 m .34939 .53979 L .27831 .58196 L p .527 .92 .832 r
F P
0 g
s
.43902 .77933 m .34884 .82562 L .375 .79795 L p .695 .982 .859 r
F P
0 g
s
.86634 .7337 m .8579 .80297 L .83313 .74679 L p .992 .791 .412 r
F P
0 g
s
.83313 .74679 m .84126 .6733 L .86634 .7337 L p .992 .791 .412 r
F P
0 g
s
.18969 .70337 m .19803 .77474 L .19261 .83114 L p 0 0 .24 r
F P
0 g
s
.25205 .86697 m .19261 .83114 L .19803 .77474 L p .351 .517 .881 r
F P
0 g
s
.60826 .51424 m .65355 .52435 L .55091 .50828 L p .161 0 0 r
F P
0 g
s
.55091 .50828 m .54159 .50379 L .60826 .51424 L p .161 0 0 r
F P
0 g
s
.60397 .77214 m .68892 .81123 L .70527 .84041 L p .125 .449 .882 r
F P
0 g
s
.47266 .50734 m .44445 .51375 L .34939 .53979 L p .204 .724 .702 r
F P
0 g
s
.44445 .51375 m .47266 .50734 L .54159 .50379 L p .044 0 0 r
F P
0 g
s
.79417 .60696 m .84126 .6733 L .77661 .61911 L p .757 .259 0 r
F P
0 g
s
.77661 .61911 m .73805 .55914 L .79417 .60696 L p .757 .259 0 r
F P
0 g
s
.25838 .82216 m .34884 .82562 L .34273 .85543 L p .679 .829 .955 r
F P
0 g
s
.34273 .85543 m .25205 .86697 L .25838 .82216 L p .679 .829 .955 r
F P
0 g
s
.54159 .50379 m .55091 .50828 L .44445 .51375 L p .044 0 0 r
F P
0 g
s
.45024 .724 m .46858 .75082 L p .41916 .77589 L .598 .829 .988 r
F P
0 g
s
.45245 .76557 m .37891 .79631 L p .41916 .77589 L .378 .829 .718 r
F P
0 g
s
.47411 .7548 m .41916 .77589 L .47655 .76248 L p 0 0 0 r
F P
0 g
s
.46858 .75082 m .47655 .76248 L .41916 .77589 L p .598 .829 .988 r
F P
0 g
s
.37891 .79631 m .375 .79795 L .41916 .77589 L p .378 .829 .718 r
F P
0 g
s
.19803 .77474 m .25838 .82216 L .25205 .86697 L p .351 .517 .881 r
F P
0 g
s
.79711 .84451 m .70527 .84041 L .68892 .81123 L p .551 .738 .963 r
F P
0 g
s
.8579 .80297 m .79711 .84451 L .77508 .80019 L p .846 .879 .864 r
F P
0 g
s
.77508 .80019 m .83313 .74679 L .8579 .80297 L p .846 .879 .864 r
F P
0 g
s
.27831 .58196 m .23449 .64504 L .18969 .70337 L p 0 0 0 r
F P
0 g
s
.19803 .77474 m .18969 .70337 L .23449 .64504 L p .13 .055 .496 r
F P
0 g
s
.23449 .64504 m .27831 .58196 L .34939 .53979 L p .057 0 0 r
F P
0 g
s
.68892 .81123 m .77508 .80019 L .79711 .84451 L p .551 .738 .963 r
F P
0 g
s
.29574 .77969 m .375 .79795 L .34884 .82562 L p .658 .837 .969 r
F P
0 g
s
.34884 .82562 m .25838 .82216 L .29574 .77969 L p .658 .837 .969 r
F P
0 g
s
.73805 .55914 m .77661 .61911 L .67741 .57934 L p .775 .297 .101 r
F P
0 g
s
.67741 .57934 m .65355 .52435 L .73805 .55914 L p .775 .297 .101 r
F P
0 g
s
.77508 .80019 m .68892 .81123 L .65321 .78596 L p .54 .754 .975 r
F P
0 g
s
.84126 .6733 m .83313 .74679 L .76992 .69649 L p .946 .702 .538 r
F P
0 g
s
.76992 .69649 m .77661 .61911 L .84126 .6733 L p .946 .702 .538 r
F P
0 g
s
.23449 .64504 m .24197 .72054 L .19803 .77474 L p .13 .055 .496 r
F P
0 g
s
.25838 .82216 m .19803 .77474 L .24197 .72054 L p .478 .546 .848 r
F P
0 g
s
.24197 .72054 m .29574 .77969 L .25838 .82216 L p .478 .546 .848 r
F P
0 g
s
.31728 .59703 m .34939 .53979 L .44445 .51375 L p .383 0 .164 r
F P
0 g
s
.34939 .53979 m .31728 .59703 L .23449 .64504 L p .057 0 0 r
F P
0 g
s
.36204 .74523 m .41916 .77589 L .375 .79795 L p .629 .838 .98 r
F P
0 g
s
.375 .79795 m .29574 .77969 L .36204 .74523 L p .629 .838 .98 r
F P
0 g
s
.65321 .78596 m .7225 .76103 L .77508 .80019 L p .54 .754 .975 r
F P
0 g
s
.65355 .52435 m .67741 .57934 L .55582 .56087 L p .686 .247 .202 r
F P
0 g
s
.55582 .56087 m .55091 .50828 L .65355 .52435 L p .686 .247 .202 r
F P
0 g
s
.24197 .72054 m .23449 .64504 L .31728 .59703 L p .417 .259 .558 r
F P
0 g
s
.83313 .74679 m .77508 .80019 L .7225 .76103 L p .82 .799 .832 r
F P
0 g
s
.7225 .76103 m .76992 .69649 L .83313 .74679 L p .82 .799 .832 r
F P
0 g
s
.42949 .56717 m .44445 .51375 L .55091 .50828 L p .564 .151 .218 r
F P
0 g
s
.44445 .51375 m .42949 .56717 L .31728 .59703 L p .383 0 .164 r
F P
0 g
s
.41916 .77589 m .36204 .74523 L .45024 .724 L p .598 .829 .988 r
F P
0 g
s
.55091 .50828 m .55582 .56087 L .42949 .56717 L p .564 .151 .218 r
F P
0 g
s
.60159 .76792 m .64392 .73263 L .7225 .76103 L p .538 .773 .985 r
F P
0 g
s
.47655 .76248 m .45024 .724 L .54882 .71955 L p .569 .814 .991 r
F P
0 g
s
.32277 .67601 m .36204 .74523 L .29574 .77969 L p .566 .573 .82 r
F P
0 g
s
.29574 .77969 m .24197 .72054 L .32277 .67601 L p .566 .573 .82 r
F P
0 g
s
.77661 .61911 m .76992 .69649 L .67323 .65962 L p .85 .606 .569 r
F P
0 g
s
.67323 .65962 m .67741 .57934 L .77661 .61911 L p .85 .606 .569 r
F P
0 g
s
.5401 .75968 m .54882 .71955 L .64392 .73263 L p .548 .794 .99 r
F P
0 g
s
.31728 .59703 m .32277 .67601 L .24197 .72054 L p .417 .259 .558 r
F P
0 g
s
.76992 .69649 m .7225 .76103 L .64392 .73263 L p .781 .734 .81 r
F P
0 g
s
.32277 .67601 m .31728 .59703 L .42949 .56717 L p .57 .373 .574 r
F P
0 g
s
.64392 .73263 m .67323 .65962 L .76992 .69649 L p .781 .734 .81 r
F P
0 g
s
.43202 .64834 m .45024 .724 L .36204 .74523 L p .633 .604 .802 r
F P
0 g
s
.36204 .74523 m .32277 .67601 L .43202 .64834 L p .633 .604 .802 r
F P
0 g
s
.67741 .57934 m .67323 .65962 L .55491 .64251 L p .762 .527 .577 r
F P
0 g
s
.55491 .64251 m .55582 .56087 L .67741 .57934 L p .762 .527 .577 r
F P
0 g
s
.67323 .65962 m .64392 .73263 L .54882 .71955 L p .737 .682 .798 r
F P
0 g
s
.42949 .56717 m .43202 .64834 L .32277 .67601 L p .57 .373 .574 r
F P
0 g
s
.43202 .64834 m .42949 .56717 L .55582 .56087 L p .674 .454 .579 r
F P
0 g
s
.55582 .56087 m .55491 .64251 L .43202 .64834 L p .674 .454 .579 r
F P
0 g
s
.55491 .64251 m .54882 .71955 L .45024 .724 L p .688 .639 .795 r
F P
0 g
s
.45024 .724 m .43202 .64834 L .55491 .64251 L p .688 .639 .795 r
F P
0 g
s
.54882 .71955 m .55491 .64251 L .67323 .65962 L p .737 .682 .798 r
F P
0 g
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.0153906 0.97619 0.207773 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.22008e-17 1.04992 -0.0702765 1.04992 [
[ 0 0 0 0 ]
[ 1 .80658 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .80658 L
0 .80658 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.46503 .50723 m .45466 .55829 L .54627 .56249 L p .714 .63 .762 r
F P
0 g
s
.54627 .56249 m .54275 .5109 L .46503 .50723 L p .714 .63 .762 r
F P
0 g
s
.54834 .61387 m .54627 .56249 L .45466 .55829 L p .72 .565 .679 r
F P
0 g
s
.54275 .5109 m .54627 .56249 L .63603 .54988 L p .675 .599 .764 r
F P
0 g
s
.54627 .56249 m .54834 .61387 L .64625 .60054 L p .664 .521 .68 r
F P
0 g
s
.64625 .60054 m .63603 .54988 L .54627 .56249 L p .664 .521 .68 r
F P
0 g
s
.39218 .48908 m .36849 .5375 L .45466 .55829 L p .752 .667 .767 r
F P
0 g
s
.45466 .55829 m .46503 .50723 L .39218 .48908 L p .752 .667 .767 r
F P
0 g
s
.44848 .60944 m .45466 .55829 L .36849 .5375 L p .773 .614 .683 r
F P
0 g
s
.45466 .55829 m .44848 .60944 L .54834 .61387 L p .72 .565 .679 r
F P
0 g
s
.54863 .65697 m .54834 .61387 L .44848 .60944 L p .713 .477 .567 r
F P
0 g
s
.54834 .61387 m .54863 .65697 L .64778 .64384 L p .639 .417 .566 r
F P
0 g
s
.64778 .64384 m .64625 .60054 L .54834 .61387 L p .639 .417 .566 r
F P
0 g
s
.36849 .5375 m .35435 .58744 L .44848 .60944 L p .773 .614 .683 r
F P
0 g
s
.44752 .65261 m .44848 .60944 L .35435 .58744 L p .783 .537 .564 r
F P
0 g
s
.44848 .60944 m .44752 .65261 L .54863 .65697 L p .713 .477 .567 r
F P
0 g
s
.47806 .46374 m .46503 .50723 L .54275 .5109 L p .695 .692 .843 r
F P
0 g
s
.54275 .5109 m .53833 .46666 L .47806 .46374 L p .695 .692 .843 r
F P
0 g
s
.53833 .46666 m .54275 .5109 L .61882 .49987 L p .675 .677 .844 r
F P
0 g
s
.63603 .54988 m .61882 .49987 L .54275 .5109 L p .675 .599 .764 r
F P
0 g
s
.61882 .49987 m .63603 .54988 L .71664 .5211 L p .631 .574 .773 r
F P
0 g
s
.63603 .54988 m .64625 .60054 L .7345 .57006 L p .6 .479 .686 r
F P
0 g
s
.7345 .57006 m .71664 .5211 L .63603 .54988 L p .6 .479 .686 r
F P
0 g
s
.42182 .44934 m .39218 .48908 L .46503 .50723 L p .714 .711 .847 r
F P
0 g
s
.46503 .50723 m .47806 .46374 L .42182 .44934 L p .714 .711 .847 r
F P
0 g
s
.64625 .60054 m .64778 .64384 L .73719 .61379 L p .547 .347 .56 r
F P
0 g
s
.73719 .61379 m .7345 .57006 L .64625 .60054 L p .547 .347 .56 r
F P
0 g
s
.61882 .49987 m .59722 .4579 L .53833 .46666 L p .675 .677 .844 r
F P
0 g
s
.59722 .4579 m .61882 .49987 L .68673 .47481 L p .653 .666 .851 r
F P
0 g
s
.71664 .5211 m .68673 .47481 L .61882 .49987 L p .631 .574 .773 r
F P
0 g
s
.33067 .45758 m .2951 .50122 L .36849 .5375 L p .786 .711 .781 r
F P
0 g
s
.36849 .5375 m .39218 .48908 L .33067 .45758 L p .786 .711 .781 r
F P
0 g
s
.35435 .58744 m .36849 .5375 L .2951 .50122 L p .827 .673 .692 r
F P
0 g
s
.54703 .68429 m .54863 .65697 L .44752 .65261 L p .665 .299 .342 r
F P
0 g
s
.54863 .65697 m .54703 .68429 L .64004 .67218 L p .56 .211 .333 r
F P
0 g
s
.64004 .67218 m .64778 .64384 L .54863 .65697 L p .56 .211 .333 r
F P
0 g
s
.35435 .58744 m .35218 .63093 L .44752 .65261 L p .783 .537 .564 r
F P
0 g
s
.45213 .68026 m .44752 .65261 L .35218 .63093 L p .752 .362 .315 r
F P
0 g
s
.44752 .65261 m .45213 .68026 L .54703 .68429 L p .665 .299 .342 r
F P
0 g
s
.37486 .42452 m .33067 .45758 L .39218 .48908 L p .728 .734 .856 r
F P
0 g
s
.39218 .48908 m .42182 .44934 L .37486 .42452 L p .728 .734 .856 r
F P
0 g
s
.2951 .50122 m .27377 .54895 L .35435 .58744 L p .827 .673 .692 r
F P
0 g
s
.35218 .63093 m .35435 .58744 L .27377 .54895 L p .856 .603 .555 r
F P
0 g
s
.49185 .43371 m .47806 .46374 L .53833 .46666 L p .643 .761 .935 r
F P
0 g
s
.53833 .46666 m .53362 .43576 L .49185 .43371 L p .643 .761 .935 r
F P
0 g
s
.53362 .43576 m .53833 .46666 L .59722 .4579 L p .653 .769 .934 r
F P
0 g
s
.45306 .42359 m .42182 .44934 L .47806 .46374 L p .635 .752 .932 r
F P
0 g
s
.47806 .46374 m .49185 .43371 L .45306 .42359 L p .635 .752 .932 r
F P
0 g
s
.64778 .64384 m .64004 .67218 L .72369 .64453 L p .412 .076 .283 r
F P
0 g
s
.72369 .64453 m .73719 .61379 L .64778 .64384 L p .412 .076 .283 r
F P
0 g
s
.68673 .47481 m .71664 .5211 L .78072 .4778 L p .58 .555 .791 r
F P
0 g
s
.71664 .5211 m .7345 .57006 L .80516 .52402 L p .518 .433 .699 r
F P
0 g
s
.80516 .52402 m .78072 .4778 L .71664 .5211 L p .518 .433 .699 r
F P
0 g
s
.59722 .4579 m .57437 .42959 L .53362 .43576 L p .653 .769 .934 r
F P
0 g
s
.57437 .42959 m .59722 .4579 L .6494 .43808 L p .664 .773 .93 r
F P
0 g
s
.68673 .47481 m .6494 .43808 L .59722 .4579 L p .653 .666 .851 r
F P
0 g
s
.6494 .43808 m .68673 .47481 L .74005 .43736 L p .63 .662 .862 r
F P
0 g
s
.78072 .4778 m .74005 .43736 L .68673 .47481 L p .58 .555 .791 r
F P
0 g
s
.7345 .57006 m .73719 .61379 L .80886 .56838 L p .414 .248 .545 r
F P
0 g
s
.80886 .56838 m .80516 .52402 L .7345 .57006 L p .414 .248 .545 r
F P
0 g
s
.42104 .40626 m .37486 .42452 L .42182 .44934 L p .63 .741 .928 r
F P
0 g
s
.42182 .44934 m .45306 .42359 L .42104 .40626 L p .63 .741 .928 r
F P
0 g
s
.27377 .54895 m .2705 .59297 L .35218 .63093 L p .856 .603 .555 r
F P
0 g
s
.36279 .66029 m .35218 .63093 L .2705 .59297 L p .829 .405 .233 r
F P
0 g
s
.35218 .63093 m .36279 .66029 L .45213 .68026 L p .752 .362 .315 r
F P
0 g
s
.54371 .69024 m .54703 .68429 L .45213 .68026 L p .289 0 0 r
F P
0 g
s
.54703 .68429 m .54371 .69024 L .62389 .67984 L p .131 0 0 r
F P
0 g
s
.62389 .67984 m .64004 .67218 L .54703 .68429 L p .131 0 0 r
F P
0 g
s
.28681 .41491 m .24187 .4517 L .2951 .50122 L p .817 .764 .803 r
F P
0 g
s
.2951 .50122 m .33067 .45758 L .28681 .41491 L p .817 .764 .803 r
F P
0 g
s
.27377 .54895 m .2951 .50122 L .24187 .4517 L p .884 .749 .708 r
F P
0 g
s
.34207 .39123 m .28681 .41491 L .33067 .45758 L p .738 .759 .87 r
F P
0 g
s
.33067 .45758 m .37486 .42452 L .34207 .39123 L p .738 .759 .87 r
F P
0 g
s
.46181 .68678 m .45213 .68026 L .36279 .66029 L p .342 0 0 r
F P
0 g
s
.45213 .68026 m .46181 .68678 L .54371 .69024 L p .289 0 0 r
F P
0 g
s
.6494 .43808 m .61019 .4157 L .57437 .42959 L p .664 .773 .93 r
F P
0 g
s
.61019 .4157 m .6494 .43808 L .68975 .4087 L p .675 .774 .925 r
F P
0 g
s
.74005 .43736 m .68975 .4087 L .6494 .43808 L p .63 .662 .862 r
F P
0 g
s
.24187 .4517 m .21473 .49615 L .27377 .54895 L p .884 .749 .708 r
F P
0 g
s
.2705 .59297 m .27377 .54895 L .21473 .49615 L p .938 .685 .528 r
F P
0 g
s
.73719 .61379 m .72369 .64453 L .79037 .60286 L p .148 0 .15 r
F P
0 g
s
.79037 .60286 m .80886 .56838 L .73719 .61379 L p .148 0 .15 r
F P
0 g
s
.50444 .42018 m .49185 .43371 L .53362 .43576 L p .458 .801 .999 r
F P
0 g
s
.55354 .41772 m .52931 .42142 L p .54025 .4234 L .534 .855 .997 r
F P
0 g
s
.57437 .42959 m .55354 .41772 L p .54025 .4234 L .534 .855 .997 r
F P
0 g
s
.55354 .41772 m .57468 .40943 L p .56806 .4115 L .356 .825 .771 r
F P
0 g
s
.52931 .42142 m .55354 .41772 L p .54864 .41863 L 0 0 0 r
F P
0 g
s
.53362 .43576 m .52931 .42142 L p .51155 .42398 L .458 .801 .999 r
F P
0 g
s
.52931 .42142 m .53362 .43576 L .57437 .42959 L p .534 .855 .997 r
F P
0 g
s
.52597 .42285 m .52931 .42142 L p .54864 .41863 L 0 0 0 r
F P
0 g
s
.53747 .42109 m .52597 .42285 L p .53118 .42188 L 0 0 0 r
F P
0 g
s
.55354 .41772 m .53747 .42109 L p .53118 .42188 L 0 0 0 r
F P
0 g
s
.53747 .42109 m .55354 .41772 L p .56806 .4115 L .356 .825 .771 r
F P
0 g
s
.54745 .41717 m .53747 .42109 L p .54449 .41889 L .356 .825 .771 r
F P
0 g
s
.57468 .40943 m .54745 .41717 L p .54449 .41889 L .356 .825 .771 r
F P
0 g
s
.55485 .41149 m .54745 .41717 L p .55555 .41345 L .653 .97 .878 r
F P
0 g
s
.59052 .39734 m .55485 .41149 L p .55555 .41345 L .653 .97 .878 r
F P
0 g
s
.55485 .41149 m .55885 .40463 L p .55414 .40951 L .799 .983 .713 r
F P
0 g
s
.54745 .41717 m .55485 .41149 L p .55046 .41543 L 0 0 0 r
F P
0 g
s
.54745 .41717 m .57468 .40943 L .59052 .39734 L p .653 .97 .878 r
F P
0 g
s
.53083 .43304 m .54745 .41717 L p .55046 .41543 L 0 0 0 r
F P
0 g
s
.53747 .42109 m .54745 .41717 L p .54383 .4203 L .126 0 0 r
F P
0 g
s
.52762 .4343 m .53747 .42109 L p .54383 .4203 L .126 0 0 r
F P
0 g
s
.54745 .41717 m .53083 .43304 L .52762 .4343 L p .126 0 0 r
F P
0 g
s
.53319 .43123 m .53083 .43304 L p .53328 .43084 L 0 0 0 r
F P
0 g
s
.55485 .41149 m .53319 .43123 L p .53328 .43084 L 0 0 0 r
F P
0 g
s
.53319 .43123 m .55485 .41149 L p .55414 .40951 L .799 .983 .713 r
F P
0 g
s
.53445 .42906 m .53319 .43123 L p .5358 .42852 L .799 .983 .713 r
F P
0 g
s
.55885 .40463 m .53445 .42906 L p .5358 .42852 L .799 .983 .713 r
F P
0 g
s
.53445 .42906 m .53446 .42675 L p .53313 .42958 L .965 .929 .605 r
F P
0 g
s
.53319 .43123 m .53445 .42906 L p .5331 .43161 L 0 0 0 r
F P
0 g
s
.52427 .44837 m .53319 .43123 L p .5331 .43161 L 0 0 0 r
F P
0 g
s
.52396 .44861 m .53083 .43304 L .53319 .43123 L p .04 0 .093 r
F P
0 g
s
.53319 .43123 m .52427 .44837 L .52396 .44861 L p .04 0 .093 r
F P
0 g
s
.52443 .44809 m .52427 .44837 L p .52455 .44785 L 0 0 0 r
F P
0 g
s
.53445 .42906 m .52443 .44809 L p .52455 .44785 L 0 0 0 r
F P
0 g
s
.52443 .44809 m .52443 .44779 L .52433 .44832 L p .887 .797 .31 r
F P
0 g
s
.52443 .44809 m .52292 .45534 L .52427 .44837 L closepath p 0 0 .142 r
F P
0 g
s
.52433 .44832 m .52292 .45534 L .52443 .44809 L p .887 .797 .31 r
F P
0 g
s
.52443 .44809 m .53445 .42906 L p .53313 .42958 L .965 .929 .605 r
F P
0 g
s
.52931 .42142 m .50444 .42018 L p .51155 .42398 L .458 .801 .999 r
F P
0 g
s
.64004 .67218 m .62389 .67984 L .69559 .65618 L p 0 0 0 r
F P
0 g
s
.69559 .65618 m .72369 .64453 L .64004 .67218 L p 0 0 0 r
F P
0 g
s
.48144 .41413 m .45306 .42359 L .49185 .43371 L p .42 .746 .993 r
F P
0 g
s
.49185 .43371 m .50444 .42018 L .48144 .41413 L p .42 .746 .993 r
F P
0 g
s
.3992 .38324 m .34207 .39123 L .37486 .42452 L p .629 .731 .921 r
F P
0 g
s
.37486 .42452 m .42104 .40626 L .3992 .38324 L p .629 .731 .921 r
F P
0 g
s
.55354 .41772 m .57437 .42959 L .61019 .4157 L p .628 .892 .987 r
F P
0 g
s
.68975 .4087 m .74005 .43736 L .77276 .3903 L p .607 .663 .878 r
F P
0 g
s
.74005 .43736 m .78072 .4778 L .82102 .42292 L p .52 .542 .819 r
F P
0 g
s
.82102 .42292 m .77276 .3903 L .74005 .43736 L p .52 .542 .819 r
F P
0 g
s
.78072 .4778 m .80516 .52402 L .85027 .46535 L p .4 .377 .718 r
F P
0 g
s
.85027 .46535 m .82102 .42292 L .78072 .4778 L p .4 .377 .718 r
F P
0 g
s
.46266 .40382 m .42104 .40626 L .45306 .42359 L p .423 .697 .978 r
F P
0 g
s
.45306 .42359 m .48144 .41413 L .46266 .40382 L p .423 .697 .978 r
F P
0 g
s
.2705 .59297 m .28655 .6254 L .36279 .66029 L p .829 .405 .233 r
F P
0 g
s
.36279 .66029 m .38497 .66965 L .46181 .68678 L p .342 0 0 r
F P
0 g
s
.38497 .66965 m .36279 .66029 L .28655 .6254 L p 0 .312 .671 r
F P
0 g
s
.61019 .4157 m .57468 .40943 L .55354 .41772 L p .628 .892 .987 r
F P
0 g
s
.57468 .40943 m .61019 .4157 L .63744 .39529 L p .708 .899 .965 r
F P
0 g
s
.68975 .4087 m .63744 .39529 L .61019 .4157 L p .675 .774 .925 r
F P
0 g
s
.63744 .39529 m .68975 .4087 L .71372 .37219 L p .684 .771 .917 r
F P
0 g
s
.77276 .3903 m .71372 .37219 L .68975 .4087 L p .607 .663 .878 r
F P
0 g
s
.21473 .49615 m .21056 .54087 L .2705 .59297 L p .938 .685 .528 r
F P
0 g
s
.28655 .6254 m .2705 .59297 L .21056 .54087 L p .852 .395 .024 r
F P
0 g
s
.80516 .52402 m .80886 .56838 L .85472 .51046 L p .174 .075 .494 r
F P
0 g
s
.85472 .51046 m .85027 .46535 L .80516 .52402 L p .174 .075 .494 r
F P
0 g
s
.53916 .67284 m .54371 .69024 L .46181 .68678 L p .508 .807 .999 r
F P
0 g
s
.54371 .69024 m .53916 .67284 L .60176 .66463 L p .555 .841 .998 r
F P
0 g
s
.60176 .66463 m .62389 .67984 L .54371 .69024 L p .555 .841 .998 r
F P
0 g
s
.45011 .39026 m .3992 .38324 L .42104 .40626 L p .454 .66 .95 r
F P
0 g
s
.42104 .40626 m .46266 .40382 L .45011 .39026 L p .454 .66 .95 r
F P
0 g
s
.72369 .64453 m .69559 .65618 L .7521 .62073 L p .499 .899 .77 r
F P
0 g
s
.7521 .62073 m .79037 .60286 L .72369 .64453 L p .499 .899 .77 r
F P
0 g
s
.47513 .6701 m .46181 .68678 L .38497 .66965 L p .482 .771 .995 r
F P
0 g
s
.46181 .68678 m .47513 .6701 L .53916 .67284 L p .508 .807 .999 r
F P
0 g
s
.32758 .35238 m .26623 .36453 L .28681 .41491 L p .74 .784 .888 r
F P
0 g
s
.28681 .41491 m .34207 .39123 L .32758 .35238 L p .74 .784 .888 r
F P
0 g
s
.24187 .4517 m .28681 .41491 L .26623 .36453 L p .839 .828 .837 r
F P
0 g
s
.39017 .35673 m .32758 .35238 L .34207 .39123 L p .632 .723 .913 r
F P
0 g
s
.34207 .39123 m .3992 .38324 L .39017 .35673 L p .632 .723 .913 r
F P
0 g
s
.26623 .36453 m .21574 .39264 L .24187 .4517 L p .839 .828 .837 r
F P
0 g
s
.21473 .49615 m .24187 .4517 L .21574 .39264 L p .938 .849 .729 r
F P
0 g
s
.63744 .39529 m .59052 .39734 L .57468 .40943 L p .708 .899 .965 r
F P
0 g
s
.59052 .39734 m .63744 .39529 L .65306 .3702 L p .758 .877 .933 r
F P
0 g
s
.71372 .37219 m .65306 .3702 L .63744 .39529 L p .684 .771 .917 r
F P
0 g
s
.62389 .67984 m .60176 .66463 L .65731 .64602 L p .613 .864 .99 r
F P
0 g
s
.65731 .64602 m .69559 .65618 L .62389 .67984 L p .613 .864 .99 r
F P
0 g
s
.51415 .42226 m .50444 .42018 L .52931 .42142 L p .112 0 0 r
F P
0 g
s
.52931 .42142 m .52597 .42285 L .51415 .42226 L p .112 0 0 r
F P
0 g
s
.50325 .41939 m .48144 .41413 L .50444 .42018 L p 0 .43 .705 r
F P
0 g
s
.50444 .42018 m .51415 .42226 L .50325 .41939 L p 0 .43 .705 r
F P
0 g
s
.49442 .41453 m .46266 .40382 L .48144 .41413 L p 0 .447 .833 r
F P
0 g
s
.49639 .41774 m .50325 .41939 L .49442 .41453 L p 0 .447 .833 r
F P
0 g
s
.51376 .4322 m .49442 .41453 L .50325 .41939 L p .64 .081 0 r
F P
0 g
s
.51192 .43018 m .49315 .41245 L p .49442 .41453 L 0 .076 .591 r
F P
0 g
s
.49315 .41245 m .48862 .40818 L .49442 .41453 L p 0 .076 .591 r
F P
0 g
s
.48144 .41413 m .49639 .41774 L p .49442 .41453 L 0 .447 .833 r
F P
0 g
s
.80886 .56838 m .79037 .60286 L .83257 .54993 L p 0 0 0 r
F P
0 g
s
.83257 .54993 m .85472 .51046 L .80886 .56838 L p 0 0 0 r
F P
0 g
s
.44525 .3748 m .39017 .35673 L .3992 .38324 L p .496 .635 .916 r
F P
0 g
s
.3992 .38324 m .45011 .39026 L .44525 .3748 L p .496 .635 .916 r
F P
0 g
s
.28655 .6254 m .31992 .63988 L .38497 .66965 L p 0 .312 .671 r
F P
0 g
s
.41531 .6566 m .38497 .66965 L .31992 .63988 L p .48 .737 .984 r
F P
0 g
s
.38497 .66965 m .41531 .6566 L .47513 .6701 L p .482 .771 .995 r
F P
0 g
s
.21056 .54087 m .23102 .57769 L .28655 .6254 L p .852 .395 .024 r
F P
0 g
s
.31992 .63988 m .28655 .6254 L .23102 .57769 L p 0 .402 .84 r
F P
0 g
s
.21574 .39264 m .18498 .43282 L .21473 .49615 L p .938 .849 .729 r
F P
0 g
s
.21056 .54087 m .21473 .49615 L .18498 .43282 L p .997 .772 .432 r
F P
0 g
s
.65306 .3702 m .71372 .37219 L .7178 .33196 L p .689 .765 .909 r
F P
0 g
s
.71372 .37219 m .77276 .3903 L .77983 .33778 L p .586 .671 .899 r
F P
0 g
s
.77983 .33778 m .7178 .33196 L .71372 .37219 L p .586 .671 .899 r
F P
0 g
s
.77276 .3903 m .82102 .42292 L .83118 .36102 L p .445 .537 .857 r
F P
0 g
s
.83118 .36102 m .77983 .33778 L .77276 .3903 L p .445 .537 .857 r
F P
0 g
s
.48862 .40818 m .45011 .39026 L .46266 .40382 L p .13 .478 .897 r
F P
0 g
s
.46266 .40382 m .49442 .41453 L .48862 .40818 L p .13 .478 .897 r
F P
0 g
s
.65306 .3702 m .59932 .38263 L .59052 .39734 L p .758 .877 .933 r
F P
0 g
s
.59932 .38263 m .65306 .3702 L .65493 .34293 L p .779 .839 .898 r
F P
0 g
s
.7178 .33196 m .65493 .34293 L .65306 .3702 L p .689 .765 .909 r
F P
0 g
s
.55485 .41149 m .59052 .39734 L .59932 .38263 L p .818 .973 .896 r
F P
0 g
s
.82102 .42292 m .85027 .46535 L .86257 .39875 L p .201 .294 .736 r
F P
0 g
s
.86257 .39875 m .83118 .36102 L .82102 .42292 L p .201 .294 .736 r
F P
0 g
s
.69559 .65618 m .65731 .64602 L .70041 .61839 L p .668 .87 .975 r
F P
0 g
s
.70041 .61839 m .7521 .62073 L .69559 .65618 L p .668 .87 .975 r
F P
0 g
s
.53414 .635 m .53916 .67284 L .47513 .6701 L p .667 .741 .905 r
F P
0 g
s
.53916 .67284 m .53414 .635 L .57739 .62918 L p .657 .734 .906 r
F P
0 g
s
.57739 .62918 m .60176 .66463 L .53916 .67284 L p .657 .734 .906 r
F P
0 g
s
.4865 .401 m .44525 .3748 L .45011 .39026 L p .306 .497 .881 r
F P
0 g
s
.45011 .39026 m .48862 .40818 L .4865 .401 L p .306 .497 .881 r
F P
0 g
s
.48983 .63306 m .47513 .6701 L .41531 .6566 L p .675 .75 .907 r
F P
0 g
s
.47513 .6701 m .48983 .63306 L .53414 .635 L p .667 .741 .905 r
F P
0 g
s
.39548 .32943 m .33409 .31185 L .32758 .35238 L p .637 .717 .905 r
F P
0 g
s
.32758 .35238 m .39017 .35673 L .39548 .32943 L p .637 .717 .905 r
F P
0 g
s
.26623 .36453 m .32758 .35238 L .33409 .31185 L p .733 .807 .909 r
F P
0 g
s
.44881 .35907 m .39548 .32943 L .39017 .35673 L p .541 .623 .882 r
F P
0 g
s
.39017 .35673 m .44525 .3748 L .44881 .35907 L p .541 .623 .882 r
F P
0 g
s
.79037 .60286 m .7521 .62073 L .78703 .57608 L p .764 .993 .878 r
F P
0 g
s
.78703 .57608 m .83257 .54993 L .79037 .60286 L p .764 .993 .878 r
F P
0 g
s
.18498 .43282 m .18025 .47832 L .21056 .54087 L p .997 .772 .432 r
F P
0 g
s
.23102 .57769 m .21056 .54087 L .18025 .47832 L p 0 0 .391 r
F P
0 g
s
.60176 .66463 m .57739 .62918 L .61544 .61608 L p .646 .729 .909 r
F P
0 g
s
.61544 .61608 m .65731 .64602 L .60176 .66463 L p .646 .729 .909 r
F P
0 g
s
.59932 .38263 m .55885 .40463 L .55485 .41149 L p .818 .973 .896 r
F P
0 g
s
.55885 .40463 m .59932 .38263 L .59994 .36682 L p .861 .901 .861 r
F P
0 g
s
.65493 .34293 m .59994 .36682 L .59932 .38263 L p .779 .839 .898 r
F P
0 g
s
.5201 .43467 m .51415 .42226 L .52597 .42285 L p .547 .05 .028 r
F P
0 g
s
.52597 .42285 m .52391 .43486 L .5201 .43467 L p .547 .05 .028 r
F P
0 g
s
.52391 .43486 m .52597 .42285 L .53747 .42109 L p .392 0 .003 r
F P
0 g
s
.51659 .43375 m .50325 .41939 L .51415 .42226 L p .639 .109 0 r
F P
0 g
s
.51415 .42226 m .5201 .43467 L .51659 .43375 L p .639 .109 0 r
F P
0 g
s
.33409 .31185 m .27308 .31126 L .26623 .36453 L p .733 .807 .909 r
F P
0 g
s
.21574 .39264 m .26623 .36453 L .27308 .31126 L p .839 .897 .88 r
F P
0 g
s
.53747 .42109 m .52762 .4343 L .52391 .43486 L p .392 0 .003 r
F P
0 g
s
.50325 .41939 m .51659 .43375 L .51376 .4322 L p .64 .081 0 r
F P
0 g
s
.23102 .57769 m .27329 .59945 L .31992 .63988 L p 0 .402 .84 r
F P
0 g
s
.36524 .63328 m .31992 .63988 L .27329 .59945 L p .497 .709 .966 r
F P
0 g
s
.31992 .63988 m .36524 .63328 L .41531 .6566 L p .48 .737 .984 r
F P
0 g
s
.85027 .46535 m .85472 .51046 L .86736 .44464 L p 0 0 .3 r
F P
0 g
s
.86736 .44464 m .86257 .39875 L .85027 .46535 L p 0 0 .3 r
F P
0 g
s
.48832 .39376 m .44881 .35907 L .44525 .3748 L p .433 .513 .84 r
F P
0 g
s
.44525 .3748 m .4865 .401 L .48832 .39376 L p .433 .513 .84 r
F P
0 g
s
.51086 .42955 m .51376 .4322 L .51192 .43018 L p 0 .076 .591 r
F P
0 g
s
.52148 .44824 m .51192 .43018 L .51376 .4322 L p .826 .377 0 r
F P
0 g
s
.51376 .4322 m .52145 .44795 L p .52148 .44824 L .826 .377 0 r
F P
0 g
s
.52145 .44795 m .52172 .4485 L .52148 .44824 L p .826 .377 0 r
F P
0 g
s
.52148 .44824 m .52292 .45534 L .5215 .44846 L p .77 .498 0 r
F P
0 g
s
.5215 .44846 m .5214 .44794 L .52148 .44824 L p .77 .498 0 r
F P
0 g
s
.5214 .44794 m .51263 .43061 L p .51192 .43018 L 0 0 .486 r
F P
0 g
s
.51263 .43061 m .51127 .42791 L .51192 .43018 L p 0 0 .486 r
F P
0 g
s
.49442 .41453 m .51086 .42955 L p .51192 .43018 L 0 .076 .591 r
F P
0 g
s
.44865 .62352 m .41531 .6566 L .36524 .63328 L p .681 .761 .912 r
F P
0 g
s
.41531 .6566 m .44865 .62352 L .48983 .63306 L p .675 .75 .907 r
F P
0 g
s
.59994 .36682 m .65493 .34293 L .64225 .31638 L p .778 .796 .868 r
F P
0 g
s
.65493 .34293 m .7178 .33196 L .70027 .29227 L p .692 .757 .901 r
F P
0 g
s
.70027 .29227 m .64225 .31638 L .65493 .34293 L p .692 .757 .901 r
F P
0 g
s
.7178 .33196 m .77983 .33778 L .75829 .28526 L p .569 .688 .921 r
F P
0 g
s
.75829 .28526 m .70027 .29227 L .7178 .33196 L p .569 .688 .921 r
F P
0 g
s
.51127 .42791 m .4865 .401 L .48862 .40818 L p .017 .265 .766 r
F P
0 g
s
.48862 .40818 m .51192 .43018 L .51127 .42791 L p .017 .265 .766 r
F P
0 g
s
.59994 .36682 m .55898 .39732 L .55885 .40463 L p .861 .901 .861 r
F P
0 g
s
.55898 .39732 m .59994 .36682 L .59214 .35163 L p .848 .82 .821 r
F P
0 g
s
.64225 .31638 m .59214 .35163 L .59994 .36682 L p .778 .796 .868 r
F P
0 g
s
.27308 .31126 m .22224 .3295 L .21574 .39264 L p .839 .897 .88 r
F P
0 g
s
.18498 .43282 m .21574 .39264 L .22224 .3295 L p .942 .961 .73 r
F P
0 g
s
.53445 .42906 m .55885 .40463 L .55898 .39732 L p .933 .942 .778 r
F P
0 g
s
.65731 .64602 m .61544 .61608 L .64445 .59679 L p .635 .728 .915 r
F P
0 g
s
.64445 .59679 m .70041 .61839 L .65731 .64602 L p .635 .728 .915 r
F P
0 g
s
.51188 .42563 m .48832 .39376 L .4865 .401 L p .299 .372 .77 r
F P
0 g
s
.4865 .401 m .51127 .42791 L .51188 .42563 L p .299 .372 .77 r
F P
0 g
s
.49395 .38726 m .4606 .34483 L .44881 .35907 L p .523 .531 .805 r
F P
0 g
s
.44881 .35907 m .48832 .39376 L .49395 .38726 L p .523 .531 .805 r
F P
0 g
s
.39548 .32943 m .44881 .35907 L .4606 .34483 L p .583 .621 .855 r
F P
0 g
s
.4606 .34483 m .41514 .3044 L .39548 .32943 L p .583 .621 .855 r
F P
0 g
s
.33409 .31185 m .39548 .32943 L .41514 .3044 L p .645 .714 .898 r
F P
0 g
s
.52952 .58464 m .53414 .635 L .48983 .63306 L p .703 .679 .823 r
F P
0 g
s
.53414 .635 m .52952 .58464 L .55497 .5811 L p .671 .654 .825 r
F P
0 g
s
.55497 .5811 m .57739 .62918 L .53414 .635 L p .671 .654 .825 r
F P
0 g
s
.55898 .39732 m .53446 .42675 L .53445 .42906 L p .933 .942 .778 r
F P
0 g
s
.53446 .42675 m .55898 .39732 L .55519 .39035 L p .908 .83 .757 r
F P
0 g
s
.59214 .35163 m .55519 .39035 L .55898 .39732 L p .848 .82 .821 r
F P
0 g
s
.18025 .47832 m .20347 .52067 L .23102 .57769 L p 0 0 .391 r
F P
0 g
s
.27329 .59945 m .23102 .57769 L .20347 .52067 L p .201 .467 .885 r
F P
0 g
s
.77983 .33778 m .83118 .36102 L .80691 .29843 L p .35 .544 .903 r
F P
0 g
s
.80691 .29843 m .75829 .28526 L .77983 .33778 L p .35 .544 .903 r
F P
0 g
s
.7521 .62073 m .70041 .61839 L .72618 .58397 L p .708 .86 .954 r
F P
0 g
s
.72618 .58397 m .78703 .57608 L .7521 .62073 L p .708 .86 .954 r
F P
0 g
s
.50341 .58346 m .48983 .63306 L .44865 .62352 L p .732 .709 .829 r
F P
0 g
s
.48983 .63306 m .50341 .58346 L .52952 .58464 L p .703 .679 .823 r
F P
0 g
s
.5137 .4236 m .49395 .38726 L .48832 .39376 L p .458 .434 .745 r
F P
0 g
s
.48832 .39376 m .51188 .42563 L .5137 .4236 L p .458 .434 .745 r
F P
0 g
s
.55519 .39035 m .59214 .35163 L .57657 .33875 L p .816 .751 .791 r
F P
0 g
s
.59214 .35163 m .64225 .31638 L .61587 .29365 L p .765 .755 .844 r
F P
0 g
s
.61587 .29365 m .57657 .33875 L .59214 .35163 L p .765 .755 .844 r
F P
0 g
s
.52255 .44882 m .5201 .43467 L .52391 .43486 L p .665 .295 .333 r
F P
0 g
s
.52391 .43486 m .52305 .44885 L .52255 .44882 L p .665 .295 .333 r
F P
0 g
s
.52305 .44885 m .52391 .43486 L .52762 .4343 L p .547 .195 .323 r
F P
0 g
s
.52209 .4487 m .51659 .43375 L .5201 .43467 L p .762 .365 .301 r
F P
0 g
s
.5201 .43467 m .52255 .44882 L .52209 .4487 L p .762 .365 .301 r
F P
0 g
s
.52762 .4343 m .52354 .44877 L .52305 .44885 L p .547 .195 .323 r
F P
0 g
s
.52354 .44877 m .52762 .4343 L .53083 .43304 L p .37 .036 .262 r
F P
0 g
s
.85472 .51046 m .83257 .54993 L .84354 .49008 L p .903 .937 .567 r
F P
0 g
s
.84354 .49008 m .86736 .44464 L .85472 .51046 L p .903 .937 .567 r
F P
0 g
s
.52172 .4485 m .51376 .4322 L .51659 .43375 L p .844 .411 .199 r
F P
0 g
s
.51659 .43375 m .52209 .4487 L .52172 .4485 L p .844 .411 .199 r
F P
0 g
s
.53083 .43304 m .52396 .44861 L .52354 .44877 L p .37 .036 .262 r
F P
0 g
s
.57739 .62918 m .55497 .5811 L .57719 .57318 L p .635 .636 .834 r
F P
0 g
s
.57719 .57318 m .61544 .61608 L .57739 .62918 L p .635 .636 .834 r
F P
0 g
s
.55519 .39035 m .53322 .42457 L .53446 .42675 L p .908 .83 .757 r
F P
0 g
s
.53322 .42457 m .55519 .39035 L .54784 .3845 L p .855 .738 .733 r
F P
0 g
s
.57657 .33875 m .54784 .3845 L .55519 .39035 L p .816 .751 .791 r
F P
0 g
s
.41514 .3044 m .3622 .27419 L .33409 .31185 L p .645 .714 .898 r
F P
0 g
s
.27308 .31126 m .33409 .31185 L .3622 .27419 L p .715 .823 .932 r
F P
0 g
s
.52172 .4485 m .52292 .45534 L .52148 .44824 L closepath p .952 .604 .288 r
F P
0 g
s
.5214 .44794 m .52292 .45534 L .52158 .44818 L p 0 0 .457 r
F P
0 g
s
.52158 .44818 m .52148 .44765 L .5214 .44794 L p 0 0 .457 r
F P
0 g
s
.51192 .43018 m .52116 .44763 L p .5214 .44794 L 0 0 .486 r
F P
0 g
s
.52116 .44763 m .52148 .44824 L .5214 .44794 L p 0 0 .486 r
F P
0 g
s
.51652 .42203 m .50278 .38221 L .49395 .38726 L p .559 .481 .724 r
F P
0 g
s
.49395 .38726 m .5137 .4236 L .51652 .42203 L p .559 .481 .724 r
F P
0 g
s
.4606 .34483 m .49395 .38726 L .50278 .38221 L p .591 .553 .78 r
F P
0 g
s
.27329 .59945 m .33013 .60193 L .36524 .63328 L p .497 .709 .966 r
F P
0 g
s
.4146 .60716 m .36524 .63328 L .33013 .60193 L p .683 .771 .918 r
F P
0 g
s
.36524 .63328 m .4146 .60716 L .44865 .62352 L p .681 .761 .912 r
F P
0 g
s
.64225 .31638 m .70027 .29227 L .66187 .25786 L p .691 .747 .895 r
F P
0 g
s
.66187 .25786 m .61587 .29365 L .64225 .31638 L p .691 .747 .895 r
F P
0 g
s
.50278 .38221 m .47945 .3337 L .4606 .34483 L p .591 .553 .78 r
F P
0 g
s
.41514 .3044 m .4606 .34483 L .47945 .3337 L p .622 .627 .835 r
F P
0 g
s
.52148 .44765 m .51188 .42563 L .51127 .42791 L p .117 .177 .65 r
F P
0 g
s
.51127 .42791 m .5214 .44794 L .52148 .44765 L p .117 .177 .65 r
F P
0 g
s
.53446 .42675 m .52443 .44779 L .52443 .44809 L p .965 .929 .605 r
F P
0 g
s
.52443 .44779 m .53446 .42675 L .53322 .42457 L p .96 .823 .664 r
F P
0 g
s
.54784 .3845 m .53086 .42274 L .53322 .42457 L p .855 .738 .733 r
F P
0 g
s
.53086 .42274 m .54784 .3845 L .53773 .38042 L p .801 .668 .717 r
F P
0 g
s
.54784 .3845 m .57657 .33875 L .55487 .32973 L p .778 .695 .772 r
F P
0 g
s
.55487 .32973 m .53773 .38042 L .54784 .3845 L p .778 .695 .772 r
F P
0 g
s
.47925 .57767 m .44865 .62352 L .4146 .60716 L p .757 .745 .842 r
F P
0 g
s
.44865 .62352 m .47925 .57767 L .50341 .58346 L p .732 .709 .829 r
F P
0 g
s
.52172 .44739 m .5137 .4236 L .51188 .42563 L p .38 .321 .666 r
F P
0 g
s
.51188 .42563 m .52148 .44765 L .52172 .44739 L p .38 .321 .666 r
F P
0 g
s
.22224 .3295 m .19099 .36465 L .18498 .43282 L p .942 .961 .73 r
F P
0 g
s
.18025 .47832 m .18498 .43282 L .19099 .36465 L p .722 .646 .088 r
F P
0 g
s
.53322 .42457 m .52427 .44751 L .52443 .44779 L p .96 .823 .664 r
F P
0 g
s
.52427 .44751 m .53322 .42457 L .53086 .42274 L p .888 .716 .663 r
F P
0 g
s
.52005 .42109 m .51386 .37921 L .50278 .38221 L p .632 .523 .712 r
F P
0 g
s
.50278 .38221 m .51652 .42203 L .52005 .42109 L p .632 .523 .712 r
F P
0 g
s
.47945 .3337 m .50278 .38221 L .51386 .37921 L p .646 .58 .766 r
F P
0 g
s
.52209 .44718 m .51652 .42203 L .5137 .4236 L p .522 .404 .66 r
F P
0 g
s
.5137 .4236 m .52172 .44739 L .52209 .44718 L p .522 .404 .66 r
F P
0 g
s
.53086 .42274 m .52396 .44727 L .52427 .44751 L p .888 .716 .663 r
F P
0 g
s
.52396 .44727 m .53086 .42274 L .52763 .42147 L p .818 .637 .657 r
F P
0 g
s
.53773 .38042 m .52763 .42147 L .53086 .42274 L p .801 .668 .717 r
F P
0 g
s
.57657 .33875 m .61587 .29365 L .57847 .27759 L p .744 .718 .828 r
F P
0 g
s
.57847 .27759 m .55487 .32973 L .57657 .33875 L p .744 .718 .828 r
F P
0 g
s
.52763 .42147 m .53773 .38042 L .52596 .37859 L p .748 .613 .708 r
F P
0 g
s
.53773 .38042 m .55487 .32973 L .52948 .32566 L p .737 .649 .762 r
F P
0 g
s
.52948 .32566 m .52596 .37859 L .53773 .38042 L p .737 .649 .762 r
F P
0 g
s
.52255 .44706 m .52005 .42109 L .51652 .42203 L p .615 .465 .655 r
F P
0 g
s
.51652 .42203 m .52209 .44718 L .52255 .44706 L p .615 .465 .655 r
F P
0 g
s
.52763 .42147 m .52354 .44711 L .52396 .44727 L p .818 .637 .657 r
F P
0 g
s
.52354 .44711 m .52763 .42147 L .52389 .4209 L p .753 .574 .653 r
F P
0 g
s
.52596 .37859 m .52389 .4209 L .52763 .42147 L p .748 .613 .708 r
F P
0 g
s
.52389 .4209 m .52596 .37859 L .51386 .37921 L p .693 .566 .707 r
F P
0 g
s
.51386 .37921 m .52005 .42109 L .52389 .4209 L p .693 .566 .707 r
F P
0 g
s
.50332 .32704 m .51386 .37921 L .52596 .37859 L p .694 .611 .76 r
F P
0 g
s
.51386 .37921 m .50332 .32704 L .47945 .3337 L p .646 .58 .766 r
F P
0 g
s
.52305 .44704 m .52389 .4209 L .52005 .42109 L p .688 .519 .652 r
F P
0 g
s
.52005 .42109 m .52255 .44706 L .52305 .44704 L p .688 .519 .652 r
F P
0 g
s
.52389 .4209 m .52305 .44704 L .52354 .44711 L p .753 .574 .653 r
F P
0 g
s
.52596 .37859 m .52948 .32566 L .50332 .32704 L p .694 .611 .76 r
F P
0 g
s
.61544 .61608 m .57719 .57318 L .59386 .56163 L p .594 .625 .852 r
F P
0 g
s
.59386 .56163 m .64445 .59679 L .61544 .61608 L p .594 .625 .852 r
F P
0 g
s
.44741 .28467 m .47945 .3337 L .50332 .32704 L p .657 .641 .822 r
F P
0 g
s
.47945 .3337 m .44741 .28467 L .41514 .3044 L p .622 .627 .835 r
F P
0 g
s
.3622 .27419 m .41514 .3044 L .44741 .28467 L p .654 .714 .892 r
F P
0 g
s
.52305 .44885 m .52292 .45534 L .52255 .44882 L closepath p .7 .405 .473 r
F P
0 g
s
.52354 .44877 m .52292 .45534 L .52305 .44885 L closepath p .602 .324 .468 r
F P
0 g
s
.52255 .44882 m .52292 .45534 L .52209 .4487 L closepath p .788 .475 .459 r
F P
0 g
s
.52396 .44861 m .52292 .45534 L .52354 .44877 L closepath p .468 .212 .442 r
F P
0 g
s
.52209 .4487 m .52292 .45534 L .52172 .4485 L closepath p .878 .544 .415 r
F P
0 g
s
.52427 .44837 m .52292 .45534 L .52396 .44861 L closepath p .24 .021 .367 r
F P
0 g
s
.52427 .44751 m .52292 .45534 L .52443 .44779 L closepath p .991 .787 .531 r
F P
0 g
s
.83118 .36102 m .86257 .39875 L .83691 .33094 L p 0 .14 .686 r
F P
0 g
s
.83691 .33094 m .80691 .29843 L .83118 .36102 L p 0 .14 .686 r
F P
0 g
s
.52148 .44765 m .52292 .45534 L .52172 .44739 L closepath p .284 .186 .563 r
F P
0 g
s
.52396 .44727 m .52292 .45534 L .52427 .44751 L closepath p .911 .683 .579 r
F P
0 g
s
.52172 .44739 m .52292 .45534 L .52209 .44718 L closepath p .478 .32 .587 r
F P
0 g
s
.52354 .44711 m .52292 .45534 L .52396 .44727 L closepath p .829 .6 .591 r
F P
0 g
s
.52209 .44718 m .52292 .45534 L .52255 .44706 L closepath p .595 .404 .593 r
F P
0 g
s
.52305 .44704 m .52292 .45534 L .52354 .44711 L closepath p .755 .532 .594 r
F P
0 g
s
.52255 .44706 m .52292 .45534 L .52305 .44704 L closepath p .68 .47 .595 r
F P
0 g
s
.526 .53277 m .52952 .58464 L .50341 .58346 L p .716 .631 .761 r
F P
0 g
s
.52952 .58464 m .526 .53277 L .53789 .53107 L p .67 .595 .763 r
F P
0 g
s
.53789 .53107 m .55497 .5811 L .52952 .58464 L p .67 .595 .763 r
F P
0 g
s
.51378 .5322 m .50341 .58346 L .47925 .57767 L p .759 .673 .767 r
F P
0 g
s
.50341 .58346 m .51378 .5322 L .526 .53277 L p .716 .631 .761 r
F P
0 g
s
.55487 .32973 m .57847 .27759 L .53431 .27029 L p .718 .687 .819 r
F P
0 g
s
.53431 .27029 m .52948 .32566 L .55487 .32973 L p .718 .687 .819 r
F P
0 g
s
.20347 .52067 m .2511 .55157 L .27329 .59945 L p .201 .467 .885 r
F P
0 g
s
.33013 .60193 m .27329 .59945 L .2511 .55157 L p .525 .689 .942 r
F P
0 g
s
.70027 .29227 m .75829 .28526 L .7084 .23915 L p .56 .712 .943 r
F P
0 g
s
.7084 .23915 m .66187 .25786 L .70027 .29227 L p .56 .712 .943 r
F P
0 g
s
.52292 .45534 m .52443 .46292 L .52427 .4632 L closepath p .122 .078 .53 r
F P
0 g
s
.52292 .45534 m .52396 .4621 L .52427 .46234 L closepath p .922 .578 .368 r
F P
0 g
s
.52292 .45534 m .52396 .46343 L .52353 .46359 L closepath p .542 .365 .591 r
F P
0 g
s
.52292 .45534 m .52427 .4632 L .52396 .46343 L closepath p .396 .262 .579 r
F P
0 g
s
.52292 .45534 m .52353 .46194 L .52396 .4621 L closepath p .832 .509 .442 r
F P
0 g
s
.52292 .45534 m .52353 .46359 L .52304 .46367 L closepath p .64 .438 .594 r
F P
0 g
s
.52292 .45534 m .52304 .46187 L .52353 .46194 L closepath p .744 .44 .468 r
F P
0 g
s
.52292 .45534 m .52254 .46364 L .52208 .46352 L closepath p .791 .564 .593 r
F P
0 g
s
.52292 .45534 m .52304 .46367 L .52254 .46364 L closepath p .718 .501 .595 r
F P
0 g
s
.52292 .45534 m .52254 .46189 L .52304 .46187 L closepath p .653 .367 .472 r
F P
0 g
s
.52292 .45534 m .52208 .46352 L .52171 .46332 L closepath p .869 .639 .587 r
F P
0 g
s
.52292 .45534 m .52207 .46201 L .52254 .46189 L closepath p .542 .274 .458 r
F P
0 g
s
.52292 .45534 m .52171 .46332 L .52146 .46306 L closepath p .955 .733 .564 r
F P
0 g
s
.52292 .45534 m .5217 .46221 L .52207 .46201 L closepath p .373 .132 .414 r
F P
0 g
s
.52138 .46277 m .52292 .45534 L .52157 .46252 L p .993 .827 .459 r
F P
0 g
s
.52157 .46252 m .52146 .46306 L .52138 .46277 L p .993 .827 .459 r
F P
0 g
s
.51166 .48099 m .52113 .46309 L p .52138 .46277 L .84 .901 .486 r
F P
0 g
s
.52113 .46309 m .52146 .46247 L .52138 .46277 L p .84 .901 .486 r
F P
0 g
s
.52292 .45534 m .52146 .46247 L .5217 .46221 L closepath p .045 0 .285 r
F P
0 g
s
.51103 .48324 m .52138 .46277 L .52146 .46306 L p .983 .884 .65 r
F P
0 g
s
.52146 .46306 m .5117 .48547 L .51103 .48324 L p .983 .884 .65 r
F P
0 g
s
.52138 .46277 m .51244 .48045 L p .51166 .48099 L .84 .901 .486 r
F P
0 g
s
.51244 .48045 m .51103 .48324 L .51166 .48099 L p .84 .901 .486 r
F P
0 g
s
.49288 .4982 m .51048 .4818 L p .51166 .48099 L .581 .878 .575 r
F P
0 g
s
.52146 .46247 m .51166 .48099 L .51351 .47899 L p 0 0 0 r
F P
0 g
s
.51048 .4818 m .51351 .47899 L .51166 .48099 L p .581 .878 .575 r
F P
0 g
s
.51351 .47899 m .52143 .46277 L p .52146 .46247 L 0 0 0 r
F P
0 g
s
.52143 .46277 m .5217 .46221 L .52146 .46247 L p 0 0 0 r
F P
0 g
s
.52146 .46247 m .52292 .45534 L .52149 .46225 L p 0 0 0 r
F P
0 g
s
.52149 .46225 m .52138 .46277 L .52146 .46247 L p 0 0 0 r
F P
0 g
s
.52443 .46262 m .52443 .46292 L .52433 .46239 L p 0 0 .306 r
F P
0 g
s
.52443 .46262 m .52427 .46234 L p .52454 .46286 L .677 .277 0 r
F P
0 g
s
.53461 .48437 m .52443 .46292 L .52443 .46262 L p 0 .054 .601 r
F P
0 g
s
.53462 .48209 m .53461 .48437 L p .53325 .48146 L 0 .054 .601 r
F P
0 g
s
.52443 .46262 m .53462 .48209 L p .53325 .48146 L 0 .054 .601 r
F P
0 g
s
.53462 .48209 m .52443 .46262 L p .52454 .46286 L .677 .277 0 r
F P
0 g
s
.53336 .47994 m .53462 .48209 L p .53323 .47945 L .677 .277 0 r
F P
0 g
s
.52427 .46234 m .53336 .47994 L p .53323 .47945 L .677 .277 0 r
F P
0 g
s
.52443 .46292 m .53461 .48437 L .53333 .48651 L p .27 .26 .664 r
F P
0 g
s
.53336 .47994 m .53096 .47814 L p .53348 .48045 L .578 .036 0 r
F P
0 g
s
.53462 .48209 m .53336 .47994 L p .53604 .48275 L 0 .165 .7 r
F P
0 g
s
.56014 .50798 m .53462 .48209 L p .53604 .48275 L 0 .165 .7 r
F P
0 g
s
.55622 .50121 m .56014 .50798 L p .55516 .50277 L 0 .165 .7 r
F P
0 g
s
.53336 .47994 m .55622 .50121 L p .55516 .50277 L 0 .165 .7 r
F P
0 g
s
.55622 .50121 m .53336 .47994 L p .53348 .48045 L .578 .036 0 r
F P
0 g
s
.54863 .49552 m .55622 .50121 L p .55152 .49691 L .578 .036 0 r
F P
0 g
s
.53096 .47814 m .54863 .49552 L p .55152 .49691 L .578 .036 0 r
F P
0 g
s
.55586 .52174 m .53333 .48651 L .53461 .48437 L p .383 .403 .757 r
F P
0 g
s
.53461 .48437 m .56 .51508 L .55586 .52174 L p .383 .403 .757 r
F P
0 g
s
.56 .51508 m .53461 .48437 L .53462 .48209 L p .167 .32 .775 r
F P
0 g
s
.53462 .48209 m .56014 .50798 L .56 .51508 L p .167 .32 .775 r
F P
0 g
s
.52396 .46343 m .53093 .48829 L .52767 .48953 L p .572 .436 .657 r
F P
0 g
s
.53093 .48829 m .52396 .46343 L .52427 .4632 L p .459 .366 .663 r
F P
0 g
s
.52427 .4632 m .53333 .48651 L .53093 .48829 L p .459 .366 .663 r
F P
0 g
s
.53333 .48651 m .52427 .4632 L .52443 .46292 L p .27 .26 .664 r
F P
0 g
s
.53817 .49156 m .54863 .49552 L p .54472 .49204 L .666 .122 0 r
F P
0 g
s
.52768 .47689 m .53817 .49156 L p .54472 .49204 L .666 .122 0 r
F P
0 g
s
.526 .53277 m .52389 .49008 L .52767 .48953 L p .663 .544 .708 r
F P
0 g
s
.52767 .48953 m .53789 .53107 L .526 .53277 L p .663 .544 .708 r
F P
0 g
s
.53789 .53107 m .52767 .48953 L .53093 .48829 L p .597 .501 .717 r
F P
0 g
s
.53093 .48829 m .54822 .52726 L .53789 .53107 L p .597 .501 .717 r
F P
0 g
s
.54822 .52726 m .53093 .48829 L .53333 .48651 L p .51 .457 .733 r
F P
0 g
s
.53333 .48651 m .55586 .52174 L .54822 .52726 L p .51 .457 .733 r
F P
0 g
s
.53817 .49156 m .526 .48978 L p .53157 .49107 L .211 0 0 r
F P
0 g
s
.54863 .49552 m .53817 .49156 L p .54572 .49412 L 0 .388 .718 r
F P
0 g
s
.54863 .49552 m .53096 .47814 L .52768 .47689 L p .666 .122 0 r
F P
0 g
s
.57928 .50552 m .54863 .49552 L p .54572 .49412 L 0 .388 .718 r
F P
0 g
s
.55645 .49686 m .57928 .50552 L p .57177 .50297 L 0 .388 .718 r
F P
0 g
s
.53817 .49156 m .55645 .49686 L p .57177 .50297 L 0 .388 .718 r
F P
0 g
s
.55645 .49686 m .53817 .49156 L p .53157 .49107 L .211 0 0 r
F P
0 g
s
.55622 .50121 m .54863 .49552 L p .55729 .49964 L 0 .435 .853 r
F P
0 g
s
.54863 .49552 m .57928 .50552 L .59564 .51786 L p 0 .435 .853 r
F P
0 g
s
.52972 .49295 m .55645 .49686 L p .55087 .49556 L .211 0 0 r
F P
0 g
s
.526 .48978 m .52972 .49295 L p .55087 .49556 L .211 0 0 r
F P
0 g
s
.52389 .49008 m .526 .53277 L .51378 .5322 L p .721 .589 .707 r
F P
0 g
s
.51378 .5322 m .52001 .4899 L .52389 .49008 L p .721 .589 .707 r
F P
0 g
s
.50251 .52941 m .51644 .48899 L .52001 .4899 L p .775 .64 .712 r
F P
0 g
s
.52001 .4899 m .51378 .5322 L .50251 .52941 L p .775 .64 .712 r
F P
0 g
s
.49339 .52469 m .51357 .48746 L .51644 .48899 L p .829 .702 .724 r
F P
0 g
s
.51644 .48899 m .50251 .52941 L .49339 .52469 L p .829 .702 .724 r
F P
0 g
s
.48739 .51853 m .5117 .48547 L .51357 .48746 L p .884 .783 .744 r
F P
0 g
s
.51357 .48746 m .49339 .52469 L .48739 .51853 L p .884 .783 .744 r
F P
0 g
s
.48519 .51155 m .51103 .48324 L .5117 .48547 L p .93 .888 .77 r
F P
0 g
s
.5117 .48547 m .48739 .51853 L .48519 .51155 L p .93 .888 .77 r
F P
0 g
s
.51357 .48746 m .52171 .46332 L .52208 .46352 L p .852 .674 .66 r
F P
0 g
s
.52208 .46352 m .51644 .48899 L .51357 .48746 L p .852 .674 .66 r
F P
0 g
s
.5117 .48547 m .52146 .46306 L .52171 .46332 L p .925 .766 .666 r
F P
0 g
s
.52171 .46332 m .51357 .48746 L .5117 .48547 L p .925 .766 .666 r
F P
0 g
s
.51638 .47744 m .50201 .4933 L .51348 .49038 L p .291 0 0 r
F P
0 g
s
.50217 .49428 m .51348 .49038 L .50201 .4933 L p 0 0 0 r
F P
0 g
s
.51348 .49038 m .50217 .49428 L .52972 .49295 L p .098 0 0 r
F P
0 g
s
.52972 .49295 m .50217 .49428 L p .50985 .4905 L .433 .821 .987 r
F P
0 g
s
.52001 .4899 m .52254 .46364 L .52304 .46367 L p .721 .546 .652 r
F P
0 g
s
.52304 .46367 m .52389 .49008 L .52001 .4899 L p .721 .546 .652 r
F P
0 g
s
.52389 .49008 m .52304 .46367 L .52353 .46359 L p .653 .492 .653 r
F P
0 g
s
.51644 .48899 m .52208 .46352 L .52254 .46364 L p .786 .604 .654 r
F P
0 g
s
.52254 .46364 m .52001 .4899 L .51644 .48899 L p .786 .604 .654 r
F P
0 g
s
.52353 .46359 m .52767 .48953 L .52389 .49008 L p .653 .492 .653 r
F P
0 g
s
.52767 .48953 m .52353 .46359 L .52396 .46343 L p .572 .436 .657 r
F P
0 g
s
.53336 .47994 m .52427 .46234 L .52396 .4621 L p .863 .414 .099 r
F P
0 g
s
.52396 .4621 m .53096 .47814 L .53336 .47994 L p .863 .414 .099 r
F P
0 g
s
.51348 .49038 m .51997 .47652 L .51638 .47744 L p .291 0 0 r
F P
0 g
s
.53817 .49156 m .52768 .47689 L .52388 .47633 L p .607 .1 .02 r
F P
0 g
s
.526 .48978 m .52388 .47633 L .51997 .47652 L p .486 .007 .042 r
F P
0 g
s
.51997 .47652 m .51348 .49038 L .526 .48978 L p .486 .007 .042 r
F P
0 g
s
.52388 .47633 m .526 .48978 L .53817 .49156 L p .607 .1 .02 r
F P
0 g
s
.52972 .49295 m .526 .48978 L .51348 .49038 L p .098 0 0 r
F P
0 g
s
.53494 .47815 m .52972 .49295 L p .50985 .4905 L .433 .821 .987 r
F P
0 g
s
.55645 .49686 m .52972 .49295 L p .54202 .49111 L .37 .761 .987 r
F P
0 g
s
.58203 .4851 m .55645 .49686 L p .54202 .49111 L .37 .761 .987 r
F P
0 g
s
.59564 .51786 m .55622 .50121 L p .55729 .49964 L 0 .435 .853 r
F P
0 g
s
.52433 .46239 m .52292 .45534 L .52443 .46262 L p 0 0 .306 r
F P
0 g
s
.52292 .45534 m .52427 .46234 L .52443 .46262 L closepath p .929 .595 .146 r
F P
0 g
s
.70041 .61839 m .64445 .59679 L .66117 .57307 L p .624 .729 .922 r
F P
0 g
s
.66117 .57307 m .72618 .58397 L .70041 .61839 L p .624 .729 .922 r
F P
0 g
s
.3622 .27419 m .3089 .2611 L .27308 .31126 L p .715 .823 .932 r
F P
0 g
s
.22224 .3295 m .27308 .31126 L .3089 .2611 L p .79 .955 .923 r
F P
0 g
s
.55497 .5811 m .53789 .53107 L .54822 .52726 L p .617 .565 .774 r
F P
0 g
s
.54822 .52726 m .57719 .57318 L .55497 .5811 L p .617 .565 .774 r
F P
0 g
s
.48877 .27277 m .50332 .32704 L .52948 .32566 L p .689 .661 .817 r
F P
0 g
s
.50332 .32704 m .48877 .27277 L .44741 .28467 L p .657 .641 .822 r
F P
0 g
s
.52948 .32566 m .53431 .27029 L .48877 .27277 L p .689 .661 .817 r
F P
0 g
s
.83257 .54993 m .78703 .57608 L .79496 .52609 L p .856 .942 .876 r
F P
0 g
s
.79496 .52609 m .84354 .49008 L .83257 .54993 L p .856 .942 .876 r
F P
0 g
s
.51638 .47744 m .52207 .46201 L .5217 .46221 L p .236 0 .2 r
F P
0 g
s
.5217 .46221 m .51351 .47899 L .51638 .47744 L p .236 0 .2 r
F P
0 g
s
.53096 .47814 m .52396 .4621 L .52353 .46194 L p .806 .393 .265 r
F P
0 g
s
.51997 .47652 m .52254 .46189 L .52207 .46201 L p .47 .127 .302 r
F P
0 g
s
.52207 .46201 m .51638 .47744 L .51997 .47652 L p .47 .127 .302 r
F P
0 g
s
.52353 .46194 m .52768 .47689 L .53096 .47814 L p .806 .393 .265 r
F P
0 g
s
.52768 .47689 m .52353 .46194 L .52304 .46187 L p .715 .333 .325 r
F P
0 g
s
.52388 .47633 m .52304 .46187 L .52254 .46189 L p .61 .251 .334 r
F P
0 g
s
.52254 .46189 m .51997 .47652 L .52388 .47633 L p .61 .251 .334 r
F P
0 g
s
.33013 .60193 m .3913 .58541 L .4146 .60716 L p .683 .771 .918 r
F P
0 g
s
.4595 .56782 m .4146 .60716 L .3913 .58541 L p .775 .788 .863 r
F P
0 g
s
.4146 .60716 m .4595 .56782 L .47925 .57767 L p .757 .745 .842 r
F P
0 g
s
.52304 .46187 m .52388 .47633 L .52768 .47689 L p .715 .333 .325 r
F P
0 g
s
.50251 .52941 m .47925 .57767 L .4595 .56782 L p .8 .725 .782 r
F P
0 g
s
.47925 .57767 m .50251 .52941 L .51378 .5322 L p .759 .673 .767 r
F P
0 g
s
.61587 .29365 m .66187 .25786 L .60628 .23329 L p .687 .738 .89 r
F P
0 g
s
.60628 .23329 m .57847 .27759 L .61587 .29365 L p .687 .738 .89 r
F P
0 g
s
.57719 .57318 m .54822 .52726 L .55586 .52174 L p .554 .54 .793 r
F P
0 g
s
.55586 .52174 m .59386 .56163 L .57719 .57318 L p .554 .54 .793 r
F P
0 g
s
.4595 .56782 m .49339 .52469 L .50251 .52941 L p .8 .725 .782 r
F P
0 g
s
.19099 .36465 m .18616 .41093 L .18025 .47832 L p .722 .646 .088 r
F P
0 g
s
.20347 .52067 m .18025 .47832 L .18616 .41093 L p .006 .135 .65 r
F P
0 g
s
.40974 .24415 m .44741 .28467 L .48877 .27277 L p .664 .717 .888 r
F P
0 g
s
.44741 .28467 m .40974 .24415 L .3622 .27419 L p .654 .714 .892 r
F P
0 g
s
.48707 .50452 m .51166 .48099 L .51103 .48324 L p .898 .987 .762 r
F P
0 g
s
.51103 .48324 m .48519 .51155 L .48707 .50452 L p .898 .987 .762 r
F P
0 g
s
.3913 .58541 m .44629 .55485 L .4595 .56782 L p .775 .788 .863 r
F P
0 g
s
.49339 .52469 m .4595 .56782 L .44629 .55485 L p .836 .79 .807 r
F P
0 g
s
.64445 .59679 m .59386 .56163 L .60313 .54756 L p .548 .621 .877 r
F P
0 g
s
.60313 .54756 m .66117 .57307 L .64445 .59679 L p .548 .621 .877 r
F P
0 g
s
.3089 .2611 m .3622 .27419 L .40974 .24415 L p .685 .829 .952 r
F P
0 g
s
.44629 .55485 m .48739 .51853 L .49339 .52469 L p .836 .79 .807 r
F P
0 g
s
.47705 .50067 m .49438 .49556 L p .49288 .4982 L .468 .888 .795 r
F P
0 g
s
.51166 .48099 m .49193 .49986 L p .49288 .4982 L .581 .878 .575 r
F P
0 g
s
.51351 .47899 m .49288 .4982 L .50201 .4933 L p 0 0 0 r
F P
0 g
s
.49438 .49556 m .50201 .4933 L .49288 .4982 L p .468 .888 .795 r
F P
0 g
s
.49193 .49986 m .48707 .50452 L .49288 .4982 L p .581 .878 .575 r
F P
0 g
s
.2511 .55157 m .3144 .56526 L .33013 .60193 L p .525 .689 .942 r
F P
0 g
s
.3913 .58541 m .33013 .60193 L .3144 .56526 L p .681 .781 .926 r
F P
0 g
s
.50201 .4933 m .51638 .47744 L .51351 .47899 L p 0 0 0 r
F P
0 g
s
.59386 .56163 m .55586 .52174 L .56 .51508 L p .472 .518 .824 r
F P
0 g
s
.57847 .27759 m .60628 .23329 L .54003 .22207 L p .681 .729 .887 r
F P
0 g
s
.54003 .22207 m .53431 .27029 L .57847 .27759 L p .681 .729 .887 r
F P
0 g
s
.86257 .39875 m .86736 .44464 L .8415 .37757 L p .917 .644 .153 r
F P
0 g
s
.8415 .37757 m .83691 .33094 L .86257 .39875 L p .917 .644 .153 r
F P
0 g
s
.56 .51508 m .60313 .54756 L .59386 .56163 L p .472 .518 .824 r
F P
0 g
s
.44115 .54006 m .48519 .51155 L .48739 .51853 L p .861 .868 .843 r
F P
0 g
s
.48739 .51853 m .44629 .55485 L .44115 .54006 L p .861 .868 .843 r
F P
0 g
s
.47156 .22588 m .48877 .27277 L .53431 .27029 L p .673 .722 .886 r
F P
0 g
s
.48877 .27277 m .47156 .22588 L .40974 .24415 L p .664 .717 .888 r
F P
0 g
s
.75829 .28526 m .80691 .29843 L .74782 .2429 L p .24 .563 .936 r
F P
0 g
s
.74782 .2429 m .7084 .23915 L .75829 .28526 L p .24 .563 .936 r
F P
0 g
s
.78703 .57608 m .72618 .58397 L .73083 .54594 L p .731 .837 .93 r
F P
0 g
s
.73083 .54594 m .79496 .52609 L .78703 .57608 L p .731 .837 .93 r
F P
0 g
s
.3089 .2611 m .26397 .26939 L .22224 .3295 L p .79 .955 .923 r
F P
0 g
s
.19099 .36465 m .22224 .3295 L .26397 .26939 L p .688 .914 .58 r
F P
0 g
s
.53431 .27029 m .54003 .22207 L .47156 .22588 L p .673 .722 .886 r
F P
0 g
s
.60313 .54756 m .56 .51508 L .56014 .50798 L p .357 .498 .863 r
F P
0 g
s
.3144 .56526 m .38157 .5603 L .3913 .58541 L p .681 .781 .926 r
F P
0 g
s
.44629 .55485 m .3913 .58541 L .38157 .5603 L p .782 .834 .892 r
F P
0 g
s
.38157 .5603 m .44115 .54006 L .44629 .55485 L p .782 .834 .892 r
F P
0 g
s
.44486 .525 m .48707 .50452 L .48519 .51155 L p .849 .951 .881 r
F P
0 g
s
.48519 .51155 m .44115 .54006 L .44486 .525 L p .849 .951 .881 r
F P
0 g
s
.66187 .25786 m .7084 .23915 L .63466 .2059 L p .562 .741 .96 r
F P
0 g
s
.63466 .2059 m .60628 .23329 L .66187 .25786 L p .562 .741 .96 r
F P
0 g
s
.56014 .50798 m .60382 .53243 L .60313 .54756 L p .357 .498 .863 r
F P
0 g
s
.60382 .53243 m .56014 .50798 L .55622 .50121 L p .19 .475 .892 r
F P
0 g
s
.18616 .41093 m .2098 .45953 L .20347 .52067 L p .006 .135 .65 r
F P
0 g
s
.2511 .55157 m .20347 .52067 L .2098 .45953 L p .377 .503 .859 r
F P
0 g
s
.66117 .57307 m .60313 .54756 L .60382 .53243 L p .497 .627 .909 r
F P
0 g
s
.45723 .51134 m .49288 .4982 L .48707 .50452 L p .738 .989 .886 r
F P
0 g
s
.48707 .50452 m .44486 .525 L .45723 .51134 L p .738 .989 .886 r
F P
0 g
s
.72618 .58397 m .66117 .57307 L .66329 .54722 L p .615 .734 .931 r
F P
0 g
s
.66329 .54722 m .73083 .54594 L .72618 .58397 L p .615 .734 .931 r
F P
0 g
s
.55622 .50121 m .59564 .51786 L .60382 .53243 L p .19 .475 .892 r
F P
0 g
s
.60382 .53243 m .66329 .54722 L .66117 .57307 L p .497 .627 .909 r
F P
0 g
s
.37142 .22063 m .40974 .24415 L .47156 .22588 L p .648 .821 .967 r
F P
0 g
s
.40974 .24415 m .37142 .22063 L .3089 .2611 L p .685 .829 .952 r
F P
0 g
s
.49288 .4982 m .45723 .51134 L .47705 .50067 L p .468 .888 .795 r
F P
0 g
s
.38709 .53441 m .44486 .525 L .44115 .54006 L p .769 .878 .926 r
F P
0 g
s
.44115 .54006 m .38157 .5603 L .38709 .53441 L p .769 .878 .926 r
F P
0 g
s
.86736 .44464 m .84354 .49008 L .8187 .42939 L p .97 .868 .68 r
F P
0 g
s
.8187 .42939 m .8415 .37757 L .86736 .44464 L p .97 .868 .68 r
F P
0 g
s
.26397 .26939 m .3089 .2611 L .37142 .22063 L p .655 .957 .94 r
F P
0 g
s
.50201 .4933 m .47705 .50067 L .50217 .49428 L p 0 0 0 r
F P
0 g
s
.2098 .45953 m .25791 .50078 L .2511 .55157 L p .377 .503 .859 r
F P
0 g
s
.3144 .56526 m .2511 .55157 L .25791 .50078 L p .557 .677 .919 r
F P
0 g
s
.66329 .54722 m .60382 .53243 L .59564 .51786 L p .442 .644 .943 r
F P
0 g
s
.60628 .23329 m .63466 .2059 L .54587 .19062 L p .579 .773 .971 r
F P
0 g
s
.54587 .19062 m .54003 .22207 L .60628 .23329 L p .579 .773 .971 r
F P
0 g
s
.26397 .26939 m .2361 .29933 L .19099 .36465 L p .688 .914 .58 r
F P
0 g
s
.18616 .41093 m .19099 .36465 L .2361 .29933 L p 0 0 .311 r
F P
0 g
s
.80691 .29843 m .83691 .33094 L .77233 .27039 L p .587 .076 0 r
F P
0 g
s
.77233 .27039 m .74782 .2429 L .80691 .29843 L p .587 .076 0 r
F P
0 g
s
.32105 .52689 m .38709 .53441 L .38157 .5603 L p .675 .789 .935 r
F P
0 g
s
.38157 .5603 m .3144 .56526 L .32105 .52689 L p .675 .789 .935 r
F P
0 g
s
.25791 .50078 m .32105 .52689 L .3144 .56526 L p .557 .677 .919 r
F P
0 g
s
.45394 .19582 m .47156 .22588 L .54003 .22207 L p .61 .802 .973 r
F P
0 g
s
.47156 .22588 m .45394 .19582 L .37142 .22063 L p .648 .821 .967 r
F P
0 g
s
.40793 .51063 m .45723 .51134 L .44486 .525 L p .725 .909 .959 r
F P
0 g
s
.44486 .525 m .38709 .53441 L .40793 .51063 L p .725 .909 .959 r
F P
0 g
s
.54003 .22207 m .54587 .19062 L .45394 .19582 L p .61 .802 .973 r
F P
0 g
s
.7084 .23915 m .74782 .2429 L .65888 .2025 L p .149 .595 .931 r
F P
0 g
s
.65888 .2025 m .63466 .2059 L .7084 .23915 L p .149 .595 .931 r
F P
0 g
s
.84354 .49008 m .79496 .52609 L .77255 .47593 L p .855 .855 .841 r
F P
0 g
s
.77255 .47593 m .8187 .42939 L .84354 .49008 L p .855 .855 .841 r
F P
0 g
s
.59564 .51786 m .6499 .52201 L .66329 .54722 L p .442 .644 .943 r
F P
0 g
s
.6499 .52201 m .59564 .51786 L .57928 .50552 L p .39 .672 .972 r
F P
0 g
s
.73083 .54594 m .66329 .54722 L .6499 .52201 L p .609 .742 .939 r
F P
0 g
s
.44226 .49185 m .47705 .50067 L .45723 .51134 L p .644 .912 .981 r
F P
0 g
s
.45723 .51134 m .40793 .51063 L .44226 .49185 L p .644 .912 .981 r
F P
0 g
s
.79496 .52609 m .73083 .54594 L .71238 .50832 L p .737 .807 .907 r
F P
0 g
s
.71238 .50832 m .77255 .47593 L .79496 .52609 L p .737 .807 .907 r
F P
0 g
s
.6499 .52201 m .71238 .50832 L .73083 .54594 L p .609 .742 .939 r
F P
0 g
s
.2361 .29933 m .23177 .34628 L .18616 .41093 L p 0 0 .311 r
F P
0 g
s
.2098 .45953 m .18616 .41093 L .23177 .34628 L p .334 .312 .686 r
F P
0 g
s
.57928 .50552 m .62188 .5004 L .6499 .52201 L p .39 .672 .972 r
F P
0 g
s
.62188 .5004 m .57928 .50552 L .55645 .49686 L p .359 .711 .986 r
F P
0 g
s
.37142 .22063 m .3388 .22043 L .26397 .26939 L p .655 .957 .94 r
F P
0 g
s
.2361 .29933 m .26397 .26939 L .3388 .22043 L p 0 0 0 r
F P
0 g
s
.3388 .22043 m .37142 .22063 L .45394 .19582 L p .443 .874 .914 r
F P
0 g
s
.35084 .49114 m .40793 .51063 L .38709 .53441 L p .665 .794 .943 r
F P
0 g
s
.38709 .53441 m .32105 .52689 L .35084 .49114 L p .665 .794 .943 r
F P
0 g
s
.83691 .33094 m .8415 .37757 L .77609 .31762 L p .949 .634 .402 r
F P
0 g
s
.77609 .31762 m .77233 .27039 L .83691 .33094 L p .949 .634 .402 r
F P
0 g
s
.48635 .48051 m .50217 .49428 L .47705 .50067 L p .535 .879 .988 r
F P
0 g
s
.47705 .50067 m .44226 .49185 L .48635 .48051 L p .535 .879 .988 r
F P
0 g
s
.55645 .49686 m .58203 .4851 L .62188 .5004 L p .359 .711 .986 r
F P
0 g
s
.50217 .49428 m .48635 .48051 L .53494 .47815 L p .433 .821 .987 r
F P
0 g
s
.52972 .49295 m .53494 .47815 L .58203 .4851 L p .37 .761 .987 r
F P
0 g
s
.63466 .2059 m .65888 .2025 L .55087 .18384 L p .138 .651 .895 r
F P
0 g
s
.55087 .18384 m .54587 .19062 L .63466 .2059 L p .138 .651 .895 r
F P
0 g
s
.71238 .50832 m .6499 .52201 L .62188 .5004 L p .606 .752 .947 r
F P
0 g
s
.23177 .34628 m .25289 .40119 L .2098 .45953 L p .334 .312 .686 r
F P
0 g
s
.25791 .50078 m .2098 .45953 L .25289 .40119 L p .493 .53 .824 r
F P
0 g
s
.29553 .4528 m .35084 .49114 L .32105 .52689 L p .59 .673 .897 r
F P
0 g
s
.32105 .52689 m .25791 .50078 L .29553 .4528 L p .59 .673 .897 r
F P
0 g
s
.25289 .40119 m .29553 .4528 L .25791 .50078 L p .493 .53 .824 r
F P
0 g
s
.43884 .1902 m .45394 .19582 L .54587 .19062 L p .244 .749 .884 r
F P
0 g
s
.45394 .19582 m .43884 .1902 L .3388 .22043 L p .443 .874 .914 r
F P
0 g
s
.74782 .2429 m .77233 .27039 L .67401 .22611 L p .703 .168 0 r
F P
0 g
s
.67401 .22611 m .65888 .2025 L .74782 .2429 L p .703 .168 0 r
F P
0 g
s
.40157 .46256 m .44226 .49185 L .40793 .51063 L p .653 .795 .951 r
F P
0 g
s
.40793 .51063 m .35084 .49114 L .40157 .46256 L p .653 .795 .951 r
F P
0 g
s
.54587 .19062 m .55087 .18384 L .43884 .1902 L p .244 .749 .884 r
F P
0 g
s
.8415 .37757 m .8187 .42939 L .75741 .37541 L p .902 .751 .684 r
F P
0 g
s
.75741 .37541 m .77609 .31762 L .8415 .37757 L p .902 .751 .684 r
F P
0 g
s
.3388 .22043 m .31843 .24579 L .2361 .29933 L p 0 0 0 r
F P
0 g
s
.23177 .34628 m .2361 .29933 L .31843 .24579 L p .35 .141 .449 r
F P
0 g
s
.77255 .47593 m .71238 .50832 L .6715 .47561 L p .732 .777 .888 r
F P
0 g
s
.62188 .5004 m .6715 .47561 L .71238 .50832 L p .606 .752 .947 r
F P
0 g
s
.6715 .47561 m .62188 .5004 L .58203 .4851 L p .608 .763 .953 r
F P
0 g
s
.31843 .24579 m .3388 .22043 L .43884 .1902 L p .279 0 0 r
F P
0 g
s
.46773 .44514 m .48635 .48051 L .44226 .49185 L p .639 .792 .956 r
F P
0 g
s
.44226 .49185 m .40157 .46256 L .46773 .44514 L p .639 .792 .956 r
F P
0 g
s
.8187 .42939 m .77255 .47593 L .71989 .43176 L p .823 .777 .809 r
F P
0 g
s
.71989 .43176 m .75741 .37541 L .8187 .42939 L p .823 .777 .809 r
F P
0 g
s
.6715 .47561 m .71989 .43176 L .77255 .47593 L p .732 .777 .888 r
F P
0 g
s
.58203 .4851 m .61208 .45221 L .6715 .47561 L p .608 .763 .953 r
F P
0 g
s
.61208 .45221 m .58203 .4851 L .53494 .47815 L p .615 .775 .957 r
F P
0 g
s
.36171 .41398 m .40157 .46256 L .35084 .49114 L p .622 .676 .881 r
F P
0 g
s
.35084 .49114 m .29553 .4528 L .36171 .41398 L p .622 .676 .881 r
F P
0 g
s
.54111 .44151 m .53494 .47815 L .48635 .48051 L p .625 .785 .958 r
F P
0 g
s
.48635 .48051 m .46773 .44514 L .54111 .44151 L p .625 .785 .958 r
F P
0 g
s
.65888 .2025 m .67401 .22611 L .55399 .20559 L p .634 .138 .054 r
F P
0 g
s
.55399 .20559 m .55087 .18384 L .65888 .2025 L p .634 .138 .054 r
F P
0 g
s
.53494 .47815 m .54111 .44151 L .61208 .45221 L p .615 .775 .957 r
F P
0 g
s
.31843 .24579 m .31525 .29324 L .23177 .34628 L p .35 .141 .449 r
F P
0 g
s
.25289 .40119 m .23177 .34628 L .31525 .29324 L p .503 .408 .68 r
F P
0 g
s
.77233 .27039 m .77609 .31762 L .67633 .27373 L p .852 .55 .477 r
F P
0 g
s
.67633 .27373 m .67401 .22611 L .77233 .27039 L p .852 .55 .477 r
F P
0 g
s
.71989 .43176 m .6715 .47561 L .61208 .45221 L p .719 .748 .875 r
F P
0 g
s
.42937 .21258 m .43884 .1902 L .55087 .18384 L p .499 .033 .078 r
F P
0 g
s
.43884 .1902 m .42937 .21258 L .31843 .24579 L p .279 0 0 r
F P
0 g
s
.3307 .35354 m .36171 .41398 L .29553 .4528 L p .575 .557 .797 r
F P
0 g
s
.29553 .4528 m .25289 .40119 L .3307 .35354 L p .575 .557 .797 r
F P
0 g
s
.31525 .29324 m .3307 .35354 L .25289 .40119 L p .503 .408 .68 r
F P
0 g
s
.55087 .18384 m .55399 .20559 L .42937 .21258 L p .499 .033 .078 r
F P
0 g
s
.31525 .29324 m .31843 .24579 L .42937 .21258 L p .538 .293 .492 r
F P
0 g
s
.44938 .39013 m .46773 .44514 L .40157 .46256 L p .651 .686 .87 r
F P
0 g
s
.40157 .46256 m .36171 .41398 L .44938 .39013 L p .651 .686 .87 r
F P
0 g
s
.77609 .31762 m .75741 .37541 L .66476 .33606 L p .828 .661 .676 r
F P
0 g
s
.66476 .33606 m .67633 .27373 L .77609 .31762 L p .828 .661 .676 r
F P
0 g
s
.75741 .37541 m .71989 .43176 L .64165 .39982 L p .783 .714 .788 r
F P
0 g
s
.61208 .45221 m .64165 .39982 L .71989 .43176 L p .719 .748 .875 r
F P
0 g
s
.64165 .39982 m .61208 .45221 L .54111 .44151 L p .7 .723 .867 r
F P
0 g
s
.64165 .39982 m .66476 .33606 L .75741 .37541 L p .783 .714 .788 r
F P
0 g
s
.67401 .22611 m .67633 .27373 L .55444 .25339 L p .756 .471 .501 r
F P
0 g
s
.55444 .25339 m .55399 .20559 L .67401 .22611 L p .756 .471 .501 r
F P
0 g
s
.54722 .38513 m .54111 .44151 L .46773 .44514 L p .677 .702 .865 r
F P
0 g
s
.46773 .44514 m .44938 .39013 L .54722 .38513 L p .677 .702 .865 r
F P
0 g
s
.54111 .44151 m .54722 .38513 L .64165 .39982 L p .7 .723 .867 r
F P
0 g
s
.42937 .21258 m .42787 .26033 L .31525 .29324 L p .538 .293 .492 r
F P
0 g
s
.3307 .35354 m .31525 .29324 L .42787 .26033 L p .608 .474 .673 r
F P
0 g
s
.43503 .32407 m .44938 .39013 L .36171 .41398 L p .638 .587 .781 r
F P
0 g
s
.36171 .41398 m .3307 .35354 L .43503 .32407 L p .638 .587 .781 r
F P
0 g
s
.42787 .26033 m .42937 .21258 L .55399 .20559 L p .658 .391 .505 r
F P
0 g
s
.55399 .20559 m .55444 .25339 L .42787 .26033 L p .658 .391 .505 r
F P
0 g
s
.42787 .26033 m .43503 .32407 L .3307 .35354 L p .608 .474 .673 r
F P
0 g
s
.66476 .33606 m .64165 .39982 L .54722 .38513 L p .739 .664 .776 r
F P
0 g
s
.67633 .27373 m .66476 .33606 L .55202 .31787 L p .758 .592 .671 r
F P
0 g
s
.55202 .31787 m .55444 .25339 L .67633 .27373 L p .758 .592 .671 r
F P
0 g
s
.55202 .31787 m .54722 .38513 L .44938 .39013 L p .691 .622 .774 r
F P
0 g
s
.44938 .39013 m .43503 .32407 L .55202 .31787 L p .691 .622 .774 r
F P
0 g
s
.54722 .38513 m .55202 .31787 L .66476 .33606 L p .739 .664 .776 r
F P
0 g
s
.43503 .32407 m .42787 .26033 L .55444 .25339 L p .688 .532 .67 r
F P
0 g
s
.55444 .25339 m .55202 .31787 L .43503 .32407 L p .688 .532 .67 r
F P
0 g
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.227012 0.200176 0.419395 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.26887e-17 1.05045 -0.043401 1.05045 [
[ 0 0 0 0 ]
[ 1 .86239 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .86239 L
0 .86239 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.46142 .53785 m .45397 .58689 L .54688 .59114 L p .719 .591 .711 r
F P
0 g
s
.54688 .59114 m .54437 .54175 L .46142 .53785 L p .719 .591 .711 r
F P
0 g
s
.54836 .63935 m .54688 .59114 L .45397 .58689 L p .72 .541 .647 r
F P
0 g
s
.54437 .54175 m .54688 .59114 L .63794 .57837 L p .669 .552 .713 r
F P
0 g
s
.54688 .59114 m .54836 .63935 L .64525 .62616 L p .658 .492 .648 r
F P
0 g
s
.64525 .62616 m .63794 .57837 L .54688 .59114 L p .658 .492 .648 r
F P
0 g
s
.47124 .4922 m .46142 .53785 L .54437 .54175 L p .713 .638 .773 r
F P
0 g
s
.54437 .54175 m .54104 .49558 L .47124 .4922 L p .713 .638 .773 r
F P
0 g
s
.54104 .49558 m .54437 .54175 L .62559 .53001 L p .676 .61 .775 r
F P
0 g
s
.63794 .57837 m .62559 .53001 L .54437 .54175 L p .669 .552 .713 r
F P
0 g
s
.38355 .51851 m .36652 .56583 L .45397 .58689 L p .766 .635 .716 r
F P
0 g
s
.45397 .58689 m .46142 .53785 L .38355 .51851 L p .766 .635 .716 r
F P
0 g
s
.44954 .63496 m .45397 .58689 L .36652 .56583 L p .778 .593 .65 r
F P
0 g
s
.45397 .58689 m .44954 .63496 L .54836 .63935 L p .72 .541 .647 r
F P
0 g
s
.40592 .47552 m .38355 .51851 L .46142 .53785 L p .747 .673 .778 r
F P
0 g
s
.46142 .53785 m .47124 .4922 L .40592 .47552 L p .747 .673 .778 r
F P
0 g
s
.54865 .682 m .54836 .63935 L .44954 .63496 L p .713 .477 .567 r
F P
0 g
s
.54836 .63935 m .54865 .682 L .64676 .669 L p .639 .417 .566 r
F P
0 g
s
.64676 .669 m .64525 .62616 L .54836 .63935 L p .639 .417 .566 r
F P
0 g
s
.62559 .53001 m .60932 .48543 L .54104 .49558 L p .676 .61 .775 r
F P
0 g
s
.60932 .48543 m .62559 .53001 L .69829 .50329 L p .635 .588 .784 r
F P
0 g
s
.62559 .53001 m .63794 .57837 L .71979 .54921 L p .613 .517 .721 r
F P
0 g
s
.71979 .54921 m .69829 .50329 L .62559 .53001 L p .613 .517 .721 r
F P
0 g
s
.63794 .57837 m .64525 .62616 L .73258 .596 L p .586 .442 .652 r
F P
0 g
s
.73258 .596 m .71979 .54921 L .63794 .57837 L p .586 .442 .652 r
F P
0 g
s
.48257 .45417 m .47124 .4922 L .54104 .49558 L p .696 .691 .842 r
F P
0 g
s
.54104 .49558 m .53719 .45688 L .48257 .45417 L p .696 .691 .842 r
F P
0 g
s
.53719 .45688 m .54104 .49558 L .60932 .48543 L p .676 .676 .843 r
F P
0 g
s
.36652 .56583 m .35639 .6132 L .44954 .63496 L p .778 .593 .65 r
F P
0 g
s
.44859 .67768 m .44954 .63496 L .35639 .6132 L p .783 .537 .564 r
F P
0 g
s
.44954 .63496 m .44859 .67768 L .54865 .682 L p .713 .477 .567 r
F P
0 g
s
.43166 .44086 m .40592 .47552 L .47124 .4922 L p .713 .71 .845 r
F P
0 g
s
.47124 .4922 m .48257 .45417 L .43166 .44086 L p .713 .71 .845 r
F P
0 g
s
.60932 .48543 m .59055 .44877 L .53719 .45688 L p .676 .676 .843 r
F P
0 g
s
.59055 .44877 m .60932 .48543 L .67008 .46243 L p .654 .666 .849 r
F P
0 g
s
.69829 .50329 m .67008 .46243 L .60932 .48543 L p .635 .588 .784 r
F P
0 g
s
.35103 .44664 m .31756 .48487 L .38355 .51851 L p .778 .714 .791 r
F P
0 g
s
.38355 .51851 m .40592 .47552 L .35103 .44664 L p .778 .714 .791 r
F P
0 g
s
.36652 .56583 m .38355 .51851 L .31756 .48487 L p .812 .689 .728 r
F P
0 g
s
.64525 .62616 m .64676 .669 L .73524 .63927 L p .547 .347 .56 r
F P
0 g
s
.73524 .63927 m .73258 .596 L .64525 .62616 L p .547 .347 .56 r
F P
0 g
s
.31756 .48487 m .29194 .52904 L .36652 .56583 L p .812 .689 .728 r
F P
0 g
s
.35639 .6132 m .36652 .56583 L .29194 .52904 L p .838 .655 .655 r
F P
0 g
s
.54768 .71487 m .54865 .682 L .44859 .67768 L p .691 .378 .441 r
F P
0 g
s
.54865 .682 m .54768 .71487 L .64211 .70263 L p .599 .302 .436 r
F P
0 g
s
.64211 .70263 m .64676 .669 L .54865 .682 L p .599 .302 .436 r
F P
0 g
s
.38929 .41796 m .35103 .44664 L .40592 .47552 L p .728 .732 .854 r
F P
0 g
s
.40592 .47552 m .43166 .44086 L .38929 .41796 L p .728 .732 .854 r
F P
0 g
s
.4944 .42768 m .48257 .45417 L .53719 .45688 L p .647 .757 .929 r
F P
0 g
s
.53719 .45688 m .53315 .42962 L .4944 .42768 L p .647 .757 .929 r
F P
0 g
s
.53315 .42962 m .53719 .45688 L .59055 .44877 L p .657 .763 .928 r
F P
0 g
s
.35639 .6132 m .35425 .65623 L .44859 .67768 L p .783 .537 .564 r
F P
0 g
s
.45134 .7108 m .44859 .67768 L .35425 .65623 L p .772 .441 .426 r
F P
0 g
s
.44859 .67768 m .45134 .7108 L .54768 .71487 L p .691 .378 .441 r
F P
0 g
s
.29194 .52904 m .27665 .5751 L .35639 .6132 L p .838 .655 .655 r
F P
0 g
s
.35425 .65623 m .35639 .6132 L .27665 .5751 L p .856 .603 .555 r
F P
0 g
s
.45842 .41811 m .43166 .44086 L .48257 .45417 L p .64 .748 .927 r
F P
0 g
s
.48257 .45417 m .4944 .42768 L .45842 .41811 L p .64 .748 .927 r
F P
0 g
s
.67008 .46243 m .69829 .50329 L .75568 .46322 L p .589 .571 .801 r
F P
0 g
s
.69829 .50329 m .71979 .54921 L .78499 .50528 L p .545 .483 .738 r
F P
0 g
s
.78499 .50528 m .75568 .46322 L .69829 .50329 L p .545 .483 .738 r
F P
0 g
s
.71979 .54921 m .73258 .596 L .8025 .55044 L p .491 .384 .659 r
F P
0 g
s
.8025 .55044 m .78499 .50528 L .71979 .54921 L p .491 .384 .659 r
F P
0 g
s
.59055 .44877 m .57096 .42379 L .53315 .42962 L p .657 .763 .928 r
F P
0 g
s
.57096 .42379 m .59055 .44877 L .63772 .43046 L p .667 .767 .925 r
F P
0 g
s
.67008 .46243 m .63772 .43046 L .59055 .44877 L p .654 .666 .849 r
F P
0 g
s
.63772 .43046 m .67008 .46243 L .7175 .42815 L p .632 .661 .86 r
F P
0 g
s
.75568 .46322 m .7175 .42815 L .67008 .46243 L p .589 .571 .801 r
F P
0 g
s
.64676 .669 m .64211 .70263 L .72714 .67464 L p .476 .195 .408 r
F P
0 g
s
.72714 .67464 m .73524 .63927 L .64676 .669 L p .476 .195 .408 r
F P
0 g
s
.42878 .40175 m .38929 .41796 L .43166 .44086 L p .636 .739 .923 r
F P
0 g
s
.43166 .44086 m .45842 .41811 L .42878 .40175 L p .636 .739 .923 r
F P
0 g
s
.73258 .596 m .73524 .63927 L .80616 .59433 L p .414 .248 .545 r
F P
0 g
s
.80616 .59433 m .8025 .55044 L .73258 .596 L p .414 .248 .545 r
F P
0 g
s
.31223 .40768 m .27015 .43914 L .31756 .48487 L p .805 .763 .813 r
F P
0 g
s
.31756 .48487 m .35103 .44664 L .31223 .40768 L p .805 .763 .813 r
F P
0 g
s
.29194 .52904 m .31756 .48487 L .27015 .43914 L p .859 .757 .749 r
F P
0 g
s
.27665 .5751 m .27342 .61866 L .35425 .65623 L p .856 .603 .555 r
F P
0 g
s
.36059 .6906 m .35425 .65623 L .27342 .61866 L p .854 .5 .38 r
F P
0 g
s
.35425 .65623 m .36059 .6906 L .45134 .7108 L p .772 .441 .426 r
F P
0 g
s
.35989 .38731 m .31223 .40768 L .35103 .44664 L p .737 .756 .868 r
F P
0 g
s
.35103 .44664 m .38929 .41796 L .35989 .38731 L p .737 .756 .868 r
F P
0 g
s
.63772 .43046 m .60415 .41067 L .57096 .42379 L p .667 .767 .925 r
F P
0 g
s
.60415 .41067 m .63772 .43046 L .67403 .40338 L p .677 .768 .92 r
F P
0 g
s
.7175 .42815 m .67403 .40338 L .63772 .43046 L p .632 .661 .86 r
F P
0 g
s
.54548 .73419 m .54768 .71487 L .45134 .7108 L p .606 .163 .172 r
F P
0 g
s
.54768 .71487 m .54548 .73419 L .63146 .72318 L p .483 .058 .156 r
F P
0 g
s
.63146 .72318 m .64211 .70263 L .54768 .71487 L p .483 .058 .156 r
F P
0 g
s
.27015 .43914 m .23769 .47877 L .29194 .52904 L p .859 .757 .749 r
F P
0 g
s
.27665 .5751 m .29194 .52904 L .23769 .47877 L p .904 .736 .664 r
F P
0 g
s
.45771 .73052 m .45134 .7108 L .36059 .6906 L p .694 .221 .124 r
F P
0 g
s
.45134 .7108 m .45771 .73052 L .54548 .73419 L p .606 .163 .172 r
F P
0 g
s
.50556 .41597 m .4944 .42768 L .53315 .42962 L p .45 .8 .998 r
F P
0 g
s
.55248 .41358 m .52933 .41717 L p .53934 .41876 L .531 .857 .996 r
F P
0 g
s
.57096 .42379 m .55248 .41358 L p .53934 .41876 L .531 .857 .996 r
F P
0 g
s
.57267 .40551 m .55248 .41358 L p .56486 .41288 L .629 .896 .986 r
F P
0 g
s
.60415 .41067 m .57267 .40551 L p .56486 .41288 L .629 .896 .986 r
F P
0 g
s
.57267 .40551 m .58779 .39376 L p .58146 .39723 L .616 .954 .813 r
F P
0 g
s
.55248 .41358 m .57267 .40551 L p .56721 .40775 L 0 0 0 r
F P
0 g
s
.52933 .41717 m .53315 .42962 L .57096 .42379 L p .531 .857 .996 r
F P
0 g
s
.55248 .41358 m .57096 .42379 L .60415 .41067 L p .629 .896 .986 r
F P
0 g
s
.53714 .4201 m .55248 .41358 L p .56721 .40775 L 0 0 0 r
F P
0 g
s
.52933 .41717 m .55248 .41358 L p .54844 .41484 L .07 0 0 r
F P
0 g
s
.53315 .42962 m .52933 .41717 L p .51222 .41927 L .45 .8 .998 r
F P
0 g
s
.55248 .41358 m .53714 .4201 L .52614 .4218 L p .07 0 0 r
F P
0 g
s
.54668 .41629 m .53714 .4201 L p .54284 .41776 L 0 0 0 r
F P
0 g
s
.57267 .40551 m .54668 .41629 L p .54284 .41776 L 0 0 0 r
F P
0 g
s
.54668 .41629 m .57267 .40551 L p .58146 .39723 L .616 .954 .813 r
F P
0 g
s
.55375 .41077 m .54668 .41629 L p .55326 .41269 L .616 .954 .813 r
F P
0 g
s
.58779 .39376 m .55375 .41077 L p .55326 .41269 L .616 .954 .813 r
F P
0 g
s
.55375 .41077 m .55757 .4041 L p .55427 .40875 L .711 .893 .513 r
F P
0 g
s
.54668 .41629 m .55375 .41077 L p .55071 .41475 L 0 0 0 r
F P
0 g
s
.52936 .44268 m .54668 .41629 L p .55071 .41475 L 0 0 0 r
F P
0 g
s
.53119 .44126 m .52936 .44268 L p .53063 .44102 L 0 0 0 r
F P
0 g
s
.55375 .41077 m .53119 .44126 L p .53063 .44102 L 0 0 0 r
F P
0 g
s
.53119 .44126 m .55375 .41077 L p .55427 .40875 L .711 .893 .513 r
F P
0 g
s
.53217 .43956 m .53119 .44126 L p .53257 .43933 L .711 .893 .513 r
F P
0 g
s
.55757 .4041 m .53217 .43956 L p .53257 .43933 L .711 .893 .513 r
F P
0 g
s
.54668 .41629 m .52936 .44268 L .52687 .44367 L p .283 0 .116 r
F P
0 g
s
.53217 .43956 m .53217 .43775 L .53176 .43978 L p .887 .797 .31 r
F P
0 g
s
.53119 .44126 m .53217 .43956 L .53176 .44151 L p 0 0 .142 r
F P
0 g
s
.53176 .44151 m .5232 .48247 L .53119 .44126 L p 0 0 .142 r
F P
0 g
s
.53176 .43978 m .5232 .48247 L .53217 .43956 L p .887 .797 .31 r
F P
0 g
s
.52614 .4218 m .52933 .41717 L p .54844 .41484 L .07 0 0 r
F P
0 g
s
.52933 .41717 m .50556 .41597 L p .51222 .41927 L .45 .8 .998 r
F P
0 g
s
.48359 .41008 m .45842 .41811 L .4944 .42768 L p .41 .741 .993 r
F P
0 g
s
.50113 .42062 m .50556 .41597 L .48359 .41008 L p .41 .741 .993 r
F P
0 g
s
.50441 .41844 m .48359 .41008 L .50556 .41597 L p .311 0 0 r
F P
0 g
s
.49597 .41372 m .47068 .40232 L p .48359 .41008 L 0 .335 .733 r
F P
0 g
s
.47068 .40232 m .46566 .40006 L .48359 .41008 L p 0 .335 .733 r
F P
0 g
s
.4944 .42768 m .50113 .42062 L p .48359 .41008 L .41 .741 .993 r
F P
0 g
s
.40862 .38005 m .35989 .38731 L .38929 .41796 L p .635 .73 .917 r
F P
0 g
s
.38929 .41796 m .42878 .40175 L .40862 .38005 L p .635 .73 .917 r
F P
0 g
s
.64211 .70263 m .63146 .72318 L .70857 .69808 L p .291 0 .067 r
F P
0 g
s
.70857 .69808 m .72714 .67464 L .64211 .70263 L p .291 0 .067 r
F P
0 g
s
.46566 .40006 m .42878 .40175 L .45842 .41811 L p .414 .691 .977 r
F P
0 g
s
.45842 .41811 m .48359 .41008 L .46566 .40006 L p .414 .691 .977 r
F P
0 g
s
.23769 .47877 m .21822 .52286 L .27665 .5751 L p .904 .736 .664 r
F P
0 g
s
.27342 .61866 m .27665 .5751 L .21822 .52286 L p .938 .685 .528 r
F P
0 g
s
.73524 .63927 m .72714 .67464 L .79506 .63242 L p .273 .018 .333 r
F P
0 g
s
.79506 .63242 m .80616 .59433 L .73524 .63927 L p .273 .018 .333 r
F P
0 g
s
.67403 .40338 m .7175 .42815 L .7462 .38529 L p .61 .663 .876 r
F P
0 g
s
.7175 .42815 m .75568 .46322 L .79128 .41269 L p .536 .562 .828 r
F P
0 g
s
.79128 .41269 m .7462 .38529 L .7175 .42815 L p .536 .562 .828 r
F P
0 g
s
.75568 .46322 m .78499 .50528 L .82617 .44953 L p .453 .449 .764 r
F P
0 g
s
.82617 .44953 m .79128 .41269 L .75568 .46322 L p .453 .449 .764 r
F P
0 g
s
.57267 .40551 m .60415 .41067 L .62934 .3914 L p .713 .903 .963 r
F P
0 g
s
.67403 .40338 m .62934 .3914 L .60415 .41067 L p .677 .768 .92 r
F P
0 g
s
.62934 .3914 m .67403 .40338 L .69539 .36983 L p .684 .765 .913 r
F P
0 g
s
.7462 .38529 m .69539 .36983 L .67403 .40338 L p .61 .663 .876 r
F P
0 g
s
.78499 .50528 m .8025 .55044 L .84714 .49238 L p .345 .302 .667 r
F P
0 g
s
.84714 .49238 m .82617 .44953 L .78499 .50528 L p .345 .302 .667 r
F P
0 g
s
.27342 .61866 m .28303 .65527 L .36059 .6906 L p .854 .5 .38 r
F P
0 g
s
.37521 .71238 m .36059 .6906 L .28303 .65527 L p .741 .227 0 r
F P
0 g
s
.36059 .6906 m .37521 .71238 L .45771 .73052 L p .694 .221 .124 r
F P
0 g
s
.45369 .38688 m .40862 .38005 L .42878 .40175 L p .447 .653 .947 r
F P
0 g
s
.42878 .40175 m .46566 .40006 L .45369 .38688 L p .447 .653 .947 r
F P
0 g
s
.54221 .73705 m .54548 .73419 L .45771 .73052 L p .172 0 0 r
F P
0 g
s
.54548 .73419 m .54221 .73705 L .61557 .72767 L p .018 0 0 r
F P
0 g
s
.61557 .72767 m .63146 .72318 L .54548 .73419 L p .018 0 0 r
F P
0 g
s
.34713 .35168 m .29445 .36191 L .31223 .40768 L p .74 .78 .886 r
F P
0 g
s
.31223 .40768 m .35989 .38731 L .34713 .35168 L p .74 .78 .886 r
F P
0 g
s
.27015 .43914 m .31223 .40768 L .29445 .36191 L p .824 .82 .845 r
F P
0 g
s
.21822 .52286 m .2141 .56711 L .27342 .61866 L p .938 .685 .528 r
F P
0 g
s
.28303 .65527 m .27342 .61866 L .2141 .56711 L p .925 .545 .258 r
F P
0 g
s
.46724 .73393 m .45771 .73052 L .37521 .71238 L p .215 0 0 r
F P
0 g
s
.45771 .73052 m .46724 .73393 L .54221 .73705 L p .172 0 0 r
F P
0 g
s
.29445 .36191 m .24744 .38492 L .27015 .43914 L p .824 .82 .845 r
F P
0 g
s
.23769 .47877 m .27015 .43914 L .24744 .38492 L p .9 .844 .78 r
F P
0 g
s
.40037 .35509 m .34713 .35168 L .35989 .38731 L p .637 .722 .909 r
F P
0 g
s
.35989 .38731 m .40862 .38005 L .40037 .35509 L p .637 .722 .909 r
F P
0 g
s
.62934 .3914 m .58779 .39376 L .57267 .40551 L p .713 .903 .963 r
F P
0 g
s
.58779 .39376 m .62934 .3914 L .64372 .36777 L p .764 .879 .929 r
F P
0 g
s
.69539 .36983 m .64372 .36777 L .62934 .3914 L p .684 .765 .913 r
F P
0 g
s
.8025 .55044 m .80616 .59433 L .85154 .53701 L p .174 .075 .494 r
F P
0 g
s
.85154 .53701 m .84714 .49238 L .8025 .55044 L p .174 .075 .494 r
F P
0 g
s
.51483 .42123 m .50556 .41597 L .52933 .41717 L p .256 0 0 r
F P
0 g
s
.52933 .41717 m .52614 .4218 L .51483 .42123 L p .256 0 0 r
F P
0 g
s
.50556 .41597 m .51483 .42123 L .50441 .41844 L p .311 0 0 r
F P
0 g
s
.72714 .67464 m .70857 .69808 L .76971 .66037 L p 0 0 0 r
F P
0 g
s
.76971 .66037 m .79506 .63242 L .72714 .67464 L p 0 0 0 r
F P
0 g
s
.63146 .72318 m .61557 .72767 L .681 .70637 L p .243 .748 .701 r
F P
0 g
s
.681 .70637 m .70857 .69808 L .63146 .72318 L p .243 .748 .701 r
F P
0 g
s
.48359 .41008 m .49934 .41641 L p .49597 .41372 L 0 .335 .733 r
F P
0 g
s
.46566 .40006 m .48861 .4104 L p .49043 .40755 L .028 .406 .857 r
F P
0 g
s
.48861 .4104 m .49597 .41372 L .49043 .40755 L p .028 .406 .857 r
F P
0 g
s
.51467 .44044 m .49356 .4118 L p .49597 .41372 L .668 .188 0 r
F P
0 g
s
.49356 .4118 m .49043 .40755 L .49597 .41372 L p .668 .188 0 r
F P
0 g
s
.49934 .41641 m .50441 .41844 L .49597 .41372 L p 0 .335 .733 r
F P
0 g
s
.5161 .44202 m .49597 .41372 L .50441 .41844 L p .787 .293 .025 r
F P
0 g
s
.49597 .41372 m .51479 .44017 L p .51467 .44044 L .668 .188 0 r
F P
0 g
s
.51479 .44017 m .5161 .44202 L .51467 .44044 L p .668 .188 0 r
F P
0 g
s
.51467 .44044 m .5232 .48247 L .51458 .44065 L p .77 .498 0 r
F P
0 g
s
.49043 .40755 m .51309 .43829 L p .51417 .43866 L 0 .083 .642 r
F P
0 g
s
.51309 .43829 m .51467 .44044 L .51417 .43866 L p 0 .083 .642 r
F P
0 g
s
.51458 .44065 m .51417 .43866 L .51467 .44044 L p .77 .498 0 r
F P
0 g
s
.50441 .41844 m .5183 .44324 L .5161 .44202 L p .787 .293 .025 r
F P
0 g
s
.5161 .44202 m .5232 .48247 L .51467 .44044 L closepath p .952 .604 .288 r
F P
0 g
s
.51417 .43866 m .5232 .48247 L .51504 .43895 L p 0 0 .457 r
F P
0 g
s
.51504 .43895 m .51465 .43687 L .51417 .43866 L p 0 0 .457 r
F P
0 g
s
.51417 .43866 m .49174 .40551 L p .49043 .40755 L 0 .083 .642 r
F P
0 g
s
.49174 .40551 m .48841 .40058 L .49043 .40755 L p 0 .083 .642 r
F P
0 g
s
.24744 .38492 m .21087 .41872 L .23769 .47877 L p .9 .844 .78 r
F P
0 g
s
.21822 .52286 m .23769 .47877 L .21087 .41872 L p .968 .844 .666 r
F P
0 g
s
.44908 .37187 m .40037 .35509 L .40862 .38005 L p .492 .628 .911 r
F P
0 g
s
.40862 .38005 m .45369 .38688 L .44908 .37187 L p .492 .628 .911 r
F P
0 g
s
.64372 .36777 m .69539 .36983 L .69874 .333 L p .689 .76 .906 r
F P
0 g
s
.69539 .36983 m .7462 .38529 L .75187 .3377 L p .59 .671 .896 r
F P
0 g
s
.75187 .3377 m .69874 .333 L .69539 .36983 L p .59 .671 .896 r
F P
0 g
s
.7462 .38529 m .79128 .41269 L .79954 .35602 L p .473 .562 .865 r
F P
0 g
s
.79954 .35602 m .75187 .3377 L .7462 .38529 L p .473 .562 .865 r
F P
0 g
s
.49043 .40755 m .45369 .38688 L .46566 .40006 L p .028 .406 .857 r
F P
0 g
s
.28303 .65527 m .30508 .68075 L .37521 .71238 L p .741 .227 0 r
F P
0 g
s
.37521 .71238 m .397 .71849 L .46724 .73393 L p .215 0 0 r
F P
0 g
s
.397 .71849 m .37521 .71238 L .30508 .68075 L p 0 .418 .776 r
F P
0 g
s
.64372 .36777 m .59617 .37948 L .58779 .39376 L p .764 .879 .929 r
F P
0 g
s
.59617 .37948 m .64372 .36777 L .64533 .34212 L p .784 .839 .894 r
F P
0 g
s
.69874 .333 m .64533 .34212 L .64372 .36777 L p .689 .76 .906 r
F P
0 g
s
.55375 .41077 m .58779 .39376 L .59617 .37948 L p .831 .988 .87 r
F P
0 g
s
.80616 .59433 m .79506 .63242 L .83823 .5787 L p 0 0 .127 r
F P
0 g
s
.83823 .5787 m .85154 .53701 L .80616 .59433 L p 0 0 .127 r
F P
0 g
s
.79128 .41269 m .82617 .44953 L .83678 .38653 L p .317 .409 .799 r
F P
0 g
s
.83678 .38653 m .79954 .35602 L .79128 .41269 L p .317 .409 .799 r
F P
0 g
s
.2141 .56711 m .22637 .60689 L .28303 .65527 L p .925 .545 .258 r
F P
0 g
s
.30508 .68075 m .28303 .65527 L .22637 .60689 L p .645 .125 0 r
F P
0 g
s
.21087 .41872 m .18879 .46019 L .21822 .52286 L p .968 .844 .666 r
F P
0 g
s
.2141 .56711 m .21822 .52286 L .18879 .46019 L p .997 .772 .432 r
F P
0 g
s
.48841 .40058 m .44908 .37187 L .45369 .38688 L p .253 .452 .862 r
F P
0 g
s
.45369 .38688 m .49043 .40755 L .48841 .40058 L p .253 .452 .862 r
F P
0 g
s
.4054 .32945 m .35333 .31464 L .34713 .35168 L p .642 .716 .902 r
F P
0 g
s
.34713 .35168 m .40037 .35509 L .4054 .32945 L p .642 .716 .902 r
F P
0 g
s
.29445 .36191 m .34713 .35168 L .35333 .31464 L p .733 .802 .907 r
F P
0 g
s
.53817 .72206 m .54221 .73705 L .46724 .73393 L p .499 .807 1 r
F P
0 g
s
.54221 .73705 m .53817 .72206 L .59593 .71459 L p .547 .841 .998 r
F P
0 g
s
.59593 .71459 m .61557 .72767 L .54221 .73705 L p .547 .841 .998 r
F P
0 g
s
.45249 .35661 m .4054 .32945 L .40037 .35509 L p .539 .615 .877 r
F P
0 g
s
.40037 .35509 m .44908 .37187 L .45249 .35661 L p .539 .615 .877 r
F P
0 g
s
.70857 .69808 m .681 .70637 L .73229 .67455 L p .549 .93 .844 r
F P
0 g
s
.73229 .67455 m .76971 .66037 L .70857 .69808 L p .549 .93 .844 r
F P
0 g
s
.47906 .71957 m .46724 .73393 L .397 .71849 L p .473 .771 .996 r
F P
0 g
s
.46724 .73393 m .47906 .71957 L .53817 .72206 L p .499 .807 1 r
F P
0 g
s
.59617 .37948 m .55757 .4041 L .55375 .41077 L p .831 .988 .87 r
F P
0 g
s
.55757 .4041 m .59617 .37948 L .59675 .36413 L p .881 .91 .844 r
F P
0 g
s
.64533 .34212 m .59675 .36413 L .59617 .37948 L p .784 .839 .894 r
F P
0 g
s
.35333 .31464 m .3012 .31377 L .29445 .36191 L p .733 .802 .907 r
F P
0 g
s
.24744 .38492 m .29445 .36191 L .3012 .31377 L p .823 .881 .887 r
F P
0 g
s
.52102 .44396 m .51483 .42123 L .52614 .4218 L p .629 .207 .223 r
F P
0 g
s
.52614 .4218 m .52399 .44411 L .52102 .44396 L p .629 .207 .223 r
F P
0 g
s
.52399 .44411 m .52614 .4218 L .53714 .4201 L p .495 .093 .207 r
F P
0 g
s
.82617 .44953 m .84714 .49238 L .85931 .42647 L p .072 .16 .651 r
F P
0 g
s
.85931 .42647 m .83678 .38653 L .82617 .44953 L p .072 .16 .651 r
F P
0 g
s
.5183 .44324 m .50441 .41844 L .51483 .42123 L p .728 .275 .175 r
F P
0 g
s
.51483 .42123 m .52102 .44396 L .5183 .44324 L p .728 .275 .175 r
F P
0 g
s
.53714 .4201 m .52687 .44367 L .52399 .44411 L p .495 .093 .207 r
F P
0 g
s
.52687 .44367 m .53714 .4201 L .54668 .41629 L p .283 0 .116 r
F P
0 g
s
.49016 .39355 m .45249 .35661 L .44908 .37187 L p .407 .481 .824 r
F P
0 g
s
.44908 .37187 m .48841 .40058 L .49016 .39355 L p .407 .481 .824 r
F P
0 g
s
.61557 .72767 m .59593 .71459 L .6471 .69772 L p .606 .865 .992 r
F P
0 g
s
.6471 .69772 m .681 .70637 L .61557 .72767 L p .606 .865 .992 r
F P
0 g
s
.59675 .36413 m .64533 .34212 L .6335 .31721 L p .783 .794 .862 r
F P
0 g
s
.64533 .34212 m .69874 .333 L .68265 .2968 L p .691 .753 .898 r
F P
0 g
s
.68265 .2968 m .6335 .31721 L .64533 .34212 L p .691 .753 .898 r
F P
0 g
s
.69874 .333 m .75187 .3377 L .73211 .29038 L p .574 .687 .918 r
F P
0 g
s
.73211 .29038 m .68265 .2968 L .69874 .333 L p .574 .687 .918 r
F P
0 g
s
.79506 .63242 m .76971 .66037 L .80797 .61266 L p .601 .865 .525 r
F P
0 g
s
.80797 .61266 m .83823 .5787 L .79506 .63242 L p .601 .865 .525 r
F P
0 g
s
.3012 .31377 m .25415 .3273 L .24744 .38492 L p .823 .881 .887 r
F P
0 g
s
.21087 .41872 m .24744 .38492 L .25415 .3273 L p .909 .946 .815 r
F P
0 g
s
.59675 .36413 m .55769 .39701 L .55757 .4041 L p .881 .91 .844 r
F P
0 g
s
.55769 .39701 m .59675 .36413 L .58928 .34938 L p .863 .821 .805 r
F P
0 g
s
.6335 .31721 m .58928 .34938 L .59675 .36413 L p .783 .794 .862 r
F P
0 g
s
.18879 .46019 m .18411 .50521 L .2141 .56711 L p .997 .772 .432 r
F P
0 g
s
.22637 .60689 m .2141 .56711 L .18411 .50521 L p .812 .466 0 r
F P
0 g
s
.30508 .68075 m .33778 .69172 L .397 .71849 L p 0 .418 .776 r
F P
0 g
s
.4239 .70731 m .397 .71849 L .33778 .69172 L p .472 .738 .986 r
F P
0 g
s
.397 .71849 m .4239 .70731 L .47906 .71957 L p .473 .771 .996 r
F P
0 g
s
.22637 .60689 m .25439 .63766 L .30508 .68075 L p .645 .125 0 r
F P
0 g
s
.33778 .69172 m .30508 .68075 L .25439 .63766 L p .06 .475 .888 r
F P
0 g
s
.53217 .43956 m .55757 .4041 L .55769 .39701 L p .959 .944 .699 r
F P
0 g
s
.49553 .38724 m .46376 .34279 L .45249 .35661 L p .51 .507 .789 r
F P
0 g
s
.45249 .35661 m .49016 .39355 L .49553 .38724 L p .51 .507 .789 r
F P
0 g
s
.4054 .32945 m .45249 .35661 L .46376 .34279 L p .582 .614 .849 r
F P
0 g
s
.46376 .34279 m .42367 .30598 L .4054 .32945 L p .582 .614 .849 r
F P
0 g
s
.35333 .31464 m .4054 .32945 L .42367 .30598 L p .649 .714 .895 r
F P
0 g
s
.51465 .43687 m .49016 .39355 L .48841 .40058 L p .211 .276 .713 r
F P
0 g
s
.48841 .40058 m .51417 .43866 L .51465 .43687 L p .211 .276 .713 r
F P
0 g
s
.84714 .49238 m .85154 .53701 L .86405 .47189 L p 0 0 .3 r
F P
0 g
s
.86405 .47189 m .85931 .42647 L .84714 .49238 L p 0 0 .3 r
F P
0 g
s
.75187 .3377 m .79954 .35602 L .77698 .29909 L p .4 .575 .909 r
F P
0 g
s
.77698 .29909 m .73211 .29038 L .75187 .3377 L p .4 .575 .909 r
F P
0 g
s
.55769 .39701 m .53217 .43775 L .53217 .43956 L p .959 .944 .699 r
F P
0 g
s
.53217 .43775 m .55769 .39701 L .55406 .39025 L p .937 .827 .711 r
F P
0 g
s
.58928 .34938 m .55406 .39025 L .55769 .39701 L p .863 .821 .805 r
F P
0 g
s
.55406 .39025 m .58928 .34938 L .57441 .3369 L p .826 .746 .776 r
F P
0 g
s
.58928 .34938 m .6335 .31721 L .60906 .29591 L p .768 .752 .838 r
F P
0 g
s
.60906 .29591 m .57441 .3369 L .58928 .34938 L p .768 .752 .838 r
F P
0 g
s
.51606 .43528 m .49553 .38724 L .49016 .39355 L p .419 .376 .704 r
F P
0 g
s
.49016 .39355 m .51465 .43687 L .51606 .43528 L p .419 .376 .704 r
F P
0 g
s
.42367 .30598 m .37888 .28035 L .35333 .31464 L p .649 .714 .895 r
F P
0 g
s
.3012 .31377 m .35333 .31464 L .37888 .28035 L p .716 .818 .929 r
F P
0 g
s
.681 .70637 m .6471 .69772 L .68664 .6727 L p .663 .873 .978 r
F P
0 g
s
.68664 .6727 m .73229 .67455 L .681 .70637 L p .663 .873 .978 r
F P
0 g
s
.6335 .31721 m .68265 .2968 L .64792 .26552 L p .69 .744 .892 r
F P
0 g
s
.64792 .26552 m .60906 .29591 L .6335 .31721 L p .69 .744 .892 r
F P
0 g
s
.55406 .39025 m .53121 .43604 L .53217 .43775 L p .937 .827 .711 r
F P
0 g
s
.53121 .43604 m .55406 .39025 L .54704 .38457 L p .873 .726 .697 r
F P
0 g
s
.57441 .3369 m .54704 .38457 L .55406 .39025 L p .826 .746 .776 r
F P
0 g
s
.25415 .3273 m .21719 .3544 L .21087 .41872 L p .909 .946 .815 r
F P
0 g
s
.18879 .46019 m .21087 .41872 L .21719 .3544 L p .945 .939 .603 r
F P
0 g
s
.5338 .68988 m .53817 .72206 L .47906 .71957 L p .664 .746 .911 r
F P
0 g
s
.53817 .72206 m .5338 .68988 L .57469 .68449 L p .654 .739 .912 r
F P
0 g
s
.57469 .68449 m .59593 .71459 L .53817 .72206 L p .654 .739 .912 r
F P
0 g
s
.50397 .38235 m .48175 .332 L .46376 .34279 L p .584 .534 .765 r
F P
0 g
s
.46376 .34279 m .49553 .38724 L .50397 .38235 L p .584 .534 .765 r
F P
0 g
s
.42367 .30598 m .46376 .34279 L .48175 .332 L p .622 .621 .829 r
F P
0 g
s
.51825 .43405 m .50397 .38235 L .49553 .38724 L p .54 .44 .69 r
F P
0 g
s
.49553 .38724 m .51606 .43528 L .51825 .43405 L p .54 .44 .69 r
F P
0 g
s
.49189 .68808 m .47906 .71957 L .4239 .70731 L p .672 .754 .913 r
F P
0 g
s
.47906 .71957 m .49189 .68808 L .5338 .68988 L p .664 .746 .911 r
F P
0 g
s
.54704 .38457 m .52938 .43461 L .53121 .43604 L p .873 .726 .697 r
F P
0 g
s
.52938 .43461 m .54704 .38457 L .53737 .38061 L p .811 .651 .685 r
F P
0 g
s
.54704 .38457 m .57441 .3369 L .55371 .32815 L p .784 .687 .757 r
F P
0 g
s
.55371 .32815 m .53737 .38061 L .54704 .38457 L p .784 .687 .757 r
F P
0 g
s
.52399 .44411 m .5232 .48247 L .52102 .44396 L closepath p .7 .405 .473 r
F P
0 g
s
.52687 .44367 m .5232 .48247 L .52399 .44411 L closepath p .602 .324 .468 r
F P
0 g
s
.52102 .44396 m .5232 .48247 L .5183 .44324 L closepath p .788 .475 .459 r
F P
0 g
s
.52936 .44268 m .5232 .48247 L .52687 .44367 L closepath p .468 .212 .442 r
F P
0 g
s
.5183 .44324 m .5232 .48247 L .5161 .44202 L closepath p .878 .544 .415 r
F P
0 g
s
.57441 .3369 m .60906 .29591 L .57449 .28088 L p .746 .714 .822 r
F P
0 g
s
.57449 .28088 m .55371 .32815 L .57441 .3369 L p .746 .714 .822 r
F P
0 g
s
.53119 .44126 m .5232 .48247 L .52936 .44268 L closepath p .24 .021 .367 r
F P
0 g
s
.52099 .43332 m .51457 .37944 L .50397 .38235 L p .624 .492 .681 r
F P
0 g
s
.50397 .38235 m .51825 .43405 L .52099 .43332 L p .624 .492 .681 r
F P
0 g
s
.48175 .332 m .50397 .38235 L .51457 .37944 L p .643 .564 .751 r
F P
0 g
s
.79954 .35602 m .83678 .38653 L .81237 .3227 L p .096 .352 .82 r
F P
0 g
s
.81237 .3227 m .77698 .29909 L .79954 .35602 L p .096 .352 .82 r
F P
0 g
s
.18411 .50521 m .19805 .54897 L .22637 .60689 L p .812 .466 0 r
F P
0 g
s
.25439 .63766 m .22637 .60689 L .19805 .54897 L p 0 .12 .669 r
F P
0 g
s
.59593 .71459 m .57469 .68449 L .61064 .67234 L p .644 .734 .915 r
F P
0 g
s
.61064 .67234 m .6471 .69772 L .59593 .71459 L p .644 .734 .915 r
F P
0 g
s
.76971 .66037 m .73229 .67455 L .76364 .63463 L p .761 .984 .907 r
F P
0 g
s
.76364 .63463 m .80797 .61266 L .76971 .66037 L p .761 .984 .907 r
F P
0 g
s
.53737 .38061 m .52687 .43361 L .52938 .43461 L p .811 .651 .685 r
F P
0 g
s
.52687 .43361 m .53737 .38061 L .52613 .37883 L p .751 .591 .678 r
F P
0 g
s
.53737 .38061 m .55371 .32815 L .52948 .32421 L p .74 .639 .747 r
F P
0 g
s
.52948 .32421 m .52613 .37883 L .53737 .38061 L p .74 .639 .747 r
F P
0 g
s
.48175 .332 m .45352 .2875 L .42367 .30598 L p .622 .621 .829 r
F P
0 g
s
.37888 .28035 m .42367 .30598 L .45352 .2875 L p .657 .713 .89 r
F P
0 g
s
.52397 .43317 m .52613 .37883 L .51457 .37944 L p .691 .54 .677 r
F P
0 g
s
.51457 .37944 m .52099 .43332 L .52397 .43317 L p .691 .54 .677 r
F P
0 g
s
.50453 .32554 m .51457 .37944 L .52613 .37883 L p .694 .599 .745 r
F P
0 g
s
.51457 .37944 m .50453 .32554 L .48175 .332 L p .643 .564 .751 r
F P
0 g
s
.52613 .37883 m .52397 .43317 L .52687 .43361 L p .751 .591 .678 r
F P
0 g
s
.52613 .37883 m .52948 .32421 L .50453 .32554 L p .694 .599 .745 r
F P
0 g
s
.45352 .2875 m .48175 .332 L .50453 .32554 L p .658 .635 .816 r
F P
0 g
s
.53121 .43604 m .5232 .48247 L .53217 .43775 L closepath p .991 .787 .531 r
F P
0 g
s
.51465 .43687 m .5232 .48247 L .51606 .43528 L closepath p .284 .186 .563 r
F P
0 g
s
.37888 .28035 m .33354 .2687 L .3012 .31377 L p .716 .818 .929 r
F P
0 g
s
.25415 .3273 m .3012 .31377 L .33354 .2687 L p .782 .932 .931 r
F P
0 g
s
.68265 .2968 m .73211 .29038 L .68743 .24905 L p .566 .711 .939 r
F P
0 g
s
.68743 .24905 m .64792 .26552 L .68265 .2968 L p .566 .711 .939 r
F P
0 g
s
.52938 .43461 m .5232 .48247 L .53121 .43604 L closepath p .911 .683 .579 r
F P
0 g
s
.85154 .53701 m .83823 .5787 L .84972 .51785 L p .802 .804 .315 r
F P
0 g
s
.84972 .51785 m .86405 .47189 L .85154 .53701 L p .802 .804 .315 r
F P
0 g
s
.51606 .43528 m .5232 .48247 L .51825 .43405 L closepath p .478 .32 .587 r
F P
0 g
s
.55371 .32815 m .57449 .28088 L .53374 .27406 L p .72 .682 .813 r
F P
0 g
s
.53374 .27406 m .52948 .32421 L .55371 .32815 L p .72 .682 .813 r
F P
0 g
s
.52687 .43361 m .5232 .48247 L .52938 .43461 L closepath p .829 .6 .591 r
F P
0 g
s
.51825 .43405 m .5232 .48247 L .52099 .43332 L closepath p .595 .404 .593 r
F P
0 g
s
.25439 .63766 m .29564 .6555 L .33778 .69172 L p .06 .475 .888 r
F P
0 g
s
.37787 .68617 m .33778 .69172 L .29564 .6555 L p .491 .711 .968 r
F P
0 g
s
.33778 .69172 m .37787 .68617 L .4239 .70731 L p .472 .738 .986 r
F P
0 g
s
.52397 .43317 m .5232 .48247 L .52687 .43361 L closepath p .755 .532 .594 r
F P
0 g
s
.52099 .43332 m .5232 .48247 L .52397 .43317 L closepath p .68 .47 .595 r
F P
0 g
s
.45296 .67923 m .4239 .70731 L .37787 .68617 L p .677 .764 .917 r
F P
0 g
s
.4239 .70731 m .45296 .67923 L .49189 .68808 L p .672 .754 .913 r
F P
0 g
s
.49172 .27637 m .50453 .32554 L .52948 .32421 L p .69 .656 .811 r
F P
0 g
s
.50453 .32554 m .49172 .27637 L .45352 .2875 L p .658 .635 .816 r
F P
0 g
s
.52948 .32421 m .53374 .27406 L .49172 .27637 L p .69 .656 .811 r
F P
0 g
s
.60906 .29591 m .64792 .26552 L .59795 .24325 L p .687 .735 .888 r
F P
0 g
s
.59795 .24325 m .57449 .28088 L .60906 .29591 L p .687 .735 .888 r
F P
0 g
s
.21719 .3544 m .19474 .39273 L .18879 .46019 L p .945 .939 .603 r
F P
0 g
s
.18411 .50521 m .18879 .46019 L .19474 .39273 L p .722 .646 .088 r
F P
0 g
s
.42172 .25309 m .45352 .2875 L .49172 .27637 L p .665 .716 .886 r
F P
0 g
s
.45352 .2875 m .42172 .25309 L .37888 .28035 L p .657 .713 .89 r
F P
0 g
s
.6471 .69772 m .61064 .67234 L .638 .65447 L p .633 .733 .92 r
F P
0 g
s
.638 .65447 m .68664 .6727 L .6471 .69772 L p .633 .733 .92 r
F P
0 g
s
.33354 .2687 m .37888 .28035 L .42172 .25309 L p .688 .824 .948 r
F P
0 g
s
.52962 .64369 m .5338 .68988 L .49189 .68808 L p .704 .676 .82 r
F P
0 g
s
.5338 .68988 m .52962 .64369 L .55442 .64032 L p .67 .651 .822 r
F P
0 g
s
.55442 .64032 m .57469 .68449 L .5338 .68988 L p .67 .651 .822 r
F P
0 g
s
.83678 .38653 m .85931 .42647 L .83391 .35937 L p 0 0 .479 r
F P
0 g
s
.83391 .35937 m .81237 .3227 L .83678 .38653 L p 0 0 .479 r
F P
0 g
s
.50417 .64257 m .49189 .68808 L .45296 .67923 L p .735 .708 .826 r
F P
0 g
s
.49189 .68808 m .50417 .64257 L .52962 .64369 L p .704 .676 .82 r
F P
0 g
s
.57449 .28088 m .59795 .24325 L .53856 .2331 L p .681 .727 .885 r
F P
0 g
s
.53856 .2331 m .53374 .27406 L .57449 .28088 L p .681 .727 .885 r
F P
0 g
s
.19805 .54897 m .22973 .58637 L .25439 .63766 L p 0 .12 .669 r
F P
0 g
s
.29564 .6555 m .25439 .63766 L .22973 .58637 L p .257 .512 .905 r
F P
0 g
s
.73211 .29038 m .77698 .29909 L .72362 .24888 L p .322 .604 .949 r
F P
0 g
s
.72362 .24888 m .68743 .24905 L .73211 .29038 L p .322 .604 .949 r
F P
0 g
s
.5232 .48247 m .53136 .53004 L .52948 .53143 L closepath p .396 .262 .579 r
F P
0 g
s
.5232 .48247 m .53236 .52837 L .53136 .53004 L closepath p .122 .078 .53 r
F P
0 g
s
.5232 .48247 m .52949 .52354 L .53137 .52494 L closepath p .922 .578 .368 r
F P
0 g
s
.5232 .48247 m .52948 .53143 L .52692 .53239 L closepath p .542 .365 .591 r
F P
0 g
s
.5232 .48247 m .52692 .52257 L .52949 .52354 L closepath p .832 .509 .442 r
F P
0 g
s
.5232 .48247 m .52692 .53239 L .52395 .53282 L closepath p .64 .438 .594 r
F P
0 g
s
.5232 .48247 m .52394 .52214 L .52692 .52257 L closepath p .744 .44 .468 r
F P
0 g
s
.5232 .48247 m .52091 .53268 L .5181 .53197 L closepath p .791 .564 .593 r
F P
0 g
s
.5232 .48247 m .52395 .53282 L .52091 .53268 L closepath p .718 .501 .595 r
F P
0 g
s
.5232 .48247 m .52087 .52228 L .52394 .52214 L closepath p .653 .367 .472 r
F P
0 g
s
.5232 .48247 m .5181 .53197 L .51585 .53078 L closepath p .869 .639 .587 r
F P
0 g
s
.5232 .48247 m .51806 .523 L .52087 .52228 L closepath p .542 .274 .458 r
F P
0 g
s
.5232 .48247 m .51585 .53078 L .51438 .52924 L closepath p .955 .733 .564 r
F P
0 g
s
.5232 .48247 m .51581 .5242 L .51806 .523 L closepath p .373 .132 .414 r
F P
0 g
s
.51386 .5275 m .5232 .48247 L .51479 .52705 L p .993 .827 .459 r
F P
0 g
s
.51479 .52705 m .51438 .52924 L .51386 .5275 L p .993 .827 .459 r
F P
0 g
s
.48829 .56199 m .51271 .52805 L p .51386 .5275 L .882 .961 .626 r
F P
0 g
s
.51436 .52575 m .5232 .48247 L .5143 .52539 L p 0 0 0 r
F P
0 g
s
.5143 .52539 m .51386 .5275 L .51436 .52575 L p 0 0 0 r
F P
0 g
s
.51271 .52805 m .51436 .52575 L .51386 .5275 L p .882 .961 .626 r
F P
0 g
s
.51386 .5275 m .49008 .56327 L p .48829 .56199 L .882 .961 .626 r
F P
0 g
s
.49008 .56327 m .48646 .56871 L .48829 .56199 L p .882 .961 .626 r
F P
0 g
s
.4592 .57378 m .48573 .56017 L p .48829 .56199 L .705 .984 .821 r
F P
0 g
s
.51436 .52575 m .49174 .55719 L p .49395 .55595 L 0 0 0 r
F P
0 g
s
.49174 .55719 m .48829 .56199 L .49395 .55595 L p 0 0 0 r
F P
0 g
s
.49395 .55595 m .51443 .5262 L p .51436 .52575 L 0 0 0 r
F P
0 g
s
.48646 .56871 m .51386 .5275 L .51438 .52924 L p .963 .892 .709 r
F P
0 g
s
.51438 .52924 m .4886 .57538 L .48646 .56871 L p .963 .892 .709 r
F P
0 g
s
.4886 .57538 m .51438 .52924 L .51585 .53078 L p .909 .776 .703 r
F P
0 g
s
.51581 .5242 m .49395 .55595 L .50284 .55127 L p .14 0 .05 r
F P
0 g
s
.47851 .56361 m .4971 .55418 L p .49395 .55595 L .34 .79 .64 r
F P
0 g
s
.4971 .55418 m .50284 .55127 L .49395 .55595 L p .34 .79 .64 r
F P
0 g
s
.48573 .56017 m .49395 .55595 L .48829 .56199 L p .705 .984 .821 r
F P
0 g
s
.51443 .5262 m .51581 .5242 L .51436 .52575 L p 0 0 0 r
F P
0 g
s
.5232 .48247 m .51436 .52575 L .51581 .5242 L closepath p .045 0 .285 r
F P
0 g
s
.53193 .52623 m .5232 .48247 L .53237 .52661 L p 0 0 .306 r
F P
0 g
s
.53137 .52494 m .53237 .52661 L .53194 .52455 L p .929 .595 .146 r
F P
0 g
s
.53194 .52455 m .5232 .48247 L .53137 .52494 L p .929 .595 .146 r
F P
0 g
s
.53137 .52494 m .52949 .52354 L p .53081 .52533 L .784 .285 0 r
F P
0 g
s
.53237 .52661 m .53137 .52494 L p .5328 .52699 L 0 0 .477 r
F P
0 g
s
.55941 .5653 m .53237 .52661 L p .5328 .52699 L 0 0 .477 r
F P
0 g
s
.53237 .52661 m .53236 .52837 L .53193 .52623 L p 0 0 .306 r
F P
0 g
s
.55928 .57208 m .53236 .52837 L .53237 .52661 L p .016 .179 .69 r
F P
0 g
s
.53237 .52661 m .55941 .5653 L .55928 .57208 L p .016 .179 .69 r
F P
0 g
s
.5556 .55883 m .55941 .5653 L p .55583 .56013 L 0 0 .477 r
F P
0 g
s
.53137 .52494 m .5556 .55883 L p .55583 .56013 L 0 0 .477 r
F P
0 g
s
.5556 .55883 m .53137 .52494 L p .53081 .52533 L .784 .285 0 r
F P
0 g
s
.5482 .5534 m .5556 .55883 L p .55225 .5543 L .784 .285 0 r
F P
0 g
s
.52949 .52354 m .5482 .5534 L p .55225 .5543 L .784 .285 0 r
F P
0 g
s
.53136 .53004 m .55525 .57845 L .54781 .58373 L p .481 .407 .696 r
F P
0 g
s
.55525 .57845 m .53136 .53004 L .53236 .52837 L p .32 .325 .709 r
F P
0 g
s
.53236 .52837 m .55928 .57208 L .55525 .57845 L p .32 .325 .709 r
F P
0 g
s
.5482 .5534 m .53802 .54961 L p .54426 .55251 L .381 0 0 r
F P
0 g
s
.5556 .55883 m .5482 .5534 L p .55537 .55756 L 0 .305 .745 r
F P
0 g
s
.59401 .58 m .5556 .55883 L p .55537 .55756 L 0 .305 .745 r
F P
0 g
s
.57807 .56823 m .59401 .58 L p .58679 .57581 L 0 .305 .745 r
F P
0 g
s
.5482 .5534 m .57807 .56823 L p .58679 .57581 L 0 .305 .745 r
F P
0 g
s
.57807 .56823 m .5482 .5534 L p .54426 .55251 L .381 0 0 r
F P
0 g
s
.60199 .59388 m .55941 .5653 L .5556 .55883 L p .077 .398 .854 r
F P
0 g
s
.5556 .55883 m .59401 .58 L .60199 .59388 L p .077 .398 .854 r
F P
0 g
s
.55583 .55998 m .57807 .56823 L p .57174 .56528 L .381 0 0 r
F P
0 g
s
.53802 .54961 m .55583 .55998 L p .57174 .56528 L .381 0 0 r
F P
0 g
s
.52692 .53239 m .53776 .58736 L .52618 .58899 L p .658 .515 .678 r
F P
0 g
s
.53776 .58736 m .52692 .53239 L .52948 .53143 L p .583 .465 .684 r
F P
0 g
s
.52948 .53143 m .54781 .58373 L .53776 .58736 L p .583 .465 .684 r
F P
0 g
s
.54781 .58373 m .52948 .53143 L .53136 .53004 L p .481 .407 .696 r
F P
0 g
s
.52618 .58899 m .52395 .53282 L .52692 .53239 L p .658 .515 .678 r
F P
0 g
s
.5298 .55625 m .55583 .55998 L p .55113 .55806 L .384 0 0 r
F P
0 g
s
.52618 .54791 m .5298 .55625 L p .55113 .55806 L .384 0 0 r
F P
0 g
s
.51429 .58845 m .52091 .53268 L .52395 .53282 L p .722 .565 .677 r
F P
0 g
s
.52395 .53282 m .52618 .58899 L .51429 .58845 L p .722 .565 .677 r
F P
0 g
s
.50332 .58579 m .5181 .53197 L .52091 .53268 L p .782 .62 .68 r
F P
0 g
s
.52091 .53268 m .51429 .58845 L .50332 .58579 L p .782 .62 .68 r
F P
0 g
s
.49444 .58127 m .51585 .53078 L .5181 .53197 L p .844 .688 .689 r
F P
0 g
s
.5181 .53197 m .50332 .58579 L .49444 .58127 L p .844 .688 .689 r
F P
0 g
s
.51585 .53078 m .49444 .58127 L .4886 .57538 L p .909 .776 .703 r
F P
0 g
s
.51399 .54848 m .50298 .55751 L .5298 .55625 L p .265 0 0 r
F P
0 g
s
.5298 .55625 m .50298 .55751 L p .51031 .5546 L .383 .808 .969 r
F P
0 g
s
.52394 .52214 m .52618 .54791 L .53802 .54961 L p .686 .257 .224 r
F P
0 g
s
.55583 .55998 m .53802 .54961 L .52618 .54791 L p .384 0 0 r
F P
0 g
s
.5298 .55625 m .52618 .54791 L .51399 .54848 L p .265 0 0 r
F P
0 g
s
.5345 .54498 m .5298 .55625 L p .51031 .5546 L .383 .808 .969 r
F P
0 g
s
.55583 .55998 m .5298 .55625 L p .54125 .55511 L .314 .743 .972 r
F P
0 g
s
.57885 .55137 m .55583 .55998 L p .54125 .55511 L .314 .743 .972 r
F P
0 g
s
.57807 .56823 m .55583 .55998 L p .57005 .56126 L .309 .694 .978 r
F P
0 g
s
.61642 .56546 m .57807 .56823 L p .57005 .56126 L .309 .694 .978 r
F P
0 g
s
.73229 .67455 m .68664 .6727 L .7101 .64163 L p .705 .863 .957 r
F P
0 g
s
.7101 .64163 m .76364 .63463 L .73229 .67455 L p .705 .863 .957 r
F P
0 g
s
.33354 .2687 m .29219 .2728 L .25415 .3273 L p .782 .932 .931 r
F P
0 g
s
.21719 .3544 m .25415 .3273 L .29219 .2728 L p .791 .998 .801 r
F P
0 g
s
.57469 .68449 m .55442 .64032 L .57606 .63276 L p .632 .631 .832 r
F P
0 g
s
.57606 .63276 m .61064 .67234 L .57469 .68449 L p .632 .631 .832 r
F P
0 g
s
.4772 .23655 m .49172 .27637 L .53374 .27406 L p .674 .721 .885 r
F P
0 g
s
.49172 .27637 m .4772 .23655 L .42172 .25309 L p .665 .716 .886 r
F P
0 g
s
.83823 .5787 m .80797 .61266 L .81732 .55896 L p .916 .979 .742 r
F P
0 g
s
.81732 .55896 m .84972 .51785 L .83823 .5787 L p .916 .979 .742 r
F P
0 g
s
.53374 .27406 m .53856 .2331 L .4772 .23655 L p .674 .721 .885 r
F P
0 g
s
.29564 .6555 m .34575 .65783 L .37787 .68617 L p .491 .711 .968 r
F P
0 g
s
.42082 .66407 m .37787 .68617 L .34575 .65783 L p .678 .775 .923 r
F P
0 g
s
.37787 .68617 m .42082 .66407 L .45296 .67923 L p .677 .764 .917 r
F P
0 g
s
.64792 .26552 m .68743 .24905 L .62198 .21937 L p .569 .74 .956 r
F P
0 g
s
.62198 .21937 m .59795 .24325 L .64792 .26552 L p .569 .74 .956 r
F P
0 g
s
.48062 .63705 m .45296 .67923 L .42082 .66407 L p .761 .747 .84 r
F P
0 g
s
.45296 .67923 m .48062 .63705 L .50417 .64257 L p .735 .708 .826 r
F P
0 g
s
.19474 .39273 m .18996 .43852 L .18411 .50521 L p .722 .646 .088 r
F P
0 g
s
.19805 .54897 m .18411 .50521 L .18996 .43852 L p 0 0 .485 r
F P
0 g
s
.61064 .67234 m .57606 .63276 L .5923 .62173 L p .588 .619 .85 r
F P
0 g
s
.5923 .62173 m .638 .65447 L .61064 .67234 L p .588 .619 .85 r
F P
0 g
s
.52618 .58899 m .52962 .64369 L .50417 .64257 L p .718 .62 .747 r
F P
0 g
s
.52962 .64369 m .52618 .58899 L .53776 .58736 L p .668 .581 .749 r
F P
0 g
s
.53776 .58736 m .55442 .64032 L .52962 .64369 L p .668 .581 .749 r
F P
0 g
s
.51429 .58845 m .50417 .64257 L .48062 .63705 L p .765 .665 .753 r
F P
0 g
s
.50417 .64257 m .51429 .58845 L .52618 .58899 L p .718 .62 .747 r
F P
0 g
s
.38924 .23251 m .42172 .25309 L .4772 .23655 L p .652 .817 .963 r
F P
0 g
s
.42172 .25309 m .38924 .23251 L .33354 .2687 L p .688 .824 .948 r
F P
0 g
s
.29219 .2728 m .33354 .2687 L .38924 .23251 L p .68 .944 .961 r
F P
0 g
s
.55442 .64032 m .53776 .58736 L .54781 .58373 L p .61 .547 .759 r
F P
0 g
s
.54781 .58373 m .57606 .63276 L .55442 .64032 L p .61 .547 .759 r
F P
0 g
s
.85931 .42647 m .86405 .47189 L .83846 .40551 L p .917 .644 .153 r
F P
0 g
s
.83846 .40551 m .83391 .35937 L .85931 .42647 L p .917 .644 .153 r
F P
0 g
s
.68664 .6727 m .638 .65447 L .6537 .63252 L p .622 .734 .927 r
F P
0 g
s
.6537 .63252 m .7101 .64163 L .68664 .6727 L p .622 .734 .927 r
F P
0 g
s
.22973 .58637 m .27599 .61279 L .29564 .6555 L p .257 .512 .905 r
F P
0 g
s
.34575 .65783 m .29564 .6555 L .27599 .61279 L p .52 .691 .946 r
F P
0 g
s
.42082 .66407 m .46138 .62765 L .48062 .63705 L p .761 .747 .84 r
F P
0 g
s
.50332 .58579 m .48062 .63705 L .46138 .62765 L p .81 .721 .767 r
F P
0 g
s
.48062 .63705 m .50332 .58579 L .51429 .58845 L p .765 .665 .753 r
F P
0 g
s
.34575 .65783 m .39887 .64393 L .42082 .66407 L p .678 .775 .923 r
F P
0 g
s
.46138 .62765 m .42082 .66407 L .39887 .64393 L p .781 .792 .862 r
F P
0 g
s
.77698 .29909 m .81237 .3227 L .75239 .26598 L p 0 .255 .735 r
F P
0 g
s
.75239 .26598 m .72362 .24888 L .77698 .29909 L p 0 .255 .735 r
F P
0 g
s
.29219 .2728 m .25942 .29305 L .21719 .3544 L p .791 .998 .801 r
F P
0 g
s
.19474 .39273 m .21719 .3544 L .25942 .29305 L p 0 0 0 r
F P
0 g
s
.59795 .24325 m .62198 .21937 L .5435 .20577 L p .586 .77 .967 r
F P
0 g
s
.5435 .20577 m .53856 .2331 L .59795 .24325 L p .586 .77 .967 r
F P
0 g
s
.80797 .61266 m .76364 .63463 L .77025 .59013 L p .837 .931 .892 r
F P
0 g
s
.77025 .59013 m .81732 .55896 L .80797 .61266 L p .837 .931 .892 r
F P
0 g
s
.50284 .55127 m .51806 .523 L .51581 .5242 L p .14 0 .05 r
F P
0 g
s
.46138 .62765 m .49444 .58127 L .50332 .58579 L p .81 .721 .767 r
F P
0 g
s
.5482 .5534 m .52949 .52354 L .52692 .52257 L p .771 .305 .139 r
F P
0 g
s
.57606 .63276 m .54781 .58373 L .55525 .57845 L p .54 .516 .778 r
F P
0 g
s
.55525 .57845 m .5923 .62173 L .57606 .63276 L p .54 .516 .778 r
F P
0 g
s
.51399 .54848 m .52087 .52228 L .51806 .523 L p .416 .028 .192 r
F P
0 g
s
.51806 .523 m .50284 .55127 L .51399 .54848 L p .416 .028 .192 r
F P
0 g
s
.52692 .52257 m .53802 .54961 L .5482 .5534 L p .771 .305 .139 r
F P
0 g
s
.53802 .54961 m .52692 .52257 L .52394 .52214 L p .686 .257 .224 r
F P
0 g
s
.52618 .54791 m .52394 .52214 L .52087 .52228 L p .574 .17 .238 r
F P
0 g
s
.52087 .52228 m .51399 .54848 L .52618 .54791 L p .574 .17 .238 r
F P
0 g
s
.4623 .21039 m .4772 .23655 L .53856 .2331 L p .615 .798 .969 r
F P
0 g
s
.4772 .23655 m .4623 .21039 L .38924 .23251 L p .652 .817 .963 r
F P
0 g
s
.44852 .61527 m .4886 .57538 L .49444 .58127 L p .852 .792 .792 r
F P
0 g
s
.49444 .58127 m .46138 .62765 L .44852 .61527 L p .852 .792 .792 r
F P
0 g
s
.39887 .64393 m .44852 .61527 L .46138 .62765 L p .781 .792 .862 r
F P
0 g
s
.18996 .43852 m .20416 .48674 L .19805 .54897 L p 0 0 .485 r
F P
0 g
s
.22973 .58637 m .19805 .54897 L .20416 .48674 L p .178 .311 .762 r
F P
0 g
s
.53856 .2331 m .5435 .20577 L .4623 .21039 L p .615 .798 .969 r
F P
0 g
s
.5923 .62173 m .55525 .57845 L .55928 .57208 L p .444 .486 .808 r
F P
0 g
s
.638 .65447 m .5923 .62173 L .60132 .60832 L p .538 .614 .876 r
F P
0 g
s
.60132 .60832 m .6537 .63252 L .638 .65447 L p .538 .614 .876 r
F P
0 g
s
.68743 .24905 m .72362 .24888 L .64412 .21253 L p .264 .65 .966 r
F P
0 g
s
.64412 .21253 m .62198 .21937 L .68743 .24905 L p .264 .65 .966 r
F P
0 g
s
.27599 .61279 m .33157 .62477 L .34575 .65783 L p .52 .691 .946 r
F P
0 g
s
.39887 .64393 m .34575 .65783 L .33157 .62477 L p .676 .784 .931 r
F P
0 g
s
.44353 .60116 m .48646 .56871 L .4886 .57538 L p .882 .88 .827 r
F P
0 g
s
.4886 .57538 m .44852 .61527 L .44353 .60116 L p .882 .88 .827 r
F P
0 g
s
.55928 .57208 m .60132 .60832 L .5923 .62173 L p .444 .486 .808 r
F P
0 g
s
.60132 .60832 m .55928 .57208 L .55941 .5653 L p .301 .452 .845 r
F P
0 g
s
.76364 .63463 m .7101 .64163 L .71406 .6074 L p .728 .841 .934 r
F P
0 g
s
.71406 .6074 m .77025 .59013 L .76364 .63463 L p .728 .841 .934 r
F P
0 g
s
.86405 .47189 m .84972 .51785 L .82473 .45602 L p .996 .846 .572 r
F P
0 g
s
.82473 .45602 m .83846 .40551 L .86405 .47189 L p .996 .846 .572 r
F P
0 g
s
.44715 .5868 m .48829 .56199 L .48646 .56871 L p .866 .971 .858 r
F P
0 g
s
.48646 .56871 m .44353 .60116 L .44715 .5868 L p .866 .971 .858 r
F P
0 g
s
.33157 .62477 m .38978 .62072 L .39887 .64393 L p .676 .784 .931 r
F P
0 g
s
.44852 .61527 m .39887 .64393 L .38978 .62072 L p .789 .842 .892 r
F P
0 g
s
.38978 .62072 m .44353 .60116 L .44852 .61527 L p .789 .842 .892 r
F P
0 g
s
.55941 .5653 m .60199 .59388 L .60132 .60832 L p .301 .452 .845 r
F P
0 g
s
.38924 .23251 m .35937 .22864 L .29219 .2728 L p .68 .944 .961 r
F P
0 g
s
.25942 .29305 m .29219 .2728 L .35937 .22864 L p .417 .826 .629 r
F P
0 g
s
.35937 .22864 m .38924 .23251 L .4623 .21039 L p .52 .895 .964 r
F P
0 g
s
.48829 .56199 m .44715 .5868 L .4592 .57378 L p .705 .984 .821 r
F P
0 g
s
.25942 .29305 m .23937 .32808 L .19474 .39273 L p 0 0 0 r
F P
0 g
s
.18996 .43852 m .19474 .39273 L .23937 .32808 L p 0 0 .311 r
F P
0 g
s
.20416 .48674 m .23628 .53166 L .22973 .58637 L p .178 .311 .762 r
F P
0 g
s
.27599 .61279 m .22973 .58637 L .23628 .53166 L p .404 .534 .874 r
F P
0 g
s
.6537 .63252 m .60132 .60832 L .60199 .59388 L p .48 .618 .909 r
F P
0 g
s
.81237 .3227 m .83391 .35937 L .77001 .29945 L p .812 .34 0 r
F P
0 g
s
.77001 .29945 m .75239 .26598 L .81237 .3227 L p .812 .34 0 r
F P
0 g
s
.7101 .64163 m .6537 .63252 L .65561 .60863 L p .613 .739 .935 r
F P
0 g
s
.65561 .60863 m .71406 .6074 L .7101 .64163 L p .613 .739 .935 r
F P
0 g
s
.48874 .54715 m .49747 .55351 L p .47851 .56361 L .5 .876 .976 r
F P
0 g
s
.49395 .55595 m .46513 .57074 L p .47851 .56361 L .34 .79 .64 r
F P
0 g
s
.50284 .55127 m .47851 .56361 L .50298 .55751 L p .029 0 0 r
F P
0 g
s
.49747 .55351 m .50298 .55751 L .47851 .56361 L p .5 .876 .976 r
F P
0 g
s
.46513 .57074 m .4592 .57378 L .47851 .56361 L p .34 .79 .64 r
F P
0 g
s
.60199 .59388 m .65561 .60863 L .6537 .63252 L p .48 .618 .909 r
F P
0 g
s
.62198 .21937 m .64412 .21253 L .54806 .19579 L p .268 .715 .959 r
F P
0 g
s
.54806 .19579 m .5435 .20577 L .62198 .21937 L p .268 .715 .959 r
F P
0 g
s
.39508 .59681 m .44715 .5868 L .44353 .60116 L p .774 .89 .927 r
F P
0 g
s
.44353 .60116 m .38978 .62072 L .39508 .59681 L p .774 .89 .927 r
F P
0 g
s
.50298 .55751 m .51399 .54848 L .50284 .55127 L p .029 0 0 r
F P
0 g
s
.84972 .51785 m .81732 .55896 L .79384 .50479 L p .93 .874 .76 r
F P
0 g
s
.79384 .50479 m .82473 .45602 L .84972 .51785 L p .93 .874 .76 r
F P
0 g
s
.23628 .53166 m .28277 .56769 L .27599 .61279 L p .404 .534 .874 r
F P
0 g
s
.33157 .62477 m .27599 .61279 L .28277 .56769 L p .554 .679 .922 r
F P
0 g
s
.44852 .20149 m .4623 .21039 L .5435 .20577 L p .361 .804 .956 r
F P
0 g
s
.4623 .21039 m .44852 .20149 L .35937 .22864 L p .52 .895 .964 r
F P
0 g
s
.65561 .60863 m .60199 .59388 L .59401 .58 L p .415 .633 .944 r
F P
0 g
s
.72362 .24888 m .75239 .26598 L .66184 .22465 L p .43 0 0 r
F P
0 g
s
.66184 .22465 m .64412 .21253 L .72362 .24888 L p .43 0 0 r
F P
0 g
s
.33799 .59029 m .39508 .59681 L .38978 .62072 L p .67 .792 .939 r
F P
0 g
s
.38978 .62072 m .33157 .62477 L .33799 .59029 L p .67 .792 .939 r
F P
0 g
s
.5435 .20577 m .54806 .19579 L .44852 .20149 L p .361 .804 .956 r
F P
0 g
s
.28277 .56769 m .33799 .59029 L .33157 .62477 L p .554 .679 .922 r
F P
0 g
s
.4148 .57488 m .4592 .57378 L .44715 .5868 L p .724 .922 .959 r
F P
0 g
s
.44715 .5868 m .39508 .59681 L .4148 .57488 L p .724 .922 .959 r
F P
0 g
s
.23937 .32808 m .23509 .37454 L .18996 .43852 L p 0 0 .311 r
F P
0 g
s
.20416 .48674 m .18996 .43852 L .23509 .37454 L p .249 .201 .606 r
F P
0 g
s
.35937 .22864 m .33551 .243 L .25942 .29305 L p .417 .826 .629 r
F P
0 g
s
.23937 .32808 m .25942 .29305 L .33551 .243 L p .091 0 .075 r
F P
0 g
s
.81732 .55896 m .77025 .59013 L .74935 .54571 L p .839 .853 .855 r
F P
0 g
s
.74935 .54571 m .79384 .50479 L .81732 .55896 L p .839 .853 .855 r
F P
0 g
s
.83391 .35937 m .83846 .40551 L .77373 .34618 L p .949 .634 .402 r
F P
0 g
s
.77373 .34618 m .77001 .29945 L .83391 .35937 L p .949 .634 .402 r
F P
0 g
s
.59401 .58 m .64289 .58538 L .65561 .60863 L p .415 .633 .944 r
F P
0 g
s
.64289 .58538 m .59401 .58 L .57807 .56823 L p .351 .658 .971 r
F P
0 g
s
.71406 .6074 m .65561 .60863 L .64289 .58538 L p .607 .746 .943 r
F P
0 g
s
.33551 .243 m .35937 .22864 L .44852 .20149 L p .015 0 0 r
F P
0 g
s
.4472 .55758 m .47851 .56361 L .4592 .57378 L p .628 .921 .977 r
F P
0 g
s
.4592 .57378 m .4148 .57488 L .4472 .55758 L p .628 .921 .977 r
F P
0 g
s
.77025 .59013 m .71406 .6074 L .69684 .57364 L p .736 .811 .911 r
F P
0 g
s
.69684 .57364 m .74935 .54571 L .77025 .59013 L p .736 .811 .911 r
F P
0 g
s
.64289 .58538 m .69684 .57364 L .71406 .6074 L p .607 .746 .943 r
F P
0 g
s
.57807 .56823 m .61642 .56546 L .64289 .58538 L p .351 .658 .971 r
F P
0 g
s
.36556 .55827 m .4148 .57488 L .39508 .59681 L p .661 .796 .947 r
F P
0 g
s
.39508 .59681 m .33799 .59029 L .36556 .55827 L p .661 .796 .947 r
F P
0 g
s
.23509 .37454 m .24779 .42724 L .20416 .48674 L p .249 .201 .606 r
F P
0 g
s
.23628 .53166 m .20416 .48674 L .24779 .42724 L p .404 .408 .75 r
F P
0 g
s
.47851 .56361 m .4472 .55758 L .48874 .54715 L p .5 .876 .976 r
F P
0 g
s
.64412 .21253 m .66184 .22465 L .55171 .20555 L p .432 0 0 r
F P
0 g
s
.55171 .20555 m .54806 .19579 L .64412 .21253 L p .432 0 0 r
F P
0 g
s
.55583 .55998 m .57885 .55137 L .61642 .56546 L p .309 .694 .978 r
F P
0 g
s
.75239 .26598 m .77001 .29945 L .67272 .25563 L p .805 .356 .173 r
F P
0 g
s
.67272 .25563 m .66184 .22465 L .75239 .26598 L p .805 .356 .173 r
F P
0 g
s
.50298 .55751 m .48874 .54715 L .5345 .54498 L p .383 .808 .969 r
F P
0 g
s
.5298 .55625 m .5345 .54498 L .57885 .55137 L p .314 .743 .972 r
F P
0 g
s
.83846 .40551 m .82473 .45602 L .76247 .40092 L p .925 .73 .62 r
F P
0 g
s
.76247 .40092 m .77373 .34618 L .83846 .40551 L p .925 .73 .62 r
F P
0 g
s
.69684 .57364 m .64289 .58538 L .61642 .56546 L p .604 .755 .951 r
F P
0 g
s
.31738 .52529 m .36556 .55827 L .33799 .59029 L p .588 .675 .901 r
F P
0 g
s
.33799 .59029 m .28277 .56769 L .31738 .52529 L p .588 .675 .901 r
F P
0 g
s
.24779 .42724 m .27636 .47971 L .23628 .53166 L p .404 .408 .75 r
F P
0 g
s
.28277 .56769 m .23628 .53166 L .27636 .47971 L p .506 .553 .838 r
F P
0 g
s
.43746 .21206 m .44852 .20149 L .54806 .19579 L p .293 0 0 r
F P
0 g
s
.44852 .20149 m .43746 .21206 L .33551 .243 L p .015 0 0 r
F P
0 g
s
.33551 .243 m .32085 .2751 L .23937 .32808 L p .091 0 .075 r
F P
0 g
s
.23509 .37454 m .23937 .32808 L .32085 .2751 L p .35 .141 .449 r
F P
0 g
s
.27636 .47971 m .31738 .52529 L .28277 .56769 L p .506 .553 .838 r
F P
0 g
s
.54806 .19579 m .55171 .20555 L .43746 .21206 L p .293 0 0 r
F P
0 g
s
.41216 .53274 m .4472 .55758 L .4148 .57488 L p .648 .797 .954 r
F P
0 g
s
.4148 .57488 m .36556 .55827 L .41216 .53274 L p .648 .797 .954 r
F P
0 g
s
.32085 .2751 m .33551 .243 L .43746 .21206 L p .409 .043 .229 r
F P
0 g
s
.82473 .45602 m .79384 .50479 L .73727 .45684 L p .874 .766 .74 r
F P
0 g
s
.73727 .45684 m .76247 .40092 L .82473 .45602 L p .874 .766 .74 r
F P
0 g
s
.74935 .54571 m .69684 .57364 L .65918 .54439 L p .731 .78 .892 r
F P
0 g
s
.61642 .56546 m .65918 .54439 L .69684 .57364 L p .604 .755 .951 r
F P
0 g
s
.65918 .54439 m .61642 .56546 L .57885 .55137 L p .606 .766 .956 r
F P
0 g
s
.79384 .50479 m .74935 .54571 L .70126 .50676 L p .812 .781 .823 r
F P
0 g
s
.70126 .50676 m .73727 .45684 L .79384 .50479 L p .812 .781 .823 r
F P
0 g
s
.65918 .54439 m .70126 .50676 L .74935 .54571 L p .731 .78 .892 r
F P
0 g
s
.32085 .2751 m .3177 .32206 L .23509 .37454 L p .35 .141 .449 r
F P
0 g
s
.24779 .42724 m .23509 .37454 L .3177 .32206 L p .466 .34 .625 r
F P
0 g
s
.77001 .29945 m .77373 .34618 L .67502 .30276 L p .852 .55 .477 r
F P
0 g
s
.67502 .30276 m .67272 .25563 L .77001 .29945 L p .852 .55 .477 r
F P
0 g
s
.47273 .51721 m .48874 .54715 L .4472 .55758 L p .635 .793 .958 r
F P
0 g
s
.4472 .55758 m .41216 .53274 L .47273 .51721 L p .635 .793 .958 r
F P
0 g
s
.66184 .22465 m .67272 .25563 L .55395 .23533 L p .709 .296 .262 r
F P
0 g
s
.55395 .23533 m .55171 .20555 L .66184 .22465 L p .709 .296 .262 r
F P
0 g
s
.37754 .49113 m .41216 .53274 L .36556 .55827 L p .62 .679 .884 r
F P
0 g
s
.36556 .55827 m .31738 .52529 L .37754 .49113 L p .62 .679 .884 r
F P
0 g
s
.57885 .55137 m .60471 .52351 L .65918 .54439 L p .606 .766 .956 r
F P
0 g
s
.60471 .52351 m .57885 .55137 L .5345 .54498 L p .612 .777 .96 r
F P
0 g
s
.5398 .51398 m .5345 .54498 L .48874 .54715 L p .622 .787 .961 r
F P
0 g
s
.48874 .54715 m .47273 .51721 L .5398 .51398 L p .622 .787 .961 r
F P
0 g
s
.5345 .54498 m .5398 .51398 L .60471 .52351 L p .612 .777 .96 r
F P
0 g
s
.43063 .24225 m .43746 .21206 L .55171 .20555 L p .585 .199 .276 r
F P
0 g
s
.43746 .21206 m .43063 .24225 L .32085 .2751 L p .409 .043 .229 r
F P
0 g
s
.3177 .32206 m .32699 .37856 L .24779 .42724 L p .466 .34 .625 r
F P
0 g
s
.27636 .47971 m .24779 .42724 L .32699 .37856 L p .533 .47 .731 r
F P
0 g
s
.55171 .20555 m .55395 .23533 L .43063 .24225 L p .585 .199 .276 r
F P
0 g
s
.70126 .50676 m .65918 .54439 L .60471 .52351 L p .718 .751 .878 r
F P
0 g
s
.34783 .43747 m .37754 .49113 L .31738 .52529 L p .581 .575 .812 r
F P
0 g
s
.31738 .52529 m .27636 .47971 L .34783 .43747 L p .581 .575 .812 r
F P
0 g
s
.3177 .32206 m .32085 .2751 L .43063 .24225 L p .538 .293 .492 r
F P
0 g
s
.32699 .37856 m .34783 .43747 L .27636 .47971 L p .533 .47 .731 r
F P
0 g
s
.77373 .34618 m .76247 .40092 L .66803 .36068 L p .839 .635 .626 r
F P
0 g
s
.66803 .36068 m .67502 .30276 L .77373 .34618 L p .839 .635 .626 r
F P
0 g
s
.45682 .47021 m .47273 .51721 L .41216 .53274 L p .649 .689 .873 r
F P
0 g
s
.41216 .53274 m .37754 .49113 L .45682 .47021 L p .649 .689 .873 r
F P
0 g
s
.67272 .25563 m .67502 .30276 L .5544 .28263 L p .756 .471 .501 r
F P
0 g
s
.5544 .28263 m .55395 .23533 L .67272 .25563 L p .756 .471 .501 r
F P
0 g
s
.73727 .45684 m .70126 .50676 L .63036 .47871 L p .776 .722 .802 r
F P
0 g
s
.60471 .52351 m .63036 .47871 L .70126 .50676 L p .718 .751 .878 r
F P
0 g
s
.63036 .47871 m .60471 .52351 L .5398 .51398 L p .699 .725 .87 r
F P
0 g
s
.76247 .40092 m .73727 .45684 L .65247 .42203 L p .813 .685 .723 r
F P
0 g
s
.65247 .42203 m .66803 .36068 L .76247 .40092 L p .813 .685 .723 r
F P
0 g
s
.63036 .47871 m .65247 .42203 L .73727 .45684 L p .776 .722 .802 r
F P
0 g
s
.54509 .46583 m .5398 .51398 L .47273 .51721 L p .676 .704 .869 r
F P
0 g
s
.47273 .51721 m .45682 .47021 L .54509 .46583 L p .676 .704 .869 r
F P
0 g
s
.43063 .24225 m .42914 .28949 L .3177 .32206 L p .538 .293 .492 r
F P
0 g
s
.32699 .37856 m .3177 .32206 L .42914 .28949 L p .592 .427 .627 r
F P
0 g
s
.42914 .28949 m .43063 .24225 L .55395 .23533 L p .658 .391 .505 r
F P
0 g
s
.5398 .51398 m .54509 .46583 L .63036 .47871 L p .699 .725 .87 r
F P
0 g
s
.4431 .41143 m .45682 .47021 L .37754 .49113 L p .64 .602 .795 r
F P
0 g
s
.37754 .49113 m .34783 .43747 L .4431 .41143 L p .64 .602 .795 r
F P
0 g
s
.55395 .23533 m .5544 .28263 L .42914 .28949 L p .658 .391 .505 r
F P
0 g
s
.42914 .28949 m .43345 .34841 L .32699 .37856 L p .592 .427 .627 r
F P
0 g
s
.34783 .43747 m .32699 .37856 L .43345 .34841 L p .622 .52 .718 r
F P
0 g
s
.67502 .30276 m .66803 .36068 L .55292 .34206 L p .761 .561 .627 r
F P
0 g
s
.55292 .34206 m .5544 .28263 L .67502 .30276 L p .761 .561 .627 r
F P
0 g
s
.43345 .34841 m .4431 .41143 L .34783 .43747 L p .622 .52 .718 r
F P
0 g
s
.65247 .42203 m .63036 .47871 L .54509 .46583 L p .735 .674 .791 r
F P
0 g
s
.54968 .40597 m .54509 .46583 L .45682 .47021 L p .69 .635 .789 r
F P
0 g
s
.45682 .47021 m .4431 .41143 L .54968 .40597 L p .69 .635 .789 r
F P
0 g
s
.43345 .34841 m .42914 .28949 L .5544 .28263 L p .683 .495 .627 r
F P
0 g
s
.54509 .46583 m .54968 .40597 L .65247 .42203 L p .735 .674 .791 r
F P
0 g
s
.66803 .36068 m .65247 .42203 L .54968 .40597 L p .753 .622 .714 r
F P
0 g
s
.54968 .40597 m .55292 .34206 L .66803 .36068 L p .753 .622 .714 r
F P
0 g
s
.5544 .28263 m .55292 .34206 L .43345 .34841 L p .683 .495 .627 r
F P
0 g
s
.55292 .34206 m .54968 .40597 L .4431 .41143 L p .691 .569 .713 r
F P
0 g
s
.4431 .41143 m .43345 .34841 L .55292 .34206 L p .691 .569 .713 r
F P
0 g
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.227012 0.39418 0.419395 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.310255 1.64675 -0.0117677 1.64675 [
[ 0 0 0 0 ]
[ 1 1.63498 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.63498 L
0 1.63498 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.46746 .49388 m .45165 .58857 L .53158 .59272 L p .718 .603 .727 r
F P
0 g
s
.53158 .59272 m .52623 .49701 L .46746 .49388 L p .718 .603 .727 r
F P
0 g
s
.53487 .6855 m .53158 .59272 L .45165 .58857 L p .72 .553 .663 r
F P
0 g
s
.52623 .49701 m .53158 .59272 L .60958 .58027 L p .671 .566 .728 r
F P
0 g
s
.53158 .59272 m .53487 .6855 L .62567 .67139 L p .66 .505 .664 r
F P
0 g
s
.62567 .67139 m .60958 .58027 L .53158 .59272 L p .66 .505 .664 r
F P
0 g
s
.41303 .4785 m .3774 .56816 L .45165 .58857 L p .762 .645 .732 r
F P
0 g
s
.45165 .58857 m .46746 .49388 L .41303 .4785 L p .762 .645 .732 r
F P
0 g
s
.44187 .68079 m .45165 .58857 L .3774 .56816 L p .778 .605 .666 r
F P
0 g
s
.45165 .58857 m .44187 .68079 L .53487 .6855 L p .72 .553 .663 r
F P
0 g
s
.48795 .40517 m .46746 .49388 L .52623 .49701 L p .71 .649 .787 r
F P
0 g
s
.52623 .49701 m .51928 .40688 L .48795 .40517 L p .71 .649 .787 r
F P
0 g
s
.51928 .40688 m .52623 .49701 L .58353 .48762 L p .677 .624 .789 r
F P
0 g
s
.60958 .58027 m .58353 .48762 L .52623 .49701 L p .671 .566 .728 r
F P
0 g
s
.45903 .39679 m .41303 .4785 L .46746 .49388 L p .74 .679 .792 r
F P
0 g
s
.46746 .49388 m .48795 .40517 L .45903 .39679 L p .74 .679 .792 r
F P
0 g
s
.58353 .48762 m .60958 .58027 L .67816 .55226 L p .618 .534 .737 r
F P
0 g
s
.60958 .58027 m .62567 .67139 L .70573 .63957 L p .589 .457 .669 r
F P
0 g
s
.70573 .63957 m .67816 .55226 L .60958 .58027 L p .589 .457 .669 r
F P
0 g
s
.53577 .76698 m .53487 .6855 L .44187 .68079 L p .716 .489 .581 r
F P
0 g
s
.53487 .6855 m .53577 .76698 L .63018 .75266 L p .64 .428 .58 r
F P
0 g
s
.63018 .75266 m .62567 .67139 L .53487 .6855 L p .64 .428 .58 r
F P
0 g
s
.58353 .48762 m .5498 .40176 L .51928 .40688 L p .677 .624 .789 r
F P
0 g
s
.5498 .40176 m .58353 .48762 L .63365 .46655 L p .642 .605 .797 r
F P
0 g
s
.67816 .55226 m .63365 .46655 L .58353 .48762 L p .618 .534 .737 r
F P
0 g
s
.3774 .56816 m .35534 .65764 L .44187 .68079 L p .778 .605 .666 r
F P
0 g
s
.43911 .76221 m .44187 .68079 L .35534 .65764 L p .787 .55 .579 r
F P
0 g
s
.44187 .68079 m .43911 .76221 L .53577 .76698 L p .716 .489 .581 r
F P
0 g
s
.36843 .45227 m .31613 .53321 L .3774 .56816 L p .805 .697 .745 r
F P
0 g
s
.3774 .56816 m .41303 .4785 L .36843 .45227 L p .805 .697 .745 r
F P
0 g
s
.35534 .65764 m .3774 .56816 L .31613 .53321 L p .837 .668 .673 r
F P
0 g
s
.43554 .38258 m .36843 .45227 L .41303 .4785 L p .766 .715 .804 r
F P
0 g
s
.41303 .4785 m .45903 .39679 L .43554 .38258 L p .766 .715 .804 r
F P
0 g
s
.62567 .67139 m .63018 .75266 L .71348 .72033 L p .546 .357 .576 r
F P
0 g
s
.71348 .72033 m .70573 .63957 L .62567 .67139 L p .546 .357 .576 r
F P
0 g
s
.63365 .46655 m .57633 .3903 L .5498 .40176 L p .642 .605 .797 r
F P
0 g
s
.57633 .3903 m .63365 .46655 L .67143 .43574 L p .604 .593 .813 r
F P
0 g
s
.63365 .46655 m .67816 .55226 L .73035 .51108 L p .555 .505 .755 r
F P
0 g
s
.73035 .51108 m .67143 .43574 L .63365 .46655 L p .555 .505 .755 r
F P
0 g
s
.51928 .40688 m .51134 .33075 L .48795 .40517 L closepath p .691 .699 .853 r
F P
0 g
s
.5498 .40176 m .51134 .33075 L .51928 .40688 L closepath p .677 .689 .854 r
F P
0 g
s
.67816 .55226 m .70573 .63957 L .76703 .59264 L p .496 .403 .679 r
F P
0 g
s
.76703 .59264 m .73035 .51108 L .67816 .55226 L p .496 .403 .679 r
F P
0 g
s
.48795 .40517 m .51134 .33075 L .45903 .39679 L closepath p .702 .712 .856 r
F P
0 g
s
.31613 .53321 m .28363 .61788 L .35534 .65764 L p .837 .668 .673 r
F P
0 g
s
.34912 .73869 m .35534 .65764 L .28363 .61788 L p .862 .62 .571 r
F P
0 g
s
.35534 .65764 m .34912 .73869 L .43911 .76221 L p .787 .55 .579 r
F P
0 g
s
.57633 .3903 m .51134 .33075 L .5498 .40176 L closepath p .663 .683 .858 r
F P
0 g
s
.45903 .39679 m .51134 .33075 L .43554 .38258 L closepath p .712 .726 .862 r
F P
0 g
s
.42002 .36395 m .33841 .41765 L .36843 .45227 L p .788 .757 .825 r
F P
0 g
s
.36843 .45227 m .43554 .38258 L .42002 .36395 L p .788 .757 .825 r
F P
0 g
s
.31613 .53321 m .36843 .45227 L .33841 .41765 L p .847 .76 .767 r
F P
0 g
s
.53414 .82923 m .53577 .76698 L .43911 .76221 L p .694 .386 .45 r
F P
0 g
s
.53577 .76698 m .53414 .82923 L .62229 .8161 L p .597 .306 .445 r
F P
0 g
s
.62229 .8161 m .63018 .75266 L .53577 .76698 L p .597 .306 .445 r
F P
0 g
s
.59608 .37366 m .51134 .33075 L .57633 .3903 L closepath p .649 .68 .866 r
F P
0 g
s
.67143 .43574 m .59608 .37366 L .57633 .3903 L p .604 .593 .813 r
F P
0 g
s
.33841 .41765 m .27433 .48678 L .31613 .53321 L p .847 .76 .767 r
F P
0 g
s
.28363 .61788 m .31613 .53321 L .27433 .48678 L p .9 .75 .685 r
F P
0 g
s
.44385 .82485 m .43911 .76221 L .34912 .73869 L p .781 .454 .435 r
F P
0 g
s
.43911 .76221 m .44385 .82485 L .53414 .82923 L p .694 .386 .45 r
F P
0 g
s
.70573 .63957 m .71348 .72033 L .77737 .67262 L p .408 .257 .563 r
F P
0 g
s
.77737 .67262 m .76703 .59264 L .70573 .63957 L p .408 .257 .563 r
F P
0 g
s
.43554 .38258 m .51134 .33075 L .42002 .36395 L closepath p .717 .742 .871 r
F P
0 g
s
.59608 .37366 m .67143 .43574 L .69265 .39813 L p .561 .588 .838 r
F P
0 g
s
.67143 .43574 m .73035 .51108 L .76029 .46047 L p .474 .478 .782 r
F P
0 g
s
.76029 .46047 m .69265 .39813 L .67143 .43574 L p .474 .478 .782 r
F P
0 g
s
.63018 .75266 m .62229 .8161 L .69997 .78649 L p .465 .193 .416 r
F P
0 g
s
.69997 .78649 m .71348 .72033 L .63018 .75266 L p .465 .193 .416 r
F P
0 g
s
.60685 .35352 m .51134 .33075 L .59608 .37366 L closepath p .636 .682 .877 r
F P
0 g
s
.69265 .39813 m .60685 .35352 L .59608 .37366 L p .561 .588 .838 r
F P
0 g
s
.73035 .51108 m .76703 .59264 L .80267 .53474 L p .354 .329 .692 r
F P
0 g
s
.80267 .53474 m .76029 .46047 L .73035 .51108 L p .354 .329 .692 r
F P
0 g
s
.42002 .36395 m .51134 .33075 L .41424 .34284 L closepath p .718 .757 .883 r
F P
0 g
s
.33841 .41765 m .42002 .36395 L .41424 .34284 L p .802 .804 .853 r
F P
0 g
s
.41424 .34284 m .32654 .37804 L .33841 .41765 L p .802 .804 .853 r
F P
0 g
s
.27433 .48678 m .33841 .41765 L .32654 .37804 L p .882 .841 .8 r
F P
0 g
s
.27433 .48678 m .23428 .56488 L .28363 .61788 L p .9 .75 .685 r
F P
0 g
s
.27445 .69829 m .28363 .61788 L .23428 .56488 L p .946 .708 .547 r
F P
0 g
s
.28363 .61788 m .27445 .69829 L .34912 .73869 L p .862 .62 .571 r
F P
0 g
s
.35986 .8033 m .34912 .73869 L .27445 .69829 L p .868 .518 .386 r
F P
0 g
s
.34912 .73869 m .35986 .8033 L .44385 .82485 L p .781 .454 .435 r
F P
0 g
s
.60737 .332 m .51134 .33075 L .60685 .35352 L closepath p .625 .689 .89 r
F P
0 g
s
.60685 .35352 m .69265 .39813 L .69455 .35754 L p .514 .593 .871 r
F P
0 g
s
.69455 .35754 m .60737 .332 L .60685 .35352 L p .514 .593 .871 r
F P
0 g
s
.57788 .29408 m .51134 .33075 L .5974 .31142 L closepath p .616 .716 .916 r
F P
0 g
s
.55089 .28198 m .51134 .33075 L .57788 .29408 L closepath p .621 .733 .927 r
F P
0 g
s
.51942 .27653 m .51134 .33075 L .55089 .28198 L closepath p .633 .751 .933 r
F P
0 g
s
.48703 .27837 m .51134 .33075 L .51942 .27653 L closepath p .649 .767 .935 r
F P
0 g
s
.4574 .2873 m .51134 .33075 L .48703 .27837 L closepath p .669 .778 .931 r
F P
0 g
s
.43386 .30225 m .51134 .33075 L .4574 .2873 L closepath p .688 .781 .922 r
F P
0 g
s
.41896 .32149 m .51134 .33075 L .43386 .30225 L closepath p .704 .778 .91 r
F P
0 g
s
.41424 .34284 m .51134 .33075 L .41896 .32149 L closepath p .714 .77 .896 r
F P
0 g
s
.5974 .31142 m .51134 .33075 L .60737 .332 L closepath p .618 .7 .903 r
F P
0 g
s
.32654 .37804 m .41424 .34284 L .41896 .32149 L p .799 .853 .89 r
F P
0 g
s
.69265 .39813 m .76029 .46047 L .76392 .40544 L p .358 .452 .82 r
F P
0 g
s
.76392 .40544 m .69455 .35754 L .69265 .39813 L p .358 .452 .82 r
F P
0 g
s
.32654 .37804 m .25706 .43329 L .27433 .48678 L p .882 .841 .8 r
F P
0 g
s
.23428 .56488 m .27433 .48678 L .25706 .43329 L p .96 .858 .695 r
F P
0 g
s
.71348 .72033 m .69997 .78649 L .75937 .74285 L p .24 0 .335 r
F P
0 g
s
.75937 .74285 m .77737 .67262 L .71348 .72033 L p .24 0 .335 r
F P
0 g
s
.76703 .59264 m .77737 .67262 L .81465 .61368 L p .155 .082 .515 r
F P
0 g
s
.81465 .61368 m .80267 .53474 L .76703 .59264 L p .155 .082 .515 r
F P
0 g
s
.60737 .332 m .69455 .35754 L .67633 .31835 L p .466 .612 .911 r
F P
0 g
s
.67633 .31835 m .5974 .31142 L .60737 .332 L p .466 .612 .911 r
F P
0 g
s
.52999 .86521 m .53414 .82923 L .44385 .82485 L p .606 .16 .165 r
F P
0 g
s
.53414 .82923 m .52999 .86521 L .6022 .85456 L p .47 .044 .148 r
F P
0 g
s
.6022 .85456 m .62229 .8161 L .53414 .82923 L p .47 .044 .148 r
F P
0 g
s
.45598 .86166 m .44385 .82485 L .35986 .8033 L p .701 .223 .111 r
F P
0 g
s
.44385 .82485 m .45598 .86166 L .52999 .86521 L p .606 .16 .165 r
F P
0 g
s
.33464 .33758 m .41896 .32149 L .43386 .30225 L p .77 .894 .931 r
F P
0 g
s
.41896 .32149 m .33464 .33758 L .32654 .37804 L p .799 .853 .89 r
F P
0 g
s
.25706 .43329 m .32654 .37804 L .33464 .33758 L p .889 .934 .841 r
F P
0 g
s
.23428 .56488 m .22295 .64437 L .27445 .69829 L p .946 .708 .547 r
F P
0 g
s
.29032 .76632 m .27445 .69829 L .22295 .64437 L p .938 .567 .251 r
F P
0 g
s
.27445 .69829 m .29032 .76632 L .35986 .8033 L p .868 .518 .386 r
F P
0 g
s
.62229 .8161 m .6022 .85456 L .6656 .83062 L p .252 0 .046 r
F P
0 g
s
.6656 .83062 m .69997 .78649 L .62229 .8161 L p .252 0 .046 r
F P
0 g
s
.5974 .31142 m .67633 .31835 L .63944 .28504 L p .423 .647 .951 r
F P
0 g
s
.63944 .28504 m .57788 .29408 L .5974 .31142 L p .423 .647 .951 r
F P
0 g
s
.76029 .46047 m .80267 .53474 L .80766 .47146 L p .096 .203 .687 r
F P
0 g
s
.80766 .47146 m .76392 .40544 L .76029 .46047 L p .096 .203 .687 r
F P
0 g
s
.25706 .43329 m .21337 .50352 L .23428 .56488 L p .96 .858 .695 r
F P
0 g
s
.22295 .64437 m .23428 .56488 L .21337 .50352 L p .998 .801 .45 r
F P
0 g
s
.36245 .30077 m .43386 .30225 L .4574 .2873 L p .702 .91 .968 r
F P
0 g
s
.43386 .30225 m .36245 .30077 L .33464 .33758 L p .77 .894 .931 r
F P
0 g
s
.69455 .35754 m .76392 .40544 L .73968 .35187 L p .184 .421 .856 r
F P
0 g
s
.73968 .35187 m .67633 .31835 L .69455 .35754 L p .184 .421 .856 r
F P
0 g
s
.38728 .84421 m .35986 .8033 L .29032 .76632 L p .745 .227 0 r
F P
0 g
s
.35986 .8033 m .38728 .84421 L .45598 .86166 L p .701 .223 .111 r
F P
0 g
s
.57788 .29408 m .63944 .28504 L .5877 .26161 L p .401 .698 .981 r
F P
0 g
s
.5877 .26161 m .55089 .28198 L .57788 .29408 L p .401 .698 .981 r
F P
0 g
s
.40732 .27193 m .4574 .2873 L .48703 .27837 L p .6 .888 .99 r
F P
0 g
s
.4574 .2873 m .40732 .27193 L .36245 .30077 L p .702 .91 .968 r
F P
0 g
s
.77737 .67262 m .75937 .74285 L .79381 .68905 L p 0 0 .103 r
F P
0 g
s
.79381 .68905 m .81465 .61368 L .77737 .67262 L p 0 0 .103 r
F P
0 g
s
.33464 .33758 m .26724 .37821 L .25706 .43329 L p .889 .934 .841 r
F P
0 g
s
.21337 .50352 m .25706 .43329 L .26724 .37821 L p .935 .957 .648 r
F P
0 g
s
.55089 .28198 m .5877 .26161 L .52696 .25102 L p .421 .763 .996 r
F P
0 g
s
.52696 .25102 m .51942 .27653 L .55089 .28198 L p .421 .763 .996 r
F P
0 g
s
.69997 .78649 m .6656 .83062 L .71371 .79547 L p 0 0 0 r
F P
0 g
s
.71371 .79547 m .75937 .74285 L .69997 .78649 L p 0 0 0 r
F P
0 g
s
.26724 .37821 m .33464 .33758 L .36245 .30077 L p .801 .997 .856 r
F P
0 g
s
.46436 .25461 m .48703 .27837 L .51942 .27653 L p .493 .832 .998 r
F P
0 g
s
.48703 .27837 m .46436 .25461 L .40732 .27193 L p .6 .888 .99 r
F P
0 g
s
.51942 .27653 m .52696 .25102 L .46436 .25461 L p .493 .832 .998 r
F P
0 g
s
.80267 .53474 m .81465 .61368 L .82007 .54918 L p 0 0 .313 r
F P
0 g
s
.82007 .54918 m .80766 .47146 L .80267 .53474 L p 0 0 .313 r
F P
0 g
s
.67633 .31835 m .73968 .35187 L .68922 .30601 L p 0 .374 .828 r
F P
0 g
s
.68922 .30601 m .63944 .28504 L .67633 .31835 L p 0 .374 .828 r
F P
0 g
s
.22295 .64437 m .24255 .71705 L .29032 .76632 L p .938 .567 .251 r
F P
0 g
s
.3307 .81435 m .29032 .76632 L .24255 .71705 L p .6 .103 0 r
F P
0 g
s
.29032 .76632 m .3307 .81435 L .38728 .84421 L p .745 .227 0 r
F P
0 g
s
.21337 .50352 m .20097 .58186 L .22295 .64437 L p .998 .801 .45 r
F P
0 g
s
.24255 .71705 m .22295 .64437 L .20097 .58186 L p .761 .455 0 r
F P
0 g
s
.76392 .40544 m .80766 .47146 L .77989 .40956 L p 0 0 .542 r
F P
0 g
s
.77989 .40956 m .73968 .35187 L .76392 .40544 L p 0 0 .542 r
F P
0 g
s
.52362 .86957 m .52999 .86521 L .45598 .86166 L p .149 0 0 r
F P
0 g
s
.52999 .86521 m .52362 .86957 L .57131 .86254 L p 0 0 0 r
F P
0 g
s
.57131 .86254 m .6022 .85456 L .52999 .86521 L p 0 0 0 r
F P
0 g
s
.47468 .86722 m .45598 .86166 L .38728 .84421 L p .194 0 0 r
F P
0 g
s
.45598 .86166 m .47468 .86722 L .52362 .86957 L p .149 0 0 r
F P
0 g
s
.3049 .32771 m .36245 .30077 L .40732 .27193 L p .517 .906 .766 r
F P
0 g
s
.36245 .30077 m .3049 .32771 L .26724 .37821 L p .801 .997 .856 r
F P
0 g
s
.26724 .37821 m .22458 .44003 L .21337 .50352 L p .935 .957 .648 r
F P
0 g
s
.20097 .58186 m .21337 .50352 L .22458 .44003 L p 0 0 0 r
F P
0 g
s
.6022 .85456 m .57131 .86254 L .61295 .8468 L p .315 .797 .737 r
F P
0 g
s
.61295 .8468 m .6656 .83062 L .6022 .85456 L p .315 .797 .737 r
F P
0 g
s
.75937 .74285 m .71371 .79547 L .74115 .75237 L p .713 .92 .577 r
F P
0 g
s
.74115 .75237 m .79381 .68905 L .75937 .74285 L p .713 .92 .577 r
F P
0 g
s
.22458 .44003 m .26724 .37821 L .3049 .32771 L p 0 0 0 r
F P
0 g
s
.63944 .28504 m .68922 .30601 L .61762 .27358 L p 0 .318 .677 r
F P
0 g
s
.61762 .27358 m .5877 .26161 L .63944 .28504 L p 0 .318 .677 r
F P
0 g
s
.38728 .84421 m .42941 .85573 L .47468 .86722 L p .194 0 0 r
F P
0 g
s
.42941 .85573 m .38728 .84421 L .3307 .81435 L p 0 .425 .808 r
F P
0 g
s
.81465 .61368 m .79381 .68905 L .79849 .63032 L p .874 .822 .346 r
F P
0 g
s
.79849 .63032 m .82007 .54918 L .81465 .61368 L p .874 .822 .346 r
F P
0 g
s
.40732 .27193 m .36669 .28788 L .3049 .32771 L p .517 .906 .766 r
F P
0 g
s
.36669 .28788 m .40732 .27193 L .46436 .25461 L p 0 0 0 r
F P
0 g
s
.6656 .83062 m .61295 .8468 L .64418 .82383 L p .626 .961 .863 r
F P
0 g
s
.64418 .82383 m .71371 .79547 L .6656 .83062 L p .626 .961 .863 r
F P
0 g
s
.80766 .47146 m .82007 .54918 L .79132 .48599 L p .922 .616 .14 r
F P
0 g
s
.79132 .48599 m .77989 .40956 L .80766 .47146 L p .922 .616 .14 r
F P
0 g
s
.5877 .26161 m .61762 .27358 L .53309 .25887 L p .283 0 0 r
F P
0 g
s
.53309 .25887 m .52696 .25102 L .5877 .26161 L p .283 0 0 r
F P
0 g
s
.20097 .58186 m .22241 .66007 L .24255 .71705 L p .761 .455 0 r
F P
0 g
s
.24255 .71705 m .29225 .77477 L .3307 .81435 L p .6 .103 0 r
F P
0 g
s
.29225 .77477 m .24255 .71705 L .22241 .66007 L p 0 .146 .69 r
F P
0 g
s
.73968 .35187 m .77989 .40956 L .72098 .35632 L p .762 .267 0 r
F P
0 g
s
.72098 .35632 m .68922 .30601 L .73968 .35187 L p .762 .267 0 r
F P
0 g
s
.44589 .26386 m .46436 .25461 L .52696 .25102 L p .149 0 0 r
F P
0 g
s
.46436 .25461 m .44589 .26386 L .36669 .28788 L p 0 0 0 r
F P
0 g
s
.52696 .25102 m .53309 .25887 L .44589 .26386 L p .149 0 0 r
F P
0 g
s
.39243 .83615 m .3307 .81435 L .29225 .77477 L p .101 .468 .891 r
F P
0 g
s
.3307 .81435 m .39243 .83615 L .42941 .85573 L p 0 .425 .808 r
F P
0 g
s
.22458 .44003 m .21242 .5171 L .20097 .58186 L p 0 0 0 r
F P
0 g
s
.22241 .66007 m .20097 .58186 L .21242 .5171 L p 0 0 .491 r
F P
0 g
s
.26825 .38153 m .3049 .32771 L .36669 .28788 L p .059 0 .001 r
F P
0 g
s
.3049 .32771 m .26825 .38153 L .22458 .44003 L p 0 0 0 r
F P
0 g
s
.21242 .5171 m .22458 .44003 L .26825 .38153 L p .001 0 .292 r
F P
0 g
s
.79381 .68905 m .74115 .75237 L .74424 .70559 L p .945 .956 .735 r
F P
0 g
s
.74424 .70559 m .79849 .63032 L .79381 .68905 L p .945 .956 .735 r
F P
0 g
s
.71371 .79547 m .64418 .82383 L .66154 .79588 L p .81 .979 .896 r
F P
0 g
s
.66154 .79588 m .74115 .75237 L .71371 .79547 L p .81 .979 .896 r
F P
0 g
s
.51558 .83973 m .52362 .86957 L .47468 .86722 L p .493 .805 1 r
F P
0 g
s
.52362 .86957 m .51558 .83973 L .5324 .83723 L p .555 .848 .998 r
F P
0 g
s
.5324 .83723 m .57131 .86254 L .52362 .86957 L p .555 .848 .998 r
F P
0 g
s
.49829 .83889 m .47468 .86722 L .42941 .85573 L p .461 .758 .994 r
F P
0 g
s
.48236 .83481 m .49829 .83889 L p .4945 .83982 L .461 .758 .994 r
F P
0 g
s
.42941 .85573 m .48236 .83481 L p .4945 .83982 L .461 .758 .994 r
F P
0 g
s
.46949 .82789 m .48236 .83481 L p .47743 .83488 L .459 .715 .979 r
F P
0 g
s
.39243 .83615 m .46949 .82789 L p .47743 .83488 L .459 .715 .979 r
F P
0 g
s
.46106 .81887 m .46949 .82789 L p .46394 .82694 L .481 .681 .954 r
F P
0 g
s
.3677 .81038 m .46106 .81887 L p .46394 .82694 L .481 .681 .954 r
F P
0 g
s
.45802 .80868 m .46106 .81887 L p .45548 .81681 L .515 .658 .924 r
F P
0 g
s
.35812 .78099 m .45802 .80868 L p .45548 .81681 L .515 .658 .924 r
F P
0 g
s
.45802 .80868 m .46073 .79844 L p .46022 .80163 L 0 0 .205 r
F P
0 g
s
.46106 .81887 m .45802 .80868 L p .45857 .81186 L .944 .72 .251 r
F P
0 g
s
.46106 .81887 m .3677 .81038 L .35812 .78099 L p .515 .658 .924 r
F P
0 g
s
.461 .82597 m .46106 .81887 L p .45857 .81186 L .944 .72 .251 r
F P
0 g
s
.45795 .8158 m .461 .82597 L p .46046 .82281 L .944 .72 .251 r
F P
0 g
s
.45802 .80868 m .45795 .8158 L p .46046 .82281 L .944 .72 .251 r
F P
0 g
s
.45795 .8158 m .45802 .80868 L p .46022 .80163 L 0 0 .205 r
F P
0 g
s
.45802 .80868 m .35812 .78099 L .36511 .75108 L p .553 .645 .895 r
F P
0 g
s
.36511 .75108 m .46073 .79844 L .45802 .80868 L p .553 .645 .895 r
F P
0 g
s
.46067 .80556 m .45795 .8158 L p .45846 .81262 L 0 0 .205 r
F P
0 g
s
.46073 .79844 m .46067 .80556 L p .45846 .81262 L 0 0 .205 r
F P
0 g
s
.46067 .80556 m .46073 .79844 L .46896 .78925 L p .172 .036 .443 r
F P
0 g
s
.46891 .79638 m .46067 .80556 L p .46219 .80258 L .172 .036 .443 r
F P
0 g
s
.46896 .78925 m .46891 .79638 L p .46219 .80258 L .172 .036 .443 r
F P
0 g
s
.48181 .78928 m .46891 .79638 L p .47128 .79377 L .429 .232 .51 r
F P
0 g
s
.48185 .78214 m .48181 .78928 L p .47128 .79377 L .429 .232 .51 r
F P
0 g
s
.49796 .78505 m .48181 .78928 L p .48477 .78719 L .571 .343 .532 r
F P
0 g
s
.49798 .7779 m .49796 .78505 L p .48477 .78719 L .571 .343 .532 r
F P
0 g
s
.51558 .77703 m .51559 .78417 L .49796 .78505 L p .669 .422 .539 r
F P
0 g
s
.49796 .78505 m .51559 .78417 L p .51328 .78255 L .526 .827 .999 r
F P
0 g
s
.47251 .69009 m .49798 .7779 L .48185 .78214 L p .657 .658 .84 r
F P
0 g
s
.48185 .78214 m .42545 .70278 L .47251 .69009 L p .657 .658 .84 r
F P
0 g
s
.48181 .78928 m .48185 .78214 L .49798 .7779 L p .571 .343 .532 r
F P
0 g
s
.52408 .68746 m .51558 .77703 L .49798 .7779 L p .686 .676 .835 r
F P
0 g
s
.49798 .7779 m .47251 .69009 L .52408 .68746 L p .686 .676 .835 r
F P
0 g
s
.49796 .78505 m .49798 .7779 L .51558 .77703 L p .669 .422 .539 r
F P
0 g
s
.47209 .75371 m .49796 .78505 L p .51328 .78255 L .526 .827 .999 r
F P
0 g
s
.48181 .78928 m .49796 .78505 L p .49405 .78405 L .596 .864 .993 r
F P
0 g
s
.3883 .72396 m .46896 .78925 L .46073 .79844 L p .59 .641 .87 r
F P
0 g
s
.46073 .79844 m .36511 .75108 L .3883 .72396 L p .59 .641 .87 r
F P
0 g
s
.42545 .70278 m .48185 .78214 L .46896 .78925 L p .624 .646 .851 r
F P
0 g
s
.46896 .78925 m .3883 .72396 L .42545 .70278 L p .624 .646 .851 r
F P
0 g
s
.46891 .79638 m .46896 .78925 L .48185 .78214 L p .429 .232 .51 r
F P
0 g
s
.42455 .7663 m .48181 .78928 L p .49405 .78405 L .596 .864 .993 r
F P
0 g
s
.46891 .79638 m .48181 .78928 L p .47674 .78917 L .667 .881 .978 r
F P
0 g
s
.38703 .7873 m .46891 .79638 L p .47674 .78917 L .667 .881 .978 r
F P
0 g
s
.46067 .80556 m .46891 .79638 L p .46325 .79734 L .721 .875 .953 r
F P
0 g
s
.29225 .77477 m .3677 .81038 L .39243 .83615 L p .101 .468 .891 r
F P
0 g
s
.46949 .82789 m .39243 .83615 L .3677 .81038 L p .481 .681 .954 r
F P
0 g
s
.3636 .8142 m .46067 .80556 L p .46325 .79734 L .721 .875 .953 r
F P
0 g
s
.45795 .8158 m .46067 .80556 L p .45504 .80763 L .753 .85 .923 r
F P
0 g
s
.35656 .84385 m .45795 .8158 L p .45504 .80763 L .753 .85 .923 r
F P
0 g
s
.46949 .82789 m .46106 .81887 L p .4626 .82183 L .964 .688 .46 r
F P
0 g
s
.46944 .83499 m .46949 .82789 L p .4626 .82183 L .964 .688 .46 r
F P
0 g
s
.48236 .83481 m .46949 .82789 L p .47185 .83046 L .876 .601 .518 r
F P
0 g
s
.48236 .83481 m .42941 .85573 L .39243 .83615 L p .459 .715 .979 r
F P
0 g
s
.48233 .84189 m .48236 .83481 L p .47185 .83046 L .876 .601 .518 r
F P
0 g
s
.49829 .83889 m .48236 .83481 L p .48528 .83686 L .791 .527 .538 r
F P
0 g
s
.47468 .86722 m .49829 .83889 L p .51332 .84125 L .493 .805 1 r
F P
0 g
s
.49827 .84598 m .49829 .83889 L p .48528 .83686 L .791 .527 .538 r
F P
0 g
s
.49829 .83889 m .51558 .83973 L p .51332 .84125 L .493 .805 1 r
F P
0 g
s
.57131 .86254 m .5324 .83723 L .54699 .83165 L p .629 .877 .988 r
F P
0 g
s
.54699 .83165 m .61295 .8468 L .57131 .86254 L p .629 .877 .988 r
F P
0 g
s
.68922 .30601 m .72098 .35632 L .63678 .31854 L p .778 .303 .107 r
F P
0 g
s
.63678 .31854 m .61762 .27358 L .68922 .30601 L p .778 .303 .107 r
F P
0 g
s
.82007 .54918 m .79849 .63032 L .77144 .57293 L p .993 .814 .561 r
F P
0 g
s
.77144 .57293 m .79132 .48599 L .82007 .54918 L p .993 .814 .561 r
F P
0 g
s
.4743 .92932 m .45448 1.02682 L .53043 1.03028 L p .716 .631 .762 r
F P
0 g
s
.53043 1.03028 m .52372 .93164 L .4743 .92932 L p .716 .631 .762 r
F P
0 g
s
.53515 1.13391 m .53043 1.03028 L .45448 1.02682 L p .721 .579 .695 r
F P
0 g
s
.52372 .93164 m .53043 1.03028 L .60453 1.0199 L p .671 .597 .764 r
F P
0 g
s
.53043 1.03028 m .53515 1.13391 L .6276 1.12139 L p .663 .534 .697 r
F P
0 g
s
.6276 1.12139 m .60453 1.0199 L .53043 1.03028 L p .663 .534 .697 r
F P
0 g
s
.42858 .91792 m .38398 1.0098 L .45448 1.02682 L p .757 .672 .768 r
F P
0 g
s
.45448 1.02682 m .4743 .92932 L .42858 .91792 L p .757 .672 .768 r
F P
0 g
s
.44048 1.12973 m .45448 1.02682 L .38398 1.0098 L p .776 .63 .7 r
F P
0 g
s
.45448 1.02682 m .44048 1.12973 L .53515 1.13391 L p .721 .579 .695 r
F P
0 g
s
.22241 .66007 m .27655 .72924 L .29225 .77477 L p 0 .146 .69 r
F P
0 g
s
.3677 .81038 m .29225 .77477 L .27655 .72924 L p .289 .494 .884 r
F P
0 g
s
.53747 1.23349 m .53515 1.13391 L .44048 1.12973 L p .719 .522 .622 r
F P
0 g
s
.53515 1.13391 m .53747 1.23349 L .63899 1.22019 L p .649 .466 .623 r
F P
0 g
s
.63899 1.22019 m .6276 1.12139 L .53515 1.13391 L p .649 .466 .623 r
F P
0 g
s
.77989 .40956 m .79132 .48599 L .73003 .43157 L p .936 .605 .381 r
F P
0 g
s
.73003 .43157 m .72098 .35632 L .77989 .40956 L p .936 .605 .381 r
F P
0 g
s
.38398 1.0098 m .35238 1.10919 L .44048 1.12973 L p .776 .63 .7 r
F P
0 g
s
.43356 1.22906 m .44048 1.12973 L .35238 1.10919 L p .786 .581 .623 r
F P
0 g
s
.44048 1.12973 m .43356 1.22906 L .53747 1.23349 L p .719 .522 .622 r
F P
0 g
s
.21242 .5171 m .23342 .60117 L .22241 .66007 L p 0 0 .491 r
F P
0 g
s
.27655 .72924 m .22241 .66007 L .23342 .60117 L p .229 .313 .743 r
F P
0 g
s
.61295 .8468 m .54699 .83165 L .55777 .82357 L p .695 .883 .967 r
F P
0 g
s
.55777 .82357 m .64418 .82383 L .61295 .8468 L p .695 .883 .967 r
F P
0 g
s
.60453 1.0199 m .57188 .92468 L .52372 .93164 L p .671 .597 .764 r
F P
0 g
s
.57188 .92468 m .60453 1.0199 L .66962 .99655 L p .621 .568 .774 r
F P
0 g
s
.60453 1.0199 m .6276 1.12139 L .70914 1.09315 L p .596 .49 .704 r
F P
0 g
s
.70914 1.09315 m .66962 .99655 L .60453 1.0199 L p .596 .49 .704 r
F P
0 g
s
.34069 .33521 m .36669 .28788 L .44589 .26386 L p .385 0 .17 r
F P
0 g
s
.36669 .28788 m .34069 .33521 L .26825 .38153 L p .059 0 .001 r
F P
0 g
s
.6276 1.12139 m .63899 1.22019 L .72871 1.19016 L p .564 .405 .624 r
F P
0 g
s
.72871 1.19016 m .70914 1.09315 L .6276 1.12139 L p .564 .405 .624 r
F P
0 g
s
.49827 .84598 m .4743 .92932 L .52372 .93164 L p .7 .686 .834 r
F P
0 g
s
.52372 .93164 m .51558 .84681 L .49827 .84598 L p .7 .686 .834 r
F P
0 g
s
.51558 .84681 m .52372 .93164 L .57188 .92468 L p .672 .666 .836 r
F P
0 g
s
.39123 .89852 m .32587 .98068 L .38398 1.0098 L p .796 .722 .782 r
F P
0 g
s
.38398 1.0098 m .42858 .91792 L .39123 .89852 L p .796 .722 .782 r
F P
0 g
s
.35238 1.10919 m .38398 1.0098 L .32587 .98068 L p .831 .692 .711 r
F P
0 g
s
.48233 .84189 m .42858 .91792 L .4743 .92932 L p .724 .712 .839 r
F P
0 g
s
.4743 .92932 m .49827 .84598 L .48233 .84189 L p .724 .712 .839 r
F P
0 g
s
.61762 .27358 m .63678 .31854 L .53702 .30136 L p .689 .252 .208 r
F P
0 g
s
.53702 .30136 m .53309 .25887 L .61762 .27358 L p .689 .252 .208 r
F P
0 g
s
.74115 .75237 m .66154 .79588 L .66284 .76583 L p .86 .909 .865 r
F P
0 g
s
.66284 .76583 m .74424 .70559 L .74115 .75237 L p .86 .909 .865 r
F P
0 g
s
.26825 .38153 m .25778 .45735 L .21242 .5171 L p .001 0 .292 r
F P
0 g
s
.23342 .60117 m .21242 .5171 L .25778 .45735 L p .283 .206 .59 r
F P
0 g
s
.57188 .92468 m .53243 .84431 L .51558 .84681 L p .672 .666 .836 r
F P
0 g
s
.53243 .84431 m .57188 .92468 L .61393 .90908 L p .641 .651 .844 r
F P
0 g
s
.66962 .99655 m .61393 .90908 L .57188 .92468 L p .621 .568 .774 r
F P
0 g
s
.32587 .98068 m .27931 1.07389 L .35238 1.10919 L p .831 .692 .711 r
F P
0 g
s
.33673 1.20722 m .35238 1.10919 L .27931 1.07389 L p .855 .65 .624 r
F P
0 g
s
.35238 1.10919 m .33673 1.20722 L .43356 1.22906 L p .786 .581 .623 r
F P
0 g
s
.43403 .30719 m .44589 .26386 L .53309 .25887 L p .566 .156 .224 r
F P
0 g
s
.44589 .26386 m .43403 .30719 L .34069 .33521 L p .385 0 .17 r
F P
0 g
s
.53711 1.31999 m .53747 1.23349 L .43356 1.22906 L p .709 .447 .528 r
F P
0 g
s
.53747 1.23349 m .53711 1.31999 L .63735 1.30725 L p .624 .379 .526 r
F P
0 g
s
.63735 1.30725 m .63899 1.22019 L .53747 1.23349 L p .624 .379 .526 r
F P
0 g
s
.25778 .45735 m .26825 .38153 L .34069 .33521 L p .359 .133 .428 r
F P
0 g
s
.64418 .82383 m .55777 .82357 L .56356 .81383 L p .739 .866 .939 r
F P
0 g
s
.56356 .81383 m .66154 .79588 L .64418 .82383 L p .739 .866 .939 r
F P
0 g
s
.46944 .83499 m .39123 .89852 L .42858 .91792 L p .744 .743 .85 r
F P
0 g
s
.42858 .91792 m .48233 .84189 L .46944 .83499 L p .744 .743 .85 r
F P
0 g
s
.61393 .90908 m .66962 .99655 L .71906 .96225 L p .561 .544 .793 r
F P
0 g
s
.66962 .99655 m .70914 1.09315 L .77162 1.05148 L p .509 .444 .719 r
F P
0 g
s
.77162 1.05148 m .71906 .96225 L .66962 .99655 L p .509 .444 .719 r
F P
0 g
s
.53309 .25887 m .53702 .30136 L .43403 .30719 L p .566 .156 .224 r
F P
0 g
s
.4345 1.31575 m .43356 1.22906 L .33673 1.20722 L p .786 .512 .521 r
F P
0 g
s
.43356 1.22906 m .4345 1.31575 L .53711 1.31999 L p .709 .447 .528 r
F P
0 g
s
.79849 .63032 m .74424 .70559 L .72165 .66016 L p .928 .841 .737 r
F P
0 g
s
.72165 .66016 m .77144 .57293 L .79849 .63032 L p .928 .841 .737 r
F P
0 g
s
.61393 .90908 m .54702 .83874 L .53243 .84431 L p .641 .651 .844 r
F P
0 g
s
.54702 .83874 m .61393 .90908 L .64548 .88631 L p .608 .642 .859 r
F P
0 g
s
.71906 .96225 m .64548 .88631 L .61393 .90908 L p .561 .544 .793 r
F P
0 g
s
.27655 .72924 m .35812 .78099 L .3677 .81038 L p .289 .494 .884 r
F P
0 g
s
.63899 1.22019 m .63735 1.30725 L .72591 1.27847 L p .517 .292 .513 r
F P
0 g
s
.72591 1.27847 m .72871 1.19016 L .63899 1.22019 L p .517 .292 .513 r
F P
0 g
s
.23342 .60117 m .2862 .68248 L .27655 .72924 L p .229 .313 .743 r
F P
0 g
s
.35812 .78099 m .27655 .72924 L .2862 .68248 L p .423 .512 .845 r
F P
0 g
s
.70914 1.09315 m .72871 1.19016 L .79776 1.14575 L p .445 .326 .623 r
F P
0 g
s
.79776 1.14575 m .77162 1.05148 L .70914 1.09315 L p .445 .326 .623 r
F P
0 g
s
.36625 .87298 m .28632 .94204 L .32587 .98068 L p .831 .783 .807 r
F P
0 g
s
.32587 .98068 m .39123 .89852 L .36625 .87298 L p .831 .783 .807 r
F P
0 g
s
.27931 1.07389 m .32587 .98068 L .28632 .94204 L p .888 .773 .729 r
F P
0 g
s
.461 .82597 m .36625 .87298 L .39123 .89852 L p .759 .778 .869 r
F P
0 g
s
.39123 .89852 m .46944 .83499 L .461 .82597 L p .759 .778 .869 r
F P
0 g
s
.72098 .35632 m .73003 .43157 L .64224 .39292 L p .843 .529 .457 r
F P
0 g
s
.64224 .39292 m .63678 .31854 L .72098 .35632 L p .843 .529 .457 r
F P
0 g
s
.79132 .48599 m .77144 .57293 L .71428 .52361 L p .915 .704 .603 r
F P
0 g
s
.71428 .52361 m .73003 .43157 L .79132 .48599 L p .915 .704 .603 r
F P
0 g
s
.51558 .84681 m .51558 .83973 L .49829 .83889 L p .712 .461 .544 r
F P
0 g
s
.51558 .83973 m .51558 .84681 L .53243 .84431 L p .626 .391 .542 r
F P
0 g
s
.53243 .84431 m .5324 .83723 L .51558 .83973 L p .626 .391 .542 r
F P
0 g
s
.49829 .83889 m .49827 .84598 L .51558 .84681 L p .712 .461 .544 r
F P
0 g
s
.66154 .79588 m .56356 .81383 L .56371 .80347 L p .76 .835 .909 r
F P
0 g
s
.56371 .80347 m .66284 .76583 L .66154 .79588 L p .76 .835 .909 r
F P
0 g
s
.27931 1.07389 m .25618 1.16965 L .33673 1.20722 L p .855 .65 .624 r
F P
0 g
s
.33891 1.29482 m .33673 1.20722 L .25618 1.16965 L p .868 .581 .5 r
F P
0 g
s
.33673 1.20722 m .33891 1.29482 L .4345 1.31575 L p .786 .512 .521 r
F P
0 g
s
.5324 .83723 m .53243 .84431 L .54702 .83874 L p .515 .303 .53 r
F P
0 g
s
.54702 .83874 m .54699 .83165 L .5324 .83723 L p .515 .303 .53 r
F P
0 g
s
.48236 .83481 m .48233 .84189 L .49827 .84598 L p .791 .527 .538 r
F P
0 g
s
.25778 .45735 m .27586 .54696 L .23342 .60117 L p .283 .206 .59 r
F P
0 g
s
.2862 .68248 m .23342 .60117 L .27586 .54696 L p .426 .401 .727 r
F P
0 g
s
.64548 .88631 m .55782 .83066 L .54702 .83874 L p .608 .642 .859 r
F P
0 g
s
.55782 .83066 m .64548 .88631 L .66303 .85861 L p .573 .642 .881 r
F P
0 g
s
.64548 .88631 m .71906 .96225 L .74731 .92017 L p .485 .525 .823 r
F P
0 g
s
.74731 .92017 m .66303 .85861 L .64548 .88631 L p .485 .525 .823 r
F P
0 g
s
.54699 .83165 m .54702 .83874 L .55782 .83066 L p .34 .169 .497 r
F P
0 g
s
.55782 .83066 m .55777 .82357 L .54699 .83165 L p .34 .169 .497 r
F P
0 g
s
.46949 .82789 m .46944 .83499 L .48233 .84189 L p .876 .601 .518 r
F P
0 g
s
.28632 .94204 m .22898 1.02682 L .27931 1.07389 L p .888 .773 .729 r
F P
0 g
s
.25618 1.16965 m .27931 1.07389 L .22898 1.02682 L p .933 .74 .62 r
F P
0 g
s
.74424 .70559 m .66284 .76583 L .64752 .73691 L p .849 .827 .826 r
F P
0 g
s
.64752 .73691 m .72165 .66016 L .74424 .70559 L p .849 .827 .826 r
F P
0 g
s
.71906 .96225 m .77162 1.05148 L .808 1.00004 L p .381 .387 .741 r
F P
0 g
s
.808 1.00004 m .74731 .92017 L .71906 .96225 L p .381 .387 .741 r
F P
0 g
s
.33324 .40998 m .34069 .33521 L .43403 .30719 L p .539 .281 .473 r
F P
0 g
s
.34069 .33521 m .33324 .40998 L .25778 .45735 L p .359 .133 .428 r
F P
0 g
s
.46106 .81887 m .461 .82597 L .46944 .83499 L p .964 .688 .46 r
F P
0 g
s
.2862 .68248 m .36511 .75108 L .35812 .78099 L p .423 .512 .845 r
F P
0 g
s
.55777 .82357 m .55782 .83066 L .56362 .82094 L p 0 0 .387 r
F P
0 g
s
.56362 .82094 m .56356 .81383 L .55777 .82357 L p 0 0 .387 r
F P
0 g
s
.66303 .85861 m .56362 .82094 L .55782 .83066 L p .573 .642 .881 r
F P
0 g
s
.45795 .8158 m .35656 .84385 L .36625 .87298 L p .763 .815 .894 r
F P
0 g
s
.36625 .87298 m .461 .82597 L .45795 .8158 L p .763 .815 .894 r
F P
0 g
s
.28632 .94204 m .36625 .87298 L .35656 .84385 L p .855 .858 .842 r
F P
0 g
s
.72871 1.19016 m .72591 1.27847 L .79403 1.23593 L p .348 .159 .477 r
F P
0 g
s
.79403 1.23593 m .79776 1.14575 L .72871 1.19016 L p .348 .159 .477 r
F P
0 g
s
.27586 .54696 m .25778 .45735 L .33324 .40998 L p .479 .336 .608 r
F P
0 g
s
.53399 1.38469 m .53711 1.31999 L .4345 1.31575 L p .675 .326 .375 r
F P
0 g
s
.53711 1.31999 m .53399 1.38469 L .62226 1.37372 L p .571 .239 .367 r
F P
0 g
s
.62226 1.37372 m .63735 1.30725 L .53711 1.31999 L p .571 .239 .367 r
F P
0 g
s
.56356 .81383 m .56362 .82094 L .56377 .81059 L p 0 0 .026 r
F P
0 g
s
.56377 .81059 m .56371 .80347 L .56356 .81383 L p 0 0 .026 r
F P
0 g
s
.44359 1.38103 m .4345 1.31575 L .33891 1.29482 L p .763 .391 .351 r
F P
0 g
s
.4345 1.31575 m .44359 1.38103 L .53399 1.38469 L p .675 .326 .375 r
F P
0 g
s
.63678 .31854 m .64224 .39292 L .53812 .37532 L p .75 .455 .483 r
F P
0 g
s
.53812 .37532 m .53702 .30136 L .63678 .31854 L p .75 .455 .483 r
F P
0 g
s
.56362 .82094 m .66303 .85861 L .66436 .82881 L p .536 .65 .908 r
F P
0 g
s
.66436 .82881 m .56377 .81059 L .56362 .82094 L p .536 .65 .908 r
F P
0 g
s
.66284 .76583 m .56371 .80347 L .55815 .79362 L p .762 .798 .882 r
F P
0 g
s
.55815 .79362 m .64752 .73691 L .66284 .76583 L p .762 .798 .882 r
F P
0 g
s
.35656 .84385 m .27012 .89758 L .28632 .94204 L p .855 .858 .842 r
F P
0 g
s
.22898 1.02682 m .28632 .94204 L .27012 .89758 L p .937 .879 .752 r
F P
0 g
s
.77144 .57293 m .72165 .66016 L .67499 .62134 L p .869 .74 .718 r
F P
0 g
s
.67499 .62134 m .71428 .52361 L .77144 .57293 L p .869 .74 .718 r
F P
0 g
s
.27586 .54696 m .32112 .63969 L .2862 .68248 L p .426 .401 .727 r
F P
0 g
s
.36511 .75108 m .2862 .68248 L .32112 .63969 L p .518 .532 .81 r
F P
0 g
s
.77162 1.05148 m .79776 1.14575 L .83834 1.09075 L p .239 .198 .609 r
F P
0 g
s
.83834 1.09075 m .808 1.00004 L .77162 1.05148 L p .239 .198 .609 r
F P
0 g
s
.66303 .85861 m .74731 .92017 L .75057 .87446 L p .382 .511 .863 r
F P
0 g
s
.75057 .87446 m .66436 .82881 L .66303 .85861 L p .382 .511 .863 r
F P
0 g
s
.56371 .80347 m .56377 .81059 L .5582 .80075 L p .987 .72 .362 r
F P
0 g
s
.5582 .80075 m .55815 .79362 L .56371 .80347 L p .987 .72 .362 r
F P
0 g
s
.63735 1.30725 m .62226 1.37372 L .70003 1.34899 L p .426 .109 .323 r
F P
0 g
s
.70003 1.34899 m .72591 1.27847 L .63735 1.30725 L p .426 .109 .323 r
F P
0 g
s
.43062 .38129 m .43403 .30719 L .53702 .30136 L p .655 .377 .487 r
F P
0 g
s
.43403 .30719 m .43062 .38129 L .33324 .40998 L p .539 .281 .473 r
F P
0 g
s
.56377 .81059 m .66436 .82881 L .64889 .80014 L p .5 .668 .938 r
F P
0 g
s
.64889 .80014 m .5582 .80075 L .56377 .81059 L p .5 .668 .938 r
F P
0 g
s
.53702 .30136 m .53812 .37532 L .43062 .38129 L p .655 .377 .487 r
F P
0 g
s
.22898 1.02682 m .20037 1.1194 L .25618 1.16965 L p .933 .74 .62 r
F P
0 g
s
.25942 1.25882 m .25618 1.16965 L .20037 1.1194 L p .955 .66 .439 r
F P
0 g
s
.25618 1.16965 m .25942 1.25882 L .33891 1.29482 L p .868 .581 .5 r
F P
0 g
s
.73003 .43157 m .71428 .52361 L .63271 .48864 L p .832 .616 .61 r
F P
0 g
s
.63271 .48864 m .64224 .39292 L .73003 .43157 L p .832 .616 .61 r
F P
0 g
s
.46067 .80556 m .3636 .8142 L .35656 .84385 L p .753 .85 .923 r
F P
0 g
s
.32112 .63969 m .3883 .72396 L .36511 .75108 L p .518 .532 .81 r
F P
0 g
s
.64752 .73691 m .55815 .79362 L .54742 .78536 L p .753 .761 .86 r
F P
0 g
s
.55815 .79362 m .5582 .80075 L .54746 .7925 L p .925 .643 .487 r
F P
0 g
s
.54746 .7925 m .54742 .78536 L .55815 .79362 L p .925 .643 .487 r
F P
0 g
s
.27012 .89758 m .35656 .84385 L .3636 .8142 L p .848 .938 .883 r
F P
0 g
s
.5582 .80075 m .64889 .80014 L .61795 .77584 L p .472 .697 .966 r
F P
0 g
s
.61795 .77584 m .54746 .7925 L .5582 .80075 L p .472 .697 .966 r
F P
0 g
s
.3595 1.36304 m .33891 1.29482 L .25942 1.25882 L p .844 .441 .278 r
F P
0 g
s
.33891 1.29482 m .3595 1.36304 L .44359 1.38103 L p .763 .391 .351 r
F P
0 g
s
.46891 .79638 m .38703 .7873 L .3636 .8142 L p .721 .875 .953 r
F P
0 g
s
.54742 .78536 m .61688 .7124 L .64752 .73691 L p .753 .761 .86 r
F P
0 g
s
.61688 .7124 m .54742 .78536 L .5327 .77961 L p .735 .728 .845 r
F P
0 g
s
.54742 .78536 m .54746 .7925 L .53272 .78675 L p .835 .561 .524 r
F P
0 g
s
.53272 .78675 m .5327 .77961 L .54742 .78536 L p .835 .561 .524 r
F P
0 g
s
.72165 .66016 m .64752 .73691 L .61688 .7124 L p .817 .756 .796 r
F P
0 g
s
.61688 .7124 m .67499 .62134 L .72165 .66016 L p .817 .756 .796 r
F P
0 g
s
.74731 .92017 m .808 1.00004 L .81318 .94378 L p .16 .297 .756 r
F P
0 g
s
.81318 .94378 m .75057 .87446 L .74731 .92017 L p .16 .297 .756 r
F P
0 g
s
.33324 .40998 m .34608 .50407 L .27586 .54696 L p .479 .336 .608 r
F P
0 g
s
.32112 .63969 m .27586 .54696 L .34608 .50407 L p .544 .459 .71 r
F P
0 g
s
.54746 .7925 m .61795 .77584 L .57477 .75879 L p .461 .736 .987 r
F P
0 g
s
.57477 .75879 m .53272 .78675 L .54746 .7925 L p .461 .736 .987 r
F P
0 g
s
.27012 .89758 m .20758 .97229 L .22898 1.02682 L p .937 .879 .752 r
F P
0 g
s
.20037 1.1194 m .22898 1.02682 L .20758 .97229 L p .995 .853 .581 r
F P
0 g
s
.5327 .77961 m .57414 .69522 L .61688 .7124 L p .735 .728 .845 r
F P
0 g
s
.57414 .69522 m .5327 .77961 L .51558 .77703 L p .712 .699 .836 r
F P
0 g
s
.5327 .77961 m .53272 .78675 L .51559 .78417 L p .752 .491 .537 r
F P
0 g
s
.51559 .78417 m .51558 .77703 L .5327 .77961 L p .752 .491 .537 r
F P
0 g
s
.48181 .78928 m .42455 .7663 L .38703 .7873 L p .667 .881 .978 r
F P
0 g
s
.51558 .77703 m .52408 .68746 L .57414 .69522 L p .712 .699 .836 r
F P
0 g
s
.53272 .78675 m .57477 .75879 L .52419 .7511 L p .478 .781 .998 r
F P
0 g
s
.52419 .7511 m .51559 .78417 L .53272 .78675 L p .478 .781 .998 r
F P
0 g
s
.34608 .50407 m .33324 .40998 L .43062 .38129 L p .596 .418 .611 r
F P
0 g
s
.66436 .82881 m .75057 .87446 L .72744 .83004 L p .237 .498 .899 r
F P
0 g
s
.72744 .83004 m .64889 .80014 L .66436 .82881 L p .237 .498 .899 r
F P
0 g
s
.49796 .78505 m .47209 .75371 L .42455 .7663 L p .596 .864 .993 r
F P
0 g
s
.51559 .78417 m .52419 .7511 L .47209 .75371 L p .526 .827 .999 r
F P
0 g
s
.79776 1.14575 m .79403 1.23593 L .834 1.18327 L p .014 0 .366 r
F P
0 g
s
.834 1.18327 m .83834 1.09075 L .79776 1.14575 L p .014 0 .366 r
F P
0 g
s
.72591 1.27847 m .70003 1.34899 L .75951 1.31254 L p .169 0 .203 r
F P
0 g
s
.75951 1.31254 m .79403 1.23593 L .72591 1.27847 L p .169 0 .203 r
F P
0 g
s
.37814 .60601 m .42545 .70278 L .3883 .72396 L p .588 .555 .784 r
F P
0 g
s
.3883 .72396 m .32112 .63969 L .37814 .60601 L p .588 .555 .784 r
F P
0 g
s
.34608 .50407 m .37814 .60601 L .32112 .63969 L p .544 .459 .71 r
F P
0 g
s
.71428 .52361 m .67499 .62134 L .60902 .59394 L p .809 .665 .703 r
F P
0 g
s
.60902 .59394 m .63271 .48864 L .71428 .52361 L p .809 .665 .703 r
F P
0 g
s
.3636 .8142 m .27994 .85187 L .27012 .89758 L p .848 .938 .883 r
F P
0 g
s
.20758 .97229 m .27012 .89758 L .27994 .85187 L p .913 .981 .74 r
F P
0 g
s
.64224 .39292 m .63271 .48864 L .53614 .47274 L p .757 .547 .612 r
F P
0 g
s
.53614 .47274 m .53812 .37532 L .64224 .39292 L p .757 .547 .612 r
F P
0 g
s
.27994 .85187 m .3636 .8142 L .38703 .7873 L p .757 .985 .903 r
F P
0 g
s
.67499 .62134 m .61688 .7124 L .57414 .69522 L p .779 .699 .776 r
F P
0 g
s
.808 1.00004 m .83834 1.09075 L .84465 1.03041 L p 0 0 .507 r
F P
0 g
s
.84465 1.03041 m .81318 .94378 L .808 1.00004 L p 0 0 .507 r
F P
0 g
s
.43646 .47814 m .43062 .38129 L .53812 .37532 L p .682 .484 .612 r
F P
0 g
s
.43062 .38129 m .43646 .47814 L .34608 .50407 L p .596 .418 .611 r
F P
0 g
s
.52826 1.41978 m .53399 1.38469 L .44359 1.38103 L p .55 .058 .042 r
F P
0 g
s
.53399 1.38469 m .52826 1.41978 L .59447 1.41165 L p .415 0 .021 r
F P
0 g
s
.59447 1.41165 m .62226 1.37372 L .53399 1.38469 L p .415 0 .021 r
F P
0 g
s
.57414 .69522 m .60902 .59394 L .67499 .62134 L p .779 .699 .776 r
F P
0 g
s
.45104 .58573 m .47251 .69009 L .42545 .70278 L p .645 .582 .77 r
F P
0 g
s
.42545 .70278 m .37814 .60601 L .45104 .58573 L p .645 .582 .77 r
F P
0 g
s
.64889 .80014 m .72744 .83004 L .67954 .79206 L p .054 .478 .887 r
F P
0 g
s
.67954 .79206 m .61795 .77584 L .64889 .80014 L p .054 .478 .887 r
F P
0 g
s
.20037 1.1194 m .20439 1.2107 L .25942 1.25882 L p .955 .66 .439 r
F P
0 g
s
.28986 1.33214 m .25942 1.25882 L .20439 1.2107 L p .881 .448 .085 r
F P
0 g
s
.25942 1.25882 m .28986 1.33214 L .3595 1.36304 L p .844 .441 .278 r
F P
0 g
s
.53812 .37532 m .53614 .47274 L .43646 .47814 L p .682 .484 .612 r
F P
0 g
s
.46038 1.41707 m .44359 1.38103 L .3595 1.36304 L p .633 .11 0 r
F P
0 g
s
.44359 1.38103 m .46038 1.41707 L .52826 1.41978 L p .55 .058 .042 r
F P
0 g
s
.37814 .60601 m .34608 .50407 L .43646 .47814 L p .626 .508 .699 r
F P
0 g
s
.60902 .59394 m .57414 .69522 L .52408 .68746 L p .737 .653 .765 r
F P
0 g
s
.20758 .97229 m .17621 1.06101 L .20037 1.1194 L p .995 .853 .581 r
F P
0 g
s
.20439 1.2107 m .20037 1.1194 L .17621 1.06101 L p .95 .693 .234 r
F P
0 g
s
.75057 .87446 m .81318 .94378 L .78496 .88872 L p 0 .129 .675 r
F P
0 g
s
.78496 .88872 m .72744 .83004 L .75057 .87446 L p 0 .129 .675 r
F P
0 g
s
.62226 1.37372 m .59447 1.41165 L .65251 1.39339 L p .191 0 0 r
F P
0 g
s
.65251 1.39339 m .70003 1.34899 L .62226 1.37372 L p .191 0 0 r
F P
0 g
s
.53125 .58151 m .52408 .68746 L .47251 .69009 L p .693 .614 .763 r
F P
0 g
s
.47251 .69009 m .45104 .58573 L .53125 .58151 L p .693 .614 .763 r
F P
0 g
s
.43646 .47814 m .45104 .58573 L .37814 .60601 L p .626 .508 .699 r
F P
0 g
s
.31576 .81002 m .38703 .7873 L .42455 .7663 L p .528 .921 .849 r
F P
0 g
s
.38703 .7873 m .31576 .81002 L .27994 .85187 L p .757 .985 .903 r
F P
0 g
s
.52408 .68746 m .53125 .58151 L .60902 .59394 L p .737 .653 .765 r
F P
0 g
s
.63271 .48864 m .60902 .59394 L .53125 .58151 L p .751 .605 .696 r
F P
0 g
s
.53125 .58151 m .53614 .47274 L .63271 .48864 L p .751 .605 .696 r
F P
0 g
s
.39743 1.40375 m .3595 1.36304 L .28986 1.33214 L p .647 .089 0 r
F P
0 g
s
.3595 1.36304 m .39743 1.40375 L .46038 1.41707 L p .633 .11 0 r
F P
0 g
s
.27994 .85187 m .2189 .91583 L .20758 .97229 L p .913 .981 .74 r
F P
0 g
s
.17621 1.06101 m .20758 .97229 L .2189 .91583 L p .816 .829 .355 r
F P
0 g
s
.61795 .77584 m .67954 .79206 L .61173 .76523 L p 0 .454 .791 r
F P
0 g
s
.61173 .76523 m .57477 .75879 L .61795 .77584 L p 0 .454 .791 r
F P
0 g
s
.45104 .58573 m .43646 .47814 L .53614 .47274 L p .692 .555 .694 r
F P
0 g
s
.79403 1.23593 m .75951 1.31254 L .794 1.26761 L p 0 0 0 r
F P
0 g
s
.794 1.26761 m .834 1.18327 L .79403 1.23593 L p 0 0 0 r
F P
0 g
s
.53614 .47274 m .53125 .58151 L .45104 .58573 L p .692 .555 .694 r
F P
0 g
s
.2189 .91583 m .27994 .85187 L .31576 .81002 L p .588 .867 .542 r
F P
0 g
s
.37433 .77706 m .42455 .7663 L .47209 .75371 L p .224 .741 .732 r
F P
0 g
s
.42455 .7663 m .37433 .77706 L .31576 .81002 L p .528 .921 .849 r
F P
0 g
s
.83834 1.09075 m .834 1.18327 L .84015 1.12552 L p 0 0 .014 r
F P
0 g
s
.84015 1.12552 m .84465 1.03041 L .83834 1.09075 L p 0 0 .014 r
F P
0 g
s
.70003 1.34899 m .65251 1.39339 L .69643 1.36662 L p 0 0 0 r
F P
0 g
s
.69643 1.36662 m .75951 1.31254 L .70003 1.34899 L p 0 0 0 r
F P
0 g
s
.57477 .75879 m .61173 .76523 L .53176 .75306 L p .124 0 0 r
F P
0 g
s
.53176 .75306 m .52419 .7511 L .57477 .75879 L p .124 0 0 r
F P
0 g
s
.47209 .75371 m .44928 .75719 L .37433 .77706 L p .224 .741 .732 r
F P
0 g
s
.44928 .75719 m .47209 .75371 L .52419 .7511 L p .012 0 0 r
F P
0 g
s
.52419 .7511 m .53176 .75306 L .44928 .75719 L p .012 0 0 r
F P
0 g
s
.72744 .83004 m .78496 .88872 L .72496 .84133 L p .615 .082 0 r
F P
0 g
s
.72496 .84133 m .67954 .79206 L .72744 .83004 L p .615 .082 0 r
F P
0 g
s
.81318 .94378 m .84465 1.03041 L .81402 .97113 L p .781 .421 0 r
F P
0 g
s
.81402 .97113 m .78496 .88872 L .81318 .94378 L p .781 .421 0 r
F P
0 g
s
.17621 1.06101 m .18063 1.15481 L .20439 1.2107 L p .95 .693 .234 r
F P
0 g
s
.20439 1.2107 m .24203 1.29099 L .28986 1.33214 L p .881 .448 .085 r
F P
0 g
s
.24203 1.29099 m .20439 1.2107 L .18063 1.15481 L p 0 0 .329 r
F P
0 g
s
.34569 1.38099 m .28986 1.33214 L .24203 1.29099 L p .472 0 0 r
F P
0 g
s
.28986 1.33214 m .34569 1.38099 L .39743 1.40375 L p .647 .089 0 r
F P
0 g
s
.2189 .91583 m .18811 1.00034 L .17621 1.06101 L p .816 .829 .355 r
F P
0 g
s
.18063 1.15481 m .17621 1.06101 L .18811 1.00034 L p 0 0 .22 r
F P
0 g
s
.31576 .81002 m .26334 .86378 L .2189 .91583 L p .588 .867 .542 r
F P
0 g
s
.26334 .86378 m .31576 .81002 L .37433 .77706 L p 0 0 0 r
F P
0 g
s
.52035 1.41941 m .52826 1.41978 L .46038 1.41707 L p 0 .555 .708 r
F P
0 g
s
.52826 1.41978 m .52035 1.41941 L .55614 1.41501 L p .111 .664 .728 r
F P
0 g
s
.55614 1.41501 m .59447 1.41165 L .52826 1.41978 L p .111 .664 .728 r
F P
0 g
s
.4836 1.41794 m .46038 1.41707 L .39743 1.40375 L p 0 .513 .766 r
F P
0 g
s
.46038 1.41707 m .4836 1.41794 L .52035 1.41941 L p 0 .555 .708 r
F P
0 g
s
.75951 1.31254 m .69643 1.36662 L .72133 1.33385 L p .689 .949 .678 r
F P
0 g
s
.72133 1.33385 m .794 1.26761 L .75951 1.31254 L p .689 .949 .678 r
F P
0 g
s
.18811 1.00034 m .2189 .91583 L .26334 .86378 L p 0 0 .081 r
F P
0 g
s
.59447 1.41165 m .55614 1.41501 L .5873 1.40517 L p .335 .817 .815 r
F P
0 g
s
.5873 1.40517 m .65251 1.39339 L .59447 1.41165 L p .335 .817 .815 r
F P
0 g
s
.834 1.18327 m .794 1.26761 L .79869 1.21855 L p .909 .913 .517 r
F P
0 g
s
.79869 1.21855 m .84015 1.12552 L .834 1.18327 L p .909 .913 .517 r
F P
0 g
s
.67954 .79206 m .72496 .84133 L .63913 .80769 L p .695 .162 0 r
F P
0 g
s
.63913 .80769 m .61173 .76523 L .67954 .79206 L p .695 .162 0 r
F P
0 g
s
.44966 1.41075 m .39743 1.40375 L .34569 1.38099 L p .012 .523 .864 r
F P
0 g
s
.39743 1.40375 m .44966 1.41075 L .4836 1.41794 L p 0 .513 .766 r
F P
0 g
s
.84465 1.03041 m .84015 1.12552 L .80986 1.06882 L p .991 .751 .383 r
F P
0 g
s
.80986 1.06882 m .81402 .97113 L .84465 1.03041 L p .991 .751 .383 r
F P
0 g
s
.33716 .82254 m .37433 .77706 L .44928 .75719 L p .308 0 .012 r
F P
0 g
s
.37433 .77706 m .33716 .82254 L .26334 .86378 L p 0 0 0 r
F P
0 g
s
.65251 1.39339 m .5873 1.40517 L .61054 1.39086 L p .577 .94 .904 r
F P
0 g
s
.61054 1.39086 m .69643 1.36662 L .65251 1.39339 L p .577 .94 .904 r
F P
0 g
s
.18063 1.15481 m .22185 1.2434 L .24203 1.29099 L p 0 0 .329 r
F P
0 g
s
.24203 1.29099 m .31067 1.35087 L .34569 1.38099 L p .472 0 0 r
F P
0 g
s
.31067 1.35087 m .24203 1.29099 L .22185 1.2434 L p 0 .255 .766 r
F P
0 g
s
.78496 .88872 m .81402 .97113 L .74801 .91994 L p .908 .507 .221 r
F P
0 g
s
.74801 .91994 m .72496 .84133 L .78496 .88872 L p .908 .507 .221 r
F P
0 g
s
.61173 .76523 m .63913 .80769 L .53738 .79238 L p .628 .134 .06 r
F P
0 g
s
.53738 .79238 m .53176 .75306 L .61173 .76523 L p .628 .134 .06 r
F P
0 g
s
.18811 1.00034 m .19245 1.09675 L .18063 1.15481 L p 0 0 .22 r
F P
0 g
s
.22185 1.2434 m .18063 1.15481 L .19245 1.09675 L p 0 .092 .612 r
F P
0 g
s
.42205 1.39853 m .34569 1.38099 L .31067 1.35087 L p .159 .547 .927 r
F P
0 g
s
.34569 1.38099 m .42205 1.39853 L .44966 1.41075 L p .012 .523 .864 r
F P
0 g
s
.43233 .79758 m .44928 .75719 L .53176 .75306 L p .505 .039 .082 r
F P
0 g
s
.44928 .75719 m .43233 .79758 L .33716 .82254 L p .308 0 .012 r
F P
0 g
s
.53176 .75306 m .53738 .79238 L .43233 .79758 L p .505 .039 .082 r
F P
0 g
s
.26334 .86378 m .23677 .9442 L .18811 1.00034 L p 0 0 .081 r
F P
0 g
s
.19245 1.09675 m .18811 1.00034 L .23677 .9442 L p .154 .044 .465 r
F P
0 g
s
.794 1.26761 m .72133 1.33385 L .7239 1.29837 L p .905 .976 .799 r
F P
0 g
s
.7239 1.29837 m .79869 1.21855 L .794 1.26761 L p .905 .976 .799 r
F P
0 g
s
.23677 .9442 m .26334 .86378 L .33716 .82254 L p .284 .005 .302 r
F P
0 g
s
.69643 1.36662 m .61054 1.39086 L .6233 1.37352 L p .742 .968 .933 r
F P
0 g
s
.6233 1.37352 m .72133 1.33385 L .69643 1.36662 L p .742 .968 .933 r
F P
0 g
s
.84015 1.12552 m .79869 1.21855 L .77161 1.17061 L p .978 .852 .649 r
F P
0 g
s
.77161 1.17061 m .80986 1.06882 L .84015 1.12552 L p .978 .852 .649 r
F P
0 g
s
.51101 1.38105 m .52035 1.41941 L .4836 1.41794 L closepath p .531 .808 .997 \
r
F P
0 g
s
.51101 1.38105 m .55614 1.41501 L .52035 1.41941 L closepath p .562 .83 .996 \
r
F P
0 g
s
.51101 1.38105 m .4836 1.41794 L .44966 1.41075 L closepath p .513 .784 .994 \
r
F P
0 g
s
.22185 1.2434 m .29654 1.3163 L .31067 1.35087 L p 0 .255 .766 r
F P
0 g
s
.40374 1.38251 m .31067 1.35087 L .29654 1.3163 L p .31 .562 .926 r
F P
0 g
s
.31067 1.35087 m .40374 1.38251 L .42205 1.39853 L p .159 .547 .927 r
F P
0 g
s
.72496 .84133 m .74801 .91994 L .65306 .88351 L p .83 .459 .351 r
F P
0 g
s
.65306 .88351 m .63913 .80769 L .72496 .84133 L p .83 .459 .351 r
F P
0 g
s
.51101 1.38105 m .5873 1.40517 L .55614 1.41501 L closepath p .601 .846 .991 \
r
F P
0 g
s
.19245 1.09675 m .23287 1.1942 L .22185 1.2434 L p 0 .092 .612 r
F P
0 g
s
.29654 1.3163 m .22185 1.2434 L .23287 1.1942 L p .252 .381 .8 r
F P
0 g
s
.81402 .97113 m .80986 1.06882 L .74469 1.01988 L p .935 .668 .508 r
F P
0 g
s
.74469 1.01988 m .74801 .91994 L .81402 .97113 L p .935 .668 .508 r
F P
0 g
s
.51101 1.38105 m .44966 1.41075 L .42205 1.39853 L closepath p .511 .761 .986 \
r
F P
0 g
s
.51101 1.38105 m .61054 1.39086 L .5873 1.40517 L closepath p .639 .852 .981 \
r
F P
0 g
s
.31824 .8996 m .33716 .82254 L .43233 .79758 L p .5 .194 .38 r
F P
0 g
s
.33716 .82254 m .31824 .8996 L .23677 .9442 L p .284 .005 .302 r
F P
0 g
s
.72133 1.33385 m .6233 1.37352 L .62402 1.35495 L p .81 .922 .912 r
F P
0 g
s
.62402 1.35495 m .7239 1.29837 L .72133 1.33385 L p .81 .922 .912 r
F P
0 g
s
.51101 1.38105 m .42205 1.39853 L .40374 1.38251 L closepath p .522 .741 .975 \
r
F P
0 g
s
.23677 .9442 m .24052 1.04307 L .19245 1.09675 L p .154 .044 .465 r
F P
0 g
s
.23287 1.1942 m .19245 1.09675 L .24052 1.04307 L p .326 .286 .659 r
F P
0 g
s
.51101 1.38105 m .6233 1.37352 L .61054 1.39086 L closepath p .67 .847 .967 r
F P
0 g
s
.79869 1.21855 m .7239 1.29837 L .70304 1.26399 L p .907 .869 .789 r
F P
0 g
s
.70304 1.26399 m .77161 1.17061 L .79869 1.21855 L p .907 .869 .789 r
F P
0 g
s
.63913 .80769 m .65306 .88351 L .54023 .8669 L p .735 .39 .396 r
F P
0 g
s
.54023 .8669 m .53738 .79238 L .63913 .80769 L p .735 .39 .396 r
F P
0 g
s
.24052 1.04307 m .23677 .9442 L .31824 .8996 L p .424 .244 .53 r
F P
0 g
s
.23287 1.1942 m .3056 1.28087 L .29654 1.3163 L p .252 .381 .8 r
F P
0 g
s
.39683 1.36431 m .29654 1.3163 L .3056 1.28087 L p .43 .572 .894 r
F P
0 g
s
.29654 1.3163 m .39683 1.36431 L .40374 1.38251 L p .31 .562 .926 r
F P
0 g
s
.51101 1.38105 m .40374 1.38251 L .39683 1.36431 L closepath p .541 .726 .959 \
r
F P
0 g
s
.42368 .87254 m .43233 .79758 L .53738 .79238 L p .632 .308 .404 r
F P
0 g
s
.43233 .79758 m .42368 .87254 L .31824 .8996 L p .5 .194 .38 r
F P
0 g
s
.53738 .79238 m .54023 .8669 L .42368 .87254 L p .632 .308 .404 r
F P
0 g
s
.51101 1.38105 m .62402 1.35495 L .6233 1.37352 L closepath p .691 .833 .951 \
r
F P
0 g
s
.80986 1.06882 m .77161 1.17061 L .71437 1.12941 L p .905 .735 .661 r
F P
0 g
s
.71437 1.12941 m .74469 1.01988 L .80986 1.06882 L p .905 .735 .661 r
F P
0 g
s
.24052 1.04307 m .27535 1.14891 L .23287 1.1942 L p .326 .286 .659 r
F P
0 g
s
.3056 1.28087 m .23287 1.1942 L .27535 1.14891 L p .435 .45 .776 r
F P
0 g
s
.74801 .91994 m .74469 1.01988 L .65104 .98506 L p .842 .58 .543 r
F P
0 g
s
.65104 .98506 m .65306 .88351 L .74801 .91994 L p .842 .58 .543 r
F P
0 g
s
.7239 1.29837 m .62402 1.35495 L .61238 1.33716 L p .817 .854 .876 r
F P
0 g
s
.61238 1.33716 m .70304 1.26399 L .7239 1.29837 L p .817 .854 .876 r
F P
0 g
s
.3056 1.28087 m .40228 1.34587 L .39683 1.36431 L p .43 .572 .894 r
F P
0 g
s
.51101 1.38105 m .39683 1.36431 L .40228 1.34587 L closepath p .565 .716 .943 \
r
F P
0 g
s
.51101 1.38105 m .58946 1.32214 L .61238 1.33716 L closepath p .7 .791 .921 r
F P
0 g
s
.51101 1.38105 m .55767 1.31165 L .58946 1.32214 L closepath p .693 .77 .911 \
r
F P
0 g
s
.51101 1.38105 m .52055 1.30691 L .55767 1.31165 L closepath p .679 .75 .905 \
r
F P
0 g
s
.51101 1.38105 m .48235 1.30852 L .52055 1.30691 L closepath p .661 .734 .903 \
r
F P
0 g
s
.51101 1.38105 m .44742 1.31626 L .48235 1.30852 L closepath p .64 .722 .907 \
r
F P
0 g
s
.51101 1.38105 m .41973 1.32922 L .44742 1.31626 L closepath p .617 .714 .915 \
r
F P
0 g
s
.51101 1.38105 m .40228 1.34587 L .41973 1.32922 L closepath p .591 .712 .928 \
r
F P
0 g
s
.51101 1.38105 m .61238 1.33716 L .62402 1.35495 L closepath p .701 .813 .935 \
r
F P
0 g
s
.3209 1.00043 m .31824 .8996 L .42368 .87254 L p .57 .356 .55 r
F P
0 g
s
.31824 .8996 m .3209 1.00043 L .24052 1.04307 L p .424 .244 .53 r
F P
0 g
s
.27535 1.14891 m .24052 1.04307 L .3209 1.00043 L p .499 .388 .659 r
F P
0 g
s
.27535 1.14891 m .33766 1.24853 L .3056 1.28087 L p .435 .45 .776 r
F P
0 g
s
.40228 1.34587 m .3056 1.28087 L .33766 1.24853 L p .518 .584 .86 r
F P
0 g
s
.33766 1.24853 m .41973 1.32922 L .40228 1.34587 L p .518 .584 .86 r
F P
0 g
s
.77161 1.17061 m .70304 1.26399 L .66033 1.23468 L p .859 .77 .763 r
F P
0 g
s
.66033 1.23468 m .71437 1.12941 L .77161 1.17061 L p .859 .77 .763 r
F P
0 g
s
.70304 1.26399 m .61238 1.33716 L .58946 1.32214 L p .797 .789 .845 r
F P
0 g
s
.65306 .88351 m .65104 .98506 L .53979 .96919 L p .757 .506 .554 r
F P
0 g
s
.53979 .96919 m .54023 .8669 L .65306 .88351 L p .757 .506 .554 r
F P
0 g
s
.58946 1.32214 m .66033 1.23468 L .70304 1.26399 L p .797 .789 .845 r
F P
0 g
s
.38976 1.22312 m .44742 1.31626 L .41973 1.32922 L p .586 .601 .834 r
F P
0 g
s
.41973 1.32922 m .33766 1.24853 L .38976 1.22312 L p .586 .601 .834 r
F P
0 g
s
.74469 1.01988 m .71437 1.12941 L .63269 1.10019 L p .829 .647 .657 r
F P
0 g
s
.63269 1.10019 m .65104 .98506 L .74469 1.01988 L p .829 .647 .657 r
F P
0 g
s
.42488 .97458 m .42368 .87254 L .54023 .8669 L p .671 .436 .555 r
F P
0 g
s
.42368 .87254 m .42488 .97458 L .3209 1.00043 L p .57 .356 .55 r
F P
0 g
s
.3209 1.00043 m .34567 1.11308 L .27535 1.14891 L p .499 .388 .659 r
F P
0 g
s
.33766 1.24853 m .27535 1.14891 L .34567 1.11308 L p .548 .498 .752 r
F P
0 g
s
.66033 1.23468 m .58946 1.32214 L .55767 1.31165 L p .765 .735 .824 r
F P
0 g
s
.54023 .8669 m .53979 .96919 L .42488 .97458 L p .671 .436 .555 r
F P
0 g
s
.34567 1.11308 m .38976 1.22312 L .33766 1.24853 L p .548 .498 .752 r
F P
0 g
s
.45622 1.20784 m .48235 1.30852 L .44742 1.31626 L p .641 .624 .818 r
F P
0 g
s
.44742 1.31626 m .38976 1.22312 L .45622 1.20784 L p .641 .624 .818 r
F P
0 g
s
.55767 1.31165 m .60012 1.21402 L .66033 1.23468 L p .765 .735 .824 r
F P
0 g
s
.60012 1.21402 m .55767 1.31165 L .52055 1.30691 L p .729 .69 .813 r
F P
0 g
s
.34567 1.11308 m .3209 1.00043 L .42488 .97458 L p .606 .458 .655 r
F P
0 g
s
.52927 1.20466 m .52055 1.30691 L .48235 1.30852 L p .687 .653 .811 r
F P
0 g
s
.48235 1.30852 m .45622 1.20784 L .52927 1.20466 L p .687 .653 .811 r
F P
0 g
s
.52055 1.30691 m .52927 1.20466 L .60012 1.21402 L p .729 .69 .813 r
F P
0 g
s
.71437 1.12941 m .66033 1.23468 L .60012 1.21402 L p .804 .694 .744 r
F P
0 g
s
.60012 1.21402 m .63269 1.10019 L .71437 1.12941 L p .804 .694 .744 r
F P
0 g
s
.65104 .98506 m .63269 1.10019 L .53599 1.08691 L p .758 .578 .653 r
F P
0 g
s
.53599 1.08691 m .53979 .96919 L .65104 .98506 L p .758 .578 .653 r
F P
0 g
s
.43617 1.09142 m .45622 1.20784 L .38976 1.22312 L p .628 .541 .738 r
F P
0 g
s
.38976 1.22312 m .34567 1.11308 L .43617 1.09142 L p .628 .541 .738 r
F P
0 g
s
.42488 .97458 m .43617 1.09142 L .34567 1.11308 L p .606 .458 .655 r
F P
0 g
s
.43617 1.09142 m .42488 .97458 L .53979 .96919 L p .687 .518 .653 r
F P
0 g
s
.63269 1.10019 m .60012 1.21402 L .52927 1.20466 L p .749 .635 .734 r
F P
0 g
s
.53979 .96919 m .53599 1.08691 L .43617 1.09142 L p .687 .518 .653 r
F P
0 g
s
.52927 1.20466 m .53599 1.08691 L .63269 1.10019 L p .749 .635 .734 r
F P
0 g
s
.53599 1.08691 m .52927 1.20466 L .45622 1.20784 L p .692 .586 .732 r
F P
0 g
s
.45622 1.20784 m .43617 1.09142 L .53599 1.08691 L p .692 .586 .732 r
F P
0 g
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.227012 0.588183 0.419395 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.26887e-17 1.05045 -0.043401 1.05045 [
[ 0 0 0 0 ]
[ 1 .86239 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .86239 L
0 .86239 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.46142 .53785 m .45397 .58689 L .54688 .59114 L p .719 .591 .711 r
F P
0 g
s
.54688 .59114 m .54437 .54175 L .46142 .53785 L p .719 .591 .711 r
F P
0 g
s
.54836 .63935 m .54688 .59114 L .45397 .58689 L p .72 .541 .647 r
F P
0 g
s
.54437 .54175 m .54688 .59114 L .63794 .57837 L p .669 .552 .713 r
F P
0 g
s
.54688 .59114 m .54836 .63935 L .64525 .62616 L p .658 .492 .648 r
F P
0 g
s
.64525 .62616 m .63794 .57837 L .54688 .59114 L p .658 .492 .648 r
F P
0 g
s
.47124 .4922 m .46142 .53785 L .54437 .54175 L p .713 .638 .773 r
F P
0 g
s
.54437 .54175 m .54104 .49558 L .47124 .4922 L p .713 .638 .773 r
F P
0 g
s
.54104 .49558 m .54437 .54175 L .62559 .53001 L p .676 .61 .775 r
F P
0 g
s
.63794 .57837 m .62559 .53001 L .54437 .54175 L p .669 .552 .713 r
F P
0 g
s
.38355 .51851 m .36652 .56583 L .45397 .58689 L p .766 .635 .716 r
F P
0 g
s
.45397 .58689 m .46142 .53785 L .38355 .51851 L p .766 .635 .716 r
F P
0 g
s
.44954 .63496 m .45397 .58689 L .36652 .56583 L p .778 .593 .65 r
F P
0 g
s
.45397 .58689 m .44954 .63496 L .54836 .63935 L p .72 .541 .647 r
F P
0 g
s
.40592 .47552 m .38355 .51851 L .46142 .53785 L p .747 .673 .778 r
F P
0 g
s
.46142 .53785 m .47124 .4922 L .40592 .47552 L p .747 .673 .778 r
F P
0 g
s
.54865 .682 m .54836 .63935 L .44954 .63496 L p .713 .477 .567 r
F P
0 g
s
.54836 .63935 m .54865 .682 L .64676 .669 L p .639 .417 .566 r
F P
0 g
s
.64676 .669 m .64525 .62616 L .54836 .63935 L p .639 .417 .566 r
F P
0 g
s
.62559 .53001 m .60932 .48543 L .54104 .49558 L p .676 .61 .775 r
F P
0 g
s
.60932 .48543 m .62559 .53001 L .69829 .50329 L p .635 .588 .784 r
F P
0 g
s
.62559 .53001 m .63794 .57837 L .71979 .54921 L p .613 .517 .721 r
F P
0 g
s
.71979 .54921 m .69829 .50329 L .62559 .53001 L p .613 .517 .721 r
F P
0 g
s
.63794 .57837 m .64525 .62616 L .73258 .596 L p .586 .442 .652 r
F P
0 g
s
.73258 .596 m .71979 .54921 L .63794 .57837 L p .586 .442 .652 r
F P
0 g
s
.48257 .45417 m .47124 .4922 L .54104 .49558 L p .696 .691 .842 r
F P
0 g
s
.54104 .49558 m .53719 .45688 L .48257 .45417 L p .696 .691 .842 r
F P
0 g
s
.53719 .45688 m .54104 .49558 L .60932 .48543 L p .676 .676 .843 r
F P
0 g
s
.36652 .56583 m .35639 .6132 L .44954 .63496 L p .778 .593 .65 r
F P
0 g
s
.44859 .67768 m .44954 .63496 L .35639 .6132 L p .783 .537 .564 r
F P
0 g
s
.44954 .63496 m .44859 .67768 L .54865 .682 L p .713 .477 .567 r
F P
0 g
s
.43166 .44086 m .40592 .47552 L .47124 .4922 L p .713 .71 .845 r
F P
0 g
s
.47124 .4922 m .48257 .45417 L .43166 .44086 L p .713 .71 .845 r
F P
0 g
s
.60932 .48543 m .59055 .44877 L .53719 .45688 L p .676 .676 .843 r
F P
0 g
s
.59055 .44877 m .60932 .48543 L .67008 .46243 L p .654 .666 .849 r
F P
0 g
s
.69829 .50329 m .67008 .46243 L .60932 .48543 L p .635 .588 .784 r
F P
0 g
s
.35103 .44664 m .31756 .48487 L .38355 .51851 L p .778 .714 .791 r
F P
0 g
s
.38355 .51851 m .40592 .47552 L .35103 .44664 L p .778 .714 .791 r
F P
0 g
s
.36652 .56583 m .38355 .51851 L .31756 .48487 L p .812 .689 .728 r
F P
0 g
s
.64525 .62616 m .64676 .669 L .73524 .63927 L p .547 .347 .56 r
F P
0 g
s
.73524 .63927 m .73258 .596 L .64525 .62616 L p .547 .347 .56 r
F P
0 g
s
.31756 .48487 m .29194 .52904 L .36652 .56583 L p .812 .689 .728 r
F P
0 g
s
.35639 .6132 m .36652 .56583 L .29194 .52904 L p .838 .655 .655 r
F P
0 g
s
.54768 .71487 m .54865 .682 L .44859 .67768 L p .691 .378 .441 r
F P
0 g
s
.54865 .682 m .54768 .71487 L .64211 .70263 L p .599 .302 .436 r
F P
0 g
s
.64211 .70263 m .64676 .669 L .54865 .682 L p .599 .302 .436 r
F P
0 g
s
.38929 .41796 m .35103 .44664 L .40592 .47552 L p .728 .732 .854 r
F P
0 g
s
.40592 .47552 m .43166 .44086 L .38929 .41796 L p .728 .732 .854 r
F P
0 g
s
.4944 .42768 m .48257 .45417 L .53719 .45688 L p .647 .757 .929 r
F P
0 g
s
.53719 .45688 m .53315 .42962 L .4944 .42768 L p .647 .757 .929 r
F P
0 g
s
.53315 .42962 m .53719 .45688 L .59055 .44877 L p .657 .763 .928 r
F P
0 g
s
.35639 .6132 m .35425 .65623 L .44859 .67768 L p .783 .537 .564 r
F P
0 g
s
.45134 .7108 m .44859 .67768 L .35425 .65623 L p .772 .441 .426 r
F P
0 g
s
.44859 .67768 m .45134 .7108 L .54768 .71487 L p .691 .378 .441 r
F P
0 g
s
.29194 .52904 m .27665 .5751 L .35639 .6132 L p .838 .655 .655 r
F P
0 g
s
.35425 .65623 m .35639 .6132 L .27665 .5751 L p .856 .603 .555 r
F P
0 g
s
.45842 .41811 m .43166 .44086 L .48257 .45417 L p .64 .748 .927 r
F P
0 g
s
.48257 .45417 m .4944 .42768 L .45842 .41811 L p .64 .748 .927 r
F P
0 g
s
.67008 .46243 m .69829 .50329 L .75568 .46322 L p .589 .571 .801 r
F P
0 g
s
.69829 .50329 m .71979 .54921 L .78499 .50528 L p .545 .483 .738 r
F P
0 g
s
.78499 .50528 m .75568 .46322 L .69829 .50329 L p .545 .483 .738 r
F P
0 g
s
.71979 .54921 m .73258 .596 L .8025 .55044 L p .491 .384 .659 r
F P
0 g
s
.8025 .55044 m .78499 .50528 L .71979 .54921 L p .491 .384 .659 r
F P
0 g
s
.59055 .44877 m .57096 .42379 L .53315 .42962 L p .657 .763 .928 r
F P
0 g
s
.57096 .42379 m .59055 .44877 L .63772 .43046 L p .667 .767 .925 r
F P
0 g
s
.67008 .46243 m .63772 .43046 L .59055 .44877 L p .654 .666 .849 r
F P
0 g
s
.63772 .43046 m .67008 .46243 L .7175 .42815 L p .632 .661 .86 r
F P
0 g
s
.75568 .46322 m .7175 .42815 L .67008 .46243 L p .589 .571 .801 r
F P
0 g
s
.64676 .669 m .64211 .70263 L .72714 .67464 L p .476 .195 .408 r
F P
0 g
s
.72714 .67464 m .73524 .63927 L .64676 .669 L p .476 .195 .408 r
F P
0 g
s
.42878 .40175 m .38929 .41796 L .43166 .44086 L p .636 .739 .923 r
F P
0 g
s
.43166 .44086 m .45842 .41811 L .42878 .40175 L p .636 .739 .923 r
F P
0 g
s
.73258 .596 m .73524 .63927 L .80616 .59433 L p .414 .248 .545 r
F P
0 g
s
.80616 .59433 m .8025 .55044 L .73258 .596 L p .414 .248 .545 r
F P
0 g
s
.31223 .40768 m .27015 .43914 L .31756 .48487 L p .805 .763 .813 r
F P
0 g
s
.31756 .48487 m .35103 .44664 L .31223 .40768 L p .805 .763 .813 r
F P
0 g
s
.29194 .52904 m .31756 .48487 L .27015 .43914 L p .859 .757 .749 r
F P
0 g
s
.27665 .5751 m .27342 .61866 L .35425 .65623 L p .856 .603 .555 r
F P
0 g
s
.36059 .6906 m .35425 .65623 L .27342 .61866 L p .854 .5 .38 r
F P
0 g
s
.35425 .65623 m .36059 .6906 L .45134 .7108 L p .772 .441 .426 r
F P
0 g
s
.35989 .38731 m .31223 .40768 L .35103 .44664 L p .737 .756 .868 r
F P
0 g
s
.35103 .44664 m .38929 .41796 L .35989 .38731 L p .737 .756 .868 r
F P
0 g
s
.63772 .43046 m .60415 .41067 L .57096 .42379 L p .667 .767 .925 r
F P
0 g
s
.60415 .41067 m .63772 .43046 L .67403 .40338 L p .677 .768 .92 r
F P
0 g
s
.7175 .42815 m .67403 .40338 L .63772 .43046 L p .632 .661 .86 r
F P
0 g
s
.54548 .73419 m .54768 .71487 L .45134 .7108 L p .606 .163 .172 r
F P
0 g
s
.54768 .71487 m .54548 .73419 L .63146 .72318 L p .483 .058 .156 r
F P
0 g
s
.63146 .72318 m .64211 .70263 L .54768 .71487 L p .483 .058 .156 r
F P
0 g
s
.27015 .43914 m .23769 .47877 L .29194 .52904 L p .859 .757 .749 r
F P
0 g
s
.27665 .5751 m .29194 .52904 L .23769 .47877 L p .904 .736 .664 r
F P
0 g
s
.45771 .73052 m .45134 .7108 L .36059 .6906 L p .694 .221 .124 r
F P
0 g
s
.45134 .7108 m .45771 .73052 L .54548 .73419 L p .606 .163 .172 r
F P
0 g
s
.50556 .41597 m .4944 .42768 L .53315 .42962 L p .45 .8 .998 r
F P
0 g
s
.55248 .41358 m .52933 .41717 L p .53934 .41876 L .531 .857 .996 r
F P
0 g
s
.57096 .42379 m .55248 .41358 L p .53934 .41876 L .531 .857 .996 r
F P
0 g
s
.57267 .40551 m .55248 .41358 L p .56486 .41288 L .629 .896 .986 r
F P
0 g
s
.60415 .41067 m .57267 .40551 L p .56486 .41288 L .629 .896 .986 r
F P
0 g
s
.57267 .40551 m .58779 .39376 L p .58146 .39723 L .616 .954 .813 r
F P
0 g
s
.55248 .41358 m .57267 .40551 L p .56721 .40775 L 0 0 0 r
F P
0 g
s
.52933 .41717 m .53315 .42962 L .57096 .42379 L p .531 .857 .996 r
F P
0 g
s
.55248 .41358 m .57096 .42379 L .60415 .41067 L p .629 .896 .986 r
F P
0 g
s
.53714 .4201 m .55248 .41358 L p .56721 .40775 L 0 0 0 r
F P
0 g
s
.52933 .41717 m .55248 .41358 L p .54844 .41484 L .07 0 0 r
F P
0 g
s
.53315 .42962 m .52933 .41717 L p .51222 .41927 L .45 .8 .998 r
F P
0 g
s
.55248 .41358 m .53714 .4201 L .52614 .4218 L p .07 0 0 r
F P
0 g
s
.54668 .41629 m .53714 .4201 L p .54284 .41776 L 0 0 0 r
F P
0 g
s
.57267 .40551 m .54668 .41629 L p .54284 .41776 L 0 0 0 r
F P
0 g
s
.54668 .41629 m .57267 .40551 L p .58146 .39723 L .616 .954 .813 r
F P
0 g
s
.55375 .41077 m .54668 .41629 L p .55326 .41269 L .616 .954 .813 r
F P
0 g
s
.58779 .39376 m .55375 .41077 L p .55326 .41269 L .616 .954 .813 r
F P
0 g
s
.55375 .41077 m .55757 .4041 L p .55427 .40875 L .711 .893 .513 r
F P
0 g
s
.54668 .41629 m .55375 .41077 L p .55071 .41475 L 0 0 0 r
F P
0 g
s
.52936 .44268 m .54668 .41629 L p .55071 .41475 L 0 0 0 r
F P
0 g
s
.53119 .44126 m .52936 .44268 L p .53063 .44102 L 0 0 0 r
F P
0 g
s
.55375 .41077 m .53119 .44126 L p .53063 .44102 L 0 0 0 r
F P
0 g
s
.53119 .44126 m .55375 .41077 L p .55427 .40875 L .711 .893 .513 r
F P
0 g
s
.53217 .43956 m .53119 .44126 L p .53257 .43933 L .711 .893 .513 r
F P
0 g
s
.55757 .4041 m .53217 .43956 L p .53257 .43933 L .711 .893 .513 r
F P
0 g
s
.54668 .41629 m .52936 .44268 L .52687 .44367 L p .283 0 .116 r
F P
0 g
s
.53217 .43956 m .53217 .43775 L .53176 .43978 L p .887 .797 .31 r
F P
0 g
s
.53119 .44126 m .53217 .43956 L .53176 .44151 L p 0 0 .142 r
F P
0 g
s
.53176 .44151 m .5232 .48247 L .53119 .44126 L p 0 0 .142 r
F P
0 g
s
.53176 .43978 m .5232 .48247 L .53217 .43956 L p .887 .797 .31 r
F P
0 g
s
.52614 .4218 m .52933 .41717 L p .54844 .41484 L .07 0 0 r
F P
0 g
s
.52933 .41717 m .50556 .41597 L p .51222 .41927 L .45 .8 .998 r
F P
0 g
s
.48359 .41008 m .45842 .41811 L .4944 .42768 L p .41 .741 .993 r
F P
0 g
s
.50113 .42062 m .50556 .41597 L .48359 .41008 L p .41 .741 .993 r
F P
0 g
s
.50441 .41844 m .48359 .41008 L .50556 .41597 L p .311 0 0 r
F P
0 g
s
.49597 .41372 m .47068 .40232 L p .48359 .41008 L 0 .335 .733 r
F P
0 g
s
.47068 .40232 m .46566 .40006 L .48359 .41008 L p 0 .335 .733 r
F P
0 g
s
.4944 .42768 m .50113 .42062 L p .48359 .41008 L .41 .741 .993 r
F P
0 g
s
.40862 .38005 m .35989 .38731 L .38929 .41796 L p .635 .73 .917 r
F P
0 g
s
.38929 .41796 m .42878 .40175 L .40862 .38005 L p .635 .73 .917 r
F P
0 g
s
.64211 .70263 m .63146 .72318 L .70857 .69808 L p .291 0 .067 r
F P
0 g
s
.70857 .69808 m .72714 .67464 L .64211 .70263 L p .291 0 .067 r
F P
0 g
s
.46566 .40006 m .42878 .40175 L .45842 .41811 L p .414 .691 .977 r
F P
0 g
s
.45842 .41811 m .48359 .41008 L .46566 .40006 L p .414 .691 .977 r
F P
0 g
s
.23769 .47877 m .21822 .52286 L .27665 .5751 L p .904 .736 .664 r
F P
0 g
s
.27342 .61866 m .27665 .5751 L .21822 .52286 L p .938 .685 .528 r
F P
0 g
s
.73524 .63927 m .72714 .67464 L .79506 .63242 L p .273 .018 .333 r
F P
0 g
s
.79506 .63242 m .80616 .59433 L .73524 .63927 L p .273 .018 .333 r
F P
0 g
s
.67403 .40338 m .7175 .42815 L .7462 .38529 L p .61 .663 .876 r
F P
0 g
s
.7175 .42815 m .75568 .46322 L .79128 .41269 L p .536 .562 .828 r
F P
0 g
s
.79128 .41269 m .7462 .38529 L .7175 .42815 L p .536 .562 .828 r
F P
0 g
s
.75568 .46322 m .78499 .50528 L .82617 .44953 L p .453 .449 .764 r
F P
0 g
s
.82617 .44953 m .79128 .41269 L .75568 .46322 L p .453 .449 .764 r
F P
0 g
s
.57267 .40551 m .60415 .41067 L .62934 .3914 L p .713 .903 .963 r
F P
0 g
s
.67403 .40338 m .62934 .3914 L .60415 .41067 L p .677 .768 .92 r
F P
0 g
s
.62934 .3914 m .67403 .40338 L .69539 .36983 L p .684 .765 .913 r
F P
0 g
s
.7462 .38529 m .69539 .36983 L .67403 .40338 L p .61 .663 .876 r
F P
0 g
s
.78499 .50528 m .8025 .55044 L .84714 .49238 L p .345 .302 .667 r
F P
0 g
s
.84714 .49238 m .82617 .44953 L .78499 .50528 L p .345 .302 .667 r
F P
0 g
s
.27342 .61866 m .28303 .65527 L .36059 .6906 L p .854 .5 .38 r
F P
0 g
s
.37521 .71238 m .36059 .6906 L .28303 .65527 L p .741 .227 0 r
F P
0 g
s
.36059 .6906 m .37521 .71238 L .45771 .73052 L p .694 .221 .124 r
F P
0 g
s
.45369 .38688 m .40862 .38005 L .42878 .40175 L p .447 .653 .947 r
F P
0 g
s
.42878 .40175 m .46566 .40006 L .45369 .38688 L p .447 .653 .947 r
F P
0 g
s
.54221 .73705 m .54548 .73419 L .45771 .73052 L p .172 0 0 r
F P
0 g
s
.54548 .73419 m .54221 .73705 L .61557 .72767 L p .018 0 0 r
F P
0 g
s
.61557 .72767 m .63146 .72318 L .54548 .73419 L p .018 0 0 r
F P
0 g
s
.34713 .35168 m .29445 .36191 L .31223 .40768 L p .74 .78 .886 r
F P
0 g
s
.31223 .40768 m .35989 .38731 L .34713 .35168 L p .74 .78 .886 r
F P
0 g
s
.27015 .43914 m .31223 .40768 L .29445 .36191 L p .824 .82 .845 r
F P
0 g
s
.21822 .52286 m .2141 .56711 L .27342 .61866 L p .938 .685 .528 r
F P
0 g
s
.28303 .65527 m .27342 .61866 L .2141 .56711 L p .925 .545 .258 r
F P
0 g
s
.46724 .73393 m .45771 .73052 L .37521 .71238 L p .215 0 0 r
F P
0 g
s
.45771 .73052 m .46724 .73393 L .54221 .73705 L p .172 0 0 r
F P
0 g
s
.29445 .36191 m .24744 .38492 L .27015 .43914 L p .824 .82 .845 r
F P
0 g
s
.23769 .47877 m .27015 .43914 L .24744 .38492 L p .9 .844 .78 r
F P
0 g
s
.40037 .35509 m .34713 .35168 L .35989 .38731 L p .637 .722 .909 r
F P
0 g
s
.35989 .38731 m .40862 .38005 L .40037 .35509 L p .637 .722 .909 r
F P
0 g
s
.62934 .3914 m .58779 .39376 L .57267 .40551 L p .713 .903 .963 r
F P
0 g
s
.58779 .39376 m .62934 .3914 L .64372 .36777 L p .764 .879 .929 r
F P
0 g
s
.69539 .36983 m .64372 .36777 L .62934 .3914 L p .684 .765 .913 r
F P
0 g
s
.8025 .55044 m .80616 .59433 L .85154 .53701 L p .174 .075 .494 r
F P
0 g
s
.85154 .53701 m .84714 .49238 L .8025 .55044 L p .174 .075 .494 r
F P
0 g
s
.51483 .42123 m .50556 .41597 L .52933 .41717 L p .256 0 0 r
F P
0 g
s
.52933 .41717 m .52614 .4218 L .51483 .42123 L p .256 0 0 r
F P
0 g
s
.50556 .41597 m .51483 .42123 L .50441 .41844 L p .311 0 0 r
F P
0 g
s
.72714 .67464 m .70857 .69808 L .76971 .66037 L p 0 0 0 r
F P
0 g
s
.76971 .66037 m .79506 .63242 L .72714 .67464 L p 0 0 0 r
F P
0 g
s
.63146 .72318 m .61557 .72767 L .681 .70637 L p .243 .748 .701 r
F P
0 g
s
.681 .70637 m .70857 .69808 L .63146 .72318 L p .243 .748 .701 r
F P
0 g
s
.48359 .41008 m .49934 .41641 L p .49597 .41372 L 0 .335 .733 r
F P
0 g
s
.46566 .40006 m .48861 .4104 L p .49043 .40755 L .028 .406 .857 r
F P
0 g
s
.48861 .4104 m .49597 .41372 L .49043 .40755 L p .028 .406 .857 r
F P
0 g
s
.51467 .44044 m .49356 .4118 L p .49597 .41372 L .668 .188 0 r
F P
0 g
s
.49356 .4118 m .49043 .40755 L .49597 .41372 L p .668 .188 0 r
F P
0 g
s
.49934 .41641 m .50441 .41844 L .49597 .41372 L p 0 .335 .733 r
F P
0 g
s
.5161 .44202 m .49597 .41372 L .50441 .41844 L p .787 .293 .025 r
F P
0 g
s
.49597 .41372 m .51479 .44017 L p .51467 .44044 L .668 .188 0 r
F P
0 g
s
.51479 .44017 m .5161 .44202 L .51467 .44044 L p .668 .188 0 r
F P
0 g
s
.51467 .44044 m .5232 .48247 L .51458 .44065 L p .77 .498 0 r
F P
0 g
s
.49043 .40755 m .51309 .43829 L p .51417 .43866 L 0 .083 .642 r
F P
0 g
s
.51309 .43829 m .51467 .44044 L .51417 .43866 L p 0 .083 .642 r
F P
0 g
s
.51458 .44065 m .51417 .43866 L .51467 .44044 L p .77 .498 0 r
F P
0 g
s
.50441 .41844 m .5183 .44324 L .5161 .44202 L p .787 .293 .025 r
F P
0 g
s
.5161 .44202 m .5232 .48247 L .51467 .44044 L closepath p .952 .604 .288 r
F P
0 g
s
.51417 .43866 m .5232 .48247 L .51504 .43895 L p 0 0 .457 r
F P
0 g
s
.51504 .43895 m .51465 .43687 L .51417 .43866 L p 0 0 .457 r
F P
0 g
s
.51417 .43866 m .49174 .40551 L p .49043 .40755 L 0 .083 .642 r
F P
0 g
s
.49174 .40551 m .48841 .40058 L .49043 .40755 L p 0 .083 .642 r
F P
0 g
s
.24744 .38492 m .21087 .41872 L .23769 .47877 L p .9 .844 .78 r
F P
0 g
s
.21822 .52286 m .23769 .47877 L .21087 .41872 L p .968 .844 .666 r
F P
0 g
s
.44908 .37187 m .40037 .35509 L .40862 .38005 L p .492 .628 .911 r
F P
0 g
s
.40862 .38005 m .45369 .38688 L .44908 .37187 L p .492 .628 .911 r
F P
0 g
s
.64372 .36777 m .69539 .36983 L .69874 .333 L p .689 .76 .906 r
F P
0 g
s
.69539 .36983 m .7462 .38529 L .75187 .3377 L p .59 .671 .896 r
F P
0 g
s
.75187 .3377 m .69874 .333 L .69539 .36983 L p .59 .671 .896 r
F P
0 g
s
.7462 .38529 m .79128 .41269 L .79954 .35602 L p .473 .562 .865 r
F P
0 g
s
.79954 .35602 m .75187 .3377 L .7462 .38529 L p .473 .562 .865 r
F P
0 g
s
.49043 .40755 m .45369 .38688 L .46566 .40006 L p .028 .406 .857 r
F P
0 g
s
.28303 .65527 m .30508 .68075 L .37521 .71238 L p .741 .227 0 r
F P
0 g
s
.37521 .71238 m .397 .71849 L .46724 .73393 L p .215 0 0 r
F P
0 g
s
.397 .71849 m .37521 .71238 L .30508 .68075 L p 0 .418 .776 r
F P
0 g
s
.64372 .36777 m .59617 .37948 L .58779 .39376 L p .764 .879 .929 r
F P
0 g
s
.59617 .37948 m .64372 .36777 L .64533 .34212 L p .784 .839 .894 r
F P
0 g
s
.69874 .333 m .64533 .34212 L .64372 .36777 L p .689 .76 .906 r
F P
0 g
s
.55375 .41077 m .58779 .39376 L .59617 .37948 L p .831 .988 .87 r
F P
0 g
s
.80616 .59433 m .79506 .63242 L .83823 .5787 L p 0 0 .127 r
F P
0 g
s
.83823 .5787 m .85154 .53701 L .80616 .59433 L p 0 0 .127 r
F P
0 g
s
.79128 .41269 m .82617 .44953 L .83678 .38653 L p .317 .409 .799 r
F P
0 g
s
.83678 .38653 m .79954 .35602 L .79128 .41269 L p .317 .409 .799 r
F P
0 g
s
.2141 .56711 m .22637 .60689 L .28303 .65527 L p .925 .545 .258 r
F P
0 g
s
.30508 .68075 m .28303 .65527 L .22637 .60689 L p .645 .125 0 r
F P
0 g
s
.21087 .41872 m .18879 .46019 L .21822 .52286 L p .968 .844 .666 r
F P
0 g
s
.2141 .56711 m .21822 .52286 L .18879 .46019 L p .997 .772 .432 r
F P
0 g
s
.48841 .40058 m .44908 .37187 L .45369 .38688 L p .253 .452 .862 r
F P
0 g
s
.45369 .38688 m .49043 .40755 L .48841 .40058 L p .253 .452 .862 r
F P
0 g
s
.4054 .32945 m .35333 .31464 L .34713 .35168 L p .642 .716 .902 r
F P
0 g
s
.34713 .35168 m .40037 .35509 L .4054 .32945 L p .642 .716 .902 r
F P
0 g
s
.29445 .36191 m .34713 .35168 L .35333 .31464 L p .733 .802 .907 r
F P
0 g
s
.53817 .72206 m .54221 .73705 L .46724 .73393 L p .499 .807 1 r
F P
0 g
s
.54221 .73705 m .53817 .72206 L .59593 .71459 L p .547 .841 .998 r
F P
0 g
s
.59593 .71459 m .61557 .72767 L .54221 .73705 L p .547 .841 .998 r
F P
0 g
s
.45249 .35661 m .4054 .32945 L .40037 .35509 L p .539 .615 .877 r
F P
0 g
s
.40037 .35509 m .44908 .37187 L .45249 .35661 L p .539 .615 .877 r
F P
0 g
s
.70857 .69808 m .681 .70637 L .73229 .67455 L p .549 .93 .844 r
F P
0 g
s
.73229 .67455 m .76971 .66037 L .70857 .69808 L p .549 .93 .844 r
F P
0 g
s
.47906 .71957 m .46724 .73393 L .397 .71849 L p .473 .771 .996 r
F P
0 g
s
.46724 .73393 m .47906 .71957 L .53817 .72206 L p .499 .807 1 r
F P
0 g
s
.59617 .37948 m .55757 .4041 L .55375 .41077 L p .831 .988 .87 r
F P
0 g
s
.55757 .4041 m .59617 .37948 L .59675 .36413 L p .881 .91 .844 r
F P
0 g
s
.64533 .34212 m .59675 .36413 L .59617 .37948 L p .784 .839 .894 r
F P
0 g
s
.35333 .31464 m .3012 .31377 L .29445 .36191 L p .733 .802 .907 r
F P
0 g
s
.24744 .38492 m .29445 .36191 L .3012 .31377 L p .823 .881 .887 r
F P
0 g
s
.52102 .44396 m .51483 .42123 L .52614 .4218 L p .629 .207 .223 r
F P
0 g
s
.52614 .4218 m .52399 .44411 L .52102 .44396 L p .629 .207 .223 r
F P
0 g
s
.52399 .44411 m .52614 .4218 L .53714 .4201 L p .495 .093 .207 r
F P
0 g
s
.82617 .44953 m .84714 .49238 L .85931 .42647 L p .072 .16 .651 r
F P
0 g
s
.85931 .42647 m .83678 .38653 L .82617 .44953 L p .072 .16 .651 r
F P
0 g
s
.5183 .44324 m .50441 .41844 L .51483 .42123 L p .728 .275 .175 r
F P
0 g
s
.51483 .42123 m .52102 .44396 L .5183 .44324 L p .728 .275 .175 r
F P
0 g
s
.53714 .4201 m .52687 .44367 L .52399 .44411 L p .495 .093 .207 r
F P
0 g
s
.52687 .44367 m .53714 .4201 L .54668 .41629 L p .283 0 .116 r
F P
0 g
s
.49016 .39355 m .45249 .35661 L .44908 .37187 L p .407 .481 .824 r
F P
0 g
s
.44908 .37187 m .48841 .40058 L .49016 .39355 L p .407 .481 .824 r
F P
0 g
s
.61557 .72767 m .59593 .71459 L .6471 .69772 L p .606 .865 .992 r
F P
0 g
s
.6471 .69772 m .681 .70637 L .61557 .72767 L p .606 .865 .992 r
F P
0 g
s
.59675 .36413 m .64533 .34212 L .6335 .31721 L p .783 .794 .862 r
F P
0 g
s
.64533 .34212 m .69874 .333 L .68265 .2968 L p .691 .753 .898 r
F P
0 g
s
.68265 .2968 m .6335 .31721 L .64533 .34212 L p .691 .753 .898 r
F P
0 g
s
.69874 .333 m .75187 .3377 L .73211 .29038 L p .574 .687 .918 r
F P
0 g
s
.73211 .29038 m .68265 .2968 L .69874 .333 L p .574 .687 .918 r
F P
0 g
s
.79506 .63242 m .76971 .66037 L .80797 .61266 L p .601 .865 .525 r
F P
0 g
s
.80797 .61266 m .83823 .5787 L .79506 .63242 L p .601 .865 .525 r
F P
0 g
s
.3012 .31377 m .25415 .3273 L .24744 .38492 L p .823 .881 .887 r
F P
0 g
s
.21087 .41872 m .24744 .38492 L .25415 .3273 L p .909 .946 .815 r
F P
0 g
s
.59675 .36413 m .55769 .39701 L .55757 .4041 L p .881 .91 .844 r
F P
0 g
s
.55769 .39701 m .59675 .36413 L .58928 .34938 L p .863 .821 .805 r
F P
0 g
s
.6335 .31721 m .58928 .34938 L .59675 .36413 L p .783 .794 .862 r
F P
0 g
s
.18879 .46019 m .18411 .50521 L .2141 .56711 L p .997 .772 .432 r
F P
0 g
s
.22637 .60689 m .2141 .56711 L .18411 .50521 L p .812 .466 0 r
F P
0 g
s
.30508 .68075 m .33778 .69172 L .397 .71849 L p 0 .418 .776 r
F P
0 g
s
.4239 .70731 m .397 .71849 L .33778 .69172 L p .472 .738 .986 r
F P
0 g
s
.397 .71849 m .4239 .70731 L .47906 .71957 L p .473 .771 .996 r
F P
0 g
s
.22637 .60689 m .25439 .63766 L .30508 .68075 L p .645 .125 0 r
F P
0 g
s
.33778 .69172 m .30508 .68075 L .25439 .63766 L p .06 .475 .888 r
F P
0 g
s
.53217 .43956 m .55757 .4041 L .55769 .39701 L p .959 .944 .699 r
F P
0 g
s
.49553 .38724 m .46376 .34279 L .45249 .35661 L p .51 .507 .789 r
F P
0 g
s
.45249 .35661 m .49016 .39355 L .49553 .38724 L p .51 .507 .789 r
F P
0 g
s
.4054 .32945 m .45249 .35661 L .46376 .34279 L p .582 .614 .849 r
F P
0 g
s
.46376 .34279 m .42367 .30598 L .4054 .32945 L p .582 .614 .849 r
F P
0 g
s
.35333 .31464 m .4054 .32945 L .42367 .30598 L p .649 .714 .895 r
F P
0 g
s
.51465 .43687 m .49016 .39355 L .48841 .40058 L p .211 .276 .713 r
F P
0 g
s
.48841 .40058 m .51417 .43866 L .51465 .43687 L p .211 .276 .713 r
F P
0 g
s
.84714 .49238 m .85154 .53701 L .86405 .47189 L p 0 0 .3 r
F P
0 g
s
.86405 .47189 m .85931 .42647 L .84714 .49238 L p 0 0 .3 r
F P
0 g
s
.75187 .3377 m .79954 .35602 L .77698 .29909 L p .4 .575 .909 r
F P
0 g
s
.77698 .29909 m .73211 .29038 L .75187 .3377 L p .4 .575 .909 r
F P
0 g
s
.55769 .39701 m .53217 .43775 L .53217 .43956 L p .959 .944 .699 r
F P
0 g
s
.53217 .43775 m .55769 .39701 L .55406 .39025 L p .937 .827 .711 r
F P
0 g
s
.58928 .34938 m .55406 .39025 L .55769 .39701 L p .863 .821 .805 r
F P
0 g
s
.55406 .39025 m .58928 .34938 L .57441 .3369 L p .826 .746 .776 r
F P
0 g
s
.58928 .34938 m .6335 .31721 L .60906 .29591 L p .768 .752 .838 r
F P
0 g
s
.60906 .29591 m .57441 .3369 L .58928 .34938 L p .768 .752 .838 r
F P
0 g
s
.51606 .43528 m .49553 .38724 L .49016 .39355 L p .419 .376 .704 r
F P
0 g
s
.49016 .39355 m .51465 .43687 L .51606 .43528 L p .419 .376 .704 r
F P
0 g
s
.42367 .30598 m .37888 .28035 L .35333 .31464 L p .649 .714 .895 r
F P
0 g
s
.3012 .31377 m .35333 .31464 L .37888 .28035 L p .716 .818 .929 r
F P
0 g
s
.681 .70637 m .6471 .69772 L .68664 .6727 L p .663 .873 .978 r
F P
0 g
s
.68664 .6727 m .73229 .67455 L .681 .70637 L p .663 .873 .978 r
F P
0 g
s
.6335 .31721 m .68265 .2968 L .64792 .26552 L p .69 .744 .892 r
F P
0 g
s
.64792 .26552 m .60906 .29591 L .6335 .31721 L p .69 .744 .892 r
F P
0 g
s
.55406 .39025 m .53121 .43604 L .53217 .43775 L p .937 .827 .711 r
F P
0 g
s
.53121 .43604 m .55406 .39025 L .54704 .38457 L p .873 .726 .697 r
F P
0 g
s
.57441 .3369 m .54704 .38457 L .55406 .39025 L p .826 .746 .776 r
F P
0 g
s
.25415 .3273 m .21719 .3544 L .21087 .41872 L p .909 .946 .815 r
F P
0 g
s
.18879 .46019 m .21087 .41872 L .21719 .3544 L p .945 .939 .603 r
F P
0 g
s
.5338 .68988 m .53817 .72206 L .47906 .71957 L p .664 .746 .911 r
F P
0 g
s
.53817 .72206 m .5338 .68988 L .57469 .68449 L p .654 .739 .912 r
F P
0 g
s
.57469 .68449 m .59593 .71459 L .53817 .72206 L p .654 .739 .912 r
F P
0 g
s
.50397 .38235 m .48175 .332 L .46376 .34279 L p .584 .534 .765 r
F P
0 g
s
.46376 .34279 m .49553 .38724 L .50397 .38235 L p .584 .534 .765 r
F P
0 g
s
.42367 .30598 m .46376 .34279 L .48175 .332 L p .622 .621 .829 r
F P
0 g
s
.51825 .43405 m .50397 .38235 L .49553 .38724 L p .54 .44 .69 r
F P
0 g
s
.49553 .38724 m .51606 .43528 L .51825 .43405 L p .54 .44 .69 r
F P
0 g
s
.49189 .68808 m .47906 .71957 L .4239 .70731 L p .672 .754 .913 r
F P
0 g
s
.47906 .71957 m .49189 .68808 L .5338 .68988 L p .664 .746 .911 r
F P
0 g
s
.54704 .38457 m .52938 .43461 L .53121 .43604 L p .873 .726 .697 r
F P
0 g
s
.52938 .43461 m .54704 .38457 L .53737 .38061 L p .811 .651 .685 r
F P
0 g
s
.54704 .38457 m .57441 .3369 L .55371 .32815 L p .784 .687 .757 r
F P
0 g
s
.55371 .32815 m .53737 .38061 L .54704 .38457 L p .784 .687 .757 r
F P
0 g
s
.52399 .44411 m .5232 .48247 L .52102 .44396 L closepath p .7 .405 .473 r
F P
0 g
s
.52687 .44367 m .5232 .48247 L .52399 .44411 L closepath p .602 .324 .468 r
F P
0 g
s
.52102 .44396 m .5232 .48247 L .5183 .44324 L closepath p .788 .475 .459 r
F P
0 g
s
.52936 .44268 m .5232 .48247 L .52687 .44367 L closepath p .468 .212 .442 r
F P
0 g
s
.5183 .44324 m .5232 .48247 L .5161 .44202 L closepath p .878 .544 .415 r
F P
0 g
s
.57441 .3369 m .60906 .29591 L .57449 .28088 L p .746 .714 .822 r
F P
0 g
s
.57449 .28088 m .55371 .32815 L .57441 .3369 L p .746 .714 .822 r
F P
0 g
s
.53119 .44126 m .5232 .48247 L .52936 .44268 L closepath p .24 .021 .367 r
F P
0 g
s
.52099 .43332 m .51457 .37944 L .50397 .38235 L p .624 .492 .681 r
F P
0 g
s
.50397 .38235 m .51825 .43405 L .52099 .43332 L p .624 .492 .681 r
F P
0 g
s
.48175 .332 m .50397 .38235 L .51457 .37944 L p .643 .564 .751 r
F P
0 g
s
.79954 .35602 m .83678 .38653 L .81237 .3227 L p .096 .352 .82 r
F P
0 g
s
.81237 .3227 m .77698 .29909 L .79954 .35602 L p .096 .352 .82 r
F P
0 g
s
.18411 .50521 m .19805 .54897 L .22637 .60689 L p .812 .466 0 r
F P
0 g
s
.25439 .63766 m .22637 .60689 L .19805 .54897 L p 0 .12 .669 r
F P
0 g
s
.59593 .71459 m .57469 .68449 L .61064 .67234 L p .644 .734 .915 r
F P
0 g
s
.61064 .67234 m .6471 .69772 L .59593 .71459 L p .644 .734 .915 r
F P
0 g
s
.76971 .66037 m .73229 .67455 L .76364 .63463 L p .761 .984 .907 r
F P
0 g
s
.76364 .63463 m .80797 .61266 L .76971 .66037 L p .761 .984 .907 r
F P
0 g
s
.53737 .38061 m .52687 .43361 L .52938 .43461 L p .811 .651 .685 r
F P
0 g
s
.52687 .43361 m .53737 .38061 L .52613 .37883 L p .751 .591 .678 r
F P
0 g
s
.53737 .38061 m .55371 .32815 L .52948 .32421 L p .74 .639 .747 r
F P
0 g
s
.52948 .32421 m .52613 .37883 L .53737 .38061 L p .74 .639 .747 r
F P
0 g
s
.48175 .332 m .45352 .2875 L .42367 .30598 L p .622 .621 .829 r
F P
0 g
s
.37888 .28035 m .42367 .30598 L .45352 .2875 L p .657 .713 .89 r
F P
0 g
s
.52397 .43317 m .52613 .37883 L .51457 .37944 L p .691 .54 .677 r
F P
0 g
s
.51457 .37944 m .52099 .43332 L .52397 .43317 L p .691 .54 .677 r
F P
0 g
s
.50453 .32554 m .51457 .37944 L .52613 .37883 L p .694 .599 .745 r
F P
0 g
s
.51457 .37944 m .50453 .32554 L .48175 .332 L p .643 .564 .751 r
F P
0 g
s
.52613 .37883 m .52397 .43317 L .52687 .43361 L p .751 .591 .678 r
F P
0 g
s
.52613 .37883 m .52948 .32421 L .50453 .32554 L p .694 .599 .745 r
F P
0 g
s
.45352 .2875 m .48175 .332 L .50453 .32554 L p .658 .635 .816 r
F P
0 g
s
.53121 .43604 m .5232 .48247 L .53217 .43775 L closepath p .991 .787 .531 r
F P
0 g
s
.51465 .43687 m .5232 .48247 L .51606 .43528 L closepath p .284 .186 .563 r
F P
0 g
s
.37888 .28035 m .33354 .2687 L .3012 .31377 L p .716 .818 .929 r
F P
0 g
s
.25415 .3273 m .3012 .31377 L .33354 .2687 L p .782 .932 .931 r
F P
0 g
s
.68265 .2968 m .73211 .29038 L .68743 .24905 L p .566 .711 .939 r
F P
0 g
s
.68743 .24905 m .64792 .26552 L .68265 .2968 L p .566 .711 .939 r
F P
0 g
s
.52938 .43461 m .5232 .48247 L .53121 .43604 L closepath p .911 .683 .579 r
F P
0 g
s
.85154 .53701 m .83823 .5787 L .84972 .51785 L p .802 .804 .315 r
F P
0 g
s
.84972 .51785 m .86405 .47189 L .85154 .53701 L p .802 .804 .315 r
F P
0 g
s
.51606 .43528 m .5232 .48247 L .51825 .43405 L closepath p .478 .32 .587 r
F P
0 g
s
.55371 .32815 m .57449 .28088 L .53374 .27406 L p .72 .682 .813 r
F P
0 g
s
.53374 .27406 m .52948 .32421 L .55371 .32815 L p .72 .682 .813 r
F P
0 g
s
.52687 .43361 m .5232 .48247 L .52938 .43461 L closepath p .829 .6 .591 r
F P
0 g
s
.51825 .43405 m .5232 .48247 L .52099 .43332 L closepath p .595 .404 .593 r
F P
0 g
s
.25439 .63766 m .29564 .6555 L .33778 .69172 L p .06 .475 .888 r
F P
0 g
s
.37787 .68617 m .33778 .69172 L .29564 .6555 L p .491 .711 .968 r
F P
0 g
s
.33778 .69172 m .37787 .68617 L .4239 .70731 L p .472 .738 .986 r
F P
0 g
s
.52397 .43317 m .5232 .48247 L .52687 .43361 L closepath p .755 .532 .594 r
F P
0 g
s
.52099 .43332 m .5232 .48247 L .52397 .43317 L closepath p .68 .47 .595 r
F P
0 g
s
.45296 .67923 m .4239 .70731 L .37787 .68617 L p .677 .764 .917 r
F P
0 g
s
.4239 .70731 m .45296 .67923 L .49189 .68808 L p .672 .754 .913 r
F P
0 g
s
.49172 .27637 m .50453 .32554 L .52948 .32421 L p .69 .656 .811 r
F P
0 g
s
.50453 .32554 m .49172 .27637 L .45352 .2875 L p .658 .635 .816 r
F P
0 g
s
.52948 .32421 m .53374 .27406 L .49172 .27637 L p .69 .656 .811 r
F P
0 g
s
.60906 .29591 m .64792 .26552 L .59795 .24325 L p .687 .735 .888 r
F P
0 g
s
.59795 .24325 m .57449 .28088 L .60906 .29591 L p .687 .735 .888 r
F P
0 g
s
.21719 .3544 m .19474 .39273 L .18879 .46019 L p .945 .939 .603 r
F P
0 g
s
.18411 .50521 m .18879 .46019 L .19474 .39273 L p .722 .646 .088 r
F P
0 g
s
.42172 .25309 m .45352 .2875 L .49172 .27637 L p .665 .716 .886 r
F P
0 g
s
.45352 .2875 m .42172 .25309 L .37888 .28035 L p .657 .713 .89 r
F P
0 g
s
.6471 .69772 m .61064 .67234 L .638 .65447 L p .633 .733 .92 r
F P
0 g
s
.638 .65447 m .68664 .6727 L .6471 .69772 L p .633 .733 .92 r
F P
0 g
s
.33354 .2687 m .37888 .28035 L .42172 .25309 L p .688 .824 .948 r
F P
0 g
s
.52962 .64369 m .5338 .68988 L .49189 .68808 L p .704 .676 .82 r
F P
0 g
s
.5338 .68988 m .52962 .64369 L .55442 .64032 L p .67 .651 .822 r
F P
0 g
s
.55442 .64032 m .57469 .68449 L .5338 .68988 L p .67 .651 .822 r
F P
0 g
s
.83678 .38653 m .85931 .42647 L .83391 .35937 L p 0 0 .479 r
F P
0 g
s
.83391 .35937 m .81237 .3227 L .83678 .38653 L p 0 0 .479 r
F P
0 g
s
.50417 .64257 m .49189 .68808 L .45296 .67923 L p .735 .708 .826 r
F P
0 g
s
.49189 .68808 m .50417 .64257 L .52962 .64369 L p .704 .676 .82 r
F P
0 g
s
.57449 .28088 m .59795 .24325 L .53856 .2331 L p .681 .727 .885 r
F P
0 g
s
.53856 .2331 m .53374 .27406 L .57449 .28088 L p .681 .727 .885 r
F P
0 g
s
.19805 .54897 m .22973 .58637 L .25439 .63766 L p 0 .12 .669 r
F P
0 g
s
.29564 .6555 m .25439 .63766 L .22973 .58637 L p .257 .512 .905 r
F P
0 g
s
.73211 .29038 m .77698 .29909 L .72362 .24888 L p .322 .604 .949 r
F P
0 g
s
.72362 .24888 m .68743 .24905 L .73211 .29038 L p .322 .604 .949 r
F P
0 g
s
.5232 .48247 m .53136 .53004 L .52948 .53143 L closepath p .396 .262 .579 r
F P
0 g
s
.5232 .48247 m .53236 .52837 L .53136 .53004 L closepath p .122 .078 .53 r
F P
0 g
s
.5232 .48247 m .52949 .52354 L .53137 .52494 L closepath p .922 .578 .368 r
F P
0 g
s
.5232 .48247 m .52948 .53143 L .52692 .53239 L closepath p .542 .365 .591 r
F P
0 g
s
.5232 .48247 m .52692 .52257 L .52949 .52354 L closepath p .832 .509 .442 r
F P
0 g
s
.5232 .48247 m .52692 .53239 L .52395 .53282 L closepath p .64 .438 .594 r
F P
0 g
s
.5232 .48247 m .52394 .52214 L .52692 .52257 L closepath p .744 .44 .468 r
F P
0 g
s
.5232 .48247 m .52091 .53268 L .5181 .53197 L closepath p .791 .564 .593 r
F P
0 g
s
.5232 .48247 m .52395 .53282 L .52091 .53268 L closepath p .718 .501 .595 r
F P
0 g
s
.5232 .48247 m .52087 .52228 L .52394 .52214 L closepath p .653 .367 .472 r
F P
0 g
s
.5232 .48247 m .5181 .53197 L .51585 .53078 L closepath p .869 .639 .587 r
F P
0 g
s
.5232 .48247 m .51806 .523 L .52087 .52228 L closepath p .542 .274 .458 r
F P
0 g
s
.5232 .48247 m .51585 .53078 L .51438 .52924 L closepath p .955 .733 .564 r
F P
0 g
s
.5232 .48247 m .51581 .5242 L .51806 .523 L closepath p .373 .132 .414 r
F P
0 g
s
.51386 .5275 m .5232 .48247 L .51479 .52705 L p .993 .827 .459 r
F P
0 g
s
.51479 .52705 m .51438 .52924 L .51386 .5275 L p .993 .827 .459 r
F P
0 g
s
.48829 .56199 m .51271 .52805 L p .51386 .5275 L .882 .961 .626 r
F P
0 g
s
.51436 .52575 m .5232 .48247 L .5143 .52539 L p 0 0 0 r
F P
0 g
s
.5143 .52539 m .51386 .5275 L .51436 .52575 L p 0 0 0 r
F P
0 g
s
.51271 .52805 m .51436 .52575 L .51386 .5275 L p .882 .961 .626 r
F P
0 g
s
.51386 .5275 m .49008 .56327 L p .48829 .56199 L .882 .961 .626 r
F P
0 g
s
.49008 .56327 m .48646 .56871 L .48829 .56199 L p .882 .961 .626 r
F P
0 g
s
.4592 .57378 m .48573 .56017 L p .48829 .56199 L .705 .984 .821 r
F P
0 g
s
.51436 .52575 m .49174 .55719 L p .49395 .55595 L 0 0 0 r
F P
0 g
s
.49174 .55719 m .48829 .56199 L .49395 .55595 L p 0 0 0 r
F P
0 g
s
.49395 .55595 m .51443 .5262 L p .51436 .52575 L 0 0 0 r
F P
0 g
s
.48646 .56871 m .51386 .5275 L .51438 .52924 L p .963 .892 .709 r
F P
0 g
s
.51438 .52924 m .4886 .57538 L .48646 .56871 L p .963 .892 .709 r
F P
0 g
s
.4886 .57538 m .51438 .52924 L .51585 .53078 L p .909 .776 .703 r
F P
0 g
s
.51581 .5242 m .49395 .55595 L .50284 .55127 L p .14 0 .05 r
F P
0 g
s
.47851 .56361 m .4971 .55418 L p .49395 .55595 L .34 .79 .64 r
F P
0 g
s
.4971 .55418 m .50284 .55127 L .49395 .55595 L p .34 .79 .64 r
F P
0 g
s
.48573 .56017 m .49395 .55595 L .48829 .56199 L p .705 .984 .821 r
F P
0 g
s
.51443 .5262 m .51581 .5242 L .51436 .52575 L p 0 0 0 r
F P
0 g
s
.5232 .48247 m .51436 .52575 L .51581 .5242 L closepath p .045 0 .285 r
F P
0 g
s
.53193 .52623 m .5232 .48247 L .53237 .52661 L p 0 0 .306 r
F P
0 g
s
.53137 .52494 m .53237 .52661 L .53194 .52455 L p .929 .595 .146 r
F P
0 g
s
.53194 .52455 m .5232 .48247 L .53137 .52494 L p .929 .595 .146 r
F P
0 g
s
.53137 .52494 m .52949 .52354 L p .53081 .52533 L .784 .285 0 r
F P
0 g
s
.53237 .52661 m .53137 .52494 L p .5328 .52699 L 0 0 .477 r
F P
0 g
s
.55941 .5653 m .53237 .52661 L p .5328 .52699 L 0 0 .477 r
F P
0 g
s
.53237 .52661 m .53236 .52837 L .53193 .52623 L p 0 0 .306 r
F P
0 g
s
.55928 .57208 m .53236 .52837 L .53237 .52661 L p .016 .179 .69 r
F P
0 g
s
.53237 .52661 m .55941 .5653 L .55928 .57208 L p .016 .179 .69 r
F P
0 g
s
.5556 .55883 m .55941 .5653 L p .55583 .56013 L 0 0 .477 r
F P
0 g
s
.53137 .52494 m .5556 .55883 L p .55583 .56013 L 0 0 .477 r
F P
0 g
s
.5556 .55883 m .53137 .52494 L p .53081 .52533 L .784 .285 0 r
F P
0 g
s
.5482 .5534 m .5556 .55883 L p .55225 .5543 L .784 .285 0 r
F P
0 g
s
.52949 .52354 m .5482 .5534 L p .55225 .5543 L .784 .285 0 r
F P
0 g
s
.53136 .53004 m .55525 .57845 L .54781 .58373 L p .481 .407 .696 r
F P
0 g
s
.55525 .57845 m .53136 .53004 L .53236 .52837 L p .32 .325 .709 r
F P
0 g
s
.53236 .52837 m .55928 .57208 L .55525 .57845 L p .32 .325 .709 r
F P
0 g
s
.5482 .5534 m .53802 .54961 L p .54426 .55251 L .381 0 0 r
F P
0 g
s
.5556 .55883 m .5482 .5534 L p .55537 .55756 L 0 .305 .745 r
F P
0 g
s
.59401 .58 m .5556 .55883 L p .55537 .55756 L 0 .305 .745 r
F P
0 g
s
.57807 .56823 m .59401 .58 L p .58679 .57581 L 0 .305 .745 r
F P
0 g
s
.5482 .5534 m .57807 .56823 L p .58679 .57581 L 0 .305 .745 r
F P
0 g
s
.57807 .56823 m .5482 .5534 L p .54426 .55251 L .381 0 0 r
F P
0 g
s
.60199 .59388 m .55941 .5653 L .5556 .55883 L p .077 .398 .854 r
F P
0 g
s
.5556 .55883 m .59401 .58 L .60199 .59388 L p .077 .398 .854 r
F P
0 g
s
.55583 .55998 m .57807 .56823 L p .57174 .56528 L .381 0 0 r
F P
0 g
s
.53802 .54961 m .55583 .55998 L p .57174 .56528 L .381 0 0 r
F P
0 g
s
.52692 .53239 m .53776 .58736 L .52618 .58899 L p .658 .515 .678 r
F P
0 g
s
.53776 .58736 m .52692 .53239 L .52948 .53143 L p .583 .465 .684 r
F P
0 g
s
.52948 .53143 m .54781 .58373 L .53776 .58736 L p .583 .465 .684 r
F P
0 g
s
.54781 .58373 m .52948 .53143 L .53136 .53004 L p .481 .407 .696 r
F P
0 g
s
.52618 .58899 m .52395 .53282 L .52692 .53239 L p .658 .515 .678 r
F P
0 g
s
.5298 .55625 m .55583 .55998 L p .55113 .55806 L .384 0 0 r
F P
0 g
s
.52618 .54791 m .5298 .55625 L p .55113 .55806 L .384 0 0 r
F P
0 g
s
.51429 .58845 m .52091 .53268 L .52395 .53282 L p .722 .565 .677 r
F P
0 g
s
.52395 .53282 m .52618 .58899 L .51429 .58845 L p .722 .565 .677 r
F P
0 g
s
.50332 .58579 m .5181 .53197 L .52091 .53268 L p .782 .62 .68 r
F P
0 g
s
.52091 .53268 m .51429 .58845 L .50332 .58579 L p .782 .62 .68 r
F P
0 g
s
.49444 .58127 m .51585 .53078 L .5181 .53197 L p .844 .688 .689 r
F P
0 g
s
.5181 .53197 m .50332 .58579 L .49444 .58127 L p .844 .688 .689 r
F P
0 g
s
.51585 .53078 m .49444 .58127 L .4886 .57538 L p .909 .776 .703 r
F P
0 g
s
.51399 .54848 m .50298 .55751 L .5298 .55625 L p .265 0 0 r
F P
0 g
s
.5298 .55625 m .50298 .55751 L p .51031 .5546 L .383 .808 .969 r
F P
0 g
s
.52394 .52214 m .52618 .54791 L .53802 .54961 L p .686 .257 .224 r
F P
0 g
s
.55583 .55998 m .53802 .54961 L .52618 .54791 L p .384 0 0 r
F P
0 g
s
.5298 .55625 m .52618 .54791 L .51399 .54848 L p .265 0 0 r
F P
0 g
s
.5345 .54498 m .5298 .55625 L p .51031 .5546 L .383 .808 .969 r
F P
0 g
s
.55583 .55998 m .5298 .55625 L p .54125 .55511 L .314 .743 .972 r
F P
0 g
s
.57885 .55137 m .55583 .55998 L p .54125 .55511 L .314 .743 .972 r
F P
0 g
s
.57807 .56823 m .55583 .55998 L p .57005 .56126 L .309 .694 .978 r
F P
0 g
s
.61642 .56546 m .57807 .56823 L p .57005 .56126 L .309 .694 .978 r
F P
0 g
s
.73229 .67455 m .68664 .6727 L .7101 .64163 L p .705 .863 .957 r
F P
0 g
s
.7101 .64163 m .76364 .63463 L .73229 .67455 L p .705 .863 .957 r
F P
0 g
s
.33354 .2687 m .29219 .2728 L .25415 .3273 L p .782 .932 .931 r
F P
0 g
s
.21719 .3544 m .25415 .3273 L .29219 .2728 L p .791 .998 .801 r
F P
0 g
s
.57469 .68449 m .55442 .64032 L .57606 .63276 L p .632 .631 .832 r
F P
0 g
s
.57606 .63276 m .61064 .67234 L .57469 .68449 L p .632 .631 .832 r
F P
0 g
s
.4772 .23655 m .49172 .27637 L .53374 .27406 L p .674 .721 .885 r
F P
0 g
s
.49172 .27637 m .4772 .23655 L .42172 .25309 L p .665 .716 .886 r
F P
0 g
s
.83823 .5787 m .80797 .61266 L .81732 .55896 L p .916 .979 .742 r
F P
0 g
s
.81732 .55896 m .84972 .51785 L .83823 .5787 L p .916 .979 .742 r
F P
0 g
s
.53374 .27406 m .53856 .2331 L .4772 .23655 L p .674 .721 .885 r
F P
0 g
s
.29564 .6555 m .34575 .65783 L .37787 .68617 L p .491 .711 .968 r
F P
0 g
s
.42082 .66407 m .37787 .68617 L .34575 .65783 L p .678 .775 .923 r
F P
0 g
s
.37787 .68617 m .42082 .66407 L .45296 .67923 L p .677 .764 .917 r
F P
0 g
s
.64792 .26552 m .68743 .24905 L .62198 .21937 L p .569 .74 .956 r
F P
0 g
s
.62198 .21937 m .59795 .24325 L .64792 .26552 L p .569 .74 .956 r
F P
0 g
s
.48062 .63705 m .45296 .67923 L .42082 .66407 L p .761 .747 .84 r
F P
0 g
s
.45296 .67923 m .48062 .63705 L .50417 .64257 L p .735 .708 .826 r
F P
0 g
s
.19474 .39273 m .18996 .43852 L .18411 .50521 L p .722 .646 .088 r
F P
0 g
s
.19805 .54897 m .18411 .50521 L .18996 .43852 L p 0 0 .485 r
F P
0 g
s
.61064 .67234 m .57606 .63276 L .5923 .62173 L p .588 .619 .85 r
F P
0 g
s
.5923 .62173 m .638 .65447 L .61064 .67234 L p .588 .619 .85 r
F P
0 g
s
.52618 .58899 m .52962 .64369 L .50417 .64257 L p .718 .62 .747 r
F P
0 g
s
.52962 .64369 m .52618 .58899 L .53776 .58736 L p .668 .581 .749 r
F P
0 g
s
.53776 .58736 m .55442 .64032 L .52962 .64369 L p .668 .581 .749 r
F P
0 g
s
.51429 .58845 m .50417 .64257 L .48062 .63705 L p .765 .665 .753 r
F P
0 g
s
.50417 .64257 m .51429 .58845 L .52618 .58899 L p .718 .62 .747 r
F P
0 g
s
.38924 .23251 m .42172 .25309 L .4772 .23655 L p .652 .817 .963 r
F P
0 g
s
.42172 .25309 m .38924 .23251 L .33354 .2687 L p .688 .824 .948 r
F P
0 g
s
.29219 .2728 m .33354 .2687 L .38924 .23251 L p .68 .944 .961 r
F P
0 g
s
.55442 .64032 m .53776 .58736 L .54781 .58373 L p .61 .547 .759 r
F P
0 g
s
.54781 .58373 m .57606 .63276 L .55442 .64032 L p .61 .547 .759 r
F P
0 g
s
.85931 .42647 m .86405 .47189 L .83846 .40551 L p .917 .644 .153 r
F P
0 g
s
.83846 .40551 m .83391 .35937 L .85931 .42647 L p .917 .644 .153 r
F P
0 g
s
.68664 .6727 m .638 .65447 L .6537 .63252 L p .622 .734 .927 r
F P
0 g
s
.6537 .63252 m .7101 .64163 L .68664 .6727 L p .622 .734 .927 r
F P
0 g
s
.22973 .58637 m .27599 .61279 L .29564 .6555 L p .257 .512 .905 r
F P
0 g
s
.34575 .65783 m .29564 .6555 L .27599 .61279 L p .52 .691 .946 r
F P
0 g
s
.42082 .66407 m .46138 .62765 L .48062 .63705 L p .761 .747 .84 r
F P
0 g
s
.50332 .58579 m .48062 .63705 L .46138 .62765 L p .81 .721 .767 r
F P
0 g
s
.48062 .63705 m .50332 .58579 L .51429 .58845 L p .765 .665 .753 r
F P
0 g
s
.34575 .65783 m .39887 .64393 L .42082 .66407 L p .678 .775 .923 r
F P
0 g
s
.46138 .62765 m .42082 .66407 L .39887 .64393 L p .781 .792 .862 r
F P
0 g
s
.77698 .29909 m .81237 .3227 L .75239 .26598 L p 0 .255 .735 r
F P
0 g
s
.75239 .26598 m .72362 .24888 L .77698 .29909 L p 0 .255 .735 r
F P
0 g
s
.29219 .2728 m .25942 .29305 L .21719 .3544 L p .791 .998 .801 r
F P
0 g
s
.19474 .39273 m .21719 .3544 L .25942 .29305 L p 0 0 0 r
F P
0 g
s
.59795 .24325 m .62198 .21937 L .5435 .20577 L p .586 .77 .967 r
F P
0 g
s
.5435 .20577 m .53856 .2331 L .59795 .24325 L p .586 .77 .967 r
F P
0 g
s
.80797 .61266 m .76364 .63463 L .77025 .59013 L p .837 .931 .892 r
F P
0 g
s
.77025 .59013 m .81732 .55896 L .80797 .61266 L p .837 .931 .892 r
F P
0 g
s
.50284 .55127 m .51806 .523 L .51581 .5242 L p .14 0 .05 r
F P
0 g
s
.46138 .62765 m .49444 .58127 L .50332 .58579 L p .81 .721 .767 r
F P
0 g
s
.5482 .5534 m .52949 .52354 L .52692 .52257 L p .771 .305 .139 r
F P
0 g
s
.57606 .63276 m .54781 .58373 L .55525 .57845 L p .54 .516 .778 r
F P
0 g
s
.55525 .57845 m .5923 .62173 L .57606 .63276 L p .54 .516 .778 r
F P
0 g
s
.51399 .54848 m .52087 .52228 L .51806 .523 L p .416 .028 .192 r
F P
0 g
s
.51806 .523 m .50284 .55127 L .51399 .54848 L p .416 .028 .192 r
F P
0 g
s
.52692 .52257 m .53802 .54961 L .5482 .5534 L p .771 .305 .139 r
F P
0 g
s
.53802 .54961 m .52692 .52257 L .52394 .52214 L p .686 .257 .224 r
F P
0 g
s
.52618 .54791 m .52394 .52214 L .52087 .52228 L p .574 .17 .238 r
F P
0 g
s
.52087 .52228 m .51399 .54848 L .52618 .54791 L p .574 .17 .238 r
F P
0 g
s
.4623 .21039 m .4772 .23655 L .53856 .2331 L p .615 .798 .969 r
F P
0 g
s
.4772 .23655 m .4623 .21039 L .38924 .23251 L p .652 .817 .963 r
F P
0 g
s
.44852 .61527 m .4886 .57538 L .49444 .58127 L p .852 .792 .792 r
F P
0 g
s
.49444 .58127 m .46138 .62765 L .44852 .61527 L p .852 .792 .792 r
F P
0 g
s
.39887 .64393 m .44852 .61527 L .46138 .62765 L p .781 .792 .862 r
F P
0 g
s
.18996 .43852 m .20416 .48674 L .19805 .54897 L p 0 0 .485 r
F P
0 g
s
.22973 .58637 m .19805 .54897 L .20416 .48674 L p .178 .311 .762 r
F P
0 g
s
.53856 .2331 m .5435 .20577 L .4623 .21039 L p .615 .798 .969 r
F P
0 g
s
.5923 .62173 m .55525 .57845 L .55928 .57208 L p .444 .486 .808 r
F P
0 g
s
.638 .65447 m .5923 .62173 L .60132 .60832 L p .538 .614 .876 r
F P
0 g
s
.60132 .60832 m .6537 .63252 L .638 .65447 L p .538 .614 .876 r
F P
0 g
s
.68743 .24905 m .72362 .24888 L .64412 .21253 L p .264 .65 .966 r
F P
0 g
s
.64412 .21253 m .62198 .21937 L .68743 .24905 L p .264 .65 .966 r
F P
0 g
s
.27599 .61279 m .33157 .62477 L .34575 .65783 L p .52 .691 .946 r
F P
0 g
s
.39887 .64393 m .34575 .65783 L .33157 .62477 L p .676 .784 .931 r
F P
0 g
s
.44353 .60116 m .48646 .56871 L .4886 .57538 L p .882 .88 .827 r
F P
0 g
s
.4886 .57538 m .44852 .61527 L .44353 .60116 L p .882 .88 .827 r
F P
0 g
s
.55928 .57208 m .60132 .60832 L .5923 .62173 L p .444 .486 .808 r
F P
0 g
s
.60132 .60832 m .55928 .57208 L .55941 .5653 L p .301 .452 .845 r
F P
0 g
s
.76364 .63463 m .7101 .64163 L .71406 .6074 L p .728 .841 .934 r
F P
0 g
s
.71406 .6074 m .77025 .59013 L .76364 .63463 L p .728 .841 .934 r
F P
0 g
s
.86405 .47189 m .84972 .51785 L .82473 .45602 L p .996 .846 .572 r
F P
0 g
s
.82473 .45602 m .83846 .40551 L .86405 .47189 L p .996 .846 .572 r
F P
0 g
s
.44715 .5868 m .48829 .56199 L .48646 .56871 L p .866 .971 .858 r
F P
0 g
s
.48646 .56871 m .44353 .60116 L .44715 .5868 L p .866 .971 .858 r
F P
0 g
s
.33157 .62477 m .38978 .62072 L .39887 .64393 L p .676 .784 .931 r
F P
0 g
s
.44852 .61527 m .39887 .64393 L .38978 .62072 L p .789 .842 .892 r
F P
0 g
s
.38978 .62072 m .44353 .60116 L .44852 .61527 L p .789 .842 .892 r
F P
0 g
s
.55941 .5653 m .60199 .59388 L .60132 .60832 L p .301 .452 .845 r
F P
0 g
s
.38924 .23251 m .35937 .22864 L .29219 .2728 L p .68 .944 .961 r
F P
0 g
s
.25942 .29305 m .29219 .2728 L .35937 .22864 L p .417 .826 .629 r
F P
0 g
s
.35937 .22864 m .38924 .23251 L .4623 .21039 L p .52 .895 .964 r
F P
0 g
s
.48829 .56199 m .44715 .5868 L .4592 .57378 L p .705 .984 .821 r
F P
0 g
s
.25942 .29305 m .23937 .32808 L .19474 .39273 L p 0 0 0 r
F P
0 g
s
.18996 .43852 m .19474 .39273 L .23937 .32808 L p 0 0 .311 r
F P
0 g
s
.20416 .48674 m .23628 .53166 L .22973 .58637 L p .178 .311 .762 r
F P
0 g
s
.27599 .61279 m .22973 .58637 L .23628 .53166 L p .404 .534 .874 r
F P
0 g
s
.6537 .63252 m .60132 .60832 L .60199 .59388 L p .48 .618 .909 r
F P
0 g
s
.81237 .3227 m .83391 .35937 L .77001 .29945 L p .812 .34 0 r
F P
0 g
s
.77001 .29945 m .75239 .26598 L .81237 .3227 L p .812 .34 0 r
F P
0 g
s
.7101 .64163 m .6537 .63252 L .65561 .60863 L p .613 .739 .935 r
F P
0 g
s
.65561 .60863 m .71406 .6074 L .7101 .64163 L p .613 .739 .935 r
F P
0 g
s
.48874 .54715 m .49747 .55351 L p .47851 .56361 L .5 .876 .976 r
F P
0 g
s
.49395 .55595 m .46513 .57074 L p .47851 .56361 L .34 .79 .64 r
F P
0 g
s
.50284 .55127 m .47851 .56361 L .50298 .55751 L p .029 0 0 r
F P
0 g
s
.49747 .55351 m .50298 .55751 L .47851 .56361 L p .5 .876 .976 r
F P
0 g
s
.46513 .57074 m .4592 .57378 L .47851 .56361 L p .34 .79 .64 r
F P
0 g
s
.60199 .59388 m .65561 .60863 L .6537 .63252 L p .48 .618 .909 r
F P
0 g
s
.62198 .21937 m .64412 .21253 L .54806 .19579 L p .268 .715 .959 r
F P
0 g
s
.54806 .19579 m .5435 .20577 L .62198 .21937 L p .268 .715 .959 r
F P
0 g
s
.39508 .59681 m .44715 .5868 L .44353 .60116 L p .774 .89 .927 r
F P
0 g
s
.44353 .60116 m .38978 .62072 L .39508 .59681 L p .774 .89 .927 r
F P
0 g
s
.50298 .55751 m .51399 .54848 L .50284 .55127 L p .029 0 0 r
F P
0 g
s
.84972 .51785 m .81732 .55896 L .79384 .50479 L p .93 .874 .76 r
F P
0 g
s
.79384 .50479 m .82473 .45602 L .84972 .51785 L p .93 .874 .76 r
F P
0 g
s
.23628 .53166 m .28277 .56769 L .27599 .61279 L p .404 .534 .874 r
F P
0 g
s
.33157 .62477 m .27599 .61279 L .28277 .56769 L p .554 .679 .922 r
F P
0 g
s
.44852 .20149 m .4623 .21039 L .5435 .20577 L p .361 .804 .956 r
F P
0 g
s
.4623 .21039 m .44852 .20149 L .35937 .22864 L p .52 .895 .964 r
F P
0 g
s
.65561 .60863 m .60199 .59388 L .59401 .58 L p .415 .633 .944 r
F P
0 g
s
.72362 .24888 m .75239 .26598 L .66184 .22465 L p .43 0 0 r
F P
0 g
s
.66184 .22465 m .64412 .21253 L .72362 .24888 L p .43 0 0 r
F P
0 g
s
.33799 .59029 m .39508 .59681 L .38978 .62072 L p .67 .792 .939 r
F P
0 g
s
.38978 .62072 m .33157 .62477 L .33799 .59029 L p .67 .792 .939 r
F P
0 g
s
.5435 .20577 m .54806 .19579 L .44852 .20149 L p .361 .804 .956 r
F P
0 g
s
.28277 .56769 m .33799 .59029 L .33157 .62477 L p .554 .679 .922 r
F P
0 g
s
.4148 .57488 m .4592 .57378 L .44715 .5868 L p .724 .922 .959 r
F P
0 g
s
.44715 .5868 m .39508 .59681 L .4148 .57488 L p .724 .922 .959 r
F P
0 g
s
.23937 .32808 m .23509 .37454 L .18996 .43852 L p 0 0 .311 r
F P
0 g
s
.20416 .48674 m .18996 .43852 L .23509 .37454 L p .249 .201 .606 r
F P
0 g
s
.35937 .22864 m .33551 .243 L .25942 .29305 L p .417 .826 .629 r
F P
0 g
s
.23937 .32808 m .25942 .29305 L .33551 .243 L p .091 0 .075 r
F P
0 g
s
.81732 .55896 m .77025 .59013 L .74935 .54571 L p .839 .853 .855 r
F P
0 g
s
.74935 .54571 m .79384 .50479 L .81732 .55896 L p .839 .853 .855 r
F P
0 g
s
.83391 .35937 m .83846 .40551 L .77373 .34618 L p .949 .634 .402 r
F P
0 g
s
.77373 .34618 m .77001 .29945 L .83391 .35937 L p .949 .634 .402 r
F P
0 g
s
.59401 .58 m .64289 .58538 L .65561 .60863 L p .415 .633 .944 r
F P
0 g
s
.64289 .58538 m .59401 .58 L .57807 .56823 L p .351 .658 .971 r
F P
0 g
s
.71406 .6074 m .65561 .60863 L .64289 .58538 L p .607 .746 .943 r
F P
0 g
s
.33551 .243 m .35937 .22864 L .44852 .20149 L p .015 0 0 r
F P
0 g
s
.4472 .55758 m .47851 .56361 L .4592 .57378 L p .628 .921 .977 r
F P
0 g
s
.4592 .57378 m .4148 .57488 L .4472 .55758 L p .628 .921 .977 r
F P
0 g
s
.77025 .59013 m .71406 .6074 L .69684 .57364 L p .736 .811 .911 r
F P
0 g
s
.69684 .57364 m .74935 .54571 L .77025 .59013 L p .736 .811 .911 r
F P
0 g
s
.64289 .58538 m .69684 .57364 L .71406 .6074 L p .607 .746 .943 r
F P
0 g
s
.57807 .56823 m .61642 .56546 L .64289 .58538 L p .351 .658 .971 r
F P
0 g
s
.36556 .55827 m .4148 .57488 L .39508 .59681 L p .661 .796 .947 r
F P
0 g
s
.39508 .59681 m .33799 .59029 L .36556 .55827 L p .661 .796 .947 r
F P
0 g
s
.23509 .37454 m .24779 .42724 L .20416 .48674 L p .249 .201 .606 r
F P
0 g
s
.23628 .53166 m .20416 .48674 L .24779 .42724 L p .404 .408 .75 r
F P
0 g
s
.47851 .56361 m .4472 .55758 L .48874 .54715 L p .5 .876 .976 r
F P
0 g
s
.64412 .21253 m .66184 .22465 L .55171 .20555 L p .432 0 0 r
F P
0 g
s
.55171 .20555 m .54806 .19579 L .64412 .21253 L p .432 0 0 r
F P
0 g
s
.55583 .55998 m .57885 .55137 L .61642 .56546 L p .309 .694 .978 r
F P
0 g
s
.75239 .26598 m .77001 .29945 L .67272 .25563 L p .805 .356 .173 r
F P
0 g
s
.67272 .25563 m .66184 .22465 L .75239 .26598 L p .805 .356 .173 r
F P
0 g
s
.50298 .55751 m .48874 .54715 L .5345 .54498 L p .383 .808 .969 r
F P
0 g
s
.5298 .55625 m .5345 .54498 L .57885 .55137 L p .314 .743 .972 r
F P
0 g
s
.83846 .40551 m .82473 .45602 L .76247 .40092 L p .925 .73 .62 r
F P
0 g
s
.76247 .40092 m .77373 .34618 L .83846 .40551 L p .925 .73 .62 r
F P
0 g
s
.69684 .57364 m .64289 .58538 L .61642 .56546 L p .604 .755 .951 r
F P
0 g
s
.31738 .52529 m .36556 .55827 L .33799 .59029 L p .588 .675 .901 r
F P
0 g
s
.33799 .59029 m .28277 .56769 L .31738 .52529 L p .588 .675 .901 r
F P
0 g
s
.24779 .42724 m .27636 .47971 L .23628 .53166 L p .404 .408 .75 r
F P
0 g
s
.28277 .56769 m .23628 .53166 L .27636 .47971 L p .506 .553 .838 r
F P
0 g
s
.43746 .21206 m .44852 .20149 L .54806 .19579 L p .293 0 0 r
F P
0 g
s
.44852 .20149 m .43746 .21206 L .33551 .243 L p .015 0 0 r
F P
0 g
s
.33551 .243 m .32085 .2751 L .23937 .32808 L p .091 0 .075 r
F P
0 g
s
.23509 .37454 m .23937 .32808 L .32085 .2751 L p .35 .141 .449 r
F P
0 g
s
.27636 .47971 m .31738 .52529 L .28277 .56769 L p .506 .553 .838 r
F P
0 g
s
.54806 .19579 m .55171 .20555 L .43746 .21206 L p .293 0 0 r
F P
0 g
s
.41216 .53274 m .4472 .55758 L .4148 .57488 L p .648 .797 .954 r
F P
0 g
s
.4148 .57488 m .36556 .55827 L .41216 .53274 L p .648 .797 .954 r
F P
0 g
s
.32085 .2751 m .33551 .243 L .43746 .21206 L p .409 .043 .229 r
F P
0 g
s
.82473 .45602 m .79384 .50479 L .73727 .45684 L p .874 .766 .74 r
F P
0 g
s
.73727 .45684 m .76247 .40092 L .82473 .45602 L p .874 .766 .74 r
F P
0 g
s
.74935 .54571 m .69684 .57364 L .65918 .54439 L p .731 .78 .892 r
F P
0 g
s
.61642 .56546 m .65918 .54439 L .69684 .57364 L p .604 .755 .951 r
F P
0 g
s
.65918 .54439 m .61642 .56546 L .57885 .55137 L p .606 .766 .956 r
F P
0 g
s
.79384 .50479 m .74935 .54571 L .70126 .50676 L p .812 .781 .823 r
F P
0 g
s
.70126 .50676 m .73727 .45684 L .79384 .50479 L p .812 .781 .823 r
F P
0 g
s
.65918 .54439 m .70126 .50676 L .74935 .54571 L p .731 .78 .892 r
F P
0 g
s
.32085 .2751 m .3177 .32206 L .23509 .37454 L p .35 .141 .449 r
F P
0 g
s
.24779 .42724 m .23509 .37454 L .3177 .32206 L p .466 .34 .625 r
F P
0 g
s
.77001 .29945 m .77373 .34618 L .67502 .30276 L p .852 .55 .477 r
F P
0 g
s
.67502 .30276 m .67272 .25563 L .77001 .29945 L p .852 .55 .477 r
F P
0 g
s
.47273 .51721 m .48874 .54715 L .4472 .55758 L p .635 .793 .958 r
F P
0 g
s
.4472 .55758 m .41216 .53274 L .47273 .51721 L p .635 .793 .958 r
F P
0 g
s
.66184 .22465 m .67272 .25563 L .55395 .23533 L p .709 .296 .262 r
F P
0 g
s
.55395 .23533 m .55171 .20555 L .66184 .22465 L p .709 .296 .262 r
F P
0 g
s
.37754 .49113 m .41216 .53274 L .36556 .55827 L p .62 .679 .884 r
F P
0 g
s
.36556 .55827 m .31738 .52529 L .37754 .49113 L p .62 .679 .884 r
F P
0 g
s
.57885 .55137 m .60471 .52351 L .65918 .54439 L p .606 .766 .956 r
F P
0 g
s
.60471 .52351 m .57885 .55137 L .5345 .54498 L p .612 .777 .96 r
F P
0 g
s
.5398 .51398 m .5345 .54498 L .48874 .54715 L p .622 .787 .961 r
F P
0 g
s
.48874 .54715 m .47273 .51721 L .5398 .51398 L p .622 .787 .961 r
F P
0 g
s
.5345 .54498 m .5398 .51398 L .60471 .52351 L p .612 .777 .96 r
F P
0 g
s
.43063 .24225 m .43746 .21206 L .55171 .20555 L p .585 .199 .276 r
F P
0 g
s
.43746 .21206 m .43063 .24225 L .32085 .2751 L p .409 .043 .229 r
F P
0 g
s
.3177 .32206 m .32699 .37856 L .24779 .42724 L p .466 .34 .625 r
F P
0 g
s
.27636 .47971 m .24779 .42724 L .32699 .37856 L p .533 .47 .731 r
F P
0 g
s
.55171 .20555 m .55395 .23533 L .43063 .24225 L p .585 .199 .276 r
F P
0 g
s
.70126 .50676 m .65918 .54439 L .60471 .52351 L p .718 .751 .878 r
F P
0 g
s
.34783 .43747 m .37754 .49113 L .31738 .52529 L p .581 .575 .812 r
F P
0 g
s
.31738 .52529 m .27636 .47971 L .34783 .43747 L p .581 .575 .812 r
F P
0 g
s
.3177 .32206 m .32085 .2751 L .43063 .24225 L p .538 .293 .492 r
F P
0 g
s
.32699 .37856 m .34783 .43747 L .27636 .47971 L p .533 .47 .731 r
F P
0 g
s
.77373 .34618 m .76247 .40092 L .66803 .36068 L p .839 .635 .626 r
F P
0 g
s
.66803 .36068 m .67502 .30276 L .77373 .34618 L p .839 .635 .626 r
F P
0 g
s
.45682 .47021 m .47273 .51721 L .41216 .53274 L p .649 .689 .873 r
F P
0 g
s
.41216 .53274 m .37754 .49113 L .45682 .47021 L p .649 .689 .873 r
F P
0 g
s
.67272 .25563 m .67502 .30276 L .5544 .28263 L p .756 .471 .501 r
F P
0 g
s
.5544 .28263 m .55395 .23533 L .67272 .25563 L p .756 .471 .501 r
F P
0 g
s
.73727 .45684 m .70126 .50676 L .63036 .47871 L p .776 .722 .802 r
F P
0 g
s
.60471 .52351 m .63036 .47871 L .70126 .50676 L p .718 .751 .878 r
F P
0 g
s
.63036 .47871 m .60471 .52351 L .5398 .51398 L p .699 .725 .87 r
F P
0 g
s
.76247 .40092 m .73727 .45684 L .65247 .42203 L p .813 .685 .723 r
F P
0 g
s
.65247 .42203 m .66803 .36068 L .76247 .40092 L p .813 .685 .723 r
F P
0 g
s
.63036 .47871 m .65247 .42203 L .73727 .45684 L p .776 .722 .802 r
F P
0 g
s
.54509 .46583 m .5398 .51398 L .47273 .51721 L p .676 .704 .869 r
F P
0 g
s
.47273 .51721 m .45682 .47021 L .54509 .46583 L p .676 .704 .869 r
F P
0 g
s
.43063 .24225 m .42914 .28949 L .3177 .32206 L p .538 .293 .492 r
F P
0 g
s
.32699 .37856 m .3177 .32206 L .42914 .28949 L p .592 .427 .627 r
F P
0 g
s
.42914 .28949 m .43063 .24225 L .55395 .23533 L p .658 .391 .505 r
F P
0 g
s
.5398 .51398 m .54509 .46583 L .63036 .47871 L p .699 .725 .87 r
F P
0 g
s
.4431 .41143 m .45682 .47021 L .37754 .49113 L p .64 .602 .795 r
F P
0 g
s
.37754 .49113 m .34783 .43747 L .4431 .41143 L p .64 .602 .795 r
F P
0 g
s
.55395 .23533 m .5544 .28263 L .42914 .28949 L p .658 .391 .505 r
F P
0 g
s
.42914 .28949 m .43345 .34841 L .32699 .37856 L p .592 .427 .627 r
F P
0 g
s
.34783 .43747 m .32699 .37856 L .43345 .34841 L p .622 .52 .718 r
F P
0 g
s
.67502 .30276 m .66803 .36068 L .55292 .34206 L p .761 .561 .627 r
F P
0 g
s
.55292 .34206 m .5544 .28263 L .67502 .30276 L p .761 .561 .627 r
F P
0 g
s
.43345 .34841 m .4431 .41143 L .34783 .43747 L p .622 .52 .718 r
F P
0 g
s
.65247 .42203 m .63036 .47871 L .54509 .46583 L p .735 .674 .791 r
F P
0 g
s
.54968 .40597 m .54509 .46583 L .45682 .47021 L p .69 .635 .789 r
F P
0 g
s
.45682 .47021 m .4431 .41143 L .54968 .40597 L p .69 .635 .789 r
F P
0 g
s
.43345 .34841 m .42914 .28949 L .5544 .28263 L p .683 .495 .627 r
F P
0 g
s
.54509 .46583 m .54968 .40597 L .65247 .42203 L p .735 .674 .791 r
F P
0 g
s
.66803 .36068 m .65247 .42203 L .54968 .40597 L p .753 .622 .714 r
F P
0 g
s
.54968 .40597 m .55292 .34206 L .66803 .36068 L p .753 .622 .714 r
F P
0 g
s
.5544 .28263 m .55292 .34206 L .43345 .34841 L p .683 .495 .627 r
F P
0 g
s
.55292 .34206 m .54968 .40597 L .4431 .41143 L p .691 .569 .713 r
F P
0 g
s
.4431 .41143 m .43345 .34841 L .55292 .34206 L p .691 .569 .713 r
F P
0 g
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.438633 0.200176 0.631016 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0589462 1.17038 -8.20741e-17 1.17038 [
[ 0 0 0 0 ]
[ 1 1.09081 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.09081 L
0 1.09081 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.47341 .55036 m .46637 .59665 L .5442 .60042 L p .719 .591 .711 r
F P
0 g
s
.5442 .60042 m .54183 .55376 L .47341 .55036 L p .719 .591 .711 r
F P
0 g
s
.5461 .64683 m .5442 .60042 L .46637 .59665 L p .72 .567 .681 r
F P
0 g
s
.54183 .55376 m .5442 .60042 L .62039 .58911 L p .67 .552 .713 r
F P
0 g
s
.5442 .60042 m .5461 .64683 L .62975 .63477 L p .665 .523 .682 r
F P
0 g
s
.62975 .63477 m .62039 .58911 L .5442 .60042 L p .665 .523 .682 r
F P
0 g
s
.48169 .50474 m .47341 .55036 L .54183 .55376 L p .717 .614 .741 r
F P
0 g
s
.54183 .55376 m .53902 .50766 L .48169 .50474 L p .717 .614 .741 r
F P
0 g
s
.53902 .50766 m .54183 .55376 L .60876 .54355 L p .674 .581 .743 r
F P
0 g
s
.62039 .58911 m .60876 .54355 L .54183 .55376 L p .67 .552 .713 r
F P
0 g
s
.40936 .53357 m .39334 .57804 L .46637 .59665 L p .765 .635 .716 r
F P
0 g
s
.46637 .59665 m .47341 .55036 L .40936 .53357 L p .765 .635 .716 r
F P
0 g
s
.46071 .64282 m .46637 .59665 L .39334 .57804 L p .772 .615 .684 r
F P
0 g
s
.46637 .59665 m .46071 .64282 L .5461 .64683 L p .72 .567 .681 r
F P
0 g
s
.42819 .49032 m .40936 .53357 L .47341 .55036 L p .757 .653 .746 r
F P
0 g
s
.47341 .55036 m .48169 .50474 L .42819 .49032 L p .757 .653 .746 r
F P
0 g
s
.54749 .69218 m .5461 .64683 L .46071 .64282 L p .72 .541 .647 r
F P
0 g
s
.5461 .64683 m .54749 .69218 L .63664 .67969 L p .658 .492 .648 r
F P
0 g
s
.63664 .67969 m .62975 .63477 L .5461 .64683 L p .658 .492 .648 r
F P
0 g
s
.4911 .4606 m .48169 .50474 L .53902 .50766 L p .713 .637 .771 r
F P
0 g
s
.53902 .50766 m .53583 .46294 L .4911 .4606 L p .713 .637 .771 r
F P
0 g
s
.53583 .46294 m .53902 .50766 L .59505 .49888 L p .677 .609 .773 r
F P
0 g
s
.60876 .54355 m .59505 .49888 L .53902 .50766 L p .674 .581 .743 r
F P
0 g
s
.39334 .57804 m .38043 .62294 L .46071 .64282 L p .772 .615 .684 r
F P
0 g
s
.45654 .68803 m .46071 .64282 L .38043 .62294 L p .778 .593 .65 r
F P
0 g
s
.46071 .64282 m .45654 .68803 L .54749 .69218 L p .72 .541 .647 r
F P
0 g
s
.44949 .44909 m .42819 .49032 L .48169 .50474 L p .746 .67 .776 r
F P
0 g
s
.48169 .50474 m .4911 .4606 L .44949 .44909 L p .746 .67 .776 r
F P
0 g
s
.59505 .49888 m .60876 .54355 L .66836 .52039 L p .626 .553 .752 r
F P
0 g
s
.60876 .54355 m .62039 .58911 L .68853 .5634 L p .614 .518 .721 r
F P
0 g
s
.68853 .5634 m .66836 .52039 L .60876 .54355 L p .614 .518 .721 r
F P
0 g
s
.62039 .58911 m .62975 .63477 L .70482 .60727 L p .601 .482 .689 r
F P
0 g
s
.70482 .60727 m .68853 .5634 L .62039 .58911 L p .601 .482 .689 r
F P
0 g
s
.54834 .73565 m .54749 .69218 L .45654 .68803 L p .717 .512 .61 r
F P
0 g
s
.54749 .69218 m .54834 .73565 L .64088 .72304 L p .65 .458 .61 r
F P
0 g
s
.64088 .72304 m .63664 .67969 L .54749 .69218 L p .65 .458 .61 r
F P
0 g
s
.59505 .49888 m .5795 .45593 L .53583 .46294 L p .677 .609 .773 r
F P
0 g
s
.5795 .45593 m .59505 .49888 L .64469 .47903 L p .637 .587 .782 r
F P
0 g
s
.66836 .52039 m .64469 .47903 L .59505 .49888 L p .626 .553 .752 r
F P
0 g
s
.62975 .63477 m .63664 .67969 L .71684 .65116 L p .587 .443 .652 r
F P
0 g
s
.71684 .65116 m .70482 .60727 L .62975 .63477 L p .587 .443 .652 r
F P
0 g
s
.38043 .62294 m .3709 .66743 L .45654 .68803 L p .778 .593 .65 r
F P
0 g
s
.45395 .73146 m .45654 .68803 L .3709 .66743 L p .781 .568 .611 r
F P
0 g
s
.45654 .68803 m .45395 .73146 L .54834 .73565 L p .717 .512 .61 r
F P
0 g
s
.50148 .41879 m .4911 .4606 L .53583 .46294 L p .707 .66 .802 r
F P
0 g
s
.53583 .46294 m .5323 .42044 L .50148 .41879 L p .707 .66 .802 r
F P
0 g
s
.5323 .42044 m .53583 .46294 L .5795 .45593 L p .678 .639 .803 r
F P
0 g
s
.38352 .46545 m .3555 .50448 L .40936 .53357 L p .795 .7 .759 r
F P
0 g
s
.40936 .53357 m .42819 .49032 L .38352 .46545 L p .795 .7 .759 r
F P
0 g
s
.39334 .57804 m .40936 .53357 L .3555 .50448 L p .811 .688 .728 r
F P
0 g
s
.47291 .41069 m .44949 .44909 L .4911 .4606 L p .732 .687 .807 r
F P
0 g
s
.4911 .4606 m .50148 .41879 L .47291 .41069 L p .732 .687 .807 r
F P
0 g
s
.3555 .50448 m .33153 .54569 L .39334 .57804 L p .811 .688 .728 r
F P
0 g
s
.38043 .62294 m .39334 .57804 L .33153 .54569 L p .825 .673 .694 r
F P
0 g
s
.41504 .42933 m .38352 .46545 L .42819 .49032 L p .777 .71 .789 r
F P
0 g
s
.42819 .49032 m .44949 .44909 L .41504 .42933 L p .777 .71 .789 r
F P
0 g
s
.5795 .45593 m .56236 .41549 L .5323 .42044 L p .678 .639 .803 r
F P
0 g
s
.56236 .41549 m .5795 .45593 L .61797 .44011 L p .648 .623 .811 r
F P
0 g
s
.64469 .47903 m .61797 .44011 L .5795 .45593 L p .637 .587 .782 r
F P
0 g
s
.63664 .67969 m .64088 .72304 L .72426 .69422 L p .569 .398 .611 r
F P
0 g
s
.72426 .69422 m .71684 .65116 L .63664 .67969 L p .569 .398 .611 r
F P
0 g
s
.33153 .54569 m .31214 .58828 L .38043 .62294 L p .825 .673 .694 r
F P
0 g
s
.3709 .66743 m .38043 .62294 L .31214 .58828 L p .838 .655 .656 r
F P
0 g
s
.54861 .77637 m .54834 .73565 L .45395 .73146 L p .713 .477 .567 r
F P
0 g
s
.54834 .73565 m .54861 .77637 L .64231 .76395 L p .639 .417 .566 r
F P
0 g
s
.64231 .76395 m .64088 .72304 L .54834 .73565 L p .639 .417 .566 r
F P
0 g
s
.44948 .39686 m .41504 .42933 L .44949 .44909 L p .755 .718 .818 r
F P
0 g
s
.44949 .44909 m .47291 .41069 L .44948 .39686 L p .755 .718 .818 r
F P
0 g
s
.64469 .47903 m .66836 .52039 L .71492 .48585 L p .571 .529 .769 r
F P
0 g
s
.66836 .52039 m .68853 .5634 L .74224 .52488 L p .547 .485 .737 r
F P
0 g
s
.74224 .52488 m .71492 .48585 L .66836 .52039 L p .547 .485 .737 r
F P
0 g
s
.61797 .44011 m .64469 .47903 L .68308 .44959 L p .594 .572 .799 r
F P
0 g
s
.71492 .48585 m .68308 .44959 L .64469 .47903 L p .571 .529 .769 r
F P
0 g
s
.3709 .66743 m .365 .71066 L .45395 .73146 L p .781 .568 .611 r
F P
0 g
s
.45305 .77224 m .45395 .73146 L .365 .71066 L p .783 .537 .564 r
F P
0 g
s
.45395 .73146 m .45305 .77224 L .54861 .77637 L p .713 .477 .567 r
F P
0 g
s
.51266 .38015 m .50148 .41879 L .5323 .42044 L p .697 .686 .835 r
F P
0 g
s
.5323 .42044 m .52849 .38102 L .51266 .38015 L p .697 .686 .835 r
F P
0 g
s
.52849 .38102 m .5323 .42044 L .56236 .41549 L p .678 .671 .836 r
F P
0 g
s
.68853 .5634 m .70482 .60727 L .76439 .56593 L p .522 .437 .701 r
F P
0 g
s
.76439 .56593 m .74224 .52488 L .68853 .5634 L p .522 .437 .701 r
F P
0 g
s
.49805 .37591 m .47291 .41069 L .50148 .41879 L p .714 .703 .839 r
F P
0 g
s
.50148 .41879 m .51266 .38015 L .49805 .37591 L p .714 .703 .839 r
F P
0 g
s
.61797 .44011 m .58867 .40439 L .56236 .41549 L p .648 .623 .811 r
F P
0 g
s
.58867 .40439 m .61797 .44011 L .64737 .4168 L p .616 .614 .826 r
F P
0 g
s
.68308 .44959 m .64737 .4168 L .61797 .44011 L p .594 .572 .799 r
F P
0 g
s
.31214 .58828 m .29778 .63143 L .3709 .66743 L p .838 .655 .656 r
F P
0 g
s
.365 .71066 m .3709 .66743 L .29778 .63143 L p .848 .633 .61 r
F P
0 g
s
.56236 .41549 m .54391 .37843 L .52849 .38102 L p .678 .671 .836 r
F P
0 g
s
.54391 .37843 m .56236 .41549 L .58867 .40439 L p .658 .662 .842 r
F P
0 g
s
.64088 .72304 m .64231 .76395 L .72679 .73553 L p .547 .347 .56 r
F P
0 g
s
.72679 .73553 m .72426 .69422 L .64088 .72304 L p .547 .347 .56 r
F P
0 g
s
.70482 .60727 m .71684 .65116 L .78082 .60816 L p .492 .384 .66 r
F P
0 g
s
.78082 .60816 m .76439 .56593 L .70482 .60727 L p .492 .384 .66 r
F P
0 g
s
.48618 .36872 m .44948 .39686 L .47291 .41069 L p .728 .724 .847 r
F P
0 g
s
.47291 .41069 m .49805 .37591 L .48618 .36872 L p .728 .724 .847 r
F P
0 g
s
.39138 .40302 m .35233 .43208 L .38352 .46545 L p .803 .757 .81 r
F P
0 g
s
.38352 .46545 m .41504 .42933 L .39138 .40302 L p .803 .757 .81 r
F P
0 g
s
.3555 .50448 m .38352 .46545 L .35233 .43208 L p .831 .757 .782 r
F P
0 g
s
.35233 .43208 m .31735 .46521 L .3555 .50448 L p .831 .757 .782 r
F P
0 g
s
.33153 .54569 m .3555 .50448 L .31735 .46521 L p .857 .754 .749 r
F P
0 g
s
.43367 .37859 m .39138 .40302 L .41504 .42933 L p .772 .753 .836 r
F P
0 g
s
.41504 .42933 m .44948 .39686 L .43367 .37859 L p .772 .753 .836 r
F P
0 g
s
.54828 .81346 m .54861 .77637 L .45305 .77224 L p .705 .435 .513 r
F P
0 g
s
.54861 .77637 m .54828 .81346 L .64081 .80149 L p .623 .368 .51 r
F P
0 g
s
.64081 .80149 m .64231 .76395 L .54861 .77637 L p .623 .368 .51 r
F P
0 g
s
.58867 .40439 m .55731 .37263 L .54391 .37843 L p .658 .662 .842 r
F P
0 g
s
.55731 .37263 m .58867 .40439 L .60852 .38814 L p .638 .657 .853 r
F P
0 g
s
.64737 .4168 m .60852 .38814 L .58867 .40439 L p .616 .614 .826 r
F P
0 g
s
.31735 .46521 m .28723 .50176 L .33153 .54569 L p .857 .754 .749 r
F P
0 g
s
.31214 .58828 m .33153 .54569 L .28723 .50176 L p .881 .747 .711 r
F P
0 g
s
.365 .71066 m .36296 .75174 L .45305 .77224 L p .783 .537 .564 r
F P
0 g
s
.45392 .80948 m .45305 .77224 L .36296 .75174 L p .781 .497 .505 r
F P
0 g
s
.45305 .77224 m .45392 .80948 L .54828 .81346 L p .705 .435 .513 r
F P
0 g
s
.29778 .63143 m .28888 .67426 L .365 .71066 L p .848 .633 .61 r
F P
0 g
s
.36296 .75174 m .365 .71066 L .28888 .67426 L p .856 .603 .555 r
F P
0 g
s
.71684 .65116 m .72426 .69422 L .79099 .6507 L p .457 .323 .609 r
F P
0 g
s
.79099 .6507 m .78082 .60816 L .71684 .65116 L p .457 .323 .609 r
F P
0 g
s
.47833 .3593 m .43367 .37859 L .44948 .39686 L p .737 .746 .86 r
F P
0 g
s
.44948 .39686 m .48618 .36872 L .47833 .3593 L p .737 .746 .86 r
F P
0 g
s
.52849 .38102 m .52446 .34558 L .51266 .38015 L closepath p .683 .713 .872 r
F P
0 g
s
.54391 .37843 m .52446 .34558 L .52849 .38102 L closepath p .675 .708 .872 r
F P
0 g
s
.51266 .38015 m .52446 .34558 L .49805 .37591 L closepath p .689 .72 .873 r
F P
0 g
s
.55731 .37263 m .52446 .34558 L .54391 .37843 L closepath p .668 .704 .875 r
F P
0 g
s
.60852 .38814 m .64737 .4168 L .6644 .38807 L p .581 .612 .848 r
F P
0 g
s
.64737 .4168 m .68308 .44959 L .70587 .41301 L p .544 .563 .825 r
F P
0 g
s
.70587 .41301 m .6644 .38807 L .64737 .4168 L p .544 .563 .825 r
F P
0 g
s
.68308 .44959 m .71492 .48585 L .74318 .44263 L p .503 .511 .797 r
F P
0 g
s
.74318 .44263 m .70587 .41301 L .68308 .44959 L p .503 .511 .797 r
F P
0 g
s
.49805 .37591 m .52446 .34558 L .48618 .36872 L closepath p .693 .727 .876 r
F P
0 g
s
.28723 .50176 m .26271 .54102 L .31214 .58828 L p .881 .747 .711 r
F P
0 g
s
.29778 .63143 m .31214 .58828 L .26271 .54102 L p .903 .735 .664 r
F P
0 g
s
.64231 .76395 m .64081 .80149 L .72418 .77414 L p .518 .282 .496 r
F P
0 g
s
.72418 .77414 m .72679 .73553 L .64231 .76395 L p .518 .282 .496 r
F P
0 g
s
.60852 .38814 m .56728 .36421 L .55731 .37263 L p .638 .657 .853 r
F P
0 g
s
.56728 .36421 m .60852 .38814 L .6197 .36829 L p .618 .659 .868 r
F P
0 g
s
.6644 .38807 m .6197 .36829 L .60852 .38814 L p .581 .612 .848 r
F P
0 g
s
.71492 .48585 m .74224 .52488 L .77543 .47637 L p .459 .452 .763 r
F P
0 g
s
.77543 .47637 m .74318 .44263 L .71492 .48585 L p .459 .452 .763 r
F P
0 g
s
.56728 .36421 m .52446 .34558 L .55731 .37263 L closepath p .661 .703 .879 r
F P
0 g
s
.48618 .36872 m .52446 .34558 L .47833 .3593 L closepath p .696 .735 .881 r
F P
0 g
s
.57272 .35402 m .52446 .34558 L .56728 .36421 L closepath p .654 .705 .884 r
F P
0 g
s
.6197 .36829 m .57272 .35402 L .56728 .36421 L p .618 .659 .868 r
F P
0 g
s
.42737 .35767 m .38141 .3726 L .39138 .40302 L p .781 .792 .862 r
F P
0 g
s
.39138 .40302 m .43367 .37859 L .42737 .35767 L p .781 .792 .862 r
F P
0 g
s
.35233 .43208 m .39138 .40302 L .38141 .3726 L p .821 .811 .841 r
F P
0 g
s
.74224 .52488 m .76439 .56593 L .80175 .51359 L p .407 .384 .721 r
F P
0 g
s
.80175 .51359 m .77543 .47637 L .74224 .52488 L p .407 .384 .721 r
F P
0 g
s
.4754 .34862 m .42737 .35767 L .43367 .37859 L p .74 .769 .877 r
F P
0 g
s
.43367 .37859 m .47833 .3593 L .4754 .34862 L p .74 .769 .877 r
F P
0 g
s
.72426 .69422 m .72679 .73553 L .79446 .6926 L p .414 .247 .544 r
F P
0 g
s
.79446 .6926 m .79099 .6507 L .72426 .69422 L p .414 .247 .544 r
F P
0 g
s
.54734 .84597 m .54828 .81346 L .45392 .80948 L p .691 .379 .442 r
F P
0 g
s
.54828 .81346 m .54734 .84597 L .63626 .83473 L p .599 .303 .437 r
F P
0 g
s
.63626 .83473 m .64081 .80149 L .54828 .81346 L p .599 .303 .437 r
F P
0 g
s
.38141 .3726 m .33854 .39316 L .35233 .43208 L p .821 .811 .841 r
F P
0 g
s
.31735 .46521 m .35233 .43208 L .33854 .39316 L p .859 .827 .815 r
F P
0 g
s
.47833 .3593 m .52446 .34558 L .4754 .34862 L closepath p .696 .743 .888 r
F P
0 g
s
.26271 .54102 m .24448 .58218 L .29778 .63143 L p .903 .735 .664 r
F P
0 g
s
.28888 .67426 m .29778 .63143 L .24448 .58218 L p .923 .716 .605 r
F P
0 g
s
.28888 .67426 m .28581 .71585 L .36296 .75174 L p .856 .603 .555 r
F P
0 g
s
.36498 .78974 m .36296 .75174 L .28581 .71585 L p .86 .561 .482 r
F P
0 g
s
.36296 .75174 m .36498 .78974 L .45392 .80948 L p .781 .497 .505 r
F P
0 g
s
.45661 .84224 m .45392 .80948 L .36498 .78974 L p .772 .442 .427 r
F P
0 g
s
.45392 .80948 m .45661 .84224 L .54734 .84597 L p .691 .379 .442 r
F P
0 g
s
.57298 .34313 m .52446 .34558 L .57272 .35402 L closepath p .649 .709 .891 r
F P
0 g
s
.57272 .35402 m .6197 .36829 L .62074 .34684 L p .6 .667 .886 r
F P
0 g
s
.62074 .34684 m .57298 .34313 L .57272 .35402 L p .6 .667 .886 r
F P
0 g
s
.6197 .36829 m .6644 .38807 L .66669 .35672 L p .547 .62 .877 r
F P
0 g
s
.66669 .35672 m .62074 .34684 L .6197 .36829 L p .547 .62 .877 r
F P
0 g
s
.33854 .39316 m .29979 .41903 L .31735 .46521 L p .859 .827 .815 r
F P
0 g
s
.28723 .50176 m .31735 .46521 L .29979 .41903 L p .897 .84 .78 r
F P
0 g
s
.55808 .32395 m .52446 .34558 L .56794 .33272 L closepath p .646 .723 .904 r
F P
0 g
s
.54444 .31782 m .52446 .34558 L .55808 .32395 L closepath p .649 .731 .909 r
F P
0 g
s
.47778 .33782 m .52446 .34558 L .4853 .32808 L closepath p .688 .753 .901 r
F P
0 g
s
.4754 .34862 m .52446 .34558 L .47778 .33782 L closepath p .693 .749 .894 r
F P
0 g
s
.56794 .33272 m .52446 .34558 L .57298 .34313 L closepath p .646 .715 .898 r
F P
0 g
s
.52853 .31506 m .52446 .34558 L .54444 .31782 L closepath p .655 .74 .912 r
F P
0 g
s
.51216 .316 m .52446 .34558 L .52853 .31506 L closepath p .663 .747 .912 r
F P
0 g
s
.49719 .32051 m .52446 .34558 L .51216 .316 L closepath p .672 .752 .911 r
F P
0 g
s
.4853 .32808 m .52446 .34558 L .49719 .32051 L closepath p .68 .754 .907 r
F P
0 g
s
.76439 .56593 m .78082 .60816 L .82136 .55351 L p .346 .304 .667 r
F P
0 g
s
.82136 .55351 m .80175 .51359 L .76439 .56593 L p .346 .304 .667 r
F P
0 g
s
.42737 .35767 m .4754 .34862 L .47778 .33782 L p .735 .79 .897 r
F P
0 g
s
.6644 .38807 m .70587 .41301 L .70976 .3727 L p .486 .565 .861 r
F P
0 g
s
.70976 .3727 m .66669 .35672 L .6644 .38807 L p .486 .565 .861 r
F P
0 g
s
.64081 .80149 m .63626 .83473 L .71626 .80906 L p .477 .197 .409 r
F P
0 g
s
.71626 .80906 m .72418 .77414 L .64081 .80149 L p .477 .197 .409 r
F P
0 g
s
.57298 .34313 m .62074 .34684 L .6112 .3261 L p .587 .683 .907 r
F P
0 g
s
.6112 .3261 m .56794 .33272 L .57298 .34313 L p .587 .683 .907 r
F P
0 g
s
.47778 .33782 m .43157 .33628 L .42737 .35767 L p .735 .79 .897 r
F P
0 g
s
.38141 .3726 m .42737 .35767 L .43157 .33628 L p .777 .83 .893 r
F P
0 g
s
.70587 .41301 m .74318 .44263 L .74887 .39458 L p .414 .498 .836 r
F P
0 g
s
.74887 .39458 m .70976 .3727 L .70587 .41301 L p .414 .498 .836 r
F P
0 g
s
.24448 .58218 m .23315 .62437 L .28888 .67426 L p .923 .716 .605 r
F P
0 g
s
.28581 .71585 m .28888 .67426 L .23315 .62437 L p .938 .685 .527 r
F P
0 g
s
.29979 .41903 m .26616 .44974 L .28723 .50176 L p .897 .84 .78 r
F P
0 g
s
.26271 .54102 m .28723 .50176 L .26616 .44974 L p .934 .846 .733 r
F P
0 g
s
.72679 .73553 m .72418 .77414 L .79089 .73284 L p .356 .151 .458 r
F P
0 g
s
.79089 .73284 m .79446 .6926 L .72679 .73553 L p .356 .151 .458 r
F P
0 g
s
.43157 .33628 m .47778 .33782 L .4853 .32808 L p .72 .805 .917 r
F P
0 g
s
.43157 .33628 m .38686 .34116 L .38141 .3726 L p .777 .83 .893 r
F P
0 g
s
.33854 .39316 m .38141 .3726 L .38686 .34116 L p .821 .87 .882 r
F P
0 g
s
.56794 .33272 m .6112 .3261 L .59183 .30846 L p .582 .705 .927 r
F P
0 g
s
.59183 .30846 m .55808 .32395 L .56794 .33272 L p .582 .705 .927 r
F P
0 g
s
.78082 .60816 m .79099 .6507 L .83354 .59526 L p .271 .203 .595 r
F P
0 g
s
.83354 .59526 m .82136 .55351 L .78082 .60816 L p .271 .203 .595 r
F P
0 g
s
.62074 .34684 m .66669 .35672 L .65326 .32608 L p .514 .64 .911 r
F P
0 g
s
.65326 .32608 m .6112 .3261 L .62074 .34684 L p .514 .64 .911 r
F P
0 g
s
.28581 .71585 m .28887 .7552 L .36498 .78974 L p .86 .561 .482 r
F P
0 g
s
.37118 .82369 m .36498 .78974 L .28887 .7552 L p .854 .5 .382 r
F P
0 g
s
.36498 .78974 m .37118 .82369 L .45661 .84224 L p .772 .442 .427 r
F P
0 g
s
.44614 .31679 m .4853 .32808 L .49719 .32051 L p .695 .811 .936 r
F P
0 g
s
.4853 .32808 m .44614 .31679 L .43157 .33628 L p .72 .805 .917 r
F P
0 g
s
.54575 .87297 m .54734 .84597 L .45661 .84224 L p .665 .299 .342 r
F P
0 g
s
.54734 .84597 m .54575 .87297 L .62862 .86269 L p .561 .212 .333 r
F P
0 g
s
.62862 .86269 m .63626 .83473 L .54734 .84597 L p .561 .212 .333 r
F P
0 g
s
.74318 .44263 m .77543 .47637 L .78296 .42205 L p .327 .415 .799 r
F P
0 g
s
.78296 .42205 m .74887 .39458 L .74318 .44263 L p .327 .415 .799 r
F P
0 g
s
.55808 .32395 m .59183 .30846 L .56462 .29604 L p .587 .733 .944 r
F P
0 g
s
.56462 .29604 m .54444 .31782 L .55808 .32395 L p .587 .733 .944 r
F P
0 g
s
.46117 .86955 m .45661 .84224 L .37118 .82369 L p .751 .361 .316 r
F P
0 g
s
.45661 .84224 m .46117 .86955 L .54575 .87297 L p .665 .299 .342 r
F P
0 g
s
.26616 .44974 m .23859 .48473 L .26271 .54102 L p .934 .846 .733 r
F P
0 g
s
.24448 .58218 m .26271 .54102 L .23859 .48473 L p .967 .843 .667 r
F P
0 g
s
.38686 .34116 m .43157 .33628 L .44614 .31679 L p .754 .861 .928 r
F P
0 g
s
.46971 .30151 m .49719 .32051 L .51216 .316 L p .664 .805 .95 r
F P
0 g
s
.49719 .32051 m .46971 .30151 L .44614 .31679 L p .695 .811 .936 r
F P
0 g
s
.38686 .34116 m .34474 .35254 L .33854 .39316 L p .821 .87 .882 r
F P
0 g
s
.29979 .41903 m .33854 .39316 L .34474 .35254 L p .866 .908 .859 r
F P
0 g
s
.54444 .31782 m .56462 .29604 L .53265 .29042 L p .604 .762 .955 r
F P
0 g
s
.53265 .29042 m .52853 .31506 L .54444 .31782 L p .604 .762 .955 r
F P
0 g
s
.66669 .35672 m .70976 .3727 L .69309 .33293 L p .42 .58 .905 r
F P
0 g
s
.69309 .33293 m .65326 .32608 L .66669 .35672 L p .42 .58 .905 r
F P
0 g
s
.49971 .29233 m .51216 .316 L .52853 .31506 L p .631 .787 .957 r
F P
0 g
s
.51216 .316 m .49971 .29233 L .46971 .30151 L p .664 .805 .95 r
F P
0 g
s
.52853 .31506 m .53265 .29042 L .49971 .29233 L p .631 .787 .957 r
F P
0 g
s
.23315 .62437 m .22924 .66661 L .28581 .71585 L p .938 .685 .527 r
F P
0 g
s
.28887 .7552 m .28581 .71585 L .22924 .66661 L p .944 .633 .419 r
F P
0 g
s
.63626 .83473 m .62862 .86269 L .70294 .83926 L p .414 .078 .284 r
F P
0 g
s
.70294 .83926 m .71626 .80906 L .63626 .83473 L p .414 .078 .284 r
F P
0 g
s
.6112 .3261 m .65326 .32608 L .62494 .29977 L p .49 .673 .945 r
F P
0 g
s
.62494 .29977 m .59183 .30846 L .6112 .3261 L p .49 .673 .945 r
F P
0 g
s
.77543 .47637 m .80175 .51359 L .81099 .45463 L p .218 .307 .742 r
F P
0 g
s
.81099 .45463 m .78296 .42205 L .77543 .47637 L p .218 .307 .742 r
F P
0 g
s
.79099 .6507 m .79446 .6926 L .83772 .63787 L p .173 .074 .494 r
F P
0 g
s
.83772 .63787 m .83354 .59526 L .79099 .6507 L p .173 .074 .494 r
F P
0 g
s
.72418 .77414 m .71626 .80906 L .78005 .77036 L p .275 .021 .336 r
F P
0 g
s
.78005 .77036 m .79089 .73284 L .72418 .77414 L p .275 .021 .336 r
F P
0 g
s
.34474 .35254 m .30629 .3704 L .29979 .41903 L p .866 .908 .859 r
F P
0 g
s
.26616 .44974 m .29979 .41903 L .30629 .3704 L p .908 .941 .816 r
F P
0 g
s
.23859 .48473 m .21798 .52328 L .24448 .58218 L p .967 .843 .667 r
F P
0 g
s
.23315 .62437 m .24448 .58218 L .21798 .52328 L p .993 .823 .572 r
F P
0 g
s
.40788 .31222 m .44614 .31679 L .46971 .30151 L p .705 .875 .961 r
F P
0 g
s
.44614 .31679 m .40788 .31222 L .38686 .34116 L p .754 .861 .928 r
F P
0 g
s
.34474 .35254 m .38686 .34116 L .40788 .31222 L p .786 .92 .927 r
F P
0 g
s
.70976 .3727 m .74887 .39458 L .72959 .34676 L p .293 .493 .882 r
F P
0 g
s
.72959 .34676 m .69309 .33293 L .70976 .3727 L p .293 .493 .882 r
F P
0 g
s
.28887 .7552 m .29826 .7913 L .37118 .82369 L p .854 .5 .382 r
F P
0 g
s
.38165 .85261 m .37118 .82369 L .29826 .7913 L p .827 .404 .235 r
F P
0 g
s
.37118 .82369 m .38165 .85261 L .46117 .86955 L p .751 .361 .316 r
F P
0 g
s
.59183 .30846 m .62494 .29977 L .58454 .28111 L p .485 .719 .974 r
F P
0 g
s
.58454 .28111 m .56462 .29604 L .59183 .30846 L p .485 .719 .974 r
F P
0 g
s
.80175 .51359 m .82136 .55351 L .83198 .49167 L p .076 .163 .653 r
F P
0 g
s
.83198 .49167 m .81099 .45463 L .80175 .51359 L p .076 .163 .653 r
F P
0 g
s
.54353 .89347 m .54575 .87297 L .46117 .86955 L p .612 .175 .188 r
F P
0 g
s
.54575 .87297 m .54353 .89347 L .61787 .88439 L p .492 .073 .173 r
F P
0 g
s
.61787 .88439 m .62862 .86269 L .54575 .87297 L p .492 .073 .173 r
F P
0 g
s
.44264 .28934 m .46971 .30151 L .49971 .29233 L p .636 .862 .984 r
F P
0 g
s
.46971 .30151 m .44264 .28934 L .40788 .31222 L p .705 .875 .961 r
F P
0 g
s
.65326 .32608 m .69309 .33293 L .65656 .29845 L p .353 .612 .948 r
F P
0 g
s
.65656 .29845 m .62494 .29977 L .65326 .32608 L p .353 .612 .948 r
F P
0 g
s
.22924 .66661 m .23315 .70785 L .28887 .7552 L p .944 .633 .419 r
F P
0 g
s
.29826 .7913 m .28887 .7552 L .23315 .70785 L p .925 .546 .262 r
F P
0 g
s
.79446 .6926 m .79089 .73284 L .83343 .68024 L p .041 0 .347 r
F P
0 g
s
.83343 .68024 m .83772 .63787 L .79446 .6926 L p .041 0 .347 r
F P
0 g
s
.4676 .89045 m .46117 .86955 L .38165 .85261 L p .699 .233 .142 r
F P
0 g
s
.46117 .86955 m .4676 .89045 L .54353 .89347 L p .612 .175 .188 r
F P
0 g
s
.30629 .3704 m .27263 .39455 L .26616 .44974 L p .908 .941 .816 r
F P
0 g
s
.23859 .48473 m .26616 .44974 L .27263 .39455 L p .942 .958 .74 r
F P
0 g
s
.56462 .29604 m .58454 .28111 L .53673 .27263 L p .508 .773 .991 r
F P
0 g
s
.53673 .27263 m .53265 .29042 L .56462 .29604 L p .508 .773 .991 r
F P
0 g
s
.21798 .52328 m .20512 .56454 L .23315 .62437 L p .993 .823 .572 r
F P
0 g
s
.22924 .66661 m .23315 .62437 L .20512 .56454 L p .997 .772 .431 r
F P
0 g
s
.71626 .80906 m .70294 .83926 L .76189 .80406 L p .155 0 .153 r
F P
0 g
s
.76189 .80406 m .78005 .77036 L .71626 .80906 L p .155 0 .153 r
F P
0 g
s
.40788 .31222 m .37148 .31481 L .34474 .35254 L p .786 .92 .927 r
F P
0 g
s
.30629 .3704 m .34474 .35254 L .37148 .31481 L p .81 .975 .899 r
F P
0 g
s
.48738 .2755 m .49971 .29233 L .53265 .29042 L p .563 .825 .995 r
F P
0 g
s
.49971 .29233 m .48738 .2755 L .44264 .28934 L p .636 .862 .984 r
F P
0 g
s
.74887 .39458 m .78296 .42205 L .76167 .36756 L p .118 .363 .825 r
F P
0 g
s
.76167 .36756 m .72959 .34676 L .74887 .39458 L p .118 .363 .825 r
F P
0 g
s
.53265 .29042 m .53673 .27263 L .48738 .2755 L p .563 .825 .995 r
F P
0 g
s
.62862 .86269 m .61787 .88439 L .68428 .86373 L p .307 0 .088 r
F P
0 g
s
.68428 .86373 m .70294 .83926 L .62862 .86269 L p .307 0 .088 r
F P
0 g
s
.37148 .31481 m .40788 .31222 L .44264 .28934 L p .697 .938 .963 r
F P
0 g
s
.82136 .55351 m .83354 .59526 L .84508 .53236 L p 0 0 .512 r
F P
0 g
s
.84508 .53236 m .83198 .49167 L .82136 .55351 L p 0 0 .512 r
F P
0 g
s
.29826 .7913 m .31405 .82309 L .38165 .85261 L p .827 .404 .235 r
F P
0 g
s
.39638 .87549 m .38165 .85261 L .31405 .82309 L p .75 .243 .007 r
F P
0 g
s
.38165 .85261 m .39638 .87549 L .4676 .89045 L p .699 .233 .142 r
F P
0 g
s
.27263 .39455 m .24485 .42464 L .23859 .48473 L p .942 .958 .74 r
F P
0 g
s
.21798 .52328 m .23859 .48473 L .24485 .42464 L p .946 .94 .606 r
F P
0 g
s
.62494 .29977 m .65656 .29845 L .60368 .27383 L p .307 .663 .973 r
F P
0 g
s
.60368 .27383 m .58454 .28111 L .62494 .29977 L p .307 .663 .973 r
F P
0 g
s
.69309 .33293 m .72959 .34676 L .68577 .30496 L p .139 .494 .905 r
F P
0 g
s
.68577 .30496 m .65656 .29845 L .69309 .33293 L p .139 .494 .905 r
F P
0 g
s
.79089 .73284 m .78005 .77036 L .82046 .72119 L p 0 0 .132 r
F P
0 g
s
.82046 .72119 m .83343 .68024 L .79089 .73284 L p 0 0 .132 r
F P
0 g
s
.23315 .70785 m .24511 .74699 L .29826 .7913 L p .925 .546 .262 r
F P
0 g
s
.31405 .82309 m .29826 .7913 L .24511 .74699 L p .852 .395 .029 r
F P
0 g
s
.20512 .56454 m .20068 .60751 L .22924 .66661 L p .997 .772 .431 r
F P
0 g
s
.23315 .70785 m .22924 .66661 L .20068 .60751 L p .953 .665 .221 r
F P
0 g
s
.78296 .42205 m .81099 .45463 L .78823 .3951 L p 0 .167 .705 r
F P
0 g
s
.78823 .3951 m .76167 .36756 L .78296 .42205 L p 0 .167 .705 r
F P
0 g
s
.37148 .31481 m .33797 .32483 L .30629 .3704 L p .81 .975 .899 r
F P
0 g
s
.27263 .39455 m .30629 .3704 L .33797 .32483 L p .802 .999 .812 r
F P
0 g
s
.4167 .28471 m .44264 .28934 L .48738 .2755 L p .554 .9 .977 r
F P
0 g
s
.44264 .28934 m .4167 .28471 L .37148 .31481 L p .697 .938 .963 r
F P
0 g
s
.54069 .90654 m .54353 .89347 L .4676 .89045 L p .495 0 0 r
F P
0 g
s
.54353 .89347 m .54069 .90654 L .6041 .89887 L p .356 0 0 r
F P
0 g
s
.6041 .89887 m .61787 .88439 L .54353 .89347 L p .356 0 0 r
F P
0 g
s
.83354 .59526 m .83772 .63787 L .84957 .57571 L p 0 0 .298 r
F P
0 g
s
.84957 .57571 m .84508 .53236 L .83354 .59526 L p 0 0 .298 r
F P
0 g
s
.47586 .90399 m .4676 .89045 L .39638 .87549 L p .57 .015 0 r
F P
0 g
s
.4676 .89045 m .47586 .90399 L .54069 .90654 L p .495 0 0 r
F P
0 g
s
.70294 .83926 m .68428 .86373 L .73653 .83281 L p 0 0 0 r
F P
0 g
s
.73653 .83281 m .76189 .80406 L .70294 .83926 L p 0 0 0 r
F P
0 g
s
.58454 .28111 m .60368 .27383 L .54065 .26258 L p .318 .733 .977 r
F P
0 g
s
.54065 .26258 m .53673 .27263 L .58454 .28111 L p .318 .733 .977 r
F P
0 g
s
.33797 .32483 m .37148 .31481 L .4167 .28471 L p .632 .962 .894 r
F P
0 g
s
.47551 .2664 m .48738 .2755 L .53673 .27263 L p .408 .819 .976 r
F P
0 g
s
.48738 .2755 m .47551 .2664 L .4167 .28471 L p .554 .9 .977 r
F P
0 g
s
.24485 .42464 m .22396 .4601 L .21798 .52328 L p .946 .94 .606 r
F P
0 g
s
.20512 .56454 m .21798 .52328 L .22396 .4601 L p .885 .846 .387 r
F P
0 g
s
.61787 .88439 m .6041 .89887 L .66046 .88146 L p .12 0 0 r
F P
0 g
s
.66046 .88146 m .68428 .86373 L .61787 .88439 L p .12 0 0 r
F P
0 g
s
.53673 .27263 m .54065 .26258 L .47551 .2664 L p .408 .819 .976 r
F P
0 g
s
.72959 .34676 m .76167 .36756 L .71163 .31958 L p 0 .277 .756 r
F P
0 g
s
.71163 .31958 m .68577 .30496 L .72959 .34676 L p 0 .277 .756 r
F P
0 g
s
.81099 .45463 m .83198 .49167 L .80824 .42893 L p 0 0 .484 r
F P
0 g
s
.80824 .42893 m .78823 .3951 L .81099 .45463 L p 0 0 .484 r
F P
0 g
s
.78005 .77036 m .76189 .80406 L .79879 .75951 L p 0 0 0 r
F P
0 g
s
.79879 .75951 m .82046 .72119 L .78005 .77036 L p 0 0 0 r
F P
0 g
s
.20068 .60751 m .20513 .65108 L .23315 .70785 L p .953 .665 .221 r
F P
0 g
s
.24511 .74699 m .23315 .70785 L .20513 .65108 L p .817 .471 0 r
F P
0 g
s
.33797 .32483 m .30839 .34243 L .27263 .39455 L p .802 .999 .812 r
F P
0 g
s
.24485 .42464 m .27263 .39455 L .30839 .34243 L p .714 .934 .613 r
F P
0 g
s
.65656 .29845 m .68577 .30496 L .62146 .2749 L p 0 .502 .862 r
F P
0 g
s
.62146 .2749 m .60368 .27383 L .65656 .29845 L p 0 .502 .862 r
F P
0 g
s
.31405 .82309 m .33617 .84951 L .39638 .87549 L p .75 .243 .007 r
F P
0 g
s
.41523 .89136 m .39638 .87549 L .33617 .84951 L p .558 0 0 r
F P
0 g
s
.39638 .87549 m .41523 .89136 L .47586 .90399 L p .57 .015 0 r
F P
0 g
s
.24511 .74699 m .26517 .78285 L .31405 .82309 L p .852 .395 .029 r
F P
0 g
s
.33617 .84951 m .31405 .82309 L .26517 .78285 L p .67 .15 0 r
F P
0 g
s
.83772 .63787 m .83343 .68024 L .84496 .62055 L p 0 0 .006 r
F P
0 g
s
.84496 .62055 m .84957 .57571 L .83772 .63787 L p 0 0 .006 r
F P
0 g
s
.39265 .28821 m .4167 .28471 L .47551 .2664 L p .347 .825 .82 r
F P
0 g
s
.4167 .28471 m .39265 .28821 L .33797 .32483 L p .632 .962 .894 r
F P
0 g
s
.22396 .4601 m .21088 .50017 L .20512 .56454 L p .885 .846 .387 r
F P
0 g
s
.20068 .60751 m .20512 .56454 L .21088 .50017 L p .72 .644 .085 r
F P
0 g
s
.68428 .86373 m .66046 .88146 L .70435 .85556 L p 0 0 0 r
F P
0 g
s
.70435 .85556 m .73653 .83281 L .68428 .86373 L p 0 0 0 r
F P
0 g
s
.30839 .34243 m .33797 .32483 L .39265 .28821 L p .449 .85 .661 r
F P
0 g
s
.53726 .91131 m .54069 .90654 L .47586 .90399 L p .239 0 0 r
F P
0 g
s
.54069 .90654 m .53726 .91131 L .58748 .90525 L p .09 0 0 r
F P
0 g
s
.58748 .90525 m .6041 .89887 L .54069 .90654 L p .09 0 0 r
F P
0 g
s
.83198 .49167 m .84508 .53236 L .82077 .46835 L p .727 .407 0 r
F P
0 g
s
.82077 .46835 m .80824 .42893 L .83198 .49167 L p .727 .407 0 r
F P
0 g
s
.48585 .90929 m .47586 .90399 L .41523 .89136 L p .285 0 0 r
F P
0 g
s
.47586 .90399 m .48585 .90929 L .53726 .91131 L p .239 0 0 r
F P
0 g
s
.60368 .27383 m .62146 .2749 L .5443 .26113 L p 0 .541 .781 r
F P
0 g
s
.5443 .26113 m .54065 .26258 L .60368 .27383 L p 0 .541 .781 r
F P
0 g
s
.20513 .65108 m .21871 .694 L .24511 .74699 L p .817 .471 0 r
F P
0 g
s
.26517 .78285 m .24511 .74699 L .21871 .694 L p 0 0 .385 r
F P
0 g
s
.76167 .36756 m .78823 .3951 L .73318 .34237 L p .548 .039 0 r
F P
0 g
s
.73318 .34237 m .71163 .31958 L .76167 .36756 L p .548 .039 0 r
F P
0 g
s
.76189 .80406 m .73653 .83281 L .7687 .79392 L p .57 .841 .493 r
F P
0 g
s
.7687 .79392 m .79879 .75951 L .76189 .80406 L p .57 .841 .493 r
F P
0 g
s
.30839 .34243 m .28381 .36752 L .24485 .42464 L p .714 .934 .613 r
F P
0 g
s
.22396 .4601 m .24485 .42464 L .28381 .36752 L p 0 0 0 r
F P
0 g
s
.6041 .89887 m .58748 .90525 L .63185 .89156 L p 0 0 0 r
F P
0 g
s
.63185 .89156 m .66046 .88146 L .6041 .89887 L p 0 0 0 r
F P
0 g
s
.46446 .26581 m .47551 .2664 L .54065 .26258 L p .095 .652 .758 r
F P
0 g
s
.47551 .2664 m .46446 .26581 L .39265 .28821 L p .347 .825 .82 r
F P
0 g
s
.83343 .68024 m .82046 .72119 L .83102 .66557 L p .796 .8 .308 r
F P
0 g
s
.83102 .66557 m .84496 .62055 L .83343 .68024 L p .796 .8 .308 r
F P
0 g
s
.54065 .26258 m .5443 .26113 L .46446 .26581 L p .095 .652 .758 r
F P
0 g
s
.26517 .78285 m .29312 .81427 L .33617 .84951 L p .67 .15 0 r
F P
0 g
s
.33617 .84951 m .36435 .86953 L .41523 .89136 L p .558 0 0 r
F P
0 g
s
.36435 .86953 m .33617 .84951 L .29312 .81427 L p 0 .165 .63 r
F P
0 g
s
.68577 .30496 m .71163 .31958 L .63729 .28488 L p .399 0 0 r
F P
0 g
s
.63729 .28488 m .62146 .2749 L .68577 .30496 L p .399 0 0 r
F P
0 g
s
.21088 .50017 m .20635 .54387 L .20068 .60751 L p .72 .644 .085 r
F P
0 g
s
.20513 .65108 m .20068 .60751 L .20635 .54387 L p 0 0 .23 r
F P
0 g
s
.41523 .89136 m .43794 .89934 L .48585 .90929 L p .285 0 0 r
F P
0 g
s
.43794 .89934 m .41523 .89136 L .36435 .86953 L p 0 .363 .712 r
F P
0 g
s
.84508 .53236 m .84957 .57571 L .82508 .51239 L p .918 .645 .155 r
F P
0 g
s
.82508 .51239 m .82077 .46835 L .84508 .53236 L p .918 .645 .155 r
F P
0 g
s
.39265 .28821 m .37128 .30026 L .30839 .34243 L p .449 .85 .661 r
F P
0 g
s
.28381 .36752 m .30839 .34243 L .37128 .30026 L p 0 0 0 r
F P
0 g
s
.37128 .30026 m .39265 .28821 L .46446 .26581 L p 0 0 0 r
F P
0 g
s
.66046 .88146 m .63185 .89156 L .66597 .87132 L p .493 .9 .798 r
F P
0 g
s
.66597 .87132 m .70435 .85556 L .66046 .88146 L p .493 .9 .798 r
F P
0 g
s
.21871 .694 m .24137 .73496 L .26517 .78285 L p 0 0 .385 r
F P
0 g
s
.29312 .81427 m .26517 .78285 L .24137 .73496 L p 0 .096 .649 r
F P
0 g
s
.28381 .36752 m .26522 .39976 L .22396 .4601 L p 0 0 0 r
F P
0 g
s
.21088 .50017 m .22396 .4601 L .26522 .39976 L p 0 0 .051 r
F P
0 g
s
.78823 .3951 m .80824 .42893 L .74949 .3731 L p .809 .337 0 r
F P
0 g
s
.74949 .3731 m .73318 .34237 L .78823 .3951 L p .809 .337 0 r
F P
0 g
s
.82046 .72119 m .79879 .75951 L .80783 .70936 L p .896 .936 .564 r
F P
0 g
s
.80783 .70936 m .83102 .66557 L .82046 .72119 L p .896 .936 .564 r
F P
0 g
s
.73653 .83281 m .70435 .85556 L .7308 .82322 L p .701 .972 .752 r
F P
0 g
s
.7308 .82322 m .7687 .79392 L .73653 .83281 L p .701 .972 .752 r
F P
0 g
s
.5333 .90703 m .53726 .91131 L .48585 .90929 L p .15 .682 .859 r
F P
0 g
s
.53726 .91131 m .5333 .90703 L .56831 .90279 L p .264 .768 .871 r
F P
0 g
s
.56831 .90279 m .58748 .90525 L .53726 .91131 L p .264 .768 .871 r
F P
0 g
s
.62146 .2749 m .63729 .28488 L .54756 .26892 L p .409 0 0 r
F P
0 g
s
.54756 .26892 m .5443 .26113 L .62146 .2749 L p .409 0 0 r
F P
0 g
s
.20635 .54387 m .21088 .59 L .20513 .65108 L p 0 0 .23 r
F P
0 g
s
.21871 .694 m .20513 .65108 L .21088 .59 L p 0 0 .481 r
F P
0 g
s
.49741 .90562 m .48585 .90929 L .43794 .89934 L p .12 .635 .89 r
F P
0 g
s
.48585 .90929 m .49741 .90562 L .5333 .90703 L p .15 .682 .859 r
F P
0 g
s
.29312 .81427 m .32849 .84011 L .36435 .86953 L p 0 .165 .63 r
F P
0 g
s
.3981 .88221 m .36435 .86953 L .32849 .84011 L p 0 .441 .86 r
F P
0 g
s
.36435 .86953 m .3981 .88221 L .43794 .89934 L p 0 .363 .712 r
F P
0 g
s
.58748 .90525 m .56831 .90279 L .59902 .89326 L p .435 .869 .915 r
F P
0 g
s
.59902 .89326 m .63185 .89156 L .58748 .90525 L p .435 .869 .915 r
F P
0 g
s
.71163 .31958 m .73318 .34237 L .65053 .30405 L p .684 .14 0 r
F P
0 g
s
.65053 .30405 m .63729 .28488 L .71163 .31958 L p .684 .14 0 r
F P
0 g
s
.4546 .27435 m .46446 .26581 L .5443 .26113 L p .267 0 0 r
F P
0 g
s
.46446 .26581 m .4546 .27435 L .37128 .30026 L p 0 0 0 r
F P
0 g
s
.84957 .57571 m .84496 .62055 L .82065 .55981 L p .992 .781 .402 r
F P
0 g
s
.82065 .55981 m .82508 .51239 L .84957 .57571 L p .992 .781 .402 r
F P
0 g
s
.5443 .26113 m .54756 .26892 L .4546 .27435 L p .267 0 0 r
F P
0 g
s
.4641 .89867 m .43794 .89934 L .3981 .88221 L p .169 .62 .937 r
F P
0 g
s
.43794 .89934 m .4641 .89867 L .49741 .90562 L p .12 .635 .89 r
F P
0 g
s
.24137 .73496 m .27277 .7726 L .29312 .81427 L p 0 .096 .649 r
F P
0 g
s
.32849 .84011 m .29312 .81427 L .27277 .7726 L p .005 .331 .815 r
F P
0 g
s
.26522 .39976 m .25354 .43852 L .21088 .50017 L p 0 0 .051 r
F P
0 g
s
.20635 .54387 m .21088 .50017 L .25354 .43852 L p 0 0 .312 r
F P
0 g
s
.79879 .75951 m .7687 .79392 L .77584 .75044 L p .912 .981 .733 r
F P
0 g
s
.77584 .75044 m .80783 .70936 L .79879 .75951 L p .912 .981 .733 r
F P
0 g
s
.37128 .30026 m .35342 .32105 L .28381 .36752 L p 0 0 0 r
F P
0 g
s
.26522 .39976 m .28381 .36752 L .35342 .32105 L p .086 0 .07 r
F P
0 g
s
.80824 .42893 m .82077 .46835 L .75974 .41122 L p .921 .528 .21 r
F P
0 g
s
.75974 .41122 m .74949 .3731 L .80824 .42893 L p .921 .528 .21 r
F P
0 g
s
.70435 .85556 m .66597 .87132 L .68599 .84627 L p .74 .987 .895 r
F P
0 g
s
.68599 .84627 m .7308 .82322 L .70435 .85556 L p .74 .987 .895 r
F P
0 g
s
.21088 .59 m .2247 .63718 L .21871 .694 L p 0 0 .481 r
F P
0 g
s
.24137 .73496 m .21871 .694 L .2247 .63718 L p 0 .132 .65 r
F P
0 g
s
.63185 .89156 m .59902 .89326 L .6223 .87927 L p .608 .937 .952 r
F P
0 g
s
.6223 .87927 m .66597 .87132 L .63185 .89156 L p .608 .937 .952 r
F P
0 g
s
.35342 .32105 m .37128 .30026 L .4546 .27435 L p .254 0 0 r
F P
0 g
s
.84496 .62055 m .83102 .66557 L .80731 .60915 L p .996 .846 .57 r
F P
0 g
s
.80731 .60915 m .82065 .55981 L .84496 .62055 L p .996 .846 .57 r
F P
0 g
s
.32849 .84011 m .3705 .85932 L .3981 .88221 L p 0 .441 .86 r
F P
0 g
s
.43669 .88678 m .3981 .88221 L .3705 .85932 L p .267 .615 .957 r
F P
0 g
s
.3981 .88221 m .43669 .88678 L .4641 .89867 L p .169 .62 .937 r
F P
0 g
s
.63729 .28488 m .65053 .30405 L .55028 .28636 L p .621 .114 .022 r
F P
0 g
s
.55028 .28636 m .54756 .26892 L .63729 .28488 L p .621 .114 .022 r
F P
0 g
s
.52889 .8932 m .5333 .90703 L .49741 .90562 L p .445 .804 .996 r
F P
0 g
s
.5333 .90703 m .52889 .8932 L .547 .89098 L p .499 .842 .996 r
F P
0 g
s
.547 .89098 m .56831 .90279 L .5333 .90703 L p .499 .842 .996 r
F P
0 g
s
.7687 .79392 m .7308 .82322 L .73585 .78737 L p .883 .975 .834 r
F P
0 g
s
.73585 .78737 m .77584 .75044 L .7687 .79392 L p .883 .975 .834 r
F P
0 g
s
.51028 .89246 m .49741 .90562 L .4641 .89867 L p .42 .767 .996 r
F P
0 g
s
.49741 .90562 m .51028 .89246 L .52889 .8932 L p .445 .804 .996 r
F P
0 g
s
.27277 .7726 m .31218 .8056 L .32849 .84011 L p .005 .331 .815 r
F P
0 g
s
.3705 .85932 m .32849 .84011 L .31218 .8056 L p .216 .496 .902 r
F P
0 g
s
.73318 .34237 m .74949 .3731 L .66059 .33238 L p .805 .354 .169 r
F P
0 g
s
.66059 .33238 m .65053 .30405 L .73318 .34237 L p .805 .354 .169 r
F P
0 g
s
.25354 .43852 m .24949 .48286 L .20635 .54387 L p 0 0 .312 r
F P
0 g
s
.21088 .59 m .20635 .54387 L .24949 .48286 L p .132 .049 .487 r
F P
0 g
s
.56831 .90279 m .547 .89098 L .56278 .88602 L p .57 .873 .994 r
F P
0 g
s
.56278 .88602 m .59902 .89326 L .56831 .90279 L p .57 .873 .994 r
F P
0 g
s
.2247 .63718 m .24766 .68386 L .24137 .73496 L p 0 .132 .65 r
F P
0 g
s
.27277 .7726 m .24137 .73496 L .24766 .68386 L p .159 .299 .758 r
F P
0 g
s
.44632 .29238 m .4546 .27435 L .54756 .26892 L p .484 .007 .047 r
F P
0 g
s
.4546 .27435 m .44632 .29238 L .35342 .32105 L p .254 0 0 r
F P
0 g
s
.82077 .46835 m .82508 .51239 L .76326 .45582 L p .949 .634 .403 r
F P
0 g
s
.76326 .45582 m .75974 .41122 L .82077 .46835 L p .949 .634 .403 r
F P
0 g
s
.35342 .32105 m .33986 .35046 L .26522 .39976 L p .086 0 .07 r
F P
0 g
s
.25354 .43852 m .26522 .39976 L .33986 .35046 L p .249 0 .301 r
F P
0 g
s
.66597 .87132 m .6223 .87927 L .63555 .86213 L p .727 .944 .953 r
F P
0 g
s
.63555 .86213 m .68599 .84627 L .66597 .87132 L p .727 .944 .953 r
F P
0 g
s
.4931 .88883 m .4641 .89867 L .43669 .88678 L p .425 .736 .991 r
F P
0 g
s
.4641 .89867 m .4931 .88883 L .51028 .89246 L p .42 .767 .996 r
F P
0 g
s
.54756 .26892 m .55028 .28636 L .44632 .29238 L p .484 .007 .047 r
F P
0 g
s
.83102 .66557 m .80783 .70936 L .78521 .65876 L p .971 .872 .681 r
F P
0 g
s
.78521 .65876 m .80731 .60915 L .83102 .66557 L p .971 .872 .681 r
F P
0 g
s
.59902 .89326 m .56278 .88602 L .57454 .8788 L p .639 .887 .986 r
F P
0 g
s
.57454 .8788 m .6223 .87927 L .59902 .89326 L p .639 .887 .986 r
F P
0 g
s
.33986 .35046 m .35342 .32105 L .44632 .29238 L p .407 .04 .226 r
F P
0 g
s
.7308 .82322 m .68599 .84627 L .68907 .8188 L p .836 .945 .893 r
F P
0 g
s
.68907 .8188 m .73585 .78737 L .7308 .82322 L p .836 .945 .893 r
F P
0 g
s
.31218 .8056 m .35856 .83273 L .3705 .85932 L p .216 .496 .902 r
F P
0 g
s
.41807 .87103 m .3705 .85932 L .35856 .83273 L p .372 .611 .943 r
F P
0 g
s
.3705 .85932 m .41807 .87103 L .43669 .88678 L p .267 .615 .957 r
F P
0 g
s
.47911 .88267 m .43669 .88678 L .41807 .87103 L p .452 .711 .978 r
F P
0 g
s
.43669 .88678 m .47911 .88267 L .4931 .88883 L p .425 .736 .991 r
F P
0 g
s
.24949 .48286 m .25354 .5315 L .21088 .59 L p .132 .049 .487 r
F P
0 g
s
.2247 .63718 m .21088 .59 L .25354 .5315 L p .246 .198 .604 r
F P
0 g
s
.24766 .68386 m .27927 .72846 L .27277 .7726 L p .159 .299 .758 r
F P
0 g
s
.31218 .8056 m .27277 .7726 L .27927 .72846 L p .284 .426 .829 r
F P
0 g
s
.74949 .3731 m .75974 .41122 L .66692 .36946 L p .844 .476 .356 r
F P
0 g
s
.66692 .36946 m .66059 .33238 L .74949 .3731 L p .844 .476 .356 r
F P
0 g
s
.82508 .51239 m .82065 .55981 L .75963 .5056 L p .944 .694 .53 r
F P
0 g
s
.75963 .5056 m .76326 .45582 L .82508 .51239 L p .944 .694 .53 r
F P
0 g
s
.6223 .87927 m .57454 .8788 L .581 .87005 L p .691 .881 .969 r
F P
0 g
s
.581 .87005 m .63555 .86213 L .6223 .87927 L p .691 .881 .969 r
F P
0 g
s
.80783 .70936 m .77584 .75044 L .75492 .7069 L p .933 .879 .759 r
F P
0 g
s
.75492 .7069 m .78521 .65876 L .80783 .70936 L p .933 .879 .759 r
F P
0 g
s
.65053 .30405 m .66059 .33238 L .55234 .31354 L p .708 .294 .259 r
F P
0 g
s
.55234 .31354 m .55028 .28636 L .65053 .30405 L p .708 .294 .259 r
F P
0 g
s
.33986 .35046 m .33131 .38802 L .25354 .43852 L p .249 0 .301 r
F P
0 g
s
.24949 .48286 m .25354 .43852 L .33131 .38802 L p .351 .142 .45 r
F P
0 g
s
.52414 .8696 m .52889 .8932 L .51028 .89246 L closepath p .587 .797 .98 r
F P
0 g
s
.52414 .8696 m .547 .89098 L .52889 .8932 L closepath p .6 .807 .979 r
F P
0 g
s
.52414 .8696 m .51028 .89246 L .4931 .88883 L closepath p .578 .786 .978 r
F P
0 g
s
.68599 .84627 m .63555 .86213 L .63698 .84353 L p .781 .904 .927 r
F P
0 g
s
.63698 .84353 m .68907 .8188 L .68599 .84627 L p .781 .904 .927 r
F P
0 g
s
.52414 .8696 m .56278 .88602 L .547 .89098 L closepath p .617 .814 .976 r
F P
0 g
s
.27927 .72846 m .31862 .76937 L .31218 .8056 L p .284 .426 .829 r
F P
0 g
s
.35856 .83273 m .31218 .8056 L .31862 .76937 L p .382 .527 .877 r
F P
0 g
s
.52414 .8696 m .4931 .88883 L .47911 .88267 L closepath p .575 .774 .973 r
F P
0 g
s
.35856 .83273 m .41049 .85293 L .41807 .87103 L p .372 .611 .943 r
F P
0 g
s
.46983 .87458 m .41807 .87103 L .41049 .85293 L p .491 .693 .958 r
F P
0 g
s
.41807 .87103 m .46983 .87458 L .47911 .88267 L p .452 .711 .978 r
F P
0 g
s
.25354 .5315 m .26587 .58292 L .2247 .63718 L p .246 .198 .604 r
F P
0 g
s
.24766 .68386 m .2247 .63718 L .26587 .58292 L p .33 .312 .688 r
F P
0 g
s
.44002 .31996 m .44632 .29238 L .55028 .28636 L p .584 .197 .274 r
F P
0 g
s
.44632 .29238 m .44002 .31996 L .33986 .35046 L p .407 .04 .226 r
F P
0 g
s
.52414 .8696 m .57454 .8788 L .56278 .88602 L closepath p .633 .816 .97 r
F P
0 g
s
.77584 .75044 m .73585 .78737 L .71738 .7518 L p .889 .875 .815 r
F P
0 g
s
.71738 .7518 m .75492 .7069 L .77584 .75044 L p .889 .875 .815 r
F P
0 g
s
.55028 .28636 m .55234 .31354 L .44002 .31996 L p .584 .197 .274 r
F P
0 g
s
.52414 .8696 m .47911 .88267 L .46983 .87458 L closepath p .577 .763 .967 r
F P
0 g
s
.33131 .38802 m .33986 .35046 L .44002 .31996 L p .49 .191 .387 r
F P
0 g
s
.63555 .86213 m .581 .87005 L .58136 .86067 L p .722 .858 .946 r
F P
0 g
s
.58136 .86067 m .63698 .84353 L .63555 .86213 L p .722 .858 .946 r
F P
0 g
s
.82065 .55981 m .80731 .60915 L .74871 .55894 L p .926 .73 .619 r
F P
0 g
s
.74871 .55894 m .75963 .5056 L .82065 .55981 L p .926 .73 .619 r
F P
0 g
s
.31862 .76937 m .36445 .80511 L .35856 .83273 L p .382 .527 .877 r
F P
0 g
s
.41049 .85293 m .35856 .83273 L .36445 .80511 L p .463 .61 .911 r
F P
0 g
s
.52414 .8696 m .581 .87005 L .57454 .8788 L closepath p .648 .814 .963 r
F P
0 g
s
.41049 .85293 m .46632 .8654 L .46983 .87458 L p .491 .693 .958 r
F P
0 g
s
.52414 .8696 m .46983 .87458 L .46632 .8654 L closepath p .585 .755 .959 r
F P
0 g
s
.26587 .58292 m .28628 .63533 L .24766 .68386 L p .33 .312 .688 r
F P
0 g
s
.27927 .72846 m .24766 .68386 L .28628 .63533 L p .396 .403 .75 r
F P
0 g
s
.33131 .38802 m .32833 .43282 L .24949 .48286 L p .351 .142 .45 r
F P
0 g
s
.25354 .5315 m .24949 .48286 L .32833 .43282 L p .418 .254 .55 r
F P
0 g
s
.75974 .41122 m .76326 .45582 L .66909 .41443 L p .852 .55 .477 r
F P
0 g
s
.66909 .41443 m .66692 .36946 L .75974 .41122 L p .852 .55 .477 r
F P
0 g
s
.73585 .78737 m .68907 .8188 L .67388 .79181 L p .842 .864 .859 r
F P
0 g
s
.67388 .79181 m .71738 .7518 L .73585 .78737 L p .842 .864 .859 r
F P
0 g
s
.36445 .80511 m .4152 .83436 L .41049 .85293 L p .463 .61 .911 r
F P
0 g
s
.46632 .8654 m .41049 .85293 L .4152 .83436 L p .533 .683 .935 r
F P
0 g
s
.52414 .8696 m .58136 .86067 L .581 .87005 L closepath p .659 .808 .955 r
F P
0 g
s
.66059 .33238 m .66692 .36946 L .55363 .35011 L p .742 .401 .405 r
F P
0 g
s
.55363 .35011 m .55234 .31354 L .66059 .33238 L p .742 .401 .405 r
F P
0 g
s
.4152 .83436 m .46906 .85609 L .46632 .8654 L p .533 .683 .935 r
F P
0 g
s
.52414 .8696 m .46632 .8654 L .46906 .85609 L closepath p .595 .749 .95 r
F P
0 g
s
.68907 .8188 m .63698 .84353 L .62599 .82549 L p .791 .848 .894 r
F P
0 g
s
.62599 .82549 m .67388 .79181 L .68907 .8188 L p .791 .848 .894 r
F P
0 g
s
.80731 .60915 m .78521 .65876 L .73069 .61396 L p .903 .754 .686 r
F P
0 g
s
.73069 .61396 m .74871 .55894 L .80731 .60915 L p .903 .754 .686 r
F P
0 g
s
.52414 .8696 m .56385 .84411 L .57547 .85169 L closepath p .666 .788 .939 r
F P
0 g
s
.52414 .8696 m .54775 .83881 L .56385 .84411 L closepath p .663 .776 .933 r
F P
0 g
s
.52414 .8696 m .52895 .83642 L .54775 .83881 L closepath p .656 .766 .93 r
F P
0 g
s
.52414 .8696 m .5096 .83723 L .52895 .83642 L closepath p .647 .757 .93 r
F P
0 g
s
.52414 .8696 m .49191 .84114 L .5096 .83723 L closepath p .635 .75 .932 r
F P
0 g
s
.52414 .8696 m .47789 .84768 L .49191 .84114 L closepath p .622 .747 .936 r
F P
0 g
s
.52414 .8696 m .46906 .85609 L .47789 .84768 L closepath p .608 .746 .943 r
F P
0 g
s
.52414 .8696 m .57547 .85169 L .58136 .86067 L closepath p .665 .798 .946 r
F P
0 g
s
.28628 .63533 m .3142 .68683 L .27927 .72846 L p .396 .403 .75 r
F P
0 g
s
.31862 .76937 m .27927 .72846 L .3142 .68683 L p .449 .481 .8 r
F P
0 g
s
.63698 .84353 m .58136 .86067 L .57547 .85169 L p .733 .827 .923 r
F P
0 g
s
.57547 .85169 m .62599 .82549 L .63698 .84353 L p .733 .827 .923 r
F P
0 g
s
.43602 .35671 m .44002 .31996 L .55234 .31354 L p .633 .313 .412 r
F P
0 g
s
.44002 .31996 m .43602 .35671 L .33131 .38802 L p .49 .191 .387 r
F P
0 g
s
.32833 .43282 m .33131 .38802 L .43602 .35671 L p .538 .294 .492 r
F P
0 g
s
.32833 .43282 m .33129 .48358 L .25354 .5315 L p .418 .254 .55 r
F P
0 g
s
.26587 .58292 m .25354 .5315 L .33129 .48358 L p .465 .339 .624 r
F P
0 g
s
.43212 .81737 m .47789 .84768 L .46906 .85609 L p .573 .68 .913 r
F P
0 g
s
.46906 .85609 m .4152 .83436 L .43212 .81737 L p .573 .68 .913 r
F P
0 g
s
.3142 .68683 m .3487 .73552 L .31862 .76937 L p .449 .481 .8 r
F P
0 g
s
.36445 .80511 m .31862 .76937 L .3487 .73552 L p .494 .55 .842 r
F P
0 g
s
.55234 .31354 m .55363 .35011 L .43602 .35671 L p .633 .313 .412 r
F P
0 g
s
.76326 .45582 m .75963 .5056 L .66683 .46597 L p .849 .6 .562 r
F P
0 g
s
.66683 .46597 m .66909 .41443 L .76326 .45582 L p .849 .6 .562 r
F P
0 g
s
.38851 .77956 m .43212 .81737 L .4152 .83436 L p .535 .615 .879 r
F P
0 g
s
.4152 .83436 m .36445 .80511 L .38851 .77956 L p .535 .615 .879 r
F P
0 g
s
.3487 .73552 m .38851 .77956 L .36445 .80511 L p .494 .55 .842 r
F P
0 g
s
.78521 .65876 m .75492 .7069 L .70614 .6686 L p .877 .77 .74 r
F P
0 g
s
.70614 .6686 m .73069 .61396 L .78521 .65876 L p .877 .77 .74 r
F P
0 g
s
.62599 .82549 m .57547 .85169 L .56385 .84411 L p .729 .794 .903 r
F P
0 g
s
.45972 .80401 m .49191 .84114 L .47789 .84768 L p .609 .684 .895 r
F P
0 g
s
.47789 .84768 m .43212 .81737 L .45972 .80401 L p .609 .684 .895 r
F P
0 g
s
.56385 .84411 m .60337 .81009 L .62599 .82549 L p .729 .794 .903 r
F P
0 g
s
.60337 .81009 m .56385 .84411 L .54775 .83881 L p .716 .762 .889 r
F P
0 g
s
.75492 .7069 m .71738 .7518 L .67592 .72078 L p .848 .781 .786 r
F P
0 g
s
.67592 .72078 m .70614 .6686 L .75492 .7069 L p .848 .781 .786 r
F P
0 g
s
.67388 .79181 m .62599 .82549 L .60337 .81009 L p .777 .793 .866 r
F P
0 g
s
.66692 .36946 m .66909 .41443 L .55406 .39525 L p .756 .472 .501 r
F P
0 g
s
.55406 .39525 m .55363 .35011 L .66692 .36946 L p .756 .472 .501 r
F P
0 g
s
.33129 .48358 m .3403 .53859 L .26587 .58292 L p .465 .339 .624 r
F P
0 g
s
.28628 .63533 m .26587 .58292 L .3403 .53859 L p .501 .408 .682 r
F P
0 g
s
.495 .79597 m .5096 .83723 L .49191 .84114 L p .642 .695 .884 r
F P
0 g
s
.49191 .84114 m .45972 .80401 L .495 .79597 L p .642 .695 .884 r
F P
0 g
s
.71738 .7518 m .67388 .79181 L .64121 .76852 L p .816 .789 .827 r
F P
0 g
s
.64121 .76852 m .67592 .72078 L .71738 .7518 L p .816 .789 .827 r
F P
0 g
s
.60337 .81009 m .64121 .76852 L .67388 .79181 L p .777 .793 .866 r
F P
0 g
s
.54775 .83881 m .57142 .79922 L .60337 .81009 L p .716 .762 .889 r
F P
0 g
s
.57142 .79922 m .54775 .83881 L .52895 .83642 L p .696 .735 .881 r
F P
0 g
s
.53379 .7943 m .52895 .83642 L .5096 .83723 L p .671 .712 .879 r
F P
0 g
s
.5096 .83723 m .495 .79597 L .53379 .7943 L p .671 .712 .879 r
F P
0 g
s
.52895 .83642 m .53379 .7943 L .57142 .79922 L p .696 .735 .881 r
F P
0 g
s
.42878 .75926 m .45972 .80401 L .43212 .81737 L p .593 .628 .855 r
F P
0 g
s
.43212 .81737 m .38851 .77956 L .42878 .75926 L p .593 .628 .855 r
F P
0 g
s
.75963 .5056 m .74871 .55894 L .66006 .52233 L p .84 .635 .626 r
F P
0 g
s
.66006 .52233 m .66683 .46597 L .75963 .5056 L p .84 .635 .626 r
F P
0 g
s
.43602 .35671 m .43462 .40179 L .32833 .43282 L p .538 .294 .492 r
F P
0 g
s
.33129 .48358 m .32833 .43282 L .43462 .40179 L p .57 .368 .568 r
F P
0 g
s
.43462 .40179 m .43602 .35671 L .55363 .35011 L p .659 .392 .505 r
F P
0 g
s
.3403 .53859 m .35517 .59586 L .28628 .63533 L p .501 .408 .682 r
F P
0 g
s
.3142 .68683 m .28628 .63533 L .35517 .59586 L p .53 .468 .731 r
F P
0 g
s
.64121 .76852 m .60337 .81009 L .57142 .79922 L p .752 .745 .846 r
F P
0 g
s
.55363 .35011 m .55406 .39525 L .43462 .40179 L p .659 .392 .505 r
F P
0 g
s
.4003 .70837 m .42878 .75926 L .38851 .77956 L p .575 .575 .815 r
F P
0 g
s
.38851 .77956 m .3487 .73552 L .4003 .70837 L p .575 .575 .815 r
F P
0 g
s
.35517 .59586 m .37543 .6532 L .3142 .68683 L p .53 .468 .731 r
F P
0 g
s
.3487 .73552 m .3142 .68683 L .37543 .6532 L p .554 .522 .774 r
F P
0 g
s
.37543 .6532 m .4003 .70837 L .3487 .73552 L p .554 .522 .774 r
F P
0 g
s
.48088 .74696 m .495 .79597 L .45972 .80401 L p .642 .647 .84 r
F P
0 g
s
.45972 .80401 m .42878 .75926 L .48088 .74696 L p .642 .647 .84 r
F P
0 g
s
.74871 .55894 m .73069 .61396 L .64893 .58143 L p .828 .663 .678 r
F P
0 g
s
.64893 .58143 m .66006 .52233 L .74871 .55894 L p .828 .663 .678 r
F P
0 g
s
.66909 .41443 m .66683 .46597 L .55357 .44761 L p .761 .522 .571 r
F P
0 g
s
.55357 .44761 m .55406 .39525 L .66909 .41443 L p .761 .522 .571 r
F P
0 g
s
.57142 .79922 m .59426 .75194 L .64121 .76852 L p .752 .745 .846 r
F P
0 g
s
.59426 .75194 m .57142 .79922 L .53379 .7943 L p .72 .705 .835 r
F P
0 g
s
.43462 .40179 m .43598 .45387 L .33129 .48358 L p .57 .368 .568 r
F P
0 g
s
.3403 .53859 m .33129 .48358 L .43598 .45387 L p .592 .426 .626 r
F P
0 g
s
.67592 .72078 m .64121 .76852 L .59426 .75194 L p .778 .727 .805 r
F P
0 g
s
.53849 .74439 m .53379 .7943 L .495 .79597 L p .684 .673 .833 r
F P
0 g
s
.495 .79597 m .48088 .74696 L .53849 .74439 L p .684 .673 .833 r
F P
0 g
s
.53379 .7943 m .53849 .74439 L .59426 .75194 L p .72 .705 .835 r
F P
0 g
s
.73069 .61396 m .70614 .6686 L .63383 .64095 L p .815 .687 .724 r
F P
0 g
s
.63383 .64095 m .64893 .58143 L .73069 .61396 L p .815 .687 .724 r
F P
0 g
s
.43598 .45387 m .43462 .40179 L .55406 .39525 L p .674 .449 .573 r
F P
0 g
s
.70614 .6686 m .67592 .72078 L .61535 .69853 L p .798 .708 .765 r
F P
0 g
s
.59426 .75194 m .61535 .69853 L .67592 .72078 L p .778 .727 .805 r
F P
0 g
s
.61535 .69853 m .63383 .64095 L .70614 .6686 L p .798 .708 .765 r
F P
0 g
s
.46783 .69181 m .48088 .74696 L .42878 .75926 L p .637 .603 .798 r
F P
0 g
s
.42878 .75926 m .4003 .70837 L .46783 .69181 L p .637 .603 .798 r
F P
0 g
s
.55406 .39525 m .55357 .44761 L .43598 .45387 L p .674 .449 .573 r
F P
0 g
s
.43598 .45387 m .44016 .51117 L .3403 .53859 L p .592 .426 .626 r
F P
0 g
s
.35517 .59586 m .3403 .53859 L .44016 .51117 L p .608 .475 .675 r
F P
0 g
s
.66683 .46597 m .66006 .52233 L .55214 .5054 L p .761 .561 .626 r
F P
0 g
s
.55214 .5054 m .55357 .44761 L .66683 .46597 L p .761 .561 .626 r
F P
0 g
s
.61535 .69853 m .59426 .75194 L .53849 .74439 L p .736 .677 .794 r
F P
0 g
s
.45639 .63256 m .46783 .69181 L .4003 .70837 L p .63 .561 .758 r
F P
0 g
s
.4003 .70837 m .37543 .6532 L .45639 .63256 L p .63 .561 .758 r
F P
0 g
s
.44016 .51117 m .44704 .57153 L .35517 .59586 L p .608 .475 .675 r
F P
0 g
s
.37543 .6532 m .35517 .59586 L .44704 .57153 L p .62 .519 .718 r
F P
0 g
s
.54284 .68835 m .53849 .74439 L .48088 .74696 L p .689 .637 .791 r
F P
0 g
s
.48088 .74696 m .46783 .69181 L .54284 .68835 L p .689 .637 .791 r
F P
0 g
s
.44704 .57153 m .45639 .63256 L .37543 .6532 L p .62 .519 .718 r
F P
0 g
s
.53849 .74439 m .54284 .68835 L .61535 .69853 L p .736 .677 .794 r
F P
0 g
s
.44016 .51117 m .43598 .45387 L .55357 .44761 L p .683 .495 .626 r
F P
0 g
s
.66006 .52233 m .64893 .58143 L .54981 .56642 L p .759 .594 .673 r
F P
0 g
s
.54981 .56642 m .55214 .5054 L .66006 .52233 L p .759 .594 .673 r
F P
0 g
s
.63383 .64095 m .61535 .69853 L .54284 .68835 L p .746 .65 .754 r
F P
0 g
s
.55357 .44761 m .55214 .5054 L .44016 .51117 L p .683 .495 .626 r
F P
0 g
s
.64893 .58143 m .63383 .64095 L .54667 .62823 L p .754 .623 .714 r
F P
0 g
s
.54667 .62823 m .54981 .56642 L .64893 .58143 L p .754 .623 .714 r
F P
0 g
s
.54284 .68835 m .54667 .62823 L .63383 .64095 L p .746 .65 .754 r
F P
0 g
s
.54667 .62823 m .54284 .68835 L .46783 .69181 L p .691 .603 .752 r
F P
0 g
s
.46783 .69181 m .45639 .63256 L .54667 .62823 L p .691 .603 .752 r
F P
0 g
s
.44704 .57153 m .44016 .51117 L .55214 .5054 L p .688 .534 .672 r
F P
0 g
s
.55214 .5054 m .54981 .56642 L .44704 .57153 L p .688 .534 .672 r
F P
0 g
s
.54981 .56642 m .54667 .62823 L .45639 .63256 L p .691 .569 .713 r
F P
0 g
s
.45639 .63256 m .44704 .57153 L .54981 .56642 L p .691 .569 .713 r
F P
0 g
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{829, 535.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<m00025b000`400?l00000o`00003oo`3ooooo
0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00
o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom0
0?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0oooo
o`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?oo
ool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo
003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oo
od00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3o
oooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0
ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03o
ool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0
oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo
0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00
o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom0
0?ooo`00o@3oool:00000?l0oooo>03oool:00000?D0oooo003d0?ooo`T000001`2OBV800`000000
_65P0;aQH00500000?l0oooo:P3oool9000000L0WdYR00<000000;aQH02lHF001@00003`0?ooo`00
lP3oool20000000307PXF`000000WdYR00d0WdYR00<000000;aQH02lHF001@2lHF0500000?l0oooo
8`3oool20000000307PXF`000000WdYR00d0WdYR00<000000;aQH02lHF001@2lHF0500000>/0oooo
003_0?ooo`<000000`1h:5/00`000000WdYR09m:HP0<09m:HP030000002lHF00_65P00X0_65P0`00
003o0?oooad0oooo0`00000307PXF`030000002OBV80WdYR00`0WdYR00<000000;aQH02lHF002P2l
HF0300000>P0oooo003/0?ooo`<000001P1h:5/00`000000WdYR09m:HP0=09m:HP030000002lHF00
_65P00/0_65P0`0000250?ooo`H00000S03oool3000000H0N2QK00<0000009m:HP2OBV803@2OBV80
0`000000_65P0;aQH00;0;aQH0<00000iP3oool00>X0oooo0P00000807PXF`030000002OBV80WdYR
00h0WdYR00<000000;aQH02lHF002`2lHF000`000000egAA0=MdD@0200000840oooo0`00000305P0
00030000001k0000000000800000Q`3oool2000000P0N2QK00<0000009m:HP2OBV803P2OBV800`00
0000_65P0;aQH00;0;aQH0030000003GM540egAA00800000i03oool00>P0oooo0P00000:07PXF`03
0000002OBV80WdYR00H0WdYR2`00000;0;aQH0030000003GM540egAA0080egAA0P00001m0?ooo`80
00000P0F00000`000000F00000000008000008<0oooo0P00000:07PXF`030000002OBV80WdYR00H0
WdYR2`00000;0;aQH0030000003GM540egAA0080egAA0P00003R0?ooo`00iP3oool3000000X0N2QK
2P0000080:n5Y`0300000031U:P0`IBX00D000001`2lHF000`000000egAA0=MdD@030=MdD@800000
NP3oool00`0000005P0000000004000000<0Y5I`00<000000;eZKP2mJVh01@00001o0?ooo`<00000
2P1h:5/:000000P0[hFW00<000000<6DZ031U:P01@0000070;aQH0030000003GM540egAA00<0egAA
0P00003P0?ooo`00i@3oool00`000000=@110000000807PXF`<0000000<0VgJX0000002_QJL03`2_
QJL00`000000`IBX0<6DZ0050<6DZ0D000000P2lHF000`000000egAA0=MdD@050=MdD@800000M`3o
ool300000080Q3Y[00<000000:AFL02TEW000`2TEW000`000000_FY^0;eZKP020;eZKP030000003F
O6D0000000800000O03oool00`000000=@110000000807PXF`<0000000<0VgJX0000002_QJL03`2_
QJL00`000000`IBX0<6DZ0050<6DZ0D000000P2lHF000`000000egAA0=MdD@050=MdD@800000gP3o
ool00><0oooo0P00000203D0@@030000001h:5/0N2QK00<0N2QK0`00000409]fZ0030000002_QJL0
[hFW00h0[hFW00<000000<6DZ031U:P02P31U:P3000000T0egAA0P00001c0?ooo`<000001024>V/0
0`000000Y5I`0:AFL0030:AFL0030000002mJVh0_FY^0080_FY^00@000000=IlI@3FO6D0eWaU0P00
001i0?ooo`8000000P0e04400`000000N2QK07PXF`0307PXF`<00000102KMZP00`000000[hFW0:n5
Y`0>0:n5Y`0300000031U:P0`IBX00X0`IBX0`0000090=MdD@800000g03oool00>40oooo0P000004
03D0@@040000001h:5/0N2QK07PXF`8000001`2KMZP00`000000[hFW0:n5Y`0>0:n5Y`0300000031
U:P0`IBX00`0`IBX0`0000080=MdD@800000L@3oool010000000D0iJ050>FP00000408@jJ`030000
002TEW00Y5I`00<0Y5I`00<000000;eZKP2mJVh00P2mJVh00`000000eWaU0=IlI@020=IlI@800000
MP3oool2000000@0=@1100@0000007PXF`1h:5/0N2QK0P00000709]fZ0030000002_QJL0[hFW00h0
[hFW00<000000<6DZ031U:P03031U:P3000000P0egAA0P00003K0?ooo`00h03oool00`000000=@11
03D0@@0303D0@@030000001h:5/00000008000002P2KMZP00`000000[hFW0:n5Y`0=0:n5Y`030000
0031U:P0`IBX00`0`IBX00<000000=>UZ@3CYJT00P0000070=MdD@800000K`3oool01@000000D0iJ
050>FP1@3UX0000000@0Q3Y[00<000000:AFL02TEW000`2TEW000`000000_FY^0;eZKP020;eZKP03
0000003FO6D0eWaU0080eWaU00<000000>b<B@000000M03oool00`000000=@1103D0@@0303D0@@03
0000001h:5/00000008000002P2KMZP00`000000[hFW0:n5Y`0=0:n5Y`0300000031U:P0`IBX00`0
`IBX00<000000=>UZ@3CYJT00P0000070=MdD@800000fP3oool00=h0oooo0P00000603D0@@800000
3@2KMZP00`000000[hFW0:n5Y`0=0:n5Y`0300000031U:P0`IBX00`0`IBX00<000000=>UZ@3CYJT0
0P3CYJT2000000D0egAA00<000000>Mn9@000000K@3oool2000000<0D0iJ00<0000008@jJ`24>V/0
0P24>V/00`000000Y5I`0:AFL0030:AFL0030000002mJVh0_FY^00<0_FY^00<000000=IlI@3FO6D0
0P3FO6D00`000000k8a90000001a0?ooo`8000001P0e0442000000d0VgJX00<000000:n5Y`2_QJL0
3@2_QJL00`000000`IBX0<6DZ00<0<6DZ0030000003CYJT0djFY0080djFY0P0000050=MdD@030000
003WORD000000=T0oooo003M0?ooo`030000000e0440=@1100@0=@110`00000>09]fZ0030000002_
QJL0[hFW00d0[hFW00<000000<6DZ031U:P02`31U:P00`000000djFY0=>UZ@050=>UZ@8000000`3G
M54010000000ighU0>Mn9@00001/0?ooo`8000000P1@3UX00`000000Q3Y[08@jJ`0308@jJ`030000
002TEW00Y5I`00<0Y5I`00<000000;eZKP2mJVh00`2mJVh00`000000eWaU0=IlI@020=IlI@040000
003/S4T00000000006l0oooo00<0000003D0@@0e0440100e0443000000h0VgJX00<000000:n5Y`2_
QJL03@2_QJL00`000000`IBX0<6DZ00;0<6DZ0030000003CYJT0djFY00D0djFY0P0000030=MdD@04
0000003WORD0ighU00000=P0oooo003L0?ooo`8000001@0e044010000000P6FY081UZ@00000>09]f
Z0030000002_QJL0[hFW00`0[hFW00<000000<6DZ031U:P03031U:P00`000000djFY0=>UZ@070=>U
Z@80000000<0egAA0000003WORD00P3WORD00`000000oooo0?ooo`1X0?ooo`8000000`1@3UX00`00
0000Q3Y[08@jJ`0308@jJ`030000002TEW00Y5I`00<0Y5I`00<000000;eZKP2mJVh00`2mJVh00`00
0000eWaU0=IlI@020=IlI@040000003/S4T0k8a9000006h0oooo0P00000503D0@@0400000020IJT0
P6FY000000h0VgJX00<000000:n5Y`2_QJL0302_QJL00`000000`IBX0<6DZ00<0<6DZ0030000003C
YJT0djFY00L0djFY0P0000000`3GM54000000>Mn9@020>Mn9@030000003oool0oooo0=D0oooo003L
0?ooo`030000000e0440=@1100<0=@1100<00000081UZ@20IJT00P20IJT00`000000VgJX09]fZ00;
09]fZ0030000002_QJL0[hFW00`0[hFW00<000000<6DZ031U:P03031U:P00`000000djFY0=>UZ@09
0=>UZ@<000000`3WORD00`000000oooo0?ooo`1W0?ooo`8000000`1@3UX00`000000Q3Y[08@jJ`02
08@jJ`X000000`2mJVh00`000000eWaU0=IlI@020=IlI@030000003/S4T0k8a900800000K@3oool0
0`000000=@1103D0@@0303D0@@0300000020IJT0P6FY0080P6FY00<0000009]fZ02KMZP02`2KMZP0
0`000000[hFW0:n5Y`0<0:n5Y`0300000031U:P0`IBX00`0`IBX00<000000=>UZ@3CYJT02@3CYJT3
000000<0ighU00<000000?ooo`3oool0e03oool00=/0oooo0P00000303D0@@8000001@20IJT00`00
0000VgJX09]fZ00;09]fZ0030000002_QJL0[hFW00`0[hFW00<000000<6DZ031U:P03031U:P00`00
0000djFY0=>UZ@0;0=>UZ@030000003WORD0ighU0080ighU00<000000?ooo`3oool0I@3oool00`00
0000000[00000003050>FP0300000024>V/000000080000000<0V6RI0000002^NIT0102^NIT00`00
0000`HVI0<69V@05000000@0eWaU00@000000>b<B@000000f800K03oool2000000<0=@110P000005
081UZ@030000002KMZP0VgJX00/0VgJX00<000000:n5Y`2_QJL0302_QJL00`000000`IBX0<6DZ00<
0<6DZ0030000003CYJT0djFY00/0djFY00<000000>Mn9@3WORD00P3WORD00`000000oooo0?ooo`3C
0?ooo`00f`3oool200000080=@1100<00000081UZ@20IJT01@20IJT00`000000VgJX09]fZ00;09]f
Z0030000002_QJL0[hFW00`0[hFW00<000000<6DZ031U:P03031U:P00`000000djFY0=>UZ@0;0=>U
Z@800000103WORD00`000000oooo0?ooo`1T0?ooo`030000000002/000000080D0iJ0`00000409QX
V@030000002^NIT0[WVI00<0[WVI00<000000<69V@31RIT00`31RIT00`000000e9^H000000020000
00050=IlI@000000k8a90>b<B@000000K03oool200000080=@1100<00000081UZ@20IJT01@20IJT0
0`000000VgJX09]fZ00;09]fZ0030000002_QJL0[hFW00`0[hFW00<000000<6DZ031U:P03031U:P0
0`000000djFY0=>UZ@0;0=>UZ@800000103WORD00`000000oooo0?ooo`3B0?ooo`00fP3oool30000
000303D0@@000000P6FY00L0P6FY00<0000009]fZ02KMZP0302KMZP00`000000[hFW0:n5Y`0;0:n5
Y`0300000031U:P0`IBX00`0`IBX00<000000=>UZ@3CYJT02`3CYJT00`000000i[bZ000000030>Mn
9@030000003oool0oooo06@0oooo0P0000001@1@3UX000000000001iDYP0000000D0V6RI00<00000
0:iiV@2^NIT00`2^NIT00`000000`HVI0<69V@030<69V@030000003DViP0e9^H0080e9^H0P000002
0>b<B@800000JP3oool30000000303D0@@000000P6FY00L0P6FY00<0000009]fZ02KMZP0302KMZP0
0`000000[hFW0:n5Y`0;0:n5Y`0300000031U:P0`IBX00`0`IBX00<000000=>UZ@3CYJT02`3CYJT0
0`000000i[bZ000000030>Mn9@030000003oool0oooo0=80oooo003J0?ooo`@000002P20IJT00`00
0000VgJX09]fZ00;09]fZ0030000002_QJL0[hFW00/0[hFW00<000000<6DZ031U:P03031U:P00`00
0000djFY0=>UZ@0:0=>UZ@050000003V_:X0i[bZ0>JlZP0000000`3WORD00`000000oooo0?ooo`1R
0?ooo`040000000002/00000000000<0NE:H00<0000009QXV@2HJ9T00`2HJ9T00`000000[WVI0:ii
V@030:iiV@0300000031RIT0`HVI00<0`HVI00<000000=BKV03DViP00`3DViP2000000030>b<B@00
0000000006X0oooo1000000:081UZ@030000002KMZP0VgJX00/0VgJX00<000000:n5Y`2_QJL02`2_
QJL00`000000`IBX0<6DZ00<0<6DZ0030000003CYJT0djFY00X0djFY00D000000>JlZP3V_:X0i[bZ
000000030>Mn9@030000003oool0oooo0=40oooo003I0?ooo`<000003020IJT00`000000VgJX09]f
Z00;09]fZ0030000002_QJL0[hFW00@0[hFW2P00000;0<6DZ0030000003CYJT0djFY00/0djFY00<0
00000>JlZP3V_:X00P3V_:X2000000030>Mn9@000000oooo06<0oooo0`00000407UBV0030000002H
J9T0V6RI00<0V6RI00<000000:iiV@2^NIT00`2^NIT00`000000`HVI0<69V@030<69V@030000003D
ViP0e9^H00<0e9^H00<000000>VaUP0000000P00001Y0?ooo`<000003020IJT00`000000VgJX09]f
Z00;09]fZ0030000002_QJL0[hFW00@0[hFW2P00000;0<6DZ0030000003CYJT0djFY00/0djFY00<0
00000>JlZP3V_:X00P3V_:X2000000030>Mn9@000000oooo0=80oooo003I0?ooo`<000003020IJT0
0`000000VgJX09]fZ00:09]fZ0P000001`2aVl400`000000_JK20;fV`P04000000L0`IBX00<00000
0=>UZ@3CYJT02`3CYJT00`000000i[bZ0>JlZP040>JlZP030000003WORD0000006<0oooo00<0000[
000000000000101iDYP00`000000V6RI09QXV@0309QXV@030000002^NIT0[WVI00<0[WVI00<00000
0<69V@31RIT00`31RIT00`000000e9^H0=BKV0030=BKV0050000003Y/IH0jK6F0>VaUP000000J@3o
ool3000000`0P6FY00<0000009]fZ02KMZP02P2KMZP8000000L0/I_100<000000;fV`P2mY/801000
00070<6DZ0030000003CYJT0djFY00/0djFY00<000000>JlZP3V_:X0103V_:X00`000000ighU0000
003B0?ooo`00f03oool30000000305I<ZP000000P6FY00X0P6FY00<0000009]fZ02KMZP01`2KMZP3
000000030:BB``000000/I_100`0/I_100<000000;fV`P2mY/80102mY/8500000080`IBX00<00000
0=>UZ@3CYJT02`3CYJT00`000000i[bZ0>JlZP050>JlZP800000HP3oool20000000304L`TP000000
NE:H00<0NE:H00<0000009QXV@2HJ9T00`2HJ9T00`000000[WVI0:iiV@030:iiV@0300000031RIT0
`HVI00<0`HVI00<000000=BKV03DViP00P3DViP00`000000jK6F0>VaUP020>VaUP030000003oool0
oooo06H0oooo0`0000000`1FC:X00000081UZ@0:081UZ@030000002KMZP0VgJX00L0VgJX0`000000
0`2TT/<000000;6K`@0<0;6K`@030000002mY/80_JK200@0_JK21@0000020<6DZ0030000003CYJT0
djFY00/0djFY00<000000>JlZP3V_:X01@3V_:X200000=80oooo003H0?ooo`8000000P1FC:X00`00
0000P6FY081UZ@0:081UZ@030000002KMZP0VgJX0080VgJX100000040:BB``030000002aVl40/I_1
00/0/I_100<000000;fV`P2mY/802@2mY/84000000/0djFY00<000000>JlZP3V_:X01`3V_:X20000
0640oooo00D0000004L`TP17<980Ac2B0000000307UBV0030000002HJ9T0V6RI00<0V6RI00<00000
0:iiV@2^NIT00`2^NIT00`000000`HVI0<69V@020<69V@030000003DViP0e9^H00<0e9^H00<00000
0>VaUP3Y/IH00P3Y/IH2000006L0oooo0P00000205I<ZP0300000020IJT0P6FY00X0P6FY00<00000
09]fZ02KMZP00P2KMZP4000000@0Y9;300<000000;6K`@2aVl402`2aVl400`000000_JK20;fV`P09
0;fV`P@000002`3CYJT00`000000i[bZ0>JlZP070>JlZP800000d@3oool005`0oooo2`00001`0?oo
o`8000000`1FC:X00`000000P6FY081UZ@0:081UZ@030000002KMZP0000000800000202TT/<00`00
0000/I_10;6K`@0;0;6K`@030000002mY/80_JK200/0_JK200@000000<Rba000000000002@3CYJT0
0`000000i[bZ0>JlZP080>JlZP030000003oool0oooo05l0oooo00D0000004L`TP17<980Ac2B0000
000407UBV0030000002HJ9T0V6RI0080V6RI00<000000:iiV@2^NIT00`2^NIT00`000000`HVI0<69
V@020<69V@030000003DViP0e9^H00<0e9^H00L000000>VaUP3Y/IH0jK6F0000003nc8T0000006H0
oooo0P00000305I<ZP0300000020IJT0P6FY00X0P6FY00<0000009]fZ00000000P0000080:BB``03
0000002aVl40/I_100/0/I_100<000000;fV`P2mY/802`2mY/8010000000b;;40000000000090=>U
Z@030000003V_:X0i[bZ00P0i[bZ00<000000?ooo`3oool0L03oool;000005@0oooo001C0?ooo`T0
0000201o21<00`000000XR<=0:8S3@05000006/0oooo0P00000405I<ZP0300000020IJT0P6FY00T0
P6FY0P00000<0:BB``030000002aVl40/I_100X0/I_100<000000;fV`P2mY/802P2mY/800`000000
b;;40<Rba0020<Rba08000001`3CYJT00`000000i[bZ0>JlZP080>JlZP030000003oool0oooo05l0
oooo00D0000004L`TP17<980Ac2B0000000407UBV0030000002HJ9T0V6RI0080V6RI00<000000:ii
V@2^NIT00`2^NIT00`000000`HVI0<69V@020<69V@030000003DViP0e9^H00<0e9^H00L000000>Va
UP3Y/IH0jK6F0000003nc8T0000006H0oooo0P00000405I<ZP0300000020IJT0P6FY00T0P6FY0P00
000<0:BB``030000002aVl40/I_100X0/I_100<000000;fV`P2mY/802P2mY/800`000000b;;40<Rb
a0020<Rba08000001`3CYJT00`000000i[bZ0>JlZP080>JlZP030000003oool0oooo06L0oooo2@00
000807l84`030000002R8`d0XR<=00D00000C`3oool004l0oooo0`0000000`170000000007l84`0?
07l84`030000002R8`d0XR<=00D0XR<=1P00001T0?ooo`8000001@1FC:X00`000000P6FY081UZ@07
081UZ@<000003@2TT/<00`000000/I_10;6K`@0:0;6K`@030000002mY/80_JK200X0_JK200<00000
0<Rba038//@01038//@3000000@0djFY00<000000>JlZP3V_:X01`3V_:X00`000000nMVX0000001P
0?ooo`8000000P17<9800`000000NE:H07UBV00207UBV0030000002HJ9T0V6RI0080V6RI00<00000
0:iiV@2^NIT00`2^NIT00`000000`HVI0<69V@020<69V@030000003DViP0e9^H00<0e9^H00L00000
0>VaUP3Y/IH0jK6F0000003nc8T0000006D0oooo0P00000505I<ZP0300000020IJT0P6FY00L0P6FY
0`00000=0:BB``030000002aVl40/I_100X0/I_100<000000;fV`P2mY/802P2mY/800`000000b;;4
0<Rba0040<Rba0<00000103CYJT00`000000i[bZ0>JlZP070>JlZP030000003ifJP0000006@0oooo
0`0000000`170000000007l84`0?07l84`030000002R8`d0XR<=00D0XR<=1P0000190?ooo`00B`3o
ool4000000@0A`0000<0000007l84`1o21<01@1o21<<000000/0XR<=1000001P0?ooo`030000001F
C:X0ETbZ00@0ETbZ00<00000081UZ@20IJT01P20IJT01@000000U8_709B;a`2DRlL0000000`0Y9;3
00<000000;6K`@2aVl402P2aVl400`000000_JK20;fV`P0:0;fV`P0300000038//@0b;;400L0b;;4
0P0000000`3CYJT000000>JlZP090>JlZP030000003ifJP000000600oooo0P00000204L`TP030000
001iDYP0NE:H0080NE:H00<0000009QXV@2HJ9T00P2HJ9T00`000000[WVI0:iiV@030:iiV@030000
0031RIT0`HVI0080`HVI00<000000=BKV03DViP00`3DViP01`000000jK6F0>VaUP3Y/IH000000?k<
R@000000I@3oool00`000000ETbZ05I<ZP0405I<ZP0300000020IJT0P6FY00H0P6FY00D0000009B;
a`2DRlL0U8_70000000<0:BB``030000002aVl40/I_100X0/I_100<000000;fV`P2mY/802P2mY/80
0`000000b;;40<Rba0070<Rba080000000<0djFY0000003V_:X02@3V_:X00`000000nMVX0000001P
0?ooo`@00000101700000`000000O`PC07l84`0507l84``000002`2R8`d4000004D0oooo00170?oo
o`@000001P17000:000000T0Z6B100<000000<5hP031N8001P0000080:8S3@<00000G@3oool20000
00L0ETbZ00<00000081UZ@20IJT00`20IJT2000000@0U8_700<000000:BB``2TT/<02P2TT/<00`00
0000/I_10;6K`@0:0;6K`@030000002mY/80_JK200T0_JK200<000000<Rba038//@02P38//@20000
00T0i[bZ00@000000?WIZ03ifJP00000H03oool200000080Ac2B00<0000007UBV01iDYP00P1iDYP0
10000000V6RI09QXV@2HJ9T:00000080`HVI00<000000=BKV03DViP00P3DViP01@000000jK6F0>Va
UP3Y/IH000000080o/b900<000000?ooo`3oool0HP3oool2000000L0ETbZ00<00000081UZ@20IJT0
0`20IJT2000000@0U8_700<000000:BB``2TT/<02P2TT/<00`000000/I_10;6K`@0:0;6K`@030000
002mY/80_JK200T0_JK200<000000<Rba038//@02P38//@2000000T0i[bZ00@000000?WIZ03ifJP0
0000G03oool4000000H0A`002P0000090:QTP@0300000031N800`GR000H00000202R8`d3000004<0
oooo00150?ooo`8000001`1700030000000308U;O@000000Z6B10100Z6B100<000000<5hP031N800
1P31N80600000080XR<=00<000000;<[002c:`000P00001K0?ooo`030000001FC:X0ETbZ00H0ETbZ
00<00000081UZ@20IJT00P20IJT00`000000U8_709B;a`0509B;a`030000002TT/<0Y9;300T0Y9;3
00<000000;6K`@2aVl402P2aVl400`000000_JK20;fV`P090;fV`P0300000038//@0b;;400X0b;;4
00<000000=?2b@000000203V_:X010000000nMVX0?WIZ000001P0?ooo`8000000`17<9801P000000
NE:H07UBV01iDYP0000009QXV@80000000<0Wgn`0000002`S:l0102`S:l00`000000`9V_0<2I[`04
000000<0e9^H00H000000>VaUP3Y/IH0jK6F0000003nc8T2000006@0oooo00<0000005I<ZP1FC:X0
1P1FC:X00`000000P6FY081UZ@02081UZ@030000002DRlL0U8_700D0U8_700<000000:BB``2TT/<0
2@2TT/<00`000000/I_10;6K`@0:0;6K`@030000002mY/80_JK200T0_JK200<000000<Rba038//@0
2P38//@00`000000dl;9000000080>JlZP040000003ifJP0nMVX000005X0oooo0P00000704L000<0
000000<0RD]m0000002XI840402XI8400`000000`GR00<5hP0060<5hP0H000000P2R8`d00`000000
/b/00;<[000200000440oooo00130?ooo`8000001@170004000000@0RD]m00<000000:QTP@2XI840
3`2XI8400`000000`GR00<5hP00<0<5hP0@000000`2c:`02000005T0oooo00<0000005I<ZP1FC:X0
1P1FC:X01@000000P6FY081UZ@20IJT0000000P0U8_700<000000:BB``2TT/<02@2TT/<00`000000
/I_10;6K`@090;6K`@030000002mY/80_JK200X0_JK200<000000<Rba038//@02P38//@010000000
dl;90=?2b@0000060>JlZP030000003ifJP0nMVX0080nMVX00<000000?ooo`3oool0GP3oool01@00
07H0000004L`TP17<98000000080NE:H0`00000309mo/0030000002`S:l0/8b_00<0/8b_00<00000
0<2I[`30VJl00P30VJl01P000000cjRa000000000000e9^H000000<0jK6F00@000000?k<R@000000
0000I03oool00`000000ETbZ05I<ZP0605I<ZP0500000020IJT0P6FY081UZ@000000202DRlL00`00
0000Y9;30:BB``090:BB``030000002aVl40/I_100T0/I_100<000000;fV`P2mY/802P2mY/800`00
0000b;;40<Rba00:0<Rba0040000003C`/T0dl;9000000H0i[bZ00<000000?WIZ03ifJP00P3ifJP0
0`000000oooo0?ooo`1E0?ooo`8000001@170004000000@0RD]m00<000000:QTP@2XI8403`2XI840
0`000000`GR00<5hP00<0<5hP0@000000`2c:`02000003l0oooo00120?ooo`<000000P1700030000
00P0RD]m00<000000:QTP@2XI8403`2XI8400`000000`GR00<5hP00?0<5hP0<000000`2c:`020000
05L0oooo0P00000805I<ZP<000002P2DRlL00`000000Y9;30:BB``090:BB``030000002aVl40/I_1
00P0/I_100<000000;fV`P2mY/802@2mY/800`000000b;;40<Rba00:0<Rba0030000003C`/T0dl;9
0080dl;900<000000>JlZP3V_:X00`3V_:X00`000000nMVX0?WIZ0020?WIZ0030000003oool0oooo
05h0oooo0P00000204L`TP<0000000<0Rg>c0000002OOk000`2OOk000`000000/8b_0;2<[`030;2<
[`0300000030VJl0`9V_0080`9V_00@000000<nX/@3?Z;40cjRa0P0000030>VaUP040000003nc8T0
0000000006@0oooo0P00000805I<ZP<000002P2DRlL00`000000Y9;30:BB``090:BB``030000002a
Vl40/I_100P0/I_100<000000;fV`P2mY/802@2mY/800`000000b;;40<Rba00:0<Rba0030000003C
`/T0dl;90080dl;900<000000>JlZP3V_:X00`3V_:X00`000000nMVX0?WIZ0020?WIZ0030000003o
ool0oooo05@0oooo0`00000204L000<000002029Bgd00`000000Z6B10:QTP@0?0:QTP@0300000031
N800`GR000l0`GR00`0000030;<[00800000?@3oool00440oooo1P00000;08U;O@030000002XI840
Z6B100l0Z6B100<000000<5hP031N8003`31N8000`000000fXaj0=Z<NP02000000<0/b/00P00001E
0?ooo`800000201FC:X00`000000U8_709B;a`0:09B;a`030000002TT/<0Y9;300T0Y9;300<00000
0;6K`@2aVl40202aVl400`000000_JK20;fV`P090;fV`P0300000038//@0b;;400T0b;;400<00000
0=?2b@3C`/T0103C`/T01@000000i[bZ0>JlZP3V_:X0000000D0nMVX00<000000?ooo`3oool0GP3o
ool200000080Ac2B00<0000008]c/`2;Lk<00P2;Lk<01@000000Wgn`09mo/02OOk00000000D0/8b_
00D000000<2I[`30VJl0`9V_000000050<nX/@@000000P3nc8T00`000000oooo0?ooo`1S0?ooo`80
0000201FC:X00`000000U8_709B;a`0:09B;a`030000002TT/<0Y9;300T0Y9;300<000000;6K`@2a
Vl40202aVl400`000000_JK20;fV`P090;fV`P0300000038//@0b;;400T0b;;400<000000=?2b@3C
`/T0103C`/T01@000000i[bZ0>JlZP3V_:X0000000D0nMVX00<000000?ooo`3oool0D`3oool60000
00/0RD]m00<000000:QTP@2XI8403`2XI8400`000000`GR00<5hP00?0<5hP0030000003JS7X0fXaj
008000000`2c:`02000003/0oooo000o0?ooo`D000003P29Bgd00`000000Z6B10:QTP@0?0:QTP@03
00000031N800`GR000l0`GR000<000000=Z<NP3JS7X00P3JS7X2000000<0/b/00P00001C0?ooo`03
000000027J00000000H0ETbZ00<000000823c@0000002`2DRlL00`000000Y9;30:BB``090:BB``03
0000002aVl40/I_100P0/I_100<000000;fV`P2mY/80202mY/800`000000b;;40<Rba00:0<Rba003
0000003C`/T0dl;900D0dl;900@000000>JlZP3V_:X000001P3ifJP00`000000oooo0?ooo`1M0?oo
o`80000000<0Ac2B000000000000102;Lk<00`000000Wgn`09mo/00209mo/0030000002`S:l0/8b_
0080/8b_00D000000<2I[`30VJl0`9V_000000040<nX/@050000003N^k@0g[^d0=jk]00000000P3n
c8T00`000000oooo0?ooo`1S0?ooo`03000000027J00000000H0ETbZ00<000000823c@0000002`2D
RlL00`000000Y9;30:BB``090:BB``030000002aVl40/I_100P0/I_100<000000;fV`P2mY/80202m
Y/800`000000b;;40<Rba00:0<Rba0030000003C`/T0dl;900D0dl;900@000000>JlZP3V_:X00000
1P3ifJP00`000000oooo0?ooo`1@0?ooo`D000003P29Bgd00`000000Z6B10:QTP@0?0:QTP@030000
0031N800`GR000l0`GR000<000000=Z<NP3JS7X00P3JS7X2000000<0/b/00P00000i0?ooo`00?P3o
ool5000000l0RD]m00<000000:QTP@2XI8401P2XI84<000000l0`GR000<000000=Z<NP3JS7X0103J
S7X2000000<0/b/000<000000?ooo`3oool0D03oool00`0000000QfP0000000605I<ZP0400000020
Pld0P8?=000000/0U8_700<000000:BB``2TT/<0202TT/<00`000000/I_10;6K`@080;6K`@030000
002mY/80_JK200P0_JK200<000000<Rba038//@02@38//@00`000000dl;90=?2b@070=?2b@800000
1`3ifJP00`000000oooo0?ooo`1M0?ooo`060000000007H0Ac2B0000001/HkL000000`2;Lk<00`00
0000Wgn`09mo/00209mo/0X00000103?Z;401@000000g[^d0=jk]03N^k@000000080o/b900<00000
0?ooo`3oool0H`3oool00`0000000QfP0000000605I<ZP0400000020Pld0P8?=000000/0U8_700<0
00000:BB``2TT/<0202TT/<00`000000/I_10;6K`@080;6K`@030000002mY/80_JK200P0_JK200<0
00000<Rba038//@02@38//@00`000000dl;90=?2b@070=?2b@8000001`3ifJP00`000000oooo0?oo
o`1?0?ooo`D000003`29Bgd00`000000Z6B10:QTP@060:QTP@`000003`31N8000`000000fXaj0=Z<
NP040=Z<NP8000000`2c:`000`000000oooo0?ooo`0f0?ooo`00?@3oool300000080FBAb00<00000
08U;O@29Bgd03029Bgd:000000T0/8R[00<000000<:GZ`32Uj/01P0000090<5hP0030000003JS7X0
fXaj00H0fXaj0P0000000`2c:`0000000000001@0?ooo`05000000027J000QfP008MX0000000101F
C:X01@000000P8?=0823c@20Pld0000000/0U8_700<000000:BB``2TT/<0202TT/<00`000000/I_1
0;6K`@080;6K`@030000002mY/80_JK200P0_JK200<000000<Rba038//@02038//@00`000000dl;9
0=?2b@090=?2b@030000003ifJP0nMVX00D0nMVX00<000000?ooo`3oool0G@3oool00`000000001f
0000000206aS]`030000002;Lk<0Rg>c00L000001@2ZJ8H00`000000`G^50<5kQ@0600000080g[^d
00<000000>kE^@0000000P00001T0?ooo`05000000027J000QfP008MX0000000101FC:X01@000000
P8?=0823c@20Pld0000000/0U8_700<000000:BB``2TT/<0202TT/<00`000000/I_10;6K`@080;6K
`@030000002mY/80_JK200P0_JK200<000000<Rba038//@02038//@00`000000dl;90=?2b@090=?2
b@030000003ifJP0nMVX00D0nMVX00<000000?ooo`3oool0CP3oool300000080FBAb00<0000008U;
O@29Bgd03029Bgd:000000T0/8R[00<000000<:GZ`32Uj/01P0000090<5hP0030000003JS7X0fXaj
00H0fXaj0P0000000`2c:`0000000000000g0?ooo`00>`3oool4000000<0FBAb00<0000008U;O@29
Bgd02@29Bgd30000000309]i[0000000/8R[0100/8R[00<000000<:GZ`32Uj/01P32Uj/6000000<0
`GR000<000000=Z<NP3JS7X0203JS7X4000004l0oooo00D00000008MX0027J000QfP0000000405I<
ZP0300000020Pld0P8?=0080P8?=00<0000009B;a`2DRlL02@2DRlL00`000000Y9;30:BB``070:BB
``030000002aVl40/I_100P0/I_100<000000;fV`P2mY/801`2mY/800`000000b;;40<Rba0090<Rb
a0030000003C`/T0dl;900P0dl;90P0000060?WIZ0800000H03oool00`0007H00000000000040000
0080SU:400<000000:YXQP2ZJ8H01`2ZJ8H00`000000`G^50<5kQ@060<5kQ@L00000I03oool01@00
00000QfP008MX0027J00000000@0ETbZ00<000000823c@20Pld00P20Pld00`000000U8_709B;a`09
09B;a`030000002TT/<0Y9;300L0Y9;300<000000;6K`@2aVl40202aVl400`000000_JK20;fV`P07
0;fV`P0300000038//@0b;;400T0b;;400<000000=?2b@3C`/T0203C`/T2000000H0nMVX0P00001>
0?ooo`@000000`1I97800`000000RD]m08U;O@0808U;O@@0000000<0VgV/0000002`R:/0402`R:/0
0`000000`YN[0<:GZ`060<:GZ`H000000`31N8000`000000fXaj0=Z<NP080=Z<NP@00000=P3oool0
03X0oooo0`00000505TTLP0300000029Bgd0RD]m00D0RD]m1000000409]i[0030000002`R:/0/8R[
00l0/8R[00<000000<:GZ`32Uj/03032Uj/5000000/0fXaj0`00001>0?ooo`03000000027J000QfP
00800QfP00@0000005I<ZP1FC:X000001P20Pld00`000000U8_709B;a`0809B;a`030000002TT/<0
Y9;300P0Y9;300<000000;6K`@2aVl401`2aVl400`000000_JK20;fV`P070;fV`P0300000038//@0
b;;400P0b;;400<000000=?2b@3C`/T0203C`/T010000000g=KA0=cFd@0000050?WIZ0800000G`3o
ool3000000L0SU:400<000000:YXQP2ZJ8H01`2ZJ8H00`000000`G^50<5kQ@080<5kQ@030000003G
SX40000000800000I03oool00`0000000QfP008MX002008MX0040000001FC:X0ETbZ000000H0P8?=
00<0000009B;a`2DRlL0202DRlL00`000000Y9;30:BB``080:BB``030000002aVl40/I_100L0/I_1
00<000000;fV`P2mY/801`2mY/800`000000b;;40<Rba0080<Rba0030000003C`/T0dl;900P0dl;9
00@000000=cFd@3Le]4000001@3ifJP2000004d0oooo0`00000405TTLP0300000029Bgd0RD]m00H0
RD]m0`00000509]i[0030000002`R:/0/8R[00l0/8R[00<000000<:GZ`32Uj/03032Uj/5000000/0
fXaj0`00000e0?ooo`00>@3oool3000000H0FBAb00<0000008U;O@29Bgd00P29Bgd3000000P0VgV/
00<000000;28Z`2`R:/03`2`R:/00`000000`YN[0<:GZ`0?0<:GZ`040000003CZJd00000000000X0
fXaj0`00001=0?ooo`03000000027J000QfP00800QfP00<0000005I<ZP0000002020Pld00`000000
U8_709B;a`0809B;a`030000002TT/<0Y9;300L0Y9;300<000000;6K`@2aVl400P2aVl48000000L0
_JK200<000000<Rba038//@01`38//@00`000000dl;90=?2b@080=?2b@050000003Le]40g=KA0=cF
d@000000103ifJP00`000000jnb;0000001M0?ooo`<00000202>DX@00`000000ZVR60:YXQP030:YX
QPP000002031NhD010000000ehj10=N>P@3GSX4300000680oooo00<00000008MX0027J000P027J00
0`000000ETbZ000000080823c@030000002DRlL0U8_700P0U8_700<000000:BB``2TT/<01`2TT/<0
0`000000/I_10;6K`@020;6K`@P000001`2mY/800`000000b;;40<Rba0070<Rba0030000003C`/T0
dl;900P0dl;900D000000=cFd@3Le]40g=KA000000040?WIZ0030000003[k8/0000004`0oooo0`00
000505TTLP0300000029Bgd0RD]m00<0RD]m0`00000809]i[0030000002`R:/0/8R[00l0/8R[00<0
00000<:GZ`32Uj/03`32Uj/010000000djV]00000000000:0=Z<NP<00000=03oool003P0oooo0P00
000805TTLP0300000029Bgd00000008000002`2KNJ`00`000000/8R[0;28Z`0?0;28Z`0300000032
Uj/0`YN[00l0`YN[00@000000=>Y[@3CZJd0djV]0P0000080=Z<NP040000003bXVH00000000004`0
oooo00<00000008MX0027J000`027J02000000P0P8?=00<0000009B;a`2DRlL0202DRlL00`000000
Y9;30:BB``050:BB``L000001@2_[MD00`000000][;F0;JbeP0400000080_JK200<000000<Rba038
//@02038//@00`000000dl;90=?2b@080=?2b@030000003Le]40g=KA0080g=KA00@000000?WIZ03i
fJP0nMVX0P00001L0?ooo`8000000P1V<W`00`000000SU:408iBQ00508iBQ0L000001@2aXLP00`00
0000^j[80;^Zb00600000080`G^500<000000=N>P@3GSX40103GSX4200000600oooo00<00000008M
X0027J000`027J02000000P0P8?=00<0000009B;a`2DRlL0202DRlL00`000000Y9;30:BB``050:BB
``L000001@2_[MD00`000000][;F0;JbeP0400000080_JK200<000000<Rba038//@02038//@00`00
0000dl;90=?2b@080=?2b@030000003Le]40g=KA0080g=KA00@000000?WIZ03ifJP0nMVX0P00001<
0?ooo`8000001`1I97800`000000RD]m00000003000000/0VgV/00<000000;28Z`2`R:/03`2`R:/0
0`000000`YN[0<:GZ`0?0<:GZ`040000003CZJd0djV]0=>Y[@800000203JS7X010000000lZ9V0000
0000000c0?ooo`00=`3oool2000000T0FBAb0P00000>09]i[0030000002`R:/0/8R[00l0/8R[00<0
00000<:GZ`32Uj/03`32Uj/00`000000djV]0=>Y[@030=>Y[@8000001P3JS7X00`000000lZ9V0?:R
IP02000004/0oooo0P000004008MX00300000020Pld0P8?=00P0P8?=00<0000009B;a`2DRlL0202D
RlL00`000000Y9;30:BB``0400000080YjSF00<000000:n]e@2_[MD01`2_[MD00`000000][;F0;Jb
eP040;JbeP@000002038//@00`000000dl;90=?2b@080=?2b@030000003Le]40g=KA00<0g=KA00@0
00000?WIZ03ifJP0nMVX0P00001K0?ooo`030000001V<W`0IS9l0080IS9l00<0000008iBQ02>DX@0
0P2>DX@3000000030:FIb@000000/J7800T0/J7800<000000;^Zb02kZ/P01P2kZ/P3000000L0ehj1
0P00001O0?ooo`80000010027J000`000000P8?=0823c@080823c@030000002DRlL0U8_700P0U8_7
00<000000:BB``2TT/<0100000020:NXeP030000002_[MD0[jgE00L0[jgE00<000000;JbeP2f/]H0
102f/]H4000000P0b;;400<000000=?2b@3C`/T0203C`/T00`000000g=KA0=cFd@030=cFd@040000
003ifJP0nMVX0?WIZ0800000B`3oool2000000P0FBAb0P00000?09]i[0030000002`R:/0/8R[00l0
/8R[00<000000<:GZ`32Uj/03P32Uj/00`000000djV]0=>Y[@040=>Y[@8000001P3JS7X00`000000
lZ9V0?:RIP0200000380oooo000f0?ooo`030000001I9780FBAb00L0FBAb0`00000@09]i[0030000
002`R:/0/8R[00h0/8R[00<000000<:GZ`32Uj/03`32Uj/00`000000djV]0=>Y[@050=>Y[@800000
1@3JS7X00`000000lZ9V0?:RIP02000004/0oooo00<00000008MX0027J000P027J02000000X0P8?=
00<0000009B;a`2DRlL01`2DRlL3000000L0YjSF00<000000:n]e@2_[MD01P2_[MD00`000000][;F
0;JbeP060;JbeP040000002l^]P00000000000D0b;;400<000000=?2b@3C`/T0203C`/T00`000000
g=KA0=cFd@050=cFd@050000003ifJP000000>_/R`000000F@3oool2000000D0IS9l00<0000008iB
Q00000000P0000050:FIb@030000002aXLP0/J7800L0/J7800<000000;^Zb02kZ/P0202kZ/P30000
00D0ehj100<000000>nTM0000000G`3oool00`0000000QfP008MX002008MX08000002P20Pld00`00
0000U8_709B;a`0709B;a`<000001`2WZ=H00`000000[jgE0:n]e@060:n]e@030000002f/]H0][;F
00H0][;F00@000000;bjf000000000001@38//@00`000000dl;90=?2b@080=?2b@030000003Le]40
g=KA00D0g=KA00D000000?WIZ0000000jnb;0000001:0?ooo`030000001I9780FBAb00H0FBAb0`00
000A09]i[0030000002`R:/0/8R[00h0/8R[00<000000<:GZ`32Uj/03P32Uj/00`000000djV]0=>Y
[@060=>Y[@8000001@3JS7X00`000000lZ9V0?:RIP0200000340oooo000e0?ooo`8000001`1I9782
00000080P6R^00<0000009]i[02KNJ`03P2KNJ`00`000000/8R[0;28Z`0>0;28Z`0300000032Uj/0
`YN[00h0`YN[00<000000=>Y[@3CZJd0203CZJd2000000<0fXaj00@000000?:RIP3bXVH0lZ9V0P00
001:0?ooo`8000000`027J000`000000I7gF0000000:0823c@030000002DRlL0U8_700D0U8_700<0
000009nUf@000000202WZ=H00`000000[jgE0:n]e@060:n]e@030000002f/]H0][;F00D0][;F00<0
00000;bjf02l^]P00P2l^]P300000080b;;400<000000=?2b@3C`/T01`3C`/T00`000000g=KA0=cF
d@060=cFd@050000003ifJP000000>_/R`000000F03oool00`000000IS9l06HbO00406HbO0<00000
202UVLT00`000000/J780;6Qb0070;6Qb0030000002kZ/P0^j[800L0^j[800@000000<Ffb`35]//0
aKK;0P0000030=N>P@030000003_Y7@0kjAd00800000G@3oool2000000<00QfP00<0000006AmeP00
00002P20Pld00`000000U8_709B;a`0509B;a`030000002OYMT0000000P0YjSF00<000000:n]e@2_
[MD01P2_[MD00`000000][;F0;JbeP050;JbeP030000002l^]P0_;[H0080_;[H0`0000020<Rba003
0000003C`/T0dl;900L0dl;900<000000=cFd@3Le]401P3Le]401@000000nMVX0000003[k8/00000
04T0oooo0P00000705TTLP0500000020J:h0P6R^081X[P000000402KNJ`00`000000/8R[0;28Z`0>
0;28Z`0300000032Uj/0`YN[00h0`YN[00<000000=>Y[@3CZJd0203CZJd2000000<0fXaj00@00000
0?:RIP3bXVH0lZ9V0P00000`0?ooo`00=03oool00`000000001?0000000605TTLP0300000020J:h0
P6R^00<0P6R^00<0000009]i[02KNJ`03@2KNJ`00`000000/8R[0;28Z`0>0;28Z`0300000032Uj/0
`YN[00h0`YN[00<000000=>Y[@3CZJd02P3CZJd2000000030=Z<NP000000lZ9V00@0lZ9V00<00000
0?ooo`3oool0B03oool01@0000000QfP008MX0027J0000000080I7gF00<000000823c@20Pld02020
Pld00`000000U8_709B;a`0209B;a`8000000`2OYMT80:NXeP030000002_[MD0[jgE00D0[jgE00<0
00000;JbeP2f/]H01P2f/]H00`000000_;[H0;bjf0050;bjf08000002@3C`/T00`000000g=KA0=cF
d@080=cFd@040000003[k8/0jnb;000005L0oooo0P00000406HbO080000000<0Ui?=0000002UVLT0
202UVLT00`000000/J780;6Qb0070;6Qb0030000002kZ/P0^j[800L0^j[800<000000<Ffb`35]//0
0`35]//2000000030=N>P@000000kjAd00<0kjAd00<000000?ooo`3oool0F`3oool01@0000000QfP
008MX0027J0000000080I7gF00<000000823c@20Pld02020Pld00`000000U8_709B;a`0209B;a`80
00000`2OYMT80:NXeP030000002_[MD0[jgE00D0[jgE00<000000;JbeP2f/]H01P2f/]H00`000000
_;[H0;bjf0050;bjf08000002@3C`/T00`000000g=KA0=cFd@080=cFd@040000003[k8/0jnb;0000
04P0oooo00<000000000C`0000001@1I9782000000@0P6R^00<0000009]i[02KNJ`03P2KNJ`00`00
0000/8R[0;28Z`0>0;28Z`0300000032Uj/0`YN[00h0`YN[00<000000=>Y[@3CZJd02P3CZJd20000
00030=Z<NP000000lZ9V00@0lZ9V00<000000?ooo`3oool0;@3oool003@0oooo00<000000000C`00
0000101I9782000000H0P6R^00<0000009]i[02KNJ`03@2KNJ`00`000000/8R[0;28Z`060;28Z`d0
00003032Uj/00`000000djV]0=>Y[@0<0=>Y[@8000001P3bXVH00`000000oooo0?ooo`170?ooo`80
00000P027J001@000000I7gF06AmeP1TOMH0000000T0P8?=00D0000009B;a`2DRlL0U8_700000005
09nUf@030000002WZ=H0YjSF00H0YjSF00<000000:n]e@2_[MD0102_[MD00`000000][;F0;JbeP05
0;JbeP030000002l^]P0_;[H00H0_;[H00<000000<33g00000001`3C`/T00`000000g=KA0=cFd@09
0=cFd@030000003[k8/0000005L0oooo00<0000001P0I00000000P1V<W`2000000@0Ui?=00<00000
0:FIb@2UVLT01P2UVLT00`000000/J780;6Qb0070;6Qb0030000002kZ/P0^j[800H0^j[800<00000
0<Ffb`35]//01P35]//2000000D0kjAd00<000000?ooo`3oool0FP3oool2000000800QfP00D00000
06AmeP1TOMH0I7gF000000090823c@050000002DRlL0U8_709B;a`0000001@2OYMT00`000000YjSF
0:NXeP060:NXeP030000002_[MD0[jgE00@0[jgE00<000000;JbeP2f/]H01@2f/]H00`000000_;[H
0;bjf0060;bjf00300000030`m`0000000L0dl;900<000000=cFd@3Le]402@3Le]400`000000jnb;
000000190?ooo`030000000004l0000000@0FBAb00<00000081X[P20J:h01020J:h00`000000VgV/
09]i[00>09]i[0030000002`R:/0/8R[00H0/8R[3000000<0<:GZ`030000003CZJd0djV]00d0djV]
0P0000060?:RIP030000003oool0oooo02`0oooo000c0?ooo`030000000004l0000000@0FBAb00<0
0000081X[P20J:h01P20J:h00`000000VgV/09]i[00<09]i[0X00000202`WlH00`000000_JW60;fY
aP020;fYaPP000001032Uj/00`000000djV]0=>Y[@0=0=>Y[@8000001P3bXVH00`000000oooo0?oo
o`170?ooo`03000000027J00000000D0I7gF00<000000823c@20Pld01`20Pld00`000000U8_70000
000709nUf@030000002WZ=H0YjSF00D0YjSF00<000000:n]e@2_[MD00`2_[MD2000000L0][;F00<0
00000;bjf02l^]P01@2l^]P01@000000`<?L0<33g030`m`0000000H0dl;900<000000=cFd@3Le]40
203Le]42000000030>_/R`000000oooo05H0oooo00<0000001P0I00000000P00000609NCc@030000
002UVLT0YIW900L0YIW900<000000;6Qb02aXLP00P2aXLP6000000L0^j[800<000000<Ffb`35]//0
1P35]//010000000c/?@0000000000030>nTM0030000003oool0oooo05/0oooo00<00000008MX000
00001@1TOMH00`000000P8?=0823c@070823c@030000002DRlL0000000L0WjGI00<000000:NXeP2W
Z=H01@2WZ=H00`000000[jgE0:n]e@030:n]e@8000001`2f/]H00`000000_;[H0;bjf0050;bjf005
00000030`m`0`<?L0<33g00000001P3C`/T00`000000g=KA0=cFd@080=cFd@80000000<0jnb;0000
003oool0A`3oool00`000000001?0000000305TTLP8000002020J:h00`000000VgV/09]i[00<09]i
[0X00000202`WlH010000000_JW60;fYaP2mZLH8000000@0`YN[00<000000=>Y[@3CZJd03P3CZJd2
000000H0lZ9V00<000000?ooo`3oool0:`3oool00380oooo00@000000000C`0004l000000P1I9782
000000T0P6R^00<0000009]i[02KNJ`0202KNJ`4000000030:>Fa`000000/9o600l0/9o600<00000
0;fYaP2mZLH02P2mZLH6000000d0djV]00@000000>K0[`3V`:l000001P3bXVH00`000000oooo0?oo
o`160?ooo`<000001P1TOMH2000000P0P8?=00<0000009nUf@2OYMT01`2OYMT00`000000YjSF0:NX
eP040:NXeP030000002_[MD0[jgE00@0[jgE00<000000;JbeP2f/]H0102f/]H00`000000_;[H0;bj
f0050;bjf00300000030`m`0`<?L00<0`<?L0P0000030=?2b@030000003Le]40g=KA00L0g=KA0P00
00000`3OkM/000000000001G0?ooo`040000000H06@0601T000000T0Ui?=00<000000:FIb@2UVLT0
102UVLT7000000@0Z;o[00<000000:S0j`0000000`0000020;^Zb00300000035]//0aKK;00H0aKK;
00<000000<k3d03>`m000P3>`m000`000000kjAd0>nTM002000005`0oooo0`00000606AmeP800000
2020Pld00`000000WjGI09nUf@0709nUf@030000002WZ=H0YjSF00@0YjSF00<000000:n]e@2_[MD0
102_[MD00`000000][;F0;JbeP040;JbeP030000002l^]P0_;[H00D0_;[H00<000000<33g030`m`0
0`30`m`2000000<0dl;900<000000=cFd@3Le]401`3Le]42000000030=o]f`000000000004P0oooo
00@000000000C`0004l000000P1I97800`000000P6R^081X[P08081X[P030000002KNJ`0VgV/00P0
VgV/100000000`2SU/L000000;2OaP0?0;2OaP030000002mZLH0_JW600T0_JW61P00000>0=>Y[@04
0000003V`:l0i/2_000000H0lZ9V00<000000?ooo`3oool0:P3oool00340oooo00@000000000C`00
04l0001?0`00000<081X[P030000002KNJ`0VgV/00<0VgV/100000050:>Fa`030000002`WlH0/9o6
00h0/9o600<000000;fYaP2mZLH03P2mZLH010000000b;K900000000000;0=>Y[@050000003V`:l0
i/2_0>K0[`0000001@3bXVH00`000000oooo0?ooo`170?ooo`800000201TOMH00`000000P8?=0823
c@040823c@030000002FXmh0000000P0WjGI00<000000:NXeP2WZ=H0102WZ=H00`000000[jgE0:n]
e@040:n]e@030000002f/]H0][;F00@0][;F00<000000;bjf02l^]P0102l^]P00`000000`<?L0<33
g0060<33g0030000003C`/T0000000T0g=KA00H000000=o]f`3OkM/000000>_/R`00001F0?ooo`06
0000000H06@0601T00000026S]@00000202GTld00`000000YIW90:FIb@0400000080Yko[00<00000
0:Roj`2X_n/01P2X_n/00`000000Z<3[0:S0j`030:S0j`@000001`35]//00`000000c/?@0<k3d003
0<k3d0040000003_Y7@0kjAd000005d0oooo0P00000806AmeP0300000020Pld0P8?=00@0P8?=00<0
000009JSgP000000202OYMT00`000000YjSF0:NXeP040:NXeP030000002_[MD0[jgE00@0[jgE00<0
00000;JbeP2f/]H0102f/]H00`000000_;[H0;bjf0040;bjf00300000030`m`0`<?L00H0`<?L00<0
00000=?2b@0000002@3Le]401P000000gngK0=o]f`000000jnb;000004L0oooo00@000000000C`00
04l0001?0`00000;081X[P030000002KNJ`0VgV/00@0VgV/100000050:>Fa`030000002`WlH0/9o6
00h0/9o600<000000;fYaP2mZLH03@2mZLH010000000b;K900000000000<0=>Y[@050000003V`:l0
i/2_0>K0[`0000001@3bXVH00`000000oooo0?ooo`0Z0?ooo`00<@3oool01@000000001?0000C`00
04l0000000h0P6R^00<0000009]i[00000000`00000:0:>Fa`030000002`WlH0/9o600d0/9o600<0
00000;fYaP2mZLH03@2mZLH00`000000b;K90<Rfb@020<Rfb@8000002@3CZJd00`000000i/2_0>K0
[`020>K0[`8000000`3bXVH2000004P0oooo0P00000906AmeP0300000020Pld0P8?=0080P8?=00@0
000009JSgP2FXmh0UZ?N0P00000709nUf@030000002WZ=H0YjSF00@0YjSF00<000000:n]e@2_[MD0
0`2_[MD00`000000][;F0;JbeP040;JbeP030000002l^]P0_;[H00<0_;[H00<000000<33g030`m`0
2030`m`00`000000g=KA0=cFd@070=cFd@040000003OkM/0gngK0=o]f`800000E`3oool010000000
601T01P0I000000208J>e0030000002GTld0Ui?=00D0Ui?=0`0000070:Noj`030000002X_n/0Z;o[
00D0Z;o[00<000000:S0j`2X`>/0102X`>/00`000000Z<3[0:S0j`0400000080aKK;00<000000<k3
d03>`m001@3>`m04000005`0oooo0P00000906AmeP0300000020Pld0P8?=0080P8?=00@0000009JS
gP2FXmh0UZ?N0P00000709nUf@030000002WZ=H0YjSF00@0YjSF00<000000:n]e@2_[MD00`2_[MD0
0`000000][;F0;JbeP040;JbeP030000002l^]P0_;[H00<0_;[H00<000000<33g030`m`02030`m`0
0`000000g=KA0=cFd@070=cFd@040000003OkM/0gngK0=o]f`800000B03oool01@000000001?0000
C`0004l0000000h0P6R^00<0000009]i[00000000`00000:0:>Fa`030000002`WlH0/9o600d0/9o6
00<000000;fYaP2mZLH0302mZLH00`000000b;K90<Rfb@020<Rfb@8000002P3CZJd00`000000i/2_
0>K0[`020>K0[`8000000`3bXVH2000002/0oooo000`0?ooo`040000000004l0001?0000C`800000
3P20J:h2000000h0XiK700<000000;2OaP2`WlH0302`WlH00`000000_JW60;fYaP0>0;fYaP030000
0038]/T0b;K900@0b;K90P0000060=>Y[@030000003V`:l0i/2_00D0i/2_00<000000?:RIP3bXVH0
0P0000180?ooo`@00000201TOMH01@000000P8?=0823c@20Pld0000000D0UZ?N00<0000009nUf@2O
YMT01@2OYMT00`000000YjSF0:NXeP030:NXeP030000002_[MD0[jgE00<0[jgE00<000000;JbeP2f
/]H00`2f/]H00`000000_;[H0;bjf0030;bjf00300000030`m`0`<?L00L0`<?L0`0000070=cFd@80
0000103OkM/2000005L0oooo00<0000001P0I00000001026S]@00`000000Ui?=09NCc@0209NCc@80
00000P2V_n/00`000000Yko[0:Noj`050:Noj`030000002X_n/0Z;o[00@0Z;o[00<000000:S0j`2X
`>/01@2X`>/00`000000Z<3[0:S0j`040:S0j`8000002P3>`m02000005`0oooo1000000806AmeP05
00000020Pld0P8?=0823c@0000001@2FXmh00`000000WjGI09nUf@0509nUf@030000002WZ=H0YjSF
00<0YjSF00<000000:n]e@2_[MD00`2_[MD00`000000][;F0;JbeP030;JbeP030000002l^]P0_;[H
00<0_;[H00<000000<33g030`m`01`30`m`3000000L0g=KA0P0000040=o]f`800000A`3oool01000
0000001?0000C`0004l2000000h0P6R^0P00000>0:>Fa`030000002`WlH0/9o600`0/9o600<00000
0;fYaP2mZLH03@2mZLH00`000000b;K90<Rfb@040<Rfb@<000001P3CZJd00`000000i/2_0>K0[`05
0>K0[`030000003bXVH0lZ9V00800000:`3oool002l0oooo00<000000000C`0004l00P0004l00`00
0000EDn_0000000;081X[P<000003`2SU/L00`000000/9o60;2OaP0<0;2OaP030000002mZLH0_JW6
00d0_JW600<000000<Rfb@38]/T01`38]/T2000000@0djV]00<000000>K0[`3V`:l01P3V`:l01000
0000lZ9V0000000000190?ooo`80000000<0>GCO0000001TOMH01`1TOMH00`000000P8?=00000007
09JSgP030000002OYMT0WjGI00D0WjGI00<000000:NXeP2WZ=H00P2WZ=H00`000000[jgE00000007
00000080][;F00<000000;bjf02l^]P00`2l^]P00`000000`<?L0<33g0060<33g00500000033c>40
`lcQ0<?<h@0000001@3Le]400`000000gngK0=o]f`040=o]f`030000003oool0oooo05H0oooo0P00
000608J>e0040000002GTld00000000000D0Y[o[00<000000:Noj`2W_n/01@2W_n/00`000000Z;o[
0:Roj`030:Roj`030000002X`>/0Z<3[00@0Z<3[00<000000:S0j`2X`>/0102X`>/2000000030:W1
j`000000c/?@00H0c/?@0`0000000`3h/TP000000?ooo`1K0?ooo`80000000<0>GCO0000001TOMH0
1`1TOMH00`000000P8?=0000000709JSgP030000002OYMT0WjGI00D0WjGI00<000000:NXeP2WZ=H0
0P2WZ=H00`000000[jgE0000000700000080][;F00<000000;bjf02l^]P00`2l^]P00`000000`<?L
0<33g0060<33g00500000033c>40`lcQ0<?<h@0000001@3Le]400`000000gngK0=o]f`040=o]f`03
0000003oool0oooo04D0oooo00<000000000C`0004l00P0004l00`000000EDn_0000000;081X[P<0
00003`2SU/L00`000000/9o60;2OaP0<0;2OaP030000002mZLH0_JW600d0_JW600<000000<Rfb@38
]/T01`38]/T2000000@0djV]00<000000>K0[`3V`:l01P3V`:l010000000lZ9V00000000000[0?oo
o`00;`3oool01@000000001?0000C`0004l000000080EDn_00<00000081X[P20J:h01`20J:h20000
00<0Thk<00<000000:>Fa`2SU/L0302SU/L00`000000/9o60;2OaP0<0;2OaP030000002mZLH0_JW6
00d0_JW600<000000<Rfb@38]/T02@38]/T2000000030=>Y[@000000i/2_00T0i/2_0P0000000`3Z
Y2L000000?ooo`170?ooo`8000000P0iM=l2000000L0I7gF0P00000809JSgP030000002OYMT0WjGI
00@0WjGI1@0000000`0;000000000000000<00000080_;[H00<000000<33g030`m`01@30`m`20000
00@0`lcQ00<000000=cFd@3Le]400P3Le]400`000000gngK0=o]f`040=o]f`800000E`3oool30000
00L0QXkD00<000000:Joj`2V_n/01P2V_n/2000000D0Yko[00<000000:Roj`2X_n/00`2X_n/00`00
0000Z<3[0:S0j`030:S0j`030000002X`>/0Z<3[00@0Z<3[00<000000:W1j`2Y`N/00P2Y`N/20000
00@0c/?@00@000000=GDf03Ee=P0eMCH0P00001L0?ooo`8000000P0iM=l2000000L0I7gF0P000008
09JSgP030000002OYMT0WjGI00@0WjGI1@0000000`0;000000000000000<00000080_;[H00<00000
0<33g030`m`01@30`m`2000000@0`lcQ00<000000=cFd@3Le]400P3Le]400`000000gngK0=o]f`04
0=o]f`800000A`3oool01@000000001?0000C`0004l000000080EDn_00<00000081X[P20J:h01`20
J:h2000000<0Thk<00<000000:>Fa`2SU/L0302SU/L00`000000/9o60;2OaP0<0;2OaP030000002m
ZLH0_JW600d0_JW600<000000<Rfb@38]/T02@38]/T2000000030=>Y[@000000i/2_00T0i/2_0P00
00000`3ZY2L000000?ooo`0Y0?ooo`00;`3oool010000000001?0000C`00000305E?[`0300000020
J:h0P6R^00D0P6R^0P00000509>>c0030000002SU/L0XiK700d0XiK700<000000;2OaP2`WlH02`2`
WlH00`000000_JW60;fYaP0=0;fYaP0300000038]/T0b;K900/0b;K90P00000;0>K0[`030000003Z
Y2L0000004T0oooo00<0000003Udg`0iM=l00P0iM=l00`000000I7gF06AmeP0406AmeP040000002<
Y>D00000000000L0UZ?N30000007090V=`040000002_?c<0[clc0:lo<`P000001030`m`00`000000
`lcQ0<?<h@040<?<h@030000003Le]40g=KA008000001`3OkM/00`000000oooo0?ooo`1F0?ooo`80
00001`26S]@010000000Y[o[0000000000080:Joj`040000002W_n/0Yko[0:Noj`X000000`2X`>/0
0`000000Z<3[0:S0j`030:S0j`030000002Y`N/0ZL7[00D0ZL7[00@000000<k3d00000000000103E
e=P2000005d0oooo00<0000003Udg`0iM=l00P0iM=l00`000000I7gF06AmeP0406AmeP040000002<
Y>D00000000000L0UZ?N30000007090V=`040000002_?c<0[clc0:lo<`P000001030`m`00`000000
`lcQ0<?<h@040<?<h@030000003Le]40g=KA008000001`3OkM/00`000000oooo0?ooo`160?ooo`04
0000000004l0001?000000<0EDn_00<00000081X[P20J:h01@20J:h2000000D0Thk<00<000000:>F
a`2SU/L03@2SU/L00`000000/9o60;2OaP0;0;2OaP030000002mZLH0_JW600`0_JW600<000000<Rf
b@38]/T03038]/T2000000/0i/2_00<000000>ZT9`000000:P3oool002l0oooo00@000000000C`00
04l00000101ECjl00`000000P6R^081X[P03081X[P030000002CS/`0Thk<00H0Thk<00<000000:>F
a`2SU/L0302SU/L00`000000/9o60;2OaP040;2OaPX00000302mZLH00`000000b;K90<Rfb@0<0<Rf
b@030000003Ba/l0000000X0i/2_00<000000>ZT9`000000B@3oool2000000@0>GCO0P00000406Am
eP040000002<Y>D0S:CU08bTi@8000000P2FXmh500000080HP0Y00<00000090V=`2@9SL0302@9SL0
0`000000[clc0:lo<`090:lo<`D000001`33c>42000000L0gngK0P00001I0?ooo`0300005@000000
000000D0QXkD00<000000:Joj`2V_n/00P2V_n/2000000H0Y[o[1000000309;OoP050000001kdol0
Nm?o07_Co`0000000P1]a_l4000000<0Z<3[0P0000090:W1j`030000003Ee=P0eMCH00D0eMCH00<0
00000?ooo`3oool0F`3oool2000000@0>GCO0P00000406AmeP040000002<Y>D0S:CU08bTi@800000
0P2FXmh500000080HP0Y00<00000090V=`2@9SL0302@9SL00`000000[clc0:lo<`090:lo<`D00000
1`33c>42000000L0gngK0P0000190?ooo`040000000004l0001?000000@0EDn_00<00000081X[P20
J:h00`20J:h00`000000Thk<09>>c00609>>c0030000002SU/L0XiK700`0XiK700<000000;2OaP2`
WlH0102`WlH:000000`0_JW600<000000<Rfb@38]/T03038]/T00`000000d/K?0000000:0>K0[`03
0000003ZY2L0000002X0oooo000_0?ooo`030000000004l0000000D0EDn_00@00000081X[P20J:h0
P6R^0P00000909>>c0030000002SU/L0XiK700/0XiK7200000070:fcg@030000002c^Md0/kWM00@0
0000202mZLH00`000000b;K90<Rfb@0<0<Rfb@040000003Ba/l0d/K?000000P0i/2_00D000000?SN
[P000000jZ@W000000190?ooo`030000000iM=l0>GCO00@0>GCO00@0000006AmeP1TOMH00000102<
Y>D4000000H0HP0Y00<00000090V=`2@9SL03@2@9SL00`000000[clc0:lo<`0<0:lo<`0400000036
C1T00000000000D0`lcQ00<000000=o]f`3OkM/01@3OkM/00`000000cOkO0000001I0?ooo`030000
001aRmd0LH_M008000000`26S]@00`000000Y[o[0:Joj`040:Joj`8000000P2V_n/2000000<0ZNKj
0P00000309;OoP030000001kdol000000080KLKo0P00000306Vio@<00000202Y`N/200000080ZL;/
00<000000=GDf03Ee=P0103Ee=P00`000000oooo0?ooo`1L0?ooo`030000000iM=l0>GCO00@0>GCO
00@0000006AmeP1TOMH00000102<Y>D4000000H0HP0Y00<00000090V=`2@9SL03@2@9SL00`000000
[clc0:lo<`0<0:lo<`0400000036C1T00000000000D0`lcQ00<000000=o]f`3OkM/01@3OkM/00`00
0000cOkO000000190?ooo`030000000004l0000000D0EDn_00@00000081X[P20J:h0P6R^0P000009
09>>c0030000002SU/L0XiK700/0XiK7200000070:fcg@030000002c^Md0/kWM00@00000202mZLH0
0`000000b;K90<Rfb@0<0<Rfb@040000003Ba/l0d/K?000000P0i/2_00D000000?SN[P000000jZ@W
0000000Y0?ooo`00;`3oool2000000L0EDn_0`00000<09>>c0030000002SU/L0XiK700L0XiK70`00
00000`2V[mh000000:fcg@0<0:fcg@030000002c^Md0/kWM00@0/kWM1@0000020;fYaP0300000038
]/T0b;K900`0b;K900<000000=;6c`3Ba/l00P3Ba/l00`000000i/2_0>K0[`050>K0[`050000003h
gZh000000>ZT9`000000B@3oool2000000H0>GCO0`000000102<Y>D0000000000000000:0680:@03
0000002@9SL0T2Hg00d0T2Hg00<000000:lo<`2_?c<03@2_?c<00`000000aT`I0<I<6@0400000003
0<;Fj0000000gngK00@0gngK0P0000000`3=o]l000000?ooo`1I0?ooo`030000001aRmd0LH_M0080
LH_M00<0000008J>e00000002@2V_n/6000000<0ZNKj0P00000209;OoP@0000000<0JKWm00000000
00000P00000306j^n0030000002Y`N/0ZL7[00<0ZL7[0P0000040:W2k0030000003Ee=P0eMCH00<0
eMCH0P00001N0?ooo`8000001P0iM=l30000000408bTi@0000000000000000X0HP0Y00<00000090V
=`2@9SL03@2@9SL00`000000[clc0:lo<`0=0:lo<`0300000036C1T0aT`I00@0000000<0`]KX0000
003OkM/0103OkM/2000000030<gng`000000oooo04T0oooo0P00000705E?[`<00000302CS/`00`00
0000XiK70:>Fa`070:>Fa`<0000000<0YZoN0000002]/md0302]/md00`000000/kWM0;>ig@040;>i
g@D000000P2mZLH00`000000b;K90<Rfb@0<0<Rfb@030000003Ba/l0d/K?0080d/K?00<000000>K0
[`3V`:l01@3V`:l01@000000n=j^0000003ZY2L0000002T0oooo000_0?ooo`8000001`1ECjl00`00
0000Thk<09>>c00<09>>c0030000002SU/L0XiK700<0XiK7100000050:J_gP030000002]/md0[K?M
00X0[K?M00<000000;>ig@2c^Md02@2c^Md4000000d0b;K900<000000=;6c`3Ba/l00`3Ba/l20000
00D0i/2_00<000000?SN[P3hgZh00P00001:0?ooo`030000000iM=l0>GCO00H0>GCO0P00000=0680
:@030000002@9SL0T2Hg00h0T2Hg00<000000:lo<`2_?c<0302_?c<00`000000aT`I0<I<6@030<I<
6@<000000`3OkM/200000080cOkO00<000000?ooo`3oool0F03oool2000000D0LH_M0`0000080:Jo
j`030000002ji?@0^^Cd00<0^^Cd1`0000000`1C0000000007<00002000000P0KZkh00<000000:W1
j`2Y`N/00P0000070:W2k0030000003Ee=P0eMCH0080000000<0e^OR0000003oool0GP3oool00`00
0000>GCO03Udg`0603Udg`8000003@1R02T00`000000T2Hg090V=`0>090V=`030000002_?c<0[clc
00`0[clc00<000000<I<6@36C1T00`36C1T3000000<0gngK0P0000020<gng`030000003oool0oooo
04P0oooo0`00000705E?[`030000002CS/`0Thk<00`0Thk<00<000000:>Fa`2SU/L00`2SU/L40000
00D0YZoN00<000000:fcg@2]/md02P2]/md00`000000/kWM0;>ig@090;>ig@@000003@38]/T00`00
0000d/K?0=;6c`030=;6c`8000001@3V`:l00`000000n=j^0?SN[P02000002T0oooo000_0?ooo`03
0000001ECjl0EDn_00D0EDn_00<0000007j7dP0000003P2CS/`00`000000XiK700000002000000T0
YZoN00<000000:fcg@2]/md02P2]/md00`000000/kWM0;>ig@0:0;>ig@030000002h_ml0^;oO00<0
00002@38]/T00`000000d/K?0=;6c`060=;6c`050000003V`:l0i/2_0>K0[`0000000`3hgZh20000
04/0oooo0P00000503Udg`030000000>0000000000d0HP0Y00<00000090V=`2@9SL03P2@9SL00`00
0000[clc0:lo<`0=0:lo<`0300000036C1T0aT`I00D0aT`I0`0000030<gng`030000003oool0oooo
05T0oooo00<00000076;g@1aRmd0101aRmd00`000000YKo/0:Fok005000000<0Y[o[00<000000;[T
m00000001@0000000`33g>`0000000000008000000<0N:O`1`0000090:W2k0030000003Ee=P00000
00<0e^OR00<000000?ooo`3oool0GP3oool2000000D0>GCO00<0000000h0000000003@1R02T00`00
0000T2Hg090V=`0>090V=`030000002_?c<0[clc00d0[clc00<000000<I<6@36C1T01@36C1T30000
00<0cOkO00<000000?ooo`3oool0B@3oool2000000L0EDn_00<0000007j7dP0000003P2CS/`00`00
0000XiK700000002000000T0YZoN00<000000:fcg@2]/md02P2]/md00`000000/kWM0;>ig@0:0;>i
g@030000002h_ml0^;oO00<000002@38]/T00`000000d/K?0=;6c`060=;6c`050000003V`:l0i/2_
0>K0[`0000000`3hgZh2000002T0oooo000_0?ooo`030000001ECjl0EDn_00D0EDn_00@0000007j7
dP1nQm8000003@2CS/`2000000`0YZoN00<000000:fcg@2]/md02@2]/md00`000000/kWM0;>ig@0;
0;>ig@030000002h_ml0^;oO00<0^;oO0`0000050<Rfb@030000003Ba/l0d/K?00P0d/K?00@00000
0>K0[`3V`:l000000`3hgZh2000004`0oooo0`0000001@0iM=l000000000000>0000000000d0HP0Y
00<00000090V=`2@9SL03`2@9SL00`000000[clc0:lo<`0=0:lo<`0300000036C1T0aT`I00L0aT`I
0P0000020<gng`030000003oool0oooo05T0oooo00<00000076;g@1aRmd0101aRmd00`000000YKo/
0:Fok0050:Fok0D000001@33g>`30000000505l07@000000S1d/08`M;00000000`2Y=2L6000000<0
N:O`00<000000:W2k02Y`^`0102Y`^`6000000@0e^OR00<000000?ooo`3oool0G`3oool300000005
03Udg`000000000000h0000000003@1R02T00`000000T2Hg090V=`0?090V=`030000002_?c<0[clc
00d0[clc00<000000<I<6@36C1T01`36C1T200000080cOkO00<000000?ooo`3oool0B@3oool20000
00L0EDn_00@0000007j7dP1nQm8000003@2CS/`2000000`0YZoN00<000000:fcg@2]/md02@2]/md0
0`000000/kWM0;>ig@0;0;>ig@030000002h_ml0^;oO00<0^;oO0`0000050<Rfb@030000003Ba/l0
d/K?00P0d/K?00@000000>K0[`3V`:l000000`3hgZh2000002T0oooo000_0?ooo`8000001@1ECjl0
0`000000OXOB07j7dP0207j7dP030000002CS/`0Thk<00P0Thk<0P0000000`2O[N4000000:J_gP0<
0:J_gP030000002]/md0[K?M00P0[K?M00<000000;>ig@2c^Md02P2c^Md00`000000^;oO0;Rog`07
0;Rog`<000000P38]/T00`000000d/K?0=;6c`090=;6c`8000001@3hgZh2000004`0oooo0`000003
00h000030000001R02T0HP0Y00X0HP0Y6000000<0:lo<`0300000036C1T0aT`I00P0aT`I0P00001M
0?ooo`8000000`1aRmd00`000000YKo/0:Fok0080:Fok00400000033g>`0`mc/0<?Lk0H0000000<0
G`0M0000002<7B`00P2<7B`01@000000ZC@W0:Td9`2Y=2L000000080_Ch=00@0000008BRi`24X^L0
Q:;W2@0000050:S2k0030000003Fin80e^OR0080e^OR00<000000?ooo`3oool0H03oool3000000<0
3P0000<000000680:@1R02T02P1R02TH000000`0[clc00<000000<I<6@36C1T02036C1T2000004`0
oooo0`00000505E?[`030000001nQm80OXOB0080OXOB00<0000009>>c02CS/`0202CS/`200000003
09n]h@000000YZoN00`0YZoN00<000000:fcg@2]/md0202]/md00`000000/kWM0;>ig@0:0;>ig@03
0000002h_ml0^;oO00L0^;oO0`0000020<Rfb@030000003Ba/l0d/K?00T0d/K?0P0000050?SN[P80
0000:03oool002l0oooo0P00000405E?[`030000001nQm80OXOB00@0OXOB00<0000009>>c02CS/`0
1@2CS/`2000000@0WjgQ00<000000:J_gP2V[mh02P2V[mh00`000000[K?M0:fcg@080:fcg@030000
002c^Md0/kWM00X0/kWM00<000000;Rog`2h_ml02P2h_ml2000000d0d/K?00<000000?SN[P3hgZh0
0`3hgZh2000004d0oooo00D0000000h0000>00003P00000000090680:@@0000000<0TEnB0000002/
M9@0402/M9@00`000000`hJC0<>6T`020<>6T`T000000`2_?c<00`000000aT`I0<I<6@080<I<6@80
0000G@3oool01P000000DhSW000000000000LH_M000000T0YKo/00<000000<?Lk00000000P000002
0<KBh`060000000@000040000000001O01d000000`2<7B`00`000000ZC@W0:Td9`020:Td9`030000
002m?Pd00000008000001024X^L00`000000Z<;/0:S2k0080:S2k0040000003Fin80e^OR0=KWhP80
0000H`3oool01@0000003P0000h0000>0000000000T0HP0Y100000000`2AGi8000000:adU00@0:ad
U00300000033QY<0`hJC0080`hJC2@0000030:lo<`0300000036C1T0aT`I00P0aT`I0P00001<0?oo
o`<00000101ECjl00`000000OXOB07j7dP0407j7dP030000002CS/`0Thk<00D0Thk<0P00000409n]
h@030000002V[mh0YZoN00X0YZoN00<000000:fcg@2]/md0202]/md00`000000/kWM0;>ig@0:0;>i
g@030000002h_ml0^;oO00X0^;oO0P00000=0=;6c`030000003hgZh0n=j^00<0n=j^0P00000X0?oo
o`00;`3oool00`0000000B:V0000000205E?[`030000001nQm80OXOB00H0OXOB00<0000009>>c02C
S/`00P2CS/`2000000L0WjgQ00<000000:J_gP2V[mh02P2V[mh00`000000[K?M0:fcg@070:fcg@03
0000002c^Md0/kWM00T0/kWM00<000000;Rog`2h_ml02`2h_ml00`000000^lKS0000000;0=;6c`80
00001P3hgZh00`000000oooo0?ooo`190?ooo`800000100>00000`000000HP0Y0680:@040680:@<0
00001@2AGi800`000000[7BD0:adU00?0:adU00300000033QY<0`hJC00/0`hJC1P0000090<I<6@80
0000G@3oool00`000000DhSW05>8i`0=000000@0a];S0P0000001@0@0000000005l07@1O01d00000
00@0S1d/00D000000:Td9`2Y=2L0ZC@W000000020;dn3@040000002?X=l0Sj3O00000080Q:;W00<0
00000:S2k02X`^`01`2X`^`00`000000e^OR0=KWhP0300000680oooo0P00000400h000030000001R
02T0HP0Y00@0HP0Y0`000005095OTP030000002/M9@0[7BD00l0[7BD00<000000<>6T`33QY<02`33
QY<6000000T0aT`I0P00001;0?ooo`80000000D00B:V0000001ECjl0EDn_0000000807j7dP030000
002CS/`0Thk<0080Thk<0P00000709n]h@030000002V[mh0YZoN00X0YZoN00<000000:fcg@2]/md0
1`2]/md00`000000/kWM0;>ig@090;>ig@030000002h_ml0^;oO00/0^;oO00<000000;_6h`000000
2`3Ba/l2000000H0n=j^00<000000?ooo`3oool09P3oool002l0oooo00<00000004RYP0000000P1E
Cjl00`000000OXOB07j7dP0707j7dP040000002CS/`00000000000T0WjgQ00<000000:J_gP2V[mh0
2@2V[mhA000000H0/kWM00<000000;Rog`2h_ml02P2h_ml01@000000^lKS0;_6h`2ka^<0000000T0
d/K?00@000000=[Je`3Jf]L000001@3hgZh00`000000oooo0?ooo`180?ooo`030000000>00003P00
00<03P0000<000000680:@1R02T00P1R02T3000000P0TEnB00<000000:adU02/M9@03`2/M9@00`00
0000`hJC0<>6T`0?0<>6T`040000003IVi400000000000L0aT`I00@000000<52000000000000F`3o
ool01@000000DhSW05>8i`1CR>L0000000T0YKo/00@000000<KBh`36d^<0a];S0`0000000`0@0000
000005l07@0205l07@030000002<7B`0S1d/0080S1d/00<000000:Td9`2Y=2L00P2Y=2L010000000
_Ch=0;dn3@00000308nPg`H000001@2X`^`300000080bOOZ00<000000?ooo`3oool0G`3oool00`00
00003P0000h0000300h000030000001R02T0HP0Y0080HP0Y0`000008095OTP030000002/M9@0[7BD
00l0[7BD00<000000<>6T`33QY<03`33QY<010000000fI^A0000000000070<I<6@0400000031@P00
0000000004T0oooo0P0000001@018ZH0000005E?[`1ECjl0000000T0OXOB00@0000009>>c0000000
00002@2O[N400`000000YZoN0:J_gP090:J_gQ4000001P2c^Md00`000000^;oO0;Rog`0:0;Rog`05
0000002ka^<0^lKS0;_6h`0000002@3Ba/l010000000f][G0=[Je`0000050?SN[P030000003oool0
oooo02H0oooo000^0?ooo`04000000018ZH00B:V004RYP8000002`1nQm800`000000WjgQ09n]h@0:
09n]h@030000002V[mh0YZoN00@0YZoN100000020:?:m0030000002Ob?D0WlSe00H0WlSe00<00000
09g6m02Ma_@00`2Ma_@7000000/0^;oO00<000000;_6h`2ka^<00`2ka^<00`000000d/K?0=;6c`05
0=;6c`050000003Jf]L0f][G0=[Je`0000001@3hgZh00`000000oooo0?ooo`170?ooo`030000000>
00003P0000@03P001@00000;095OTP030000002/M9@0[7BD00l0[7BD00<000000<>6T`33QY<03`33
QY<010000000fI^A0=VKT@3IVi42000000H0aT`I00@000000<520031@P000000F`3oool200000080
DhSW00<000000:Fok02U_n`01`2U_n`3000000040<C7g00000004000000000<0G`0M00<0000008`M
;02<7B`01P0000020:Td9`050000002m?Pd0_Ch=0;dn3@0000000`2?X=l00`000000Z<;]0:S2k@02
0:S2k@H000000`39mnX00`000000oooo0?ooo`1O0?ooo`030000000>00003P0000@03P001@00000;
095OTP030000002/M9@0[7BD00l0[7BD00<000000<>6T`33QY<03`33QY<010000000fI^A0=VKT@3I
Vi42000000H0aT`I00@000000<520031@P000000B03oool0100000000B:V004RYP018ZH2000000/0
OXOB00<0000009n]h@2O[N402P2O[N400`000000YZoN0:J_gP040:J_gP@0000000<0Xl[d0000002O
b?D0202Ob?D00`000000WLKd09g6m00309g6m0H000002`2h_ml2000000D0^lKS00<000000=;6c`3B
a/l01@3Ba/l01@000000f][G0=[Je`3Jf]L0000000D0n=j^00<000000?ooo`3oool09P3oool002h0
oooo00D00000004RYP018ZH00B:V0000000;07j7dP030000002G[>D0000000`0WjgQ00<000000:J_
gP2V[mh00`0000060:?:m0030000002Ob?D0WlSe00H0WlSe00<0000009g6m02Ma_@01`2Ma_@00`00
0000Vl?c09_3l`02000000P0^;oO00<000000;_6h`2ka^<01@2ka^<00`000000d/K?0=;6c`030=;6
c`030000003Jf]L0f][G00<0f][G00@000000?SN[P3hgZh0n=j^0P0000180?ooo`030000000>0000
3P0000@03P000P00000?095OTP030000002/M9@0[7BD00l0[7BD00<000000<>6T`33QY<03`33QY<0
0`000000fI^A0=VKT@030=VKT@<000000`36C1T01@000000`D800<520031@P00000005/0oooo1000
00050:Fok0D000000P34am`00`00000040000100000205l07@D000000`2UF7800`000000_F]`0;e[
L005000000050;dn3@000000000008nPg`0000002@2X`^d01@000000bOOZ0<WgjP39mnX000000640
oooo00<0000000h0000>0000100>0002000000l0TEnB00<000000:adU02/M9@03`2/M9@00`000000
`hJC0<>6T`0?0<>6T`030000003IVi40fI^A00<0fI^A0`0000030<I<6@0500000031@P00`D800<52
00000000A`3oool01@0000000B:V004RYP018ZH0000000/0OXOB00<0000009N/i@000000302O[N40
0`000000YZoN0:J_gP03000000H0Xl[d00<0000009o8m@2Ob?D01P2Ob?D00`000000WLKd09g6m007
09g6m0040000002K`o<00000000000P0^;oO00<000000;_6h`2ka^<01P2ka^<00`000000d/K?0=;6
c`030=;6c`030000003Jf]L0f][G00<0f][G00@000000?SN[P3hgZh0n=j^0P00000X0?ooo`00;P3o
ool0100000000B:V004RYP018ZH2000000T0OXOB00@0000009N/i@2G[>D0UjcU0P00000;09n]h@80
00002P2Sb_@00`000000WlSe09o8m@0509o8m@030000002Ma_@0WLKd00H0WLKd00<0000009_3l`2K
`o<00`2K`o<2000000D0^;oO00<000000;_6h`2ka^<01`2ka^<01@000000d/K?0=;6c`3Ba/l00000
00H0f][G00D000000?SN[P3hgZh0n=j^000000180?ooo`800000100>000300000100TEnB00<00000
0:adU02/M9@03`2/M9@00`000000`hJC0<>6T`0?0<>6T`030000003IVi40fI^A00H0fI^A0P000002
0<I<6@0500000031@P00`D800<5200000000F`3oool00`000000;8K[00000005000000D0YL3]0P00
00000`0@000000000000000200000080QSe]00<000000:EHLP2UF7800`2UF7800`000000_F]`0;e[
L0030;e[L0030000003EOFP000000080000000<0VJ7J000000000000202X`^d01@000000bOOZ0<Wg
jP39mnX000000600oooo0P00000400h000<00000402AGi800`000000[7BD0:adU00?0:adU0030000
0033QY<0`hJC00l0`hJC00<000000=VKT@3IVi401P3IVi4200000080aT`I00D000000<520031@P00
`D80000000160?ooo`04000000018ZH00B:V004RYP8000002@1nQm8010000000UjcU09N/i@2G[>D2
000000/0WjgQ0P0000090:?:m0030000002Ob?D0WlSe00H0WlSe00<0000009g6m02Ma_@01P2Ma_@0
0`000000Vl?c09_3l`0209_3l`8000001@2h_ml00`000000^lKS0;_6h`080;_6h`050000003Ba/l0
d/K?0=;6c`0000001P3Jf]L01@000000n=j^0?SN[P3hgZh0000002T0oooo000^0?ooo`0700000001
8ZH00B:V004RYP000000H83K0000000707j7dP030000002G[>D0UjcU00@0UjcU00<0000009n]h@2O
[N401P2O[N42000000030:O;l`000000000000T0Xl[d00<0000009o8m@2Ob?D01@2Ob?D00`000000
WLKd09g6m00509g6m0030000002K`o<0Vl?c00H0Vl?c0P0000020;Rog`030000002ka^<0^lKS00T0
^lKS00<000000=;6c`000000203Jf]L010000000n=j^0000000000180?ooo`040000000>00003P00
00h0008000000P1Z@Xh00`000000TEnB095OTP0>095OTP030000002/M9@0[7BD00l0[7BD00<00000
0<>6T`33QY<03`33QY<00`000000fI^A0=VKT@080=VKT@<000001031@P000`000000oooo0?ooo`1I
0?ooo`040000000/Q^/0;8K[000000P0YL3]0`0000000`1F55h0000008HmK@0308HmK@030000002U
F780YEQb00<0YEQb00<000000;e[L02mJg000`2mJg0010000000eGeX0=EmJ03EOFP200000080Yl;]
0P0000050:S2k@0300000039mnX0bOOZ00800000H@3oool0100000003P0000h0000>000200000080
JT:>00<00000095OTP2AGi803P2AGi800`000000[7BD0:adU00?0:adU00300000033QY<0`hJC00l0
`hJC00<000000=VKT@3IVi40203IVi43000000@0`D8000<000000?ooo`3oool0@`3oool01`000000
0B:V004RYP018ZH000000620f`0000001`1nQm800`000000UjcU09N/i@0409N/i@030000002O[N40
WjgQ00H0WjgQ0P0000000`2Wbo<00000000000090:?:m0030000002Ob?D0WlSe00D0WlSe00<00000
09g6m02Ma_@01@2Ma_@00`000000Vl?c09_3l`0509_3l`8000000P2h_ml00`000000^lKS0;_6h`0:
0;_6h`030000003Ba/l0000000P0f][G00@000000?SN[P0000000000:@3oool002h0oooo00D00000
004RYP018ZH00B:V000000020620f`8000001@1nQm800`000000UjcU09N/i@0509N/i@030000002O
[N40WjgQ00<0WjgQ0P0000050:O;l`030000002Sb_@0Xl[d00H0Xl[d2`00000409g6m0030000002K
`o<0Vl?c00T0Vl?c0P00000=0;_6h`030000003Jf]L0f][G00L0f][G00@000000?SN[P0000000000
A`3oool00`0000003P0000h00002000000@0JT:>00<00000095OTP2AGi803P2AGi800`000000[7BD
0:adU00?0:adU00300000033QY<0`hJC00l0`hJC00<000000=VKT@3IVi402P3IVi42000000<0`D80
00<000000?ooo`3oool0FP3oool010000000;8K[02b6j`0000050:G0k@<000000`1F55h00`000000
QSe]08HmK@0208HmK@030000002UF780YEQb00<0YEQb00<000000;e[L02mJg000`2mJg000`000000
eGeX0=EmJ0020=EmJ08000000`2W`^d300000080Z<;]1000001Q0?ooo`030000000>00003P000080
0000101Z@Xh00`000000TEnB095OTP0>095OTP030000002/M9@0[7BD00l0[7BD00<000000<>6T`33
QY<03`33QY<00`000000fI^A0=VKT@0:0=VKT@8000000`31@P000`000000oooo0?ooo`130?ooo`05
000000018ZH00B:V004RYP0000000P1PP=/2000000D0OXOB00<0000009N/i@2G[>D01@2G[>D00`00
0000WjgQ09n]h@0309n]h@8000001@2Wbo<00`000000Xl[d0:?:m0050:?:m0`00000102Ma_@00`00
0000Vl?c09_3l`0809_3l`8000003P2ka^<00`000000f][G0=[Je`070=[Je`040000003hgZh00000
000002T0oooo000^0?ooo`05000000018ZH00B:V004RYP000000101PP=/01@000000OXOB07j7dP1n
Qm80000000T0UjcU0P0000000`2O[N400000000000080:O;l`8000000P2Sb_@400000080R>7l00<0
000006kBo01^d_`00`1^d_`00`000000G/;l05k2o005000000P0Vl?c0`00000209_0lP030000002k
a^<0^lKS00L0^lKS0P0000020;c>j0030000003Jf]L0f][G00L0f][G00<000000>O_T@000000AP3o
ool0100000003P0000h00000000606Y2SP030000002AGi80TEnB00h0TEnB00<000000:adU02/M9@0
3`2/M9@00`000000`hJC0<>6T`0>0<>6T`030000003IVi40fI^A00`0fI^A0P0000030<5200030000
003oool0oooo05X0oooo0P000000100/Q^/000000:G0k@2U`>d2000000030:G1k@000000000000<0
EQAN00<0000008HmK@26?Fd00P26?Fd00`000000YEQb0:EHLP030:EHLP030000002mJg00_F]`00<0
_F]`00<000000=EmJ03EOFP00P3EOFP00`000000jhe?000000050:O2k@@00000HP3oool010000000
3P0000h00000000606Y2SP030000002AGi80TEnB00h0TEnB00<000000:adU02/M9@03`2/M9@00`00
0000`hJC0<>6T`0>0<>6T`030000003IVi40fI^A00`0fI^A0P0000030<5200030000003oool0oooo
0480oooo00D00000004RYP018ZH00B:V000000040620f`050000001nQm80OXOB07j7dP0000002@2G
[>D20000000309n]h@000000000000P0Yl_c0P0000020:?:m0<000000P28hO`2000000D0K];l00<0
000005k2o01N`_`01@00000809_3l`8000000P2K`?82000000T0^lKS0P0000000`2lc^P000000=[J
e`090=[Je`030000003Wki40000002T0oooo000_0?ooo`03000000018ZH0000000H0H83K00<00000
07j7dP000000302G[>D2000000/0Yl_c0`00000408SQo0<000000`1^d_`2000000<0G/;l0P000002
05^fo0<000000`2K`o<2000000H0Vl3b0P0000050;_6h`800000102lc^P00`000000f][G0=[Je`07
0=[Je`030000003Wki40000004D0oooo1000000706Y2SP030000002AGi80TEnB00h0TEnB00<00000
0:adU02/M9@03`2/M9@00`000000`hJC0<>6T`0>0<>6T`030000003IVi40fI^A00`0fI^A00@00000
0?:cR@00000000000P31@P000`000000oooo0?ooo`1J0?ooo`D000000P2U`Nd00`000000000d0000
000205HDGP0300000026?Fd0QSe]00<0QSe]00<000000:EHLP2UF7800`2UF7800`000000_F]`0;e[
L0030;e[L0030000003EOFP0eGeX0080eGeX00@000000>^=C`3[SDl000000`2W`^d400000680oooo
1000000706Y2SP030000002AGi80TEnB00h0TEnB00<000000:adU02/M9@03`2/M9@00`000000`hJC
0<>6T`0>0<>6T`030000003IVi40fI^A00`0fI^A00@000000?:cR@00000000000P31@P000`000000
oooo0?ooo`120?ooo`03000000018ZH0000000H0H83K00<0000007j7dP000000302G[>D2000000/0
Yl_c0`00000408SQo0<000000`1^d_`2000000<0G/;l0P00000205^fo0<000000`2K`o<2000000H0
Vl3b00<000000;_6h`2ka^<0102ka^<2000000@0_<kX00<000000=[Je`3Jf]L01`3Jf]L00`000000
innA0000000Y0?ooo`00;`3oool00`0000000B:V000000070620f`8000002`2G[>D00`000000Z/_a
0:[;l@02000000L0Yl_c0P0000030:CYn`L0000000D0e;>i0000000000000000089d^`03000000L0
FkKl0`00000:09_0lP030000002ka^<0^lKS008000001`2lc^P00`000000f][G0=[Je`040=[Je`@0
0000A@3oool3000000X0JT:>00<00000095OTP2AGi803@2AGi800`000000[7BD0:adU0060:adU0`0
00003P33QY<00`000000fI^A0=VKT@0<0=VKT@070000003b/hT0l[>90?:cR@000000`D800000001N
0?ooo`0300000004PMh000000080000000<0000d0000001F55h00P1F55h00`000000QSe]08HmK@02
08HmK@030000002UF780YEQb00@0YEQb00<000000;e[L02mJg000`2mJg000`000000eGeX0=EmJ003
0=EmJ0030000003[SDl0000000D00000H`3oool3000000X0JT:>00<00000095OTP2AGi803@2AGi80
0`000000[7BD0:adU0060:adU0`000003P33QY<00`000000fI^A0=VKT@0<0=VKT@070000003b/hT0
l[>90?:cR@000000`D80000000140?ooo`03000000018ZH0000000L0H83K0P00000;09N/i@030000
002Zbo40Z/_a008000001`2Wbo<2000000<0Y>Wk1`0000001@3D/kT000000000002HP;L0PWBk00<0
00001`1K]_`3000000T0Vl3b0P0000020;_6h`8000001P2lc^P00`000000f][G0=[Je`050=[Je`@0
0000:P3oool00300oooo0P0000070620f`040000002>[N/00000000000P0UjcU00<000000:[;l@2Z
bo400`2Zbo4300000080Yl_c0P0000050:CYna@00000101S[?P00`000000Vl3b09_0lP0709_0lP@0
00002@2lc^P00`000000f][G0=[Je`030=[Je`030000003KlN00fo7P00800000A@3oool00`000000
JT:>06Y2SP0:06Y2SP030000002AGi80TEnB00/0TEnB2`0000090;2Sb`030000002l[/`0_:k<00H0
00002033QY<00`000000fI^A0=VKT@0<0=VKT@030000003b/hT0l[>90080l[>900<000000<520000
0000G`3oool01@000000187N0000000003@0000000<0EQAN00<0000008HmK@26?Fd00P26?Fd00`00
0000YEQb0:EHLP040:EHLP030000002mJg00_F]`00@0_F]`00<000000=EmJ03EOFP00P3EOFP00`00
0000jhe?00000003000006D0oooo00<0000006Y2SP1Z@Xh02P1Z@Xh00`000000TEnB095OTP0;095O
TP/000002@2`Xl/00`000000_:k<0;b^c006000000P0`hJC00<000000=VKT@3IVi40303IVi400`00
0000l[>90?:cR@020?:cR@0300000031@P00000004@0oooo0P0000070620f`040000002>[N/00000
000000P0UjcU00<000000:[;l@2Zbo400`2Zbo4300000080Yl_c0P0000050:CYn`/0000000<0PWBk
0000000ZDLH01P00000406>/n0030000002K`?80Vl3b00L0Vl3b100000090;c>j0030000003Jf]L0
f][G0080f][G0P0000020=_ah0800000:P3oool00300oooo0P0000070620f`040000002>[N/0SZg[
08j]j`8000001@2G[>D00`000000Z/_a0:[;l@070:[;l@d0000000<0k^?500000000000010000000
0`2HP;L0PWBk00000005000000H0Hjch0P00000309_0lP@000000P2K_O000`000000_<kX0;c>j009
0;c>j0050000003Jf]L0f][G0=[Je`0000000P3KlN000`000000innA000000140?ooo`800000301Z
@Xh00`000000TEnB095OTP07095OTP@000000P2RV/d00`000000/:?;0;2Sb`0?0;2Sb`030000002l
[/`0_:k<00H0_:k<1P0000020<>6T`030000003IVi40fI^A00`0fI^A00<000000?:cR@3b/hT00`3b
/hT00`000000`D800000001O0?ooo`040000000003@0000d000000<0EQAN00<0000008HmK@26?Fd0
0P26?Fd00`000000YEQb0:EHLP040:EHLP030000002mJg00_F]`00@0_F]`00<000000=EmJ03EOFP0
0P3EOFP00`000000jhe?0>^=C`02000006D0oooo0P00000<06Y2SP030000002AGi80TEnB00L0TEnB
100000020::Jc@030000002`Xl/0/:?;00l0/:?;00<000000;b^c02l[/`01P2l[/`600000080`hJC
00<000000=VKT@3IVi40303IVi400`000000l[>90?:cR@030?:cR@0300000031@P00000004<0oooo
0P0000070620f`040000002>[N/0SZg[08j]j`8000001@2G[>D00`000000Z/_a0:[;l@070:[;l@d0
000000<0k^?50000003D/kT01@0000000`22M;/0000000000004000000H0Hjch0P00000309_0lP@0
00000P2K_O000`000000_<kX0;c>j0080;c>j0050000003Jf]L0f][G0=[Je`0000000`3KlN000`00
0000innA0000000Z0?ooo`00<@3oool00`000000H83K0620f`050620f`030000002>[N/0SZg[00<0
SZg[0P00000209N/i@030000002Zbo40Z/_a00P0Z/_a00<000000;WXm@2ij?D0102ij?D500000005
0=cNe`000000000000000036XkH00P000000102YRkD0V82g00000022M;/@000000L0Vkg`00<00000
0;c>j02lc^P0202lc^P010000000f][G0000000000030=_ah0800000A03oool3000000`0JT:>00<0
0000095OTP2AGi800`2AGi84000000L0XY[=00<000000;2Sb`2`Xl/03P2`Xl/00`000000_:k<0;b^
c00<0;b^c0@00000303IVi400`000000l[>90?:cR@050?:cR@<00000GP3oool010000000000d0000
=000000305HDGP0300000026?Fd0QSe]0080QSe]00<000000:EHLP2UF780102UF7800`000000_F]`
0;e[L0040;e[L0030000003EOFP0eGeX0080eGeX00D000000>^=C`3[SDl000000>27201T0?ooo`<0
0000301Z@Xh00`000000TEnB095OTP03095OTP@000001`2RV/d00`000000/:?;0;2Sb`0>0;2Sb`03
0000002l[/`0_:k<00`0_:k<1000000<0=VKT@030000003b/hT0l[>900D0l[>90`0000130?ooo`03
0000001PP=/0H83K00D0H83K00<0000008j]j`2>[N/00`2>[N/200000080UjcU00<000000:[;l@2Z
bo40202Zbo400`000000^NSe0;WXm@040;WXm@D0000000<0g=kG0000000000000P0000001@2hU[@0
00000000002HP;L0PWBk00<0000000<0FgoL0000000000002`00000709^ml0030000002lc^P0_<kX
00P0_<kX0`0000040=_ah0800000:`3oool00340oooo0`0000050620f`030000002>[N/0SZg[00D0
SZg[1P0000060:[;l@030000002ij?D0^NSe00H0000000H0fO?Q0000003Lg]L0g=kG0000003Fb/h2
000000050<JS]P00000000000:V;]@2HP;L00P0000001@2=R//0000007R4dP000000FgoL00800000
1P1aY?400`000000Vkg`09^ml00709^ml0030000002lc^P0_<kX00P0_<kX0P0000050=_ah0800000
A03oool00`0000008@in0000000<06Y2SP030000002AGi80000000<000002`2RV/d00`000000/:?;
0;2Sb`0>0;2Sb`030000002l[/`0_:k<00h0_:k<00<000000<Nkc`0000000P0000090=VKT@030000
003b/hT0l[>900L0l[>900<000000?ooo`3oool0G03oool00`000000000d0000000405HDGP030000
0026?Fd0QSe]0080QSe]00<000000:EHLP2UF780102UF7800`000000_F]`0;e[L0040;e[L0030000
003EOFP0eGeX0080eGeX00D000000>^=C`3[SDl000000>27201T0?ooo`030000000Q3Wh0000000`0
JT:>00<00000095OTP0000000`00000;0::Jc@030000002`Xl/0/:?;00h0/:?;00<000000;b^c02l
[/`03P2l[/`00`000000ak_?00000002000000T0fI^A00<000000?:cR@3b/hT01`3b/hT00`000000
oooo0?ooo`110?ooo`<000001@1PP=/00`000000SZg[08j]j`0508j]j`H000001P2Zbo400`000000
^NSe0;WXm@06000000040=Wch@000000g=kG0=cNe`D0000000D0^9Jd0000002YRkD0V82g00000002
08f:b`8000000P1KOm`2000000H0LJCa00<0000009^ml02K_O001`2K_O000`000000_<kX0;c>j007
0;c>j08000001P3KlN02000002/0oooo000b0?ooo`030000000cMn80000000<0H83K00<0000008j]
j`2>[N/01`2>[N/00`000000[<W_0:c9k`020:c9k`T000001034h>d3000000060=cNe`0000000000
0=K:cP000000c;W81P00000209f@aP050000002=R//0000007R4dP0000000P1KOm`2000000D0LJCa
00<0000009^ml02K_O001`2K_O000`000000_<kX0;c>j0030;c>j0@0000000<0^mK^0000003KlN00
103KlN000`000000oooo0?ooo`120?ooo`040000000Q3Wh08@in000000`0JT:>0P00000?0::Jc@03
0000002`Xl/0/:?;00h0/:?;00<000000;b^c02l[/`03@2l[/`00`000000ak_?0<Nkc`030<Nkc`80
00001`3IVi400`000000l[>90?:cR@080?:cR@030000003oool0oooo05X0oooo00@000000000=000
03@000000`1F55h00`000000QSe]08HmK@0208HmK@`000000`2mJg000`000000eGeX0=EmJ0020=Em
J0060000003[SDl0jhe?0000003PQ`P00000HP3oool0100000008@in024>OP00000<06Y2SP800000
3`2RV/d00`000000/:?;0;2Sb`0>0;2Sb`030000002l[/`0_:k<00d0_:k<00<000000<Nkc`37^ll0
0`37^ll2000000L0fI^A00<000000?:cR@3b/hT0203b/hT00`000000oooo0?ooo`110?ooo`030000
000cMn80000000<0H83K00<0000008j]j`2>[N/01`2>[N/00`000000[<W_0:c9k`020:c9k`T00000
1034h>d3000000040=cNe`000000000000000080c;W81P000000102MT<H0000008f:b`2=R//20000
00<0FgoL0P000005076Tl@030000002K_O00Vkg`00L0Vkg`00<000000;c>j02lc^P00`2lc^P30000
00030;_FkP000000fo7P00D0fo7P00<000000?ooo`3oool0:P3oool00380oooo00@0000003=ghP0c
Mn8000000P1PP=/00`000000SZg[08j]j`0708j]j`030000002/bNl0[<W_00L0[<W_00<000000<CP
k@34h>d01034h>d200000080g=kG00H000000=K:cP3Fb/h000000<bib00000020<:/a080000000L0
ZiS30000002MT<H0WI360000002=R//000000080N8CB00@0000005]og0000000Oj3X100000000`1a
Y?40000009^ml00809^ml0030000002lc^P0_<kX00<00000102ke^h00`000000fo7P0=_ah0030=_a
h0800000@`3oool01@0000008@in024>OP0Q3Wh0000000X0JT:>0P0000000`2@T]4000000::Jc@0>
0::Jc@030000002`Xl/0/:?;00h0/:?;00<000000;b^c02l[/`03@2l[/`00`000000ak_?0<Nkc`05
0<Nkc`<00000103IVi400`000000l[>90?:cR@080?:cR@030000003oool0oooo05X0oooo00@00000
0000=00003@000000`1F55h00`000000QSe]000000020000000309IUU`000000[GNG00D0[GNG00@0
00000<68U`31R9L0`HRG1@0000040=EmJ0030000003[SDl0jhe?00800000H@3oool01@0000008@in
024>OP0Q3Wh0000000X0JT:>0P0000000`2@T]4000000::Jc@0>0::Jc@030000002`Xl/0/:?;00h0
/:?;00<000000;b^c02l[/`03@2l[/`00`000000ak_?0<Nkc`050<Nkc`<00000103IVi400`000000
l[>90?:cR@080?:cR@030000003oool0oooo0440oooo00@0000003=ghP0cMn8000000P1PP=/00`00
0000SZg[08j]j`0708j]j`030000002/bNl0[<W_00L0[<W_00<000000<CPk@34h>d01034h>d20000
0080g=kG00h000000=K:cP3Fb/h000000<bib0000000`Zc40000002gXL8000000:^H``000000WI36
00000080SH[;00<0000007R4dP1hQ=800P1KOm`00`000000Oj3X0000000300000003076Tl@000000
Vkg`00P0Vkg`00<000000;c>j02lc^P00`0000040;_FkP030000003KlN00fo7P00<0fo7P0P00000/
0?ooo`00<P3oool200000080<gOR0`00000908j]j`030000002/bNl0[<W_00L0[<W_00@000000<CP
k@34h>d0a>3]0`0000001038eN@000000=cNe`0000030=K:cP070000003<^LP000000<:/a0000000
]j72000000020:^H``060000002MT<H0WI360000002=R//000000`1hQ=800`000000Oj3X07nPj003
07nPj0h000001`2ke^h00`000000fo7P0=_ah0030=_ah0030000003oool0oooo0440oooo0P000004
024>OP030000001Z@Xh0JT:>00D0JT:>0P000003092Bd@030000002RV/d0XY[=00h0XY[=00<00000
0;2Sb`2`Xl/0302`Xl/00`000000_:k<0;b^c00>0;b^c00300000037^ll0ak_?00P0ak_?0`000000
0`3IVi4000000?:cR@090?:cR@800000F`3oool010000000000d0000=000000305HDGP800000102F
IIL00`000000[GNG0:egU`040:egU`0300000031R9L0`HRG00@0`HRG00<000000=JJUP0000000P00
0000103EOFP000000>^=C`3[SDl200000600oooo0P000004024>OP030000001Z@Xh0JT:>00D0JT:>
0P000003092Bd@030000002RV/d0XY[=00h0XY[=00<000000;2Sb`2`Xl/0302`Xl/00`000000_:k<
0;b^c00>0;b^c00300000037^ll0ak_?00P0ak_?0`0000000`3IVi4000000?:cR@090?:cR@800000
@P3oool200000080<gOR0`00000908j]j`030000002/bNl0[<W_00L0[<W_00@000000<CPk@34h>d0
a>3]0`0000001038eN@000000=cNe`0000020=K:cP080000003<^LP0c;W800000032[<@000000;NQ
`P0000020:^H``030000002MT<H000000080SH[;00<0000007R4dP1hQ=800P00000507nPj0h00000
1`2ke^h00`000000fo7P0=_ah0030=_ah0030000003oool0oooo02/0oooo000c0?ooo`030000000c
Mn80<gOR0080<gOR0`00000608j]j`030000002/bNl0[<W_00L0[<W_00<000000<CPk@0000000P00
00050<SEi0070000003Fb/h0e/[>0=K:cP000000c;W8000000020<:/a0030000002gXL8000000080
ZiS300@0000009f@aP2MT<H000000P2=R//010000000N8CB0000002<W^02000000D0Oj3X00<00000
09fkkP2M^nh01`2M^nh00`000000^mK^0;_FkP060;_FkP040000003KlN00fo7P0=_ah0800000A03o
ool00`0000008@in024>OP03024>OP030000001Z@Xh0JT:>00<0JT:>0P000006092Bd@030000002R
V/d0XY[=00d0XY[=00<000000;2Sb`2`Xl/0302`Xl/00`000000_:k<0;b^c00=0;b^c00300000037
^ll0ak_?00`0ak_?0P00000:0?:cR@800000F`3oool00`000000000d0000000205HDGP<000001@2F
IIL00`000000[GNG0:egU`040:egU`0300000031R9L0`HRG00@0`HRG00<000000=JJUP3FVYH00P3F
VYH200000080jhe?0P00001P0?ooo`030000000Q3Wh08@in00<08@in00<0000006Y2SP1Z@Xh00`1Z
@Xh2000000H0T9;A00<000000::Jc@2RV/d03@2RV/d00`000000/:?;0;2Sb`0<0;2Sb`030000002l
[/`0_:k<00d0_:k<00<000000<Nkc`37^ll03037^ll2000000X0l[>90P0000130?ooo`030000000c
Mn80<gOR0080<gOR0`00000608j]j`030000002/bNl0[<W_00L0[<W_00<000000<CPk@0000000P00
00050<SEi0040000003Fb/h0e/[>00000080c;W800H000000<:/a032[<@000000;NQ`P0000020:^H
``040000002MT<H0WI3600000080SH[;00@0000007R4dP000000S9kP0P00000507nPj0030000002M
^nh0WK_^00L0WK_^00<000000;_FkP2ke^h01@2ke^h00`000000fo7P0=_ah0020=_ah0800000;P3o
ool003<0oooo0P00000303=ghP0300000026/?40Q[3a00@000000P2>[N/00`000000[<W_0:c9k`02
0:c9k`L000001P38eN@2000000040<K9g0000000e/[>00000080c;W800H000000<:/a032[<@00000
0;NQ`P0000030:^H``040000002MT<H0WI3600000080SH[;00<0000008bNh02<W^000P2<W^020000
00<0Oj3X00<0000009fkkP2M^nh01`2M^nh00`000000^mK^0;_FkP060;_FkP060000003KlN000000
00000033o^000000@`3oool00`0000008@in024>OP04024>OP030000001Z@Xh0JT:>0080JT:>00<0
0000092Bd@2@T]401P2@T]400`000000XY[=0::Jc@0=0::Jc@030000002`Xl/0/:?;00`0/:?;00<0
00000;b^c02l[/`03@2l[/`00`000000ak_?0<Nkc`0<0<Nkc`030000003Ac=@0000000T0l[>90P00
001J0?ooo`030000000003@0000d00<000000P1fCYD00`000000UVFG09IUU`0309IUU`030000002]
MiL0[GNG00@0[GNG00<000000<68U`31R9L01031R9L00`000000eYZF0=JJUP030=JJUP80000000@0
jhe?0000003PQ`P00000GP3oool00`0000008@in024>OP04024>OP030000001Z@Xh0JT:>0080JT:>
00<00000092Bd@2@T]401P2@T]400`000000XY[=0::Jc@0=0::Jc@030000002`Xl/0/:?;00`0/:?;
00<000000;b^c02l[/`03@2l[/`00`000000ak_?0<Nkc`0<0<Nkc`030000003Ac=@0000000T0l[>9
0P0000130?ooo`8000000`0cMn800`000000Q[3a08J`l@0400000080SZg[00<000000:c9k`2/bNl0
0P2/bNl7000000H0b=GT0P0000001036bM`000000=K:cP0000020<bib00300000032[<@000000080
]j7200@000000:^H``2[V<<000000`2MT<H010000000SH[;08f:b`00000408bNh08000000`1oX>P0
0`000000WK_^09fkkP0709fkkP030000002ke^h0^mK^00D0^mK^00<000000=_ah03KlN000P000000
0`33o^0000000?ooo`0]0?ooo`00=03oool00`000000<gOR03=ghP0203=ghP0300000026/?40Q[3a
00<0Q[3a1`0000050:k7k@0300000038eN@0b=GT00<0b=GT0P0000040<K9g0040000003<^LP0c;W8
000000<0`Zc400@000000;NQ`P2gXL8000000P2[V<<01`000000WI3609f@aP000000SH[;0000002H
WmX00P00000408bNh080000000<0Oj3X0000002M^nh01`2M^nh00`000000^mK^0;_FkP060;_FkP<0
00000P33o^000`000000oooo0?ooo`120?ooo`030000000Q3Wh08@in00@08@in00<0000006Y2SP1Z
@Xh00P00000:092Bd@030000002RV/d0XY[=00`0XY[=00<000000;2Sb`2`Xl/0302`Xl/00`000000
_:k<0;b^c00<0;b^c00300000037^ll0ak_?00d0ak_?00<000000=7<e03Ac=@00P0000070?:cR@03
0000003mbVT0000005T0oooo00@000000000=00003@00000101fCYD00`000000UVFG09IUU`0309IU
U`030000002]MiL0[GNG00@0[GNG00<000000<68U`31R9L01031R9L00`000000eYZF0=JJUP030=JJ
UP030000003//I80000000<00000GP3oool00`0000008@in024>OP04024>OP030000001Z@Xh0JT:>
008000002P2@T]400`000000XY[=0::Jc@0<0::Jc@030000002`Xl/0/:?;00`0/:?;00<000000;b^
c02l[/`0302l[/`00`000000ak_?0<Nkc`0=0<Nkc`030000003Ac=@0dLcD008000001`3b/hT00`00
0000oLYY000000130?ooo`030000000cMn80<gOR0080<gOR00<0000008J`l@26/?400`26/?470000
00D0[/O]00<000000<SEi038eN@00`38eN@2000000@0a/WL00@000000<bib03<^LP000000P32[<@0
1`000000]j720;NQ`P2gXL8000000:^H``0000000`2MT<H010000000SH[;0000002HWmX2000000@0
S9kP0P0000000`1oX>P0000009fkkP0709fkkP030000002ke^h0^mK^00H0^mK^0`0000020<?nh003
0000003oool0oooo02d0oooo000d0?ooo`8000000`0cMn800`000000Q[3a08J`l@0608J`l@030000
002^and0[/O]00L0[/O]00D000000<SEi038eN@0b=GT000000050<K9g00500000031_]L000000<bi
b00000000P32[<@01@000000]j720;NQ`P2gXL80000000<0ZiS30P2MT<H2000000@0V9oJ00<00000
08bNh02<W^000`2<W^06000000@0WK_^00<000000;_FkP2ke^h00P2ke^h5000000<0`okP00<00000
0?ooo`3oool0@`3oool00`0000008@in024>OP04024>OP<000003@2@T]400`000000XY[=0::Jc@0<
0::Jc@030000002`Xl/0/:?;00/0/:?;00<000000;b^c02l[/`0302l[/`00`000000ak_?0<Nkc`0<
0<Nkc`030000003Ac=@0dLcD00<0dLcD00<000000?:cR@3b/hT00`3b/hT010000000oLYY0?g:J@00
001I0?ooo`040000=00000000000000000@0MTjE00<0000009IUU`2FIIL00`2FIIL00`000000[GNG
0:egU`040:egU`0300000031R9L0`HRG00@0`HRG00<000000=JJUP3FVYH00`3FVYH010000000k;6B
0>baTP3//I82000005h0oooo00<00000024>OP0Q3Wh0100Q3Wh3000000d0T9;A00<000000::Jc@2R
V/d0302RV/d00`000000/:?;0;2Sb`0;0;2Sb`030000002l[/`0_:k<00`0_:k<00<000000<Nkc`37
^ll03037^ll00`000000dLcD0=7<e0030=7<e0030000003b/hT0l[>900<0l[>900@000000?g:J@3m
bVT00000@`3oool2000000<0<gOR00<0000008J`l@26/?401P26/?400`000000[/O]0:k7k@070:k7
k@0500000038eN@0b=GT0<SEi00000001@36bM`01@000000`KkG0000003<^LP000000080`Zc400D0
00000;NQ`P2gXL80]j72000000020:^H``80WI360`00000409ROfP030000002<W^00S9kP00<0S9kP
1P00000409fkkP030000002ke^h0^mK^0080^mK^1@0000030<?nh0030000003oool0oooo02h0oooo
000e0?ooo`030000000cMn80<gOR0080<gOR00<0000008J`l@26/?401@26/?400`000000[/O]0:k7
k@070:k7k@0400000038eN@00000000000D0a/WL00@000000<6ne`31_]L0`KkG1P0000020;NQ`P03
0000002[V<<0000000<000000P2RX]D00`000000V9oJ09ROfP0209ROfP8000000`2<W^000`000000
Wk[/09njk00309njk0T000000`2eg?@01@000000`okP0<?nh033o^00000004H0oooo00<00000024>
OP0Q3Wh0100Q3Wh00`000000T9;A092Bd@0=092Bd@030000002RV/d0XY[=00X0XY[=5000000;0;b^
c00300000037^ll0ak_?00/0ak_?00<000000=7<e03Ac=@01@3Ac=@00`000000l[>90?:cR@020?:c
R@040000003mbVT0oLYY000005P0oooo0P00000203hWS@030000001fCYD0MTjE0080MTjE00<00000
09IUU`2FIIL00`2FIIL00`000000[GNG0:egU`040:egU`0300000031R9L0`HRG00@0`HRG00<00000
0=JJUP3FVYH00P3FVYH00`000000k;6B0>baTP020>baTP800000GP3oool00`0000008@in024>OP04
024>OP030000002@T]40T9;A00d0T9;A00<000000::Jc@2RV/d02P2RV/dD000000/0_:k<00<00000
0<Nkc`37^ll02`37^ll00`000000dLcD0=7<e0050=7<e0030000003b/hT0l[>90080l[>900@00000
0?g:J@3mbVT00000A03oool00`000000<gOR03=ghP0203=ghP0300000026/?40Q[3a00D0Q[3a00<0
00000:k7k@2^and01`2^and010000000b=GT0000000000050<K9g00400000031_]L0`KkG0<6ne`H0
00000P2gXL800`000000ZiS300000002000000<0XZ;E00<0000009ROfP2HWmX00P2HWmX2000000<0
S9kP00<0000009njk02O^^`00`2O^^`9000000<0]Mcd00D000000<?nh033o^00`okP0000000a0?oo
o`00=P3oool200000080<gOR00<0000008J`l@26/?401P26/?400`000000[/O]0:k7k@050:k7k@<0
00001@36bM`2000000<0`KkG00<000000;^ee02k]M@00P2k]M@00`000000/jgB0000000300000080
ZjOC00<000000::Re@2RX]D00P2RX]D00`000000V9oJ09ROfP0309ROfP80000000<0S9kP0000002O
^^`01`2O^^`00`000000]Mcd0;GLm0060;GLm00500000033o^00`okP0<?nh0000000AP3oool00`00
00008@in024>OP03024>OP030000001jRmT0000000l0T9;A00<000000::Jc@2RV/d01@2RV/d40000
0080VMCl0P00000<097@o@040000002<bod0S<_m08c;o@L000000`2l[/`00`000000ak_?0<Nkc`0<
0<Nkc`030000003Ac=@0dLcD00H0dLcD00D000000?:cR@3b/hT0l[>9000000030?g:J@030000003o
ool0oooo05D0oooo00D0000003hWS@0n9hd0?RN=0000000407I>U@030000002FIIL0UVFG00@0UVFG
00<000000:egU`2]MiL00`2]MiL00`000000`HRG0<68U`040<68U`030000003FVYH0eYZF0080eYZF
00<000000>baTP3//I800P3//I83000005d0oooo00<00000024>OP0Q3Wh00`0Q3Wh00`000000NX_I
0000000?092Bd@030000002RV/d0XY[=00D0XY[=1000000209WDo0800000302Ad?d010000000S<_m
08c;o@2<bod7000000<0_:k<00<000000<Nkc`37^ll03037^ll00`000000dLcD0=7<e0060=7<e005
0000003b/hT0l[>90?:cR@0000000`3mbVT00`000000oooo0?ooo`120?ooo`8000000P0cMn800`00
0000Q[3a08J`l@0608J`l@030000002^and0[/O]00D0[/O]0`0000050<K9g08000000`31_]L00`00
0000^kGD0;^ee0020;^ee0030000002c[M80000000<000000P2[Ym<00`000000XZ;E0::Re@020::R
e@030000002HWmX0V9oJ00<0V9oJ00@0000008bNh02<W^000000202O^^`00`000000]Mcd0;GLm006
0;GLm00500000033o^00`okP0<?nh0000000<@3oool003L0oooo0`0000000`0cMn80000008J`l@06
08J`l@040000002^and0[/O]0:k7k@@000000`2^aN/01@000000a/WL0<K9g036bM`0000000D0`KkG
00<000000;^ee02k]M@00P2k]M@01@000000/jgB0;>]dP2c[M80000000@0ZjOC00D000000::Re@2R
X]D0XZ;E0000000709ROfP800000202O^^`00`000000]Mcd0;GLm0050;GLm00500000033o^00`okP
0<?nh0000000AP3oool2000000D08@in00@0000007Z;f@1jRmT000003P2@T]4010000000XY[=0::J
c@2RV/d4000000L0VMCl00<00000097@o@2Ad?d02P2Ad?d00`000000S<_m08c;o@0808c;o@D00000
3037^ll00`000000dLcD0=7<e0080=7<e080000000<0l[>90000003mbVT00P3mbVT00`000000oooo
0?ooo`1E0?ooo`030000000n9hd0?RN=0080?RN=00D0000007I>U@1fCYD0MTjE0000000609IUU`03
0000002]MiL0[GNG00<0[GNG00<000000<68U`31R9L00`31R9L00`000000eYZF0=JJUP030=JJUP03
0000003//I80k;6B0080k;6B0`00001L0?ooo`8000001@0Q3Wh010000000NX_I07Z;f@00000>092B
d@040000002RV/d0XY[=0::Jc@@000001`2Ie?`00`000000TM3m097@o@0:097@o@030000002<bod0
S<_m00P0S<_m1@00000<0<Nkc`030000003Ac=@0dLcD00P0dLcD0P0000000`3b/hT000000?g:J@02
0?g:J@030000003oool0oooo04<0oooo0`0000000`0cMn80000008J`l@0608J`l@040000002^and0
[/O]0:k7k@@000000`2^aN/01@000000a/WL0<K9g036bM`0000000D0`KkG00<000000;^ee02k]M@0
0P2k]M@01@000000/jgB0;>]dP2c[M80000000<0ZjOC00<000000::Re@2RX]D00P2RX]D00`000000
V9oJ09ROfP0509ROfP800000202O^^`00`000000]Mcd0;GLm0050;GLm00500000033o^00`okP0<?n
h0000000<P3oool003T0oooo3P0000080:k5j`0300000036bM`0000000D0`KkG00<000000;^ee02k
]M@00P2k]M@00`000000/jgB0;>]dP020;>]dP030000002[Ym<0ZjOC0080ZjOC00<000000::Re@2R
X]D00P2RX]D00`000000V9oJ09ROfP0209ROfP8000000P2R^^X2000000D0Wk[/00<000000;GLm02e
g?@01@2eg?@00`000000`okP0<?nh002000004L0oooo00<000000000?@0000000`0Q3Wh00`000000
NX_I07Z;f@0207Z;f@030000002@T]40T9;A00/0T9;A1000000;09WDo08000001P2Ad?d00`2B:S`0
TM3m097@o@02097@o@030000002<bod0S<_m00X0S<_m00<0000008W5o029aO`00`0000080<Nkc`03
0000003Ac=@0dLcD00/0dLcD0P0000030?g:J@030000003oool0oooo05D0oooo00<0000003hWS@0n
9hd00P0n9hd00`000000MTjE07I>U@0207I>U@030000002FIIL0UVFG00<0UVFG00<000000:egU`2]
MiL00`2]MiL00`000000`HRG0<68U`030<68U`030000003FVYH0eYZF00<0eYZF00D000000>baTP3/
/I80k;6B000000020?o<PP030000003oool0oooo05X0oooo00<000000000?@0000000`0Q3Wh00`00
0000NX_I07Z;f@0207Z;f@030000002@T]40T9;A00/0T9;A1000000;09WDo08000001P2Ad?d00`2B
:S`0TM3m097@o@02097@o@030000002<bod0S<_m00X0S<_m00<0000008W5o029aO`00`0000080<Nk
c`030000003Ac=@0dLcD00/0dLcD0P0000030?g:J@030000003oool0oooo04D0oooo3P0000080:k5
j`0300000036bM`0000000D0`KkG00<000000;^ee02k]M@00P2k]M@00`000000/jgB0;>]dP020;>]
dP030000002[Ym<0ZjOC0080ZjOC00<000000::Re@2RX]D00P2RX]D00`000000V9oJ09ROfP0209RO
fP8000000P2R^^X2000000D0Wk[/00<000000;GLm02eg?@01@2eg?@00`000000`okP0<?nh0020000
03<0oooo000j0?ooo`0300000000I]L0000000P0OkGg00<000000:k5j`2^aN/0202^aN/2000000@0
`KkG00<000000;^ee02k]M@00`2k]M@00`000000/jgB0;>]dP020;>]dP030000002[Ym<0ZjOC00<0
ZjOC00<000000::Re@2RX]D00P2RX]D010000000V9oJ0000000000060::jjP<000000P2O^^`00`00
0000]Mcd0;GLm0040;GLm00300000033o^00000000800000B03oool00`000000000m00000002024>
OP030000001jRmT0NX_I00@0NX_I00<00000092Bd@2@T]40202@T]4200000080XMKj0P00000<09WD
o08000002@2Ad?d00`000000S<_m08c;o@0908c;o@8000001P29aO`2000000D0ak_?00<000000=7<
e03Ac=@03@3Ac=@01@000000oLYY0?g:J@3mbVT0000005L0oooo0P00000303hWS@030000001fCYD0
MTjE0080MTjE00<0000009IUU`2FIIL00`2FIIL00`000000[GNG0:egU`030:egU`0300000031R9L0
`HRG00<0`HRG00<000000=JJUP3FVYH00`3FVYH01@000000k;6B0>baTP3//I8000000080olb200<0
00000?ooo`3oool0FP3oool00`000000000m00000002024>OP030000001jRmT0NX_I00@0NX_I00<0
0000092Bd@2@T]40202@T]4200000080XMKj0P00000<09WDo08000002@2Ad?d00`000000S<_m08c;
o@0908c;o@8000001P29aO`2000000D0ak_?00<000000=7<e03Ac=@03@3Ac=@01@000000oLYY0?g:
J@3mbVT0000004P0oooo00<00000001Ve`000000201o]OL00`000000[/G[0:k5j`080:k5j`800000
1031_]L00`000000^kGD0;^ee0030;^ee0030000002c[M80/jgB0080/jgB00<000000:^Wd`2[Ym<0
0P2[Ym<00`000000XZ;E0::Re@030::Re@040000002HWmX00000000000H0X[[Z0`00000209njk003
0000002eg?@0]Mcd00@0]Mcd00<000000<?nh00000000P00000d0?ooo`00>`3oool3000000P0OkGg
00<000000:k5j`2^aN/01@2^aN/200000080[/;Y0P0000020<6ne`030000002k]M@0^kGD00<0^kGD
00<000000;>]dP2c[M800P2c[M800`000000ZjOC0:^Wd`030:^Wd`030000002RX]D0XZ;E0080XZ;E
0P00000;0::jjPD00000102eg?@3000004X0oooo00D000000000?@0000008@in0000000807Z;f@03
0000002@T]40T9;A00D0T9;A0P0000060:7FnP030000002Ie?`0VMCl00X0VMCl00<00000097@o@2A
d?d01`2Ad?d00`000000S<_m08c;o@0808c;o@0300000029aO`0RLGl00P0RLGl0`0000020<Nkc`03
0000003Ac=@0dLcD00`0dLcD0P0000030?g:J@030000003oool0oooo05D0oooo0P00000303hWS@03
0000001fCYD0MTjE0080MTjE00<0000009IUU`2FIIL00`2FIIL00`000000[GNG0:egU`030:egU`03
00000031R9L0`HRG00<0`HRG00<000000=JJUP3FVYH00`3FVYH01@000000k;6B0>baTP3//I800000
0080olb200<000000?ooo`3oool0FP3oool01@000000000m0000000Q3Wh0000000P0NX_I00<00000
092Bd@2@T]401@2@T]42000000H0XMKj00<0000009WDo02Ie?`02P2Ie?`00`000000TM3m097@o@07
097@o@030000002<bod0S<_m00P0S<_m00<0000008W5o029aO`02029aO`300000080ak_?00<00000
0=7<e03Ac=@0303Ac=@2000000<0oLYY00<000000?ooo`3oool0A`3oool3000000P0OkGg00<00000
0:k5j`2^aN/01@2^aN/200000080[/;Y0P0000020<6ne`030000002k]M@0^kGD00<0^kGD00<00000
0;>]dP2c[M800P2c[M800`000000ZjOC0:^Wd`030:^Wd`030000002RX]D0XZ;E0080XZ;E0P00000;
0::jjPD00000102eg?@3000003H0oooo000m0?ooo`<000001`1o]OL00`000000[/G[0:k5j`020:k5
j`8000001P2^`^T3000000D0^kGD00<000000;>]dP2c[M800P2c[M800`000000ZjOC0:^Wd`040:^W
d`80XZ;E0P0000020:Fjj0800000202R^^X2000000@0Zmki1@00001<0?ooo`050000000003d00000
024>OP0000002@1jRmT00`000000T9;A092Bd@02092Bd@8000002@2Qe_X2000000T0VMCl40000005
08c;o@0300000029aO`0RLGl00`0RLGl0P00000=0=7<e08000000P3HhMd010000000oLYY0?g:J@00
001G0?ooo`8000000`0n9hd00`000000MTjE07I>U@0207I>U@030000002FIIL0UVFG00<0UVFG00<0
00000:egU`2]MiL00`2]MiL00`000000`HRG0<68U`030<68U`030000003FVYH0eYZF00<0eYZF00D0
00000>baTP3//I80k;6B000000020?o<PP030000003oool0oooo05X0oooo00D000000000?@000000
8@in0000000907Z;f@030000002@T]40T9;A0080T9;A0P0000090:7FnP8000002@2Ie?`@000000D0
S<_m00<0000008W5o029aO`03029aO`2000000d0dLcD0P0000020=SQg@040000003mbVT0oLYY0000
04/0oooo0`00000707nem`030000002^aN/0[/G[0080[/G[0P0000060:k2j@<000001@2k]M@00`00
0000/jgB0;>]dP020;>]dP030000002[Ym<0ZjOC00<0ZjOC00<000000::Re@2RX]D00P0000020:Fj
j0800000202R^^X2000000@0Zmki1@00000h0?ooo`00?P3oool3000000L0OkGg00@000000:k5j`00
00000000202^`^T00`000000[;oX0:boj003000000030;^ee0000000/jgB00@0/jgB00@000000:^W
d`2[Ym<0ZjOC1@0000060:Fjj0030000002R^^X0X[[Z00<0X[[Z0P0000070:_Nn@<00000C@3oool0
10000000000m00000000000;07Z;f@040000002@T]400000000000d0XMKj0P00000309WDo0@00000
0P3Xak@020000000f;2a0=R`/@000000b9n^0000002hTJd000000P2XQ:h010000000U7N_0000001j
J;87000000T0RLGl1000000208[1n@8000002P3Ac=@00`000000f>7M0=SQg@020=SQg@040000003m
bVT0oLYY000005L0oooo0P00000303hWS@030000001fCYD0MTjE0080MTjE00<0000009IUU`2FIIL0
0`2FIIL00`000000[GNG0:egU`06000000<0`HRG00<000000=JJUP3FVYH00P3FVYH00`000000k;6B
0>baTP020>baTP040000003oc8800000000005`0oooo00@000000000?@00000000002`1jRmT01000
0000T9;A00000000000=0:7FnP8000000`2Ie?`400000080j<Nd00P000000=R`/@3H/;4000000<RO
[P000000^96]00000080Z8B^00@0000009Ag[`000000NVRb1`00000908W5o0@000000P2:`OT20000
00X0dLcD00<000000=SQg@3HhMd00P3HhMd010000000oLYY0?g:J@00001<0?ooo`<000001`1o]OL0
10000000[/G[0000000000080:k2j@030000002/_nP0[;oX00<0000000<0^kGD0000002c[M80102c
[M8010000000ZjOC0:^Wd`2[Ym<5000000H0YK[X00<000000::jjP2R^^X00`2R^^X2000000L0Zmki
0`00000i0?ooo`00@03oool2000000@0OkGg1@0000080:k2j@030000002/_nP0[;oX00@0[;oX2`00
00040:Rki`030000002U^^P0YK[X00D0YK[X0P0000000`2R^^X00000000000070:_Nn@<00000C`3o
ool00`000000000m0000000=07Z;f@8000003`2Qe_X6000000040?KU]P000000j<Nd00000080f;2a
00<000000<RO[P0000000`2hTJd00`000000Z8B^0000000209Ag[`040000001jJ;800000055C]P80
000000@07g;Q00000000000000001029aO`3000000P0R/7i00<000000=7<e03Ac=@01P3Ac=@00`00
0000f>7M0=SQg@030=SQg@030000003mbVT0000005P0oooo00<000000000J00000000`0n9hd01@00
0000MTjE07I>U@1fCYD000000080UVFG1P0000030;6A]P0300000030W[H0`9jf00D000000`3FVYH0
0`000000k;6B0>baTP020>baTP040000003oc8800000000005`0oooo00<000000000?@0000003@1j
RmT2000000l0XMKj1P000000103fiKH000000>S7]00000020=R`/@0300000038Wjh0000000<0^96]
00<000000:R4[P0000000P2DMjl010000000NVRb0000001ADkH20000000401mbh@00000000000000
00@0RLGl0`00000808[1n@030000003Ac=@0dLcD00H0dLcD00<000000=SQg@3HhMd00`3HhMd00`00
0000oLYY0000001?0?ooo`800000101o]OL5000000P0[/;Y00<000000:boj02/_nP0102/_nP;0000
00@0Z;_W00<000000:Fjj02U^^P01@2U^^P2000000030::jjP000000000000L0Zmki0`00000k0?oo
o`00@P3oool4000000D0N[ck0P0000050:k2j@030000002/_nP0[;oX00H0[;oX00<000000:Zmi`2Z
_NL00`2Z_NL00`000000Z;_W0:Rki`050:Rki`030000002U^^P0YK[X00H0YK[X0`0000070:_Nn@80
0000D@3oool010000000000m00000000000;07Z;f@030000002Xe_P0Z=Kh00@000002@2Qe_X30000
00060;7kf`00000000000000003fiKH000000P3Xak@01P000000f;2a0=R`/@000000b9n^000000<0
^96]00<000000:R4[P0000000P2DMjl010000000NVRb0000001ADkH3000000807g;Q1@00000<08[1
n@800000103Ac=@2000000L0f>7M0P00001I0?ooo`030000J0000000?RN=0080?RN=00<0000007I>
U@1fCYD01000000309n5]`030000002aTKH0/I6f00<0/I6f00<000000<2N]P30W[H00`30W[H01P00
0000cjjh000000000000eYZF000000<0k;6B00<000000?o<PP3oc8800P00001L0?ooo`0400000000
03d00000000000/0NX_I00<000000:SFn02Xe_P0100000090:7FnP<0000000H0/O_K000000000000
00000?KU]P0000020>S7]0060000003H/;40f;2a00000038Wjh000000`2hTJd00`000000Z8B^0000
000209Ag[`040000001jJ;800000055C]P<000000P0OL^45000000`0R/7i0P0000040=7<e0800000
1`3HhMd200000540oooo1000000507Zln`8000001@2^`^T00`000000[;oX0:boj0060:boj0030000
002Z_NL0Z[gW00<0Z[gW00<000000:Rki`2X^nL01@2X^nL00`000000YK[X0:Fjj0060:Fjj0<00000
1`2[g_T2000003d0oooo00140?ooo`8000001`1j_?/200000080[/;Y00<000000:boj02/_nP01P2/
_nP00`000000Z[gW0:Zmi`040:Zmi`030000002X^nL0Z;_W00H0Z;_W00<000000:Fjj02U^^P00P2U
^^P3000000<0W=gm0`0000020:_Nn@800000D`3oool010000000000m0000001IQ>42000000T0NX_I
00<000000:SFn02Xe_P0102Xe_P4000000<0XMKj0`0000001@2anm/000000000003Gmn4000000080
m^Ff0P3Xak@01`000000f;2a0=R`/@3H/;4000000<RO[P0000000`2hTJd00`000000Z8B^0:R4[P02
09Ag[`050000001jJ;80NVRb0000001ADkH00P00000401mbh@@000003@2:`OT2000000030=7<e000
0000f>7M00P0f>7M0P00001I0?ooo`8000000`0n9hd30000000308Ui^P000000WhFg00@0WhFg00<0
00000;6A]P2aTKH00`2aTKH00`000000`9jf0<2N]P030<2N]P040000003?[[P0cjjh0<n^^0800000
0`3//I8010000000olb20?o<PP00001M0?ooo`040000000003d0000005V4h@8000002@1jRmT00`00
0000Z=Kh0:SFn0040:SFn0@000000`2Qe_X3000000050;7kf`00000000000=Ogh@0000000P3fiKH2
0>S7]0070000003H/;40f;2a0=R`/@000000b9n^000000030;RA[@030000002XQ:h0Z8B^0080U7N_
00D0000007YX/P1jJ;800000055C]P02000000@07g;Q1000000=08[1n@80000000<0dLcD0000003H
hMd0203HhMd2000005<0oooo0P00000707Zln`8000000P2^`^T00`000000[;oX0:boj0060:boj003
0000002Z_NL0Z[gW00@0Z[gW00<000000:Rki`2X^nL01P2X^nL00`000000YK[X0:Fjj0020:Fjj0<0
00000`2LgOd300000080Zmki0P00000o0?ooo`00AP3oool3000000H0N[ck100000070:boj0030000
002Z_NL0Z[gW00D0Z[gW00<000000:Rki`2X^nL01@2X^nL00`000000YK[X0:Fjj002000000T0W=gm
0P00001E0?ooo`030000000003d0000000<0FHCQ00<0000007Z;f@1jRmT01@1jRmT00`000000Z=Kh
0:SFn0090:SFn0@0000000<0/O_K0000000000000`3Gmn400`000000m^Ff000000020>S7]0040000
003H/;40f;2a00000080b9n^00D000000;RA[@2hTJd0^96]000000020:R4[P070000002DMjl0U7N_
0000001jJ;800000055C]P04000000@07g;Q0`00000;08[1n@@000002`3HhMd00`000000oooo0?oo
o`1G0?ooo`8000000`0n9hd00`000000RGVj08Ui^P0208Ui^P030000002OQKL0WhFg0080WhFg00<0
00000;6A]P2aTKH00`2aTKH00`000000`9jf0<2N]P020<2N]P030000003?[[P0cjjh00<0cjjh0`00
00001@3//I8000000?o<PP3oc880000005d0oooo00<000000000?@0000000`1IQ>400`000000NX_I
07Z;f@0507Z;f@030000002Xe_P0Z=Kh00T0Z=Kh100000000`2anm/00000000000030=Ogh@030000
003fiKH000000080j<Nd00@000000=R`/@3H/;4000000P38Wjh01@000000^96]0;RA[@2hTJd00000
0080Z8B^00L0000009Ag[`2DMjl0000007YX/P000000DE>f00@00000100OL^43000000/0R/7i1000
000;0=SQg@030000003oool0oooo05<0oooo0`00000607Zln`@000001`2/_nP00`000000Z[gW0:Zm
i`050:Zmi`030000002X^nL0Z;_W00D0Z;_W00<000000:Fjj02U^^P00P00000909cMo@800000@@3o
ool004P0oooo0`00000207Zln`800000101kaOh400000080[;oX00<000000:Zmi`2Z_NL01P2Z_NL0
0`000000Z;_W0:Rki`020:Rki`H000001`2LgOd4000005P0oooo00<0000m0000001IQ>400`1IQ>40
0`000000NX_I07Z;f@0307Z;f@030000002Xe_P0Z=Kh00/0Z=Kh00@000000;7kf`00000000000`3G
mn43000000040?KU]P3Xak@0j<Nd000000<0f;2a00@000000<RO[P38Wjh000000`2hTJd010000000
Z8B^0:R4[P00000209Ag[`060000001jJ;80NVRb0000001ADkH000000P1BO=h2000000@07g;Q0`00
000308[1n@H000000`2=_?H00`000000f>7M0=SQg@090=SQg@030000003oool0oooo05L0oooo00@0
00000000J0000000?RN=0P00000408Ui^P030000002OQKL0WhFg00<0WhFg00<000000;6A]P2aTKH0
0P2aTKH00`000000`9jf0<2N]P020<2N]P030000003?[[P0cjjh0080cjjh00@000000=k2_03N`[`0
g/:l0P0000020?o<PP030000003oool0oooo05`0oooo00<0000m0000001IQ>400`1IQ>400`000000
NX_I07Z;f@0307Z;f@030000002Xe_P0Z=Kh00/0Z=Kh00@000000;7kf`00000000000`3Gmn430000
00040?KU]P3Xak@0j<Nd000000<0f;2a00@000000<RO[P38Wjh000000`2hTJd010000000Z8B^0:R4
[P00000209Ag[`060000001jJ;80NVRb0000001ADkH000000P1BO=h2000000@07g;Q0`00000308[1
n@H000000`2=_?H00`000000f>7M0=SQg@090=SQg@030000003oool0oooo05D0oooo0`00000207Zl
n`800000101kaOh400000080[;oX00<000000:Zmi`2Z_NL01P2Z_NL00`000000Z;_W0:Rki`020:Rk
i`H000001`2LgOd4000004<0oooo001:0?ooo`<000002P1kaOh@000000D0S]Oo0P00000309cMo@<0
0000G03oool00`000000FHCQ05V4h@0405V4h@8000000P1jRmT00`000000Z=Kh0:SFn00;0:SFn0<0
0000103Gmn401@000000gN;I0=gRf@3Mh]T000000080j<Nd00D000000=R`/@3H/;40f;2a00000002
0<RO[P050000002hTJd0^96]0;RA[@0000000P2XQ:h010000000U7N_09Ag[`00000207YX/P040000
001ADkH00000000000<0DWcN0P00000401mbh@@000002P2=_?H00`000000f>7M0=SQg@060=SQg@<0
0000F@3oool010000000001X00000000000206YZ_`0500000029NKX0RGVj08Ui^P0000001@2OQKL0
0`000000/I6f0;6A]P020;6A]P0300000030W[H0`9jf0080`9jf00<000000<n^^03?[[P00P3?[[P0
0`000000g/:l0=k2_0020=k2_0040>cM`P0000000000000005h0oooo00<0000005V4h@1IQ>40101I
Q>4200000080NX_I00<000000:SFn02Xe_P02`2Xe_P3000000@0eoOQ00D000000=gRf@3Mh]T0gN;I
000000020>S7]0050000003H/;40f;2a0=R`/@0000000P38Wjh01@000000^96]0;RA[@2hTJd00000
0080Z8B^00@0000009Ag[`2DMjl000000P1jJ;8010000000DE>f000000000003059lgP800000100O
L^44000000X0SKcf00<000000=SQg@3HhMd01P3HhMd3000005T0oooo0`00000:07_5oQ0000001@2>
eol2000000<0W=gm0`0000170?ooo`00C`3oool6000000<0NlGn00<0000008;>o`22c_l01`22c_l0
0`000000S]Oo08kGo`0708kGo`D00000G`3oool00`000000FHCQ05V4h@0605V4h@030000001jRmT0
000000`0Z=Kh0P0000040=Ogh@8000000`3Mh]T010000000elg@0000000000040=R`/@0300000038
Wjh0000000@0^96]00@000000:R4[P2XQ:h000000`2DMjl010000000NVRb00000000000207>3e080
00000`1BO=h2000000<07g;Q00<0000008flmP2=_?H02P2=_?H00`000000f>7M0=SQg@050=SQg@04
0000003Dm^@0e?KT000005T0oooo00<000000000J00000000`1ZJ[l00`000000RGVj08Ui^P0208Ui
^P030000002OQKL0WhFg0080WhFg00D000000;6A]P2aTKH0/I6f000000050<2N]P050000003?[[P0
cjjh0<n^^0000000103N`[`00`000000k=g200000002000005h0oooo00<0000005V4h@1IQ>401P1I
Q>400`000000NX_I0000000<0:SFn0800000103Gmn42000000<0gN;I00@000000=O=d00000000000
103H/;400`000000b9n^000000040;RA[@040000002XQ:h0Z8B^000000<0U7N_00@0000007YX/P00
000000000P1cPm@2000000<0DWcN0P00000301mbh@030000002=_?H0SKcf00X0SKcf00<000000=SQ
g@3HhMd01@3HhMd010000000e?KT0=Cfi000001N0?ooo`H000000`1kaOh00`000000P/ko08;>o`07
08;>o`030000002>eol0S]Oo00L0S]Oo1@00001:0?ooo`00E@3oool8000000H0P/ko00<0000008kG
o`2>eol01P00001T0?ooo`030000001IQ>40FHCQ00L0FHCQ3P0000050=Ogh@030000003Mh]T0gN;I
0080gN;I00@000000=O=d03GcM00elg@0P0000020=R`/@0400000038Wjh0b9n^000000@0^96]00@0
00000:R4[P2XQ:h0Z8B^0`2DMjl200000080RhW<00D0000007>3e01cPm@0Lh?D00000004059lgP80
00000P0OL^400`000000SKcf08flmP0:08flmP030000003HhMd0f>7M0080f>7M0P0000020=Cfi003
0000003oool0oooo05T0oooo00<0001X0000000000000`1ZJ[l01@000000RGVj08Ui^P29NKX00000
00@0WhFg00D000000;6A]P2aTKH0/I6f000000040<2N]P030000003?[[P0cjjh0080cjjh00D00000
0=k2_03N`[`0g/:l000000030>cM`P800000GP3oool00`000000FHCQ05V4h@0705V4h@h000001@3G
mn400`000000gN;I0=gRf@020=gRf@040000003GcM00elg@0=O=d08000000P3H/;4010000000b9n^
0<RO[P0000040;RA[@040000002XQ:h0Z8B^0:R4[P<0U7N_0P00000208^9c0050000001cPm@0Lh?D
07>3e0000000101BO=h2000000807g;Q00<0000008flmP2=_?H02P2=_?H00`000000f>7M0=SQg@02
0=SQg@8000000P3Dm^@00`000000oooo0?ooo`1S0?ooo`P000001P22c_l00`000000S]Oo08kGo`06
000004l0oooo001M0?ooo`T00000JP3oool00`000000FHCQ05V4h@0705V4h@030000002]e?@0[MCd
00X0[MCd00<000000=Ogh@3Gmn400P3Gmn400`000000gN;I0=gRf@020=gRf@050000003GcM00elg@
0=O=d00000000P3=^lT4000000030<RO[P000000^96]00<0^96]00D000000:R4[P2XQ:h0Z8B^09Ag
[`020000000309b@a`000000RhW<0080RhW<00D0000007>3e01cPm@0Lh?D00000005059lgP<00000
302=_?H01@000000f>7M0=SQg@3HhMd0000000@0e?KT00<000000?ooo`3oool0F@3oool00`000000
=E?30000000306YZ_`0500000029NKX0RGVj08Ui^P000000102OQKL01@000000/I6f0;6A]P2aTKH0
000000@0`9jf00<000000<n^^03?[[P00P3?[[P010000000g/:l0=k2_00000030>cM`P800000G`3o
ool00`000000FHCQ05V4h@0705V4h@030000002]e?@0[MCd00X0[MCd00<000000=Ogh@3Gmn400P3G
mn400`000000gN;I0=gRf@020=gRf@050000003GcM00elg@0=O=d00000000P3=^lT4000000030<RO
[P000000^96]00<0^96]00D000000:R4[P2XQ:h0Z8B^09Ag[`020000000309b@a`000000RhW<0080
RhW<00D0000007>3e01cPm@0Lh?D00000005059lgP<00000302=_?H01@000000f>7M0=SQg@3HhMd0
000000@0e?KT00<000000?ooo`3oool0J`3oool9000005D0oooo003@0?ooo`<000001`1IQ>400`00
0000[MCd0:gDm00:0:gDm0030000003Gmn40eoOQ00800000103Mh]T01@000000elg@0=O=d03GcM00
000000D0cK_900<000000<:]a@0000002P00000309b@a`030000002;RL`0RhW<0080RhW<00@00000
07>3e01cPm@0Lh?D0P000005059lgPP000001P2=_?H3000000D0e?KT00<000000?ooo`3oool0F@3o
ool010000000=E?303EC``00000306YZ_`0500000029NKX0RGVj08Ui^P0000000`2OQKL01@000000
/I6f0;6A]P2aTKH0000000@0`9jf00D000000<n^^03?[[P0cjjh000000030=k2_0060000003/gL80
k=g20000003/nL000000G`3oool3000000L0FHCQ00<000000:gDm02]e?@02P2]e?@00`000000eoOQ
0=Ogh@02000000@0gN;I00D000000=O=d03GcM00elg@000000050<fkb@0300000032[LD0000000X0
00000`2LT<L00`000000RhW<08^9c00208^9c0040000001cPm@0Lh?D07>3e08000001@1BO=h80000
00H0SKcf0`0000050=Cfi0030000003oool0oooo0<T0oooo003A0?ooo`040000000XN>@000000000
00D0FHCQ00<000000:gDm02]e?@02@2]e?@010000000eoOQ0=Ogh@0000040=gRf@800000103GcM00
0`000000cK_90<fkb@020<fkb@0500000032[LD0`Zg50<:]a@000000102gX/@01@000000ZYW40:ZI
a02ZVL@0000000@0W93700<0000008^9c02;RL`00P2;RL`00`000000Lh?D07>3e00207>3e0030000
001BO=h0DWcN00<0DWcN00<00000096ilP2A^O80102A^O87000000L0e?KT00<000000?ooo`3oool0
F@3oool200000080=E?300@0000006YZ_`1ZJ[l000000`29NKX00`000000WhFg09n5]`0209n5]`04
0000002aTKH0/I6f000000@0`9jf00D000000<n^^03?[[P0cjjh000000020=k2_0070000003/gL80
k=g20>cM`P000000k?W00000001P0?ooo`040000000XN>@00000000000D0FHCQ00<000000:gDm02]
e?@02@2]e?@010000000eoOQ0=Ogh@0000040=gRf@800000103GcM000`000000cK_90<fkb@020<fk
b@0500000032[LD0`Zg50<:]a@000000102gX/@01@000000ZYW40:ZIa02ZVL@0000000@0W93700<0
000008^9c02;RL`00P2;RL`00`000000Lh?D07>3e00207>3e0030000001BO=h0DWcN00<0DWcN00<0
0000096ilP2A^O80102A^O87000000L0e?KT00<000000?ooo`3oool0b@3oool00=40oooo00@00000
02Qhi00XN>@0:7ST0P00000205V4h@030000002]e?@0[MCd00X0[MCd0`0000040=gRf@030000003G
cM00elg@00<0elg@00<000000<fkb@3=^lT00`3=^lT01@000000`Zg50<:]a@32[LD0000000@0]j;4
00<000000:ZIa02ZVL@00P2ZVL@00`000000W93709b@a`0209b@a`030000002;RL`0RhW<0080RhW<
00<0000007>3e01cPm@00P1cPm@00`000000DWcN059lgP02059lgP030000002A^O80TKWb00X0TKWb
00<000000=Cfi03Dm^@0103Dm^@00`000000oooo0?ooo`1K0?ooo`80000000<0=E?30000001ZJ[l0
0P1ZJ[l010000000RGVj08Ui^P00000409n5]`040000002aTKH0/I6f000000<0`9jf00D000000<n^
^03?[[P0cjjh000000030=k2_0040000003/gL80k=g200000080k?W000<000000?ooo`3oool0GP3o
ool010000000:7ST02Qhi00XN>@200000080FHCQ00<000000:gDm02]e?@02P2]e?@3000000@0gN;I
00<000000=O=d03GcM000`3GcM000`000000cK_90<fkb@030<fkb@0500000032[LD0`Zg50<:]a@00
0000102gX/@00`000000ZYW40:ZIa0020:ZIa0030000002LT<L0W9370080W93700<0000008^9c02;
RL`00P2;RL`00`000000Lh?D07>3e00207>3e0030000001BO=h0DWcN0080DWcN00<00000096ilP2A
^O802P2A^O800`000000e?KT0=Cfi0040=Cfi0030000003oool0oooo0<X0oooo003B0?ooo`030000
000XN>@0:7ST0080:7ST0`0000060:gDm0L000001@3Mh]T00`000000elg@0=O=d0030=O=d0030000
003=^lT0cK_900<0cK_900D000000<:]a@32[LD0`Zg5000000050;NRa0030000002ZVL@0ZYW40080
ZYW400<0000009b@a`2LT<L00P2LT<L00`000000RhW<08^9c00208^9c0030000001cPm@0Lh?D00<0
Lh?D00@00000059lgP1BO=h000003@2A^O800`000000e?KT0=Cfi0030=Cfi0800000G@3oool01@00
000002Nb0000000eDl<000000080JVZo00D0000008Ui^P29NKX0RGVj0000000309n5]`030000002a
TKH00000008000000P30W[H01@000000cjjh0<n^^03?[[P000000080g/:l00@000000>cM`P3/gL80
00000P3/nL000`000000oooo0?ooo`1P0?ooo`030000000XN>@0:7ST0080:7ST0`0000060:gDm0L0
00001@3Mh]T00`000000elg@0=O=d0030=O=d0030000003=^lT0cK_900<0cK_900D000000<:]a@32
[LD0`Zg5000000050;NRa0030000002ZVL@0ZYW40080ZYW400<0000009b@a`2LT<L00P2LT<L00`00
0000RhW<08^9c00208^9c0030000001cPm@0Lh?D00<0Lh?D00@00000059lgP1BO=h000003@2A^O80
0`000000e?KT0=Cfi0030=Cfi0800000c03oool00=80oooo00<0000002Qhi00XN>@0100XN>@70000
00H0/=3`00<000000=gRf@3Mh]T00P3Mh]T00`000000elg@0=O=d0030=O=d0030000003=^lT0cK_9
00@0cK_900D000000<:]a@32[LD0`Zg5000000050;NRa0030000002ZVL@0ZYW40080ZYW400<00000
09b@a`2LT<L00`2LT<L00`000000RhW<08^9c00208^9c0030000001cPm@0Lh?D00@0Lh?D00<0DWcN
0000002A^O80302A^O8010000000e?KT0=Cfi03Dm^@3000005l0oooo00D00000000W/P000000=E?3
0000000206YZ_`0300000029NKX0RGVj00H0000000<0[K7J0000002e^=/0100000001@3?[[P00000
0=k2_03N`[`000000080k=g200@000000>ci`03/nL000000H`3oool00`000000:7ST02Qhi00402Qh
i0L000001P2`d?000`000000gN;I0=gRf@020=gRf@030000003GcM00elg@00<0elg@00<000000<fk
b@3=^lT0103=^lT01@000000`Zg50<:]a@32[LD0000000D0]j;400<000000:ZIa02ZVL@00P2ZVL@0
0`000000W93709b@a`0309b@a`030000002;RL`0RhW<0080RhW<00<0000007>3e01cPm@0101cPm@0
0`1BO=h00000096ilP0<096ilP040000003Dm^@0e?KT0=Cfi0<00000c@3oool00=<0oooo00<00000
02Qhi00XN>@00`0XN>@00`000000/=3`0;3@l00;0;3@l0040000003Mh]T0gN;I000000D0elg@00<0
00000<fkb@3=^lT0103=^lT00`000000`Zg50<:]a@020<:]a@030000002gX/@0]j;400<0]j;400<0
00000:ZIa02ZVL@00`2ZVL@00`000000W93709b@a`0209b@a`030000002;RL`0RhW<00<0RhW<00<0
000007>3e01cPm@0101cPm@4000000T0TKWb00<000000=Cfi03Dm^@00P0000000`2do=l000000?oo
o`1P0?ooo`8000000P0eDl<01`000000JVZo00000029NKX0000009ZWg`0000000P2TZm`010000000
[K7J0:fafP0000030;Fhf`040000002l`=d0000000000080g/:l00<000000>cM`P0000000P3/nL00
0`000000oooo0?ooo`1S0?ooo`030000000XN>@0:7ST00<0:7ST00<000000;3@l02`d?002`2`d?00
10000000gN;I0=gRf@0000050=O=d0030000003=^lT0cK_900@0cK_900<000000<:]a@32[LD00P32
[LD00`000000]j;40;NRa0030;NRa0030000002ZVL@0ZYW400<0ZYW400<0000009b@a`2LT<L00P2L
T<L00`000000RhW<08^9c00308^9c0030000001cPm@0Lh?D00@0Lh?D10000009096ilP030000003D
m^@0e?KT0080000000<0]?cO0000003oool0c@3oool00=<0oooo00<0000002Qhi00XN>@0100XN>@0
0`000000/=3`0;3@l00:0;3@l0030000003Mh]T0000000D0elg@00<000000<fkb@3=^lT01@3=^lT0
0`000000`Zg50<:]a@020<:]a@030000002gX/@0]j;400<0]j;400<000000:ZIa02ZVL@00`2ZVL@0
0`000000W93709b@a`0309b@a`030000002;RL`0RhW<00<0RhW<00<0000007>3e01cPm@00P1cPm@0
0`000000U[S_09Jhk`0209Jhk`H000000`2A^O8300000080]?cO00<000000?ooo`3oool0H@3oool2
0000000303EC``000000JVZo008000000`2JYml01P000000Y:_L0:B[g0000000[K7J00000080]KSK
00D000000;c0g@2l`=d000000<7:hP0200000080k=g200<000000>ci`0000000IP3oool00`000000
:7ST02Qhi00402Qhi0030000002`d?00/=3`00X0/=3`00<000000=gRf@0000001@3GcM000`000000
cK_90<fkb@050<fkb@0300000032[LD0`Zg50080`Zg500<000000;NRa02gX/@00`2gX/@00`000000
ZYW40:ZIa0030:ZIa0030000002LT<L0W93700<0W93700<0000008^9c02;RL`00`2;RL`00`000000
Lh?D07>3e00207>3e0030000002F^>l0U[S_0080U[S_1P000003096ilP<000000P2do=l00`000000
oooo0?ooo`3=0?ooo`00e03oool2000000@0:7ST00<000000;3@l02`d?002@2`d?03000000H0elg@
00<000000<fkb@3=^lT0103=^lT00`000000`Zg50<:]a@030<:]a@030000002gX/@0]j;400<0]j;4
00<000000:ZIa02ZVL@00`2ZVL@00`000000W93709b@a`0409b@a`030000002;RL`0RhW<00<0RhW<
00D0000007>3e01cPm@0Lh?D0000000:09Jhk`@00000102do=l00`000000oooo0?ooo`1Q0?ooo`04
000000009k80000003EC``80000000<0SZGU0000000000000P2JYml01@000000Y:_L0000002]/MX0
00000080]KSK00@000000;c0g@000000`L[R0`000000103/gL8000000>ci`000001X0?ooo`800000
100XN>@00`000000/=3`0;3@l0090;3@l0<000001P3GcM000`000000cK_90<fkb@040<fkb@030000
0032[LD0`Zg500<0`Zg500<000000;NRa02gX/@00`2gX/@00`000000ZYW40:ZIa0030:ZIa0030000
002LT<L0W93700@0W93700<0000008^9c02;RL`00`2;RL`01@000000Lh?D07>3e01cPm@0000000X0
U[S_100000040;Clg`030000003oool0oooo0<d0oooo003E0?ooo`<000000`0XN>@00`000000/=3`
0;3@l0040;3@l0@000000`2abnd00`000000elg@0=O=d0020=O=d0030000003=^lT0cK_900D0cK_9
00<000000<:]a@32[LD00P32[LD00`000000]j;40;NRa0050;NRa0030000002ZVL@0ZYW400<0ZYW4
00<0000009b@a`2LT<L00`2LT<L00`000000RhW<08^9c00408^9c0030000001cPm@0000000d0U[S_
00<000000;Clg`2do=l00P2do=l00`000000oooo0?ooo`1S0?ooo`05000000009k80000000000021
Y^`00P0000003P2>YND0000009ZWg`000000Y:_L0000002]/MX000000;Fhf`000000_<3M00000031
b^8000000P33e^P2000000030>ci`0000000oooo06T0oooo0`00000302Qhi0030000002`d?00/=3`
00@0/=3`100000030;7;k@030000003GcM00elg@0080elg@00<000000<fkb@3=^lT01@3=^lT00`00
0000`Zg50<:]a@020<:]a@030000002gX/@0]j;400D0]j;400<000000:ZIa02ZVL@00`2ZVL@00`00
0000W93709b@a`0309b@a`030000002;RL`0RhW<00@0RhW<00<0000007>3e00000003@2F^>l00`00
0000]?cO0;Clg`020;Clg`030000003oool0oooo0<h0oooo003G0?ooo`D000000P2`d?04000000P0
/L_]0P0000000`3GcM0000000<fkb@060<fkb@0300000032[LD0`Zg500<0`Zg500<000000;NRa02g
X/@01@2gX/@00`000000ZYW40:ZIa0030:ZIa0030000002LT<L0W93700@0W93700<0000008^9c02;
RL`0102;RL`2000000`0U[S_00<000000;Clg`2do=l00P2do=l00`000000oooo0?ooo`1U0?ooo`04
000000009k80000000000080PJK/1@000000102TZm`000000000002e^=/4000000040<?Fj0000000
00000<3Pk`800000K@3oool500000080/=3`100000080;7;k@80000000<0elg@0000003=^lT01P3=
^lT00`000000`Zg50<:]a@030<:]a@030000002gX/@0]j;400D0]j;400<000000:ZIa02ZVL@00`2Z
VL@00`000000W93709b@a`0409b@a`030000002;RL`0RhW<00@0RhW<0P00000<09Jhk`030000002d
o=l0]?cO0080]?cO00<000000?ooo`3oool0c`3oool00=P0oooo00<00000001Td000I=000`00000>
0;7;k@8000001`3=^lT00`000000`Zg50<:]a@030<:]a@030000002gX/@0]j;400D0]j;400<00000
0:ZIa02ZVL@0102ZVL@00`000000W93709b@a`0409b@a`040000002;RL`0RhW<08^9c08000000P2L
^>`3000000T0U[S_00<000000;Clg`2do=l00P00001Y0?ooo`80000000<0LJSc0000000000003P00
00001030h>l0000000000000001_0?ooo`0300000000I=0006C@00<000003P2abnd2000000L0cK_9
00<000000<:]a@32[LD00`32[LD00`000000]j;40;NRa0050;NRa0030000002ZVL@0ZYW400@0ZYW4
00<0000009b@a`2LT<L0102LT<L010000000RhW<08^9c02;RL`200000080W;S/0`00000909Jhk`03
0000002do=l0]?cO00800000dP3oool00=X0oooo00@00000001Td000I=000000302abnd200000080
/LKZ0P0000040<fkb@0300000032[LD0`Zg500@0`Zg500<000000;NRa02gX/@01@2gX/@00`000000
ZYW40:ZIa0040:ZIa0030000002LT<L0W93700@0W93700@0000008^9c000000000001`2L^>`20000
00H0U[S_00<000000;Clg`0000000P00001[0?oooaD00000LP3oool01000000006C@001Td000000<
0;7;k@8000000P2aa^X2000000@0cK_900<000000<:]a@32[LD01032[LD00`000000]j;40;NRa005
0;NRa0030000002ZVL@0ZYW400@0ZYW400<0000009b@a`2LT<L0102LT<L010000000RhW<00000000
000709bhk08000001P2F^>l00`000000]?cO0000000200000=<0oooo003K0?ooo`80000000<006C@
0000002abnd02@2abnd00`000000/LKZ0;76jP040;76jP8000000P3=^lT00`000000`Zg50<:]a@04
0<:]a@030000002gX/@0]j;400D0]j;400<000000:ZIa02ZVL@0102ZVL@00`000000W93709b@a`04
09b@a`8000002`2L^>`300000080U[S_1000001^0?ooo`l000000`2Rj_X00`000000oooo0?ooo`1b
0?ooo`80000000<006C@0000002abnd02@2abnd00`000000/LKZ0;76jP040;76jP8000000P3=^lT0
0`000000`Zg50<:]a@040<:]a@030000002gX/@0]j;400D0]j;400<000000:ZIa02ZVL@0102ZVL@0
0`000000W93709b@a`0409b@a`8000002`2L^>`300000080U[S_1000003E0?ooo`00g@3oool01000
000006C@0000000000060;7;k@8000002@2aa^X3000000D0`Zg500<000000;NRa02gX/@01P2gX/@0
0`000000ZYW40:ZIa0050:ZIa080W937100000020:6hj@030000002L^>`0W;S/00/0W;S/1000001c
0?ooo`@0000000<0C[[i0000000000000`0000000`27hoX0000000000002000007L0oooo00@00000
001Td000000000001P2abnd2000000T0/LKZ0`0000050<:]a@030000002gX/@0]j;400H0]j;400<0
00000:ZIa02ZVL@01@2ZVL@209b@a`@000000P2Q^>T00`000000W;S/09bhk00;09bhk0@00000e`3o
ool00=h0oooo0P0000000`00I=0000000;7;k@030;7;k@030000002aa^X0/LKZ00T0/LKZ00<00000
0:k2j02^`^P0100000000`32[LD000000;NRa0070;NRa0040000002ZVL@0ZYW40:ZIa0H000001`2Q
^>T2000000X0W;S/1000001g0?ooo`X00000NP3oool200000003001Td0000000/L_]00<0/L_]00<0
00000;76jP2aa^X02@2aa^X00`000000[/;X0:k2j004000000030<:]a@000000]j;400L0]j;400@0
00000:ZIa02ZVL@0ZYW41P0000070:6hj@8000002P2L^>`400000=P0oooo003P0?ooo`<0000000<0
/L_]0000000000002`2aa^X00`000000[/;X0:k2j0050:k2j0h000001@2V^nP00`000000XKSY0:6h
j@070:6hj@030000002L^>`0W;S/00D0W;S/1000003o0?ooo`<0000000<0/L_]0000000000002`2a
a^X00`000000[/;X0:k2j0050:k2j0h000001@2V^nP00`000000XKSY0:6hj@070:6hj@030000002L
^>`0W;S/00D0W;S/1000003J0?ooo`00hP3oool3000000X0/LKZ0P0000090:k2j0030000002[_^L0
ZkkW00H0ZkkW00<000000:Jkj02V^nP01P2V^nP00`000000XKSY0:6hj@080:6hj@030000002L^>`0
W;S/00<0W;S/0`00003o0?ooo`@0oooo0`00000:0;76jP8000002@2^`^P00`000000ZkkW0:^ni`06
0:^ni`030000002V^nP0Y[_X00H0Y[_X00<000000:6hj@2Q^>T0202Q^>T00`000000W;S/09bhk003
09bhk0<00000g03oool00>D0oooo0`0000060;76jP030000002^`^P0[/;X00P0[/;X00<000000:^n
i`2[_^L01`2[_^L00`000000Y[_X0:Jkj0070:Jkj0030000002Q^>T0XKSY00P0XKSY0P000000102L
^>`0000000000000003o0?ooo`T0oooo0`0000060;76jP030000002^`^P0[/;X00P0[/;X00<00000
0:^ni`2[_^L01`2[_^L00`000000Y[_X0:Jkj0070:Jkj0030000002Q^>T0XKSY00P0XKSY0P000000
102L^>`0000000000000003N0?ooo`00i`3oool400000080/LKZ00<000000:k2j02^`^P02@2^`^P0
0`000000ZkkW0:^ni`070:^ni`030000002V^nP0Y[_X00L0Y[_X00<000000:6hj@2Q^>T02@2Q^>T3
00000?l0oooo3@3oool400000080/LKZ00<000000:k2j02^`^P02@2^`^P00`000000ZkkW0:^ni`07
0:^ni`030000002V^nP0Y[_X00L0Y[_X00<000000:6hj@2Q^>T02@2Q^>T300000>00oooo003Z0?oo
o`@000002`2^`^P00`000000ZkkW0:^ni`080:^ni`030000002V^nP0Y[_X00L0Y[_X00<000000:6h
j@2Q^>T0102Q^>T400000?l0oooo4`3oool4000000/0[/;X00<000000:^ni`2[_^L0202[_^L00`00
0000Y[_X0:Jkj0070:Jkj0030000002Q^>T0XKSY00@0XKSY1000003S0?ooo`00kP3oool4000000L0
[/;X00<000000:^ni`2[_^L0202[_^L00`000000Y[_X0:Jkj0070:Jkj0030000002Q^>T0XKSY00@0
0000o`3ooolK0?ooo`@000001`2^`^P00`000000ZkkW0:^ni`080:^ni`030000002V^nP0Y[_X00L0
Y[_X00<000000:6hj@2Q^>T01000003W0?ooo`00lP3oool400000080[/;X00<000000:^ni`2[_^L0
2@2[_^L00`000000Y[_X0:Jkj0030:Jkj0L00000o`3ooolS0?ooo`@000000P2^`^P00`000000ZkkW
0:^ni`090:^ni`030000002V^nP0Y[_X00<0Y[_X1`00003[0?ooo`00mP3ooolD00000?l0oooo;P3o
oolD00000?80oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0
ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03o
ool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0
oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo
0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00
o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom0
0?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0oooo
o`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?oo
ool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo
003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oo
od00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3o
oooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0
ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03o
ool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0
oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo
0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00
o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom0
0?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0oooo
o`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?oo
ool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo
003i0?ooo`X00000o`3ooooo0?oooc`0oooo003f0?oooa800000o`3ooooo0?ooocL0oooo003c0?oo
o`@0000000<0HP0[0000002@9cT01P2@9cT010000000/40e0;10=@2`@3D600000?l0ooooo`3ooole
0?ooo`00l@3oool3000000@0HP0[00<00000090W>@2@9cT01@2@9cT00`000000/40e0;10=@050;10
=@0400000037CA/0000000000?l0ooooo`3ooolc0?ooo`00k`3oool3000000D0HP0[00<00000090W
>@2@9cT01`2@9cT00`000000/40e0;10=@050;10=@0300000037CA/0addK00800000o`3ooooo0?oo
oc40oooo003]0?ooo`<000001P1R02/>000000D0/40e00<000000<M=6`37CA/00P37CA/200000?l0
ooooo`3oool_0?ooo`00j`3oool2000000803`0000<000000680:`1R02/0100000000`29AgT00000
0:MPO0080:MPO0030000002oM7/0_gAk00@000000P2`@3D00`000000addK0<M=6`030<M=6`030000
003oool0oooo0?l0ooooo`3oool/0?ooo`00jP3oool0100000003`0000l0000?0004000000D0RDMi
00<000000:MPO02WH7`01`2WH7`00`000000_gAk0;mdN`040;mdN`@000001037CA/200000?l0oooo
o`3oool]0?ooo`00j@3oool0100000003`0000l0000?0002000000P0RDMi00<000000:MPO02WH7`0
1`2WH7`00`000000_gAk0;mdN`060;mdN`040000003GQg@00000000000<0addK0P00003o0?ooool0
oooo;03oool00>P0oooo0P000000100?0000000000000000000908U7N@030000002WH7`0Yf1l00L0
Yf1l00<000000;mdN`2oM7/01P2oM7/010000000ehMd0=N7M03GQg@4000000030<=400000000oooo
0?l0ooooo`3ooolZ0?ooo`00j03oool00`0000003`000000000205/RK@0300000029AgT0RDMi00H0
RDMi00<000000:MPO02WH7`0202WH7`00`000000_gAk0;mdN`060;mdN`030000003GQg@0ehMd00@0
ehMd0P0000000`33A00000000?ooo`3o0?ooool0oooo:@3oool00>L0oooo00<0000000l000000000
0`1K8Vd00`000000RDMi08U7N@0608U7N@030000002WH7`0Yf1l00P0Yf1l00<000000;mdN`2oM7/0
1`2oM7/00`000000ehMd0=N7M0040=N7M080000000<0`d@00000003oool0o`3ooooo0?ooobP0oooo
003V0?ooo`<00000101K8Vd00`000000RDMi08U7N@0608U7N@030000002WH7`0Yf1l00<0Yf1l2000
00070;mdN`030000003GQg@0ehMd00@0ehMd00D000000>nJH@000000`d@00000003o0?ooool0oooo
:03oool00>D0oooo0P00000605/RK@0300000029AgT0RDMi00@0RDMi200000050:ikW00300000031
S9`0`HbL00D000000P2oM7/00`000000ehMd0=N7M0040=N7M0030000003_VV40kiYQ00800000o`3o
oooo0?ooobP0oooo003U0?ooo`8000001P1K8Vd00`000000RDMi08U7N@0400000080V6^L00<00000
0:ikW02^Ni`0202^Ni`00`000000`HbL0<6<W0050<6<W0<000001P3GQg@00`000000kiYQ0>nJH@02
0>nJH@030000003oool0oooo0?l0ooooo`3ooolU0?ooo`00i03oool00`000000001:0000000605/R
K@<000001P2HJi`00`000000[W^L0:ikW0080:ikW00300000031S9`0`HbL00L0`HbL0`0000050=N7
M0030000003_VV40kiYQ0080kiYQ00<000000?ooo`3oool0o`3ooooo0?ooob@0oooo003S0?ooo`80
000000<0001:0000001K8Vd00`1K8Vd3000000P0V6^L00<000000:ikW02^Ni`0202^Ni`00`000000
`HbL0<6<W0070<6<W0030000003DWI`0e9fL008000000`3GQg@00`000000kiYQ0>nJH@020>nJH@03
0000003oool0oooo0?l0ooooo`3ooolT0?ooo`00h`3oool00`000000001:0000000305/RK@800000
0P1jEY/00`000000V6^L09Q[W00609Q[W0030000002^Ni`0[W^L00P0[W^L00<000000<6<W031S9`0
1`31S9`00`000000e9fL0=BMW0020=BMW080000000<0ehMd0000003_VV400`3_VV4200000?l0oooo
o`3ooolU0?ooo`00hP3oool010000000001:0000BP00000205/RK@030000001jEY/0NUJK0080NUJK
00<0000009Q[W02HJi`01`2HJi`00`000000[W^L0:ikW0060:ikW00300000031S9`0`HbL00P0`HbL
00<000000=BMW03DWI`0103DWI`2000000@0kiYQ0P00003o0?ooool0oooo9@3oool00>80oooo00<0
00000000BP0004X00`00000507YFV`030000002HJi`0V6^L00L0V6^L00<000000:ikW02^Ni`01P2^
Ni`00`000000`HbL0<6<W0070<6<W0030000003DWI`0e9fL00H0e9fL0P0000030>nJH@030000003/
WB<000000?l0ooooo`3ooolT0?ooo`00hP3oool010000000001:0000BP00000707YFV`030000002H
Ji`0V6^L00L0V6^L00<000000:ikW02^Ni`01P2^Ni`00`000000`HbL0<6<W0070<6<W0030000003D
WI`0e9fL00H0e9fL00<000000>ZdVP0000000`3_VV4200000?l0ooooo`3ooolT0?ooo`00G@3oool;
000007X0oooo00@000000000BP0000000000201jEY/00`000000V6^L09Q[W00609Q[W0030000002^
Ni`0[W^L00H0[W^L00<000000<6<W031S9`01`31S9`00`000000e9fL0=BMW0060=BMW0030000003Z
]9X0j[BJ0080000000@0kiYQ0000003/WB<00000P@3oool;00000?l0ooooUP3oool005@0oooo4`00
00000`1^000000000000000500000780oooo0P0000000`0004X000000000000807YFV`030000002H
Ji`0V6^L00D0V6^L3`0000050<6<W0030000003DWI`0e9fL00H0e9fL00<000000>ZdVP3Z]9X00P3Z
]9X2000000030>bM8`000000oooo07P0oooo1`0000000`1;000000000000000A00000?l0ooooSP3o
ool00540oooo2`00000809DbAP030000002eBd<0]D]300D000000`1^0004000006h0oooo00<00000
0000BP0000000P18=9L00`000000NUJK07YFV`0507YFV`030000002HJi`0V6^L0080V6^L0`000000
0`2PP[8000000;6>/@070;6>/@0300000030V[80`9Zb0080`9Zb1P0000070=BMW0030000003Z]9X0
j[BJ00@0j[BJ00<000000>bM8`000000MP3oool;000000P0UC9600<000000;E;@`2eBd<01@000003
06h000@00000o`3ooon:0?ooo`00C@3oool50000000306P;>P000000UC9600l0UC9600<000000;E;
@`2eBd<01@2eBd<60000000306h000000000000006`0oooo0P00000304PdU`030000001jEY/0NUJK
00D0NUJK00<0000009Q[W00000000P0000040:22/P030000002aS[40/Hja00H0/Hja00<000000<2J
/P30V[801`30V[83000000D0e9fL00<000000>ZdVP3Z]9X0103Z]9X00`000000k9dS0000001b0?oo
o`D0000000<0J0/j0000002E<TH03`2E<TH00`000000]D]30;E;@`050;E;@`H0000000<0KP000000
00000000o`3ooon80?ooo`00BP3oool5000000@0J0/j00<0000009DbAP2E<TH03P2E<TH00`000000
]D]30;E;@`0;0;E;@`D00000JP3oool2000000<0B3BG00<0000007YFV`1jEY/01@1jEY/2000000L0
X8:b00<000000;6>/@2aS[401P2aS[400`000000`9Zb0<2J/P070<2J/P030000003?Z[<0cjZc0080
00000`3DWI`00`000000j[BJ0>ZdVP040>ZdVP<00000K`3oool5000000@0J0/j00<0000009DbAP2E
<TH03P2E<TH00`000000]D]30;E;@`0;0;E;@`D00000o`3ooon60?ooo`00B03oool4000000H0J0/j
00<0000009DbAP2E<TH03`2E<TH00`000000]D]30;E;@`0=0;E;@`030000003>Fb`0000000800000
J03oool00`000000B3BG04PdU`0204PdU`030000001jEY/0NUJK00<0NUJK0`0000080:22/P030000
002aS[40/Hja00H0/Hja00<000000<2J/P30V[801P30V[800`000000cjZc0<nZ/`030<nZ/`800000
00<0e9fL0000003Z]9X0103Z]9X01@000000o]2?0000003/WB<0000006/0oooo1@00000606P;>P03
0000002E<TH0UC9600l0UC9600<000000;E;@`2eBd<03@2eBd<00`000000cU//0000000200000?l0
ooooQ03oool004H0oooo1000000806P;>P030000002E<TH0UC9600H0UC963000000>0;E;@`030000
003>Fb`0cU//00<00000IP3oool00`000000B3BG04PdU`0304PdU`030000001jEY/0NUJK00800000
0`2;MKD00`000000X8:b0:22/P050:22/P030000002aS[40/Hja00H0/Hja00<000000<2J/P30V[80
1P30V[800`000000cjZc0<nZ/`050<nZ/`8000001@3Z]9X00`000000o]2?0?k@S`02000006T0oooo
1000000906P;>P030000002E<TH0UC9600H0UC963000000>0;E;@`030000003>Fb`0cU//00<00000
o`3ooon20?ooo`00A03oool3000000T0J0/j2`0000090:QTP@0300000031N800`GR000H00000202e
Bd<00`000000cU//0<iK;0020<iK;0<00000I03oool00`000000B3BG04PdU`0304PdU`<000001@2;
MKD00`000000X8:b0:22/P060:22/P030000002aS[40/Hja00D0/Hja00<000000<2J/P30V[801P30
V[800`000000cjZc0<nZ/`060<nZ/`800000103Z]9X00`000000o]2?0?k@S`02000006P0oooo0P00
000:06P;>P/000002@2XI8400`000000`GR00<5hP006000000P0]D]300<000000<iK;03>Fb`00P3>
Fb`300000?l0ooooP03oool004<0oooo0P00000706P;>P@000000P29Bgd00`000000Z6B10:QTP@0?
0:QTP@0300000031N800`GR000H0`GR01P0000030;E;@`030000003>Fb`0cU//00<0cU//0P00001R
0?ooo`<000001018=9L00`000000RgFe08]e]@0508]e]@030000002PP[80X8:b00H0X8:b00<00000
0;6>/@2aS[401@2aS[400`000000`9Zb0<2J/P060<2J/P030000003?Z[<0cjZc00D0cjZc00<00000
0=jm]`3N_KL00P0000020>ZdVP050000003nd8l0o]2?0?k@S`000000IP3oool00`0000005`0C0000
000706P;>P@000000P29Bgd00`000000Z6B10:QTP@0?0:QTP@0300000031N800`GR000H0`GR01P00
00030;E;@`030000003>Fb`0cU//00<0cU//0P00003o0?ooogl0oooo00110?ooo`80000000<05`0C
0000001X2cX00P1X2cX4000000H0RD]m00<000000:QTP@2XI8403`2XI8400`000000`GR00<5hP00<
0<5hP0D000001P3>Fb`200000600oooo00<000000000O@0000000`18=9L00`000000KFJj00000006
08]e]@030000002PP[80X8:b00H0X8:b00<000000;6>/@2aS[401@2aS[400`000000`9Zb0<2J/P06
0<2J/P030000003?Z[<0cjZc00D0cjZc00<000000=jm]`3N_KL00P3N_KL2000000@0o]2?00<00000
0?ooo`3oool0H`3oool00`0000005`0C0000000406P;>P@000001P29Bgd00`000000Z6B10:QTP@0?
0:QTP@0300000031N800`GR000`0`GR01@0000060<iK;0800000o`3ooomm0?ooo`00?`3oool20000
00805`0C1@00000:08U;O@030000002XI840Z6B100l0Z6B100<000000<5hP031N8003`31N8001000
0000fXaj0000000000060<iK;0800000GP3oool00`000000001m0000000204PdU`040000001]I[X0
KFJj000000L0RgFe00<000000:22/P2PP[801@2PP[800`000000/Hja0;6>/@050;6>/@0300000030
V[80`9Zb00D0`9Zb00<000000<nZ/`3?Z[<01@3?Z[<00`000000g[fg0=jm]`040=jm]`030000003n
d8l0o]2?0080o]2?00<000000?ooo`3oool0H@3oool2000000805`0C1@00000:08U;O@030000002X
I840Z6B100l0Z6B100<000000<5hP031N8003`31N80010000000fXaj0000000000060<iK;0800000
o`3ooomk0?ooo`00?P3oool0100000005`0C01L04`0G01<2000000h0RD]m00<000000:QTP@2XI840
3`2XI8400`000000`GR00<5hP00?0<5hP0040000003JS7X0fXaj0=Z<NP8000001P3>Fb`00`000000
oooo0?ooo`1K0?ooo`030000000007d000000080B3BG00D0000006eV^P1]I[X0KFJj0000000608]e
]@030000002PP[80X8:b00D0X8:b00@000000;6>/@2aS[40/Hja200000040<2J/P030000003?Z[<0
cjZc00D0cjZc00<000000=jm]`3N_KL0103N_KL010000000o]2?0?k@S`3nd8l200000640oooo0P00
000301L04`8000003P29Bgd00`000000Z6B10:QTP@0?0:QTP@0300000031N800`GR000l0`GR000@0
00000=Z<NP3JS7X0fXaj0P0000060<iK;0030000003oool0oooo0?l0ooooN03oool003`0oooo0P00
000201L04`<000003`29Bgd00`000000Z6B10:QTP@060:QTP@`000003`31N8000`000000fXaj0=Z<
NP030=Z<NP<000000`3>Fb`2000005`0oooo00<000000000O@0007d00P00000406eV^P030000002;
MKD0RgFe00@0RgFe00<000000:22/P2PP[80102PP[85000000@0/Ig300@000000;bW``2lYl<0_:O3
1@0000060<nZ/`030000003N_KL0g[fg00@0g[fg00<000000>gG_00000000P3nd8l200000600oooo
00@0000001L04`0G01<05`0C0`00000?08U;O@030000002XI840Z6B100H0Z6B13000000?0<5hP003
0000003JS7X0fXaj00<0fXaj0`0000030<iK;0800000o`3ooomi0?ooo`00>P3oool2000000<05`0C
00@0000005TTLP1I978000003P29Bgd:000000T0[WjP00<000000<:?X032Sj001P0000090<5hP003
0000003JS7X0fXaj00H0fXaj0P0000020<iK;0800000F`3oool010000000001m0000O@00000606eV
^P030000002;MKD0RgFe00@0RgFe00<000000:22/P0000000`0000000`2UU<D000000;6M``060;6M
``030000002lYl<0_:O300D0_:O30`0000040<nZ/`030000003N_KL0g[fg00@0g[fg00<000000>gG
_00000000P3nd8l2000005h0oooo0P00000301L04`040000001I9780FBAb000000h0RD]m2P000009
0:inX00300000032Sj00`XnP00H000002@31N8000`000000fXaj0=Z<NP060=Z<NP8000000P3>Fb`2
00000?l0ooooN03oool003T0oooo00@0000001L04`0G01<05`0C0P00000305TTLP0300000029Bgd0
RD]m00T0RD]m0`0000000`2GKJ0000000:inX00@0:inX00300000032Sj00`XnP00H0`XnP1P000003
0<5hP0030000003JS7X0fXaj00P0fXaj0`0000000`3?E`0000000000001J0?ooo`040000000007d0
0000000000D0KFJj00<0000008]e]@2;MKD0102;MKD2000000D0YIC500<000000;6M``2aWL<01@2a
WL<00`000000_:O30;bW``040;bW``0400000037//H0ak;60<NbaP80000000<0cjZc0000003N_KL0
1@3N_KL01P000000kMNl0>gG_03]ek`000000?k@S`800000G@3oool0100000005`0C01L04`0G01<2
000000<0FBAb00<0000008U;O@29Bgd02@29Bgd30000000309M]X0000000[WjP0100[WjP00<00000
0<:?X032Sj001P32Sj06000000<0`GR000<000000=Z<NP3JS7X0203JS7X3000000030<mG00000000
00000?l0ooooMP3oool003P0oooo00D0000001L04`0G01<05`0C0000000505TTLP0300000029Bgd0
RD]m00D0RD]m1000000409M]X0030000002^OZ00[WjP00l0[WjP00<000000<:?X032Sj003032Sj04
000000`0fXaj0P0000020<mG00030000003oool0oooo05L0oooo00@000000000O@00000000001P1]
I[X010000000RgFe08]e]@2;MKD20000000309J>b0000000YIC500D0YIC500<000000;6M``2aWL<0
102aWL<00`000000_:O30;bW``040;bW``0300000037//H0ak;600<0ak;60P0000060=jm]`040000
003]ek`0kMNl0>gG_080000000<0gm9H0000003oool0F`3oool01@0000005`0C01L04`0G01<00000
00D0FBAb00<0000008U;O@29Bgd01@29Bgd4000000@0UffP00<000000:inX02^OZ003`2^OZ000`00
0000`XnP0<:?X00<0<:?X0@00000303JS7X200000080ceL000<000000?ooo`3oool0o`3ooomc0?oo
o`00>03oool0100000005`0C00000000000605TTLP0300000029Bgd0RD]m0080RD]m0`00000809M]
X0030000002^OZ00[WjP00l0[WjP00<000000<:?X032Sj003`32Sj03000000/0fXaj0P0000020<mG
00030000003oool0oooo05H0oooo00D000000000O@000000>U2n0000000506eV^P040000002;MKD0
0000000000<0UXk800<000000:FDa@2UU<D0102UU<D00`000000/Ig30;6M``040;6M``030000002l
Yl<0_:O300<0_:O300<000000<NbaP37//H01037//H00`000000dL7;000000040=jm]`030000003]
ek`0kMNl00<0kMNl00<000000=oBF0000000G03oool0100000005`0C00000000000605TTLP030000
0029Bgd0RD]m0080RD]m0`00000809M]X0030000002^OZ00[WjP00l0[WjP00<000000<:?X032Sj00
3`32Sj03000000/0fXaj0P0000020<mG00030000003oool0oooo0?l0ooooLP3oool003L0oooo00<0
000001L04`000000201I97800`000000RD]m00000002000000/0UffP00<000000:inX02^OZ003`2^
OZ000`000000`XnP0<:?X00?0<:?X0030000003FXZ00eZ:P008000002@3JS7X00`000000lZ9V0000
00020<mG00030000003oool0oooo05D0oooo0P00000203Y@_P030000001]I[X0KFJj00@0KFJj00<0
000009J>b02FS/P0102FS/P00`000000YIC50:FDa@030:FDa@030000002aWL<0/Ig300<0/Ig300<0
00000;bW``2lYl<0102lYl<00`000000ak;60<NbaP040<NbaP030000003A`L/0dL7;008000000P3N
_KL00`000000kMNl0>gG_0020>gG_0<00000G03oool00`0000005`0C0000000805TTLP0300000029
Bgd00000008000002`2GKJ000`000000[WjP0:inX00?0:inX00300000032Sj00`XnP00l0`XnP00<0
00000=JRX03FXZ000P0000090=Z<NP030000003bXVH000000080ceL000<000000?ooo`3oool0o`3o
ooma0?ooo`00=P3oool3000000T0FBAb0P00000?09M]X0030000002^OZ00[WjP00h0[WjP00<00000
0<:?X032Sj003`32Sj000`000000eZ:P0=JRX0020=JRX08000001`3JS7X010000000lZ9V0?:RIP00
00020<mG00030000003oool0oooo05D0oooo00D0000003Y@_P0jD;h0>U2n0000000406eV^P030000
0024R<l0000000D0UXk800<000000:FDa@2UU<D00`2UU<D00`000000/Ig30;6M``030;6M``030000
002lYl<0_:O300@0_:O300<000000<NbaP37//H00`37//H00`000000dL7;0=71b`030=71b`800000
1@3]ek`3000005/0oooo0`00000905TTLP8000003`2GKJ000`000000[WjP0:inX00>0:inX0030000
0032Sj00`XnP00l0`XnP00<000000=JRX03FXZ000P3FXZ02000000L0fXaj00@000000?:RIP3bXVH0
00000P3?E`000`000000oooo0?ooo`3o0?ooog00oooo000f0?ooo`030000001I9780FBAb00L0FBAb
0`00000@09M]X0030000002^OZ00[WjP00h0[WjP00<000000<:?X032Sj003`32Sj000`000000eZ:P
0=JRX0040=JRX08000001@3JS7X01`000000lZ9V0?:RIP3bXVH000000<mG00000000E`3oool00`00
0000>U2n03Y@_P0203Y@_P040000001]I[X0KFJj00000080Q8S?00<0000009J>b02FS/P0102FS/P0
0`000000YIC50:FDa@020:FDa@030000002aWL<0/Ig300<0/Ig300<000000;bW``2lYl<00`2lYl<0
0`000000ak;60<NbaP030<NbaP030000003A`L/0dL7;00D0dL7;00<000000>gG_03]ek`00P3]ek`0
10000000lOBl00000000001K0?ooo`030000001I9780FBAb00L0FBAb0`00000@09M]X0030000002^
OZ00[WjP00h0[WjP00<000000<:?X032Sj003`32Sj000`000000eZ:P0=JRX0040=JRX08000001@3J
S7X01`000000lZ9V0?:RIP3bXVH000000<mG00000000o`3ooomb0?ooo`00=@3oool2000000P0FBAb
00@0000007MGW`1gEil00000402GKJ000`000000[WjP0:inX00>0:inX00300000032Sj00`XnP00h0
`XnP00<000000=JRX03FXZ001`3FXZ02000000<0fXaj00<000000?:RIP3bXVH00P3bXVH00`000000
ceL00000001F0?ooo`8000000`0jD;h00`000000KFJj0000000408B8c`030000002FS/P0UXk800<0
UXk800<000000:FDa@2UU<D00`2UU<D00`000000/Ig30;6M``020;6M``030000002lYl<0_:O300<0
_:O300<000000<NbaP37//H00`37//H00`000000dL7;0=71b`040=71b`8000000`3]ek`00`000000
lOBl0?7d_002000005X0oooo0P00000805TTLP040000001gEil0MeNO00000100UffP00<000000:in
X02^OZ003P2^OZ000`000000`XnP0<:?X00>0<:?X0030000003FXZ00eZ:P00L0eZ:P0P0000030=Z<
NP030000003bXVH0lZ9V0080lZ9V00<000000<mG00000000o`3oooma0?ooo`00=03oool3000000H0
FBAb0P00000307MGW`030000002GKJ00UffP00h0UffP00<000000:inX02^OZ001P2^OZ0;000000h0
`XnP00<000000=JRX03FXZ002@3FXZ02000000030=Z<NP000000lZ9V00@0lZ9V0P00001G0?ooo`03
0000000jD;h0>U2n0080>U2n00<0000008B8c`24R<l01024R<l00`000000UXk809J>b00309J>b003
0000002UU<D0YIC50080YIC500<000000;6M``2aWL<01@0000020;bW``0300000037//H0ak;600<0
ak;600<000000=71b`3A`L/0103A`L/01P000000fM?C0=WCd`000000kMNl000000<0lOBl00<00000
0?ooo`3oool0F03oool3000000H0FBAb0P00000307MGW`030000002GKJ00UffP00h0UffP00<00000
0:inX02^OZ001P2^OZ0;000000h0`XnP00<000000=JRX03FXZ002@3FXZ02000000030=Z<NP000000
lZ9V00@0lZ9V0P00003o0?ooog40oooo000d0?ooo`030000000004l0000000D0FBAb00<0000007MG
W`1gEil00`1gEil00`000000UffP09M]X00<09M]X0/00000202`TKH00`000000`9nf0<2O]P060000
00P0`XnP00<000000=JRX03FXZ002`3FXZ02000000H0lZ9V0P00001F0?ooo`8000000`0jD;h20000
00H0Q8S?00<0000009J>b02FS/P00P2FS/P00`000000YIC50:FDa@0500000080[jgE00<000000;Jb
eP2f/]H00`0000040<NbaP030000003A`L/0dL7;00<0dL7;0P0000030=WCd`030000003]ek`00000
00<0lOBl00<000000?ooo`3oool0F03oool00`000000001?0000000505TTLP030000001gEil0MeNO
00<0MeNO00<0000009M]X02GKJ00302GKJ0;000000P0/96f00<000000<2O]P30WkH01P0000080<:?
X0030000003FXZ00eZ:P00/0eZ:P0P0000060?:RIP800000o`3ooom`0?ooo`00<`3oool200000003
0000C`000000FBAb0080FBAb0P00000707MGW`030000002GKJ00UffP00L0UffP1000000209n5]`03
0000002`TKH0/96f00h0/96f00<000000<2O]P30WkH01P30WkH600000080`XnP00<000000=JRX03F
XZ00303FXZ02000000H0lZ9V00<000000?ooo`3oool0E@3oool200000080>U2n00<0000006b3f000
00001@24R<l00`000000UXk809J>b00209J>b0<000000P2XZ=L00`000000[jgE0:n]e@020:n]e@03
0000002f/]H0][;F0080][;F0`0000020<NbaP030000003A`L/0dL7;0080dL7;00<000000=WCd`3I
dm<0103Idm<01@000000lOBl0?7d_03am;`0000005X0oooo0P0000000`0004l0000005TTLP0205TT
LP8000001`1gEil00`000000UffP09M]X00709M]X0@000000P2OQKL00`000000/96f0;2A]P0>0;2A
]P0300000030WkH0`9nf00H0`9nf1P0000020<:?X0030000003FXZ00eZ:P00`0eZ:P0P0000060?:R
IP030000003oool0oooo0?l0ooooKP3oool003<0oooo00@000000000C`0004l000000P1I97800`00
0000MeNO07MGW`0707MGW`030000002GKJ00UffP00<0UffP1000000609n5]`030000002`TKH0/96f
00h0/96f00<000000<2O]P30WkH03030WkH4000000d0eZ:P00@000000>bjWP00000000001@3bXVH0
0`000000oooo0?ooo`1D0?ooo`04000000009K000000000000<0K8?H00<0000008B8c`24R<l00`24
R<l010000000UXk800000000000209nUf@050000002XZ=L0Z:SG0:RXe`0000000`2_[MD01@000000
][;F0;JbeP2f/]H0000000<0_;[H0P0000040=71b`030000003Idm<0fM?C00<0fM?C0`0000020?7d
_0030000003oool0oooo05T0oooo00@000000000C`0004l000000P1I97800`000000MeNO07MGW`07
07MGW`030000002GKJ00UffP00<0UffP1000000609n5]`030000002`TKH0/96f00h0/96f00<00000
0<2O]P30WkH03030WkH4000000d0eZ:P00@000000>bjWP00000000001@3bXVH00`000000oooo0?oo
o`3o0?ooofd0oooo000b0?ooo`040000000004l0001?0000C`<000002P1gEil00`000000UffP0000
0003000000X0WhFg00<000000;2A]P2`TKH03P2`TKH00`000000`9nf0<2O]P0>0<2O]P040000003@
[kT00000000000/0eZ:P00D000000>bjWP3/^Yh0k;ZN000000040?:RIP030000003oool0oooo05D0
oooo0`00000406b3f08000001024R<l00`000000WjGI09nUf@0209nUf@050000002XZ=L0Z:SG0:RX
e`0000000`2_[MD01@000000][;F0;JbeP2f/]H0000000<0_;[H00H000000<32g000000000000=71
b`0000050=WCd`050000003Lj=d0g>SM0000003am;`00P00001J0?ooo`040000000004l0001?0000
C`<000002P1gEil00`000000UffP00000003000000X0WhFg00<000000;2A]P2`TKH03P2`TKH00`00
0000`9nf0<2O]P0>0<2O]P040000003@[kT00000000000/0eZ:P00D000000>bjWP3/^Yh0k;ZN0000
00040?:RIP030000003oool0oooo0?l0ooooK@3oool00380oooo00D000000000C`0004l0001?0000
000<07MGW`8000003P2OQKL00`000000/96f0;2A]P0>0;2A]P0300000030WkH0`9nf00h0`9nf00@0
00000=2_^@3@[kT0d:ni0P0000090=JRX0030000003/^Yh0k;ZN0080k;ZN00@000000?:RIP3bXVH0
lZ9V0P00001G0?ooo`8000001P1/PmP01P000000Q8S?08B8c`000000UjCN000000@0WjGI00@00000
0:RXe`2XZ=L000000P2_[MD01@000000][;F0;JbeP2f/]H0000000<0_;[H00<000000<32g030`]`0
0P30`]`00`000000fM?C0=WCd`030=WCd`050000003Lj=d0g>SM0000003am;`00P00001K0?ooo`05
0000000004l0001?0000C`000000301gEil2000000h0WhFg00<000000;2A]P2`TKH03P2`TKH00`00
0000`9nf0<2O]P0>0<2O]P040000003@[kT0d:ni0=2_^@8000002@3FXZ000`000000k;ZN0>bjWP02
0>bjWP040000003bXVH0lZ9V0?:RIP800000o`3ooom^0?ooo`00<@3oool010000000001?0000C`00
04l2000000X0MeNO0`00000@09n5]`030000002`TKH0/96f00d0/96f00<000000<2O]P30WkH03@30
WkH00`000000d:ni0=2_^@040=2_^@<000001@3FXZ000`000000k;ZN0>bjWP040>bjWP030000003b
XVH0lZ9V00800000E`3oool4000000D0K8?H00<0000008B8c`0000000P2GY=h200000080WjGI00L0
00000:RXe`2XZ=L0Z:SG0000002_[MD0000000<0][;F00@000000;bjf02l^]P000001030`]`00`00
0000`lcQ000000020=WCd`8000000`3Lj=d3000005/0oooo00@000000000C`0004l0001?0P00000:
07MGW`<00000402OQKL00`000000/96f0;2A]P0=0;2A]P0300000030WkH0`9nf00d0`9nf00<00000
0=2_^@3@[kT0103@[kT3000000D0eZ:P00<000000>bjWP3/^Yh0103/^Yh00`000000lZ9V0?:RIP02
00000?l0ooooKP3oool00340oooo00H000000000C`0004l0000003lcV`00000907MGW`0500000028
N;/0R7Rk08Qh^`0000003`2OQKL00`000000/96f0;2A]P0=0;2A]P0300000030WkH0`9nf00d0`9nf
00<000000=2_^@3@[kT01`3@[kT2000000<0eZ:P00<000000>bjWP3/^Yh01@3/^Yh2000000030?:R
IP000000000005L0oooo0P0000000`19O^80000006b3f00406b3f0800000102GY=h@00000080`<;L
00L000000<?<h@33c>40`lcQ0000003Idm<0000000D0g>SM0P00001L0?ooo`060000000004l0001?
0000000o<i/000002@1gEil01@000000R7Rk08Qh^`28N;/0000000l0WhFg00<000000;2A]P2`TKH0
3@2`TKH00`000000`9nf0<2O]P0=0<2O]P030000003@[kT0d:ni00L0d:ni0P0000030=JRX0030000
003/^Yh0k;ZN00D0k;ZN0P0000000`3bXVH000000000003o0?ooofd0oooo000`0?ooo`0500000000
04l0001?0000C`0000000P0o<i/00`000000MeNO07MGW`0507MGW`0300000028N;/0R7Rk0080R7Rk
00<0000009n5]`2OQKL03@2OQKL00`000000/96f0;2A]P0=0;2A]P0300000030WkH0`9nf00d0`9nf
00<000000=2_^@3@[kT02@3@[kT2000000030=JRX0000000k;ZN00P0k;ZN0`00001H0?ooo`030000
0019O^80BGkR008000000`1/PmP00`000000SJGU000000040000000304h00`000000P@TD00H0P@TD
00@000000:0R3`2P8Pl0X28?1@0000040<?<h@030000003Lj=d0g>SM0080g>SM0`00001L0?ooo`05
0000000004l0001?0000C`0000000P0o<i/00`000000MeNO07MGW`0507MGW`0300000028N;/0R7Rk
0080R7Rk00<0000009n5]`2OQKL03@2OQKL00`000000/96f0;2A]P0=0;2A]P0300000030WkH0`9nf
00d0`9nf00<000000=2_^@3@[kT02@3@[kT2000000030=JRX0000000k;ZN00P0k;ZN0`00003o0?oo
ofd0oooo000`0?ooo`040000000004l0001?000000<0?c>K00<0000007MGW`1gEil00`1gEil20000
00D0R7Rk00<0000009n5]`2OQKL03@2OQKL00`000000/96f0;2A]P050;2A]P/000003@30WkH00`00
0000d:ni0=2_^@0;0=2_^@8000002P3/^Yh00`000000jZ@W0000001H0?ooo`8000000P19O^860000
00@0CP0300<00000084950212A@01P212A@00`000000X28?0:0R3`060:0R3`<0000000@0`]GX0000
003Lj=d0g>SM0P0000000`3?n^D000000000001L0?ooo`040000000004l0001?000000<0?c>K00<0
000007MGW`1gEil00`1gEil2000000D0R7Rk00<0000009n5]`2OQKL03@2OQKL00`000000/96f0;2A
]P050;2A]P/000003@30WkH00`000000d:ni0=2_^@0;0=2_^@8000002P3/^Yh00`000000jZ@W0000
003o0?ooof`0oooo000`0?ooo`030000000004l0000000@0?c>K00<0000007MGW`1gEil00P1gEil0
0`000000R7Rk08Qh^`0608Qh^`030000002OQKL0WhFg00/0WhFg2@0000080;2Rb@030000002l[<X0
_:c:00D000001`30WkH00`000000d:ni0=2_^@0=0=2_^@8000002@3/^Yh00`000000jZ@W0000001I
0?ooo`<0000000@0BGkR00000000000000001P1>00<00`000000P@TD08495007084950030000002P
8Pl0X28?00D0X28?00<000000;4Y00000000100000030<oji@030000003oool0oooo05/0oooo00<0
00000000C`000000100o<i/00`000000MeNO07MGW`0207MGW`0300000028N;/0R7Rk00H0R7Rk00<0
000009n5]`2OQKL02`2OQKL9000000P0/:;900<000000;b/bP2l[<X01@0000070<2O]P030000003@
[kT0d:ni00d0d:ni0P0000090>bjWP030000003ZY2L000000?l0ooooK03oool00300oooo0P000005
03lcV`050000001gEil0MeNO07MGW`0000002@28N;/00`000000WhFg09n5]`0709n5]`@0000000<0
Xi[;0000002`X/T03P2`X/T00`000000_:c:0;b/bP050;b/bPD000000P30WkH00`000000d:ni0=2_
^@0<0=2_^@040000003Oa;d0glBm000000P0k;ZN0P0000000`3ZY2L000000?ooo`1G0?ooo`030000
000IMn@0000000<000001@1>00<A000000@0X28?00<000000;4Y002a:@000P0000030<oji@030000
003oool0oooo05`0oooo0P00000503lcV`050000001gEil0MeNO07MGW`0000002@28N;/00`000000
WhFg09n5]`0709n5]`@0000000<0Xi[;0000002`X/T03P2`X/T00`000000_:c:0;b/bP050;b/bPD0
00000P30WkH00`000000d:ni0=2_^@0<0=2_^@040000003Oa;d0glBm000000P0k;ZN0P0000000`3Z
Y2L000000?ooo`3o0?ooofX0oooo000_0?ooo`030000000004l0000000H0?c>K0`00000:08Qh^`03
0000002OQKL0WhFg00@0WhFg0`0000050:>Jb`030000002`X/T0/:;900d0/:;900<000000;b/bP2l
[<X02P2l[<X4000000d0d:ni00D000000=o4_@3Oa;d0glBm000000060>bjWP050000003nf9800000
0>ZT9`000000F@3oool500000080CP030`0000000`1o<F4000000:5>I`090:5>I`030000002lHfD0
_6=U0080_6=U1`0000020;4Y00<00000GP3oool00`000000001?0000000603lcV`<000002P28N;/0
0`000000WhFg09n5]`0409n5]`<000001@2SV//00`000000/:;90;2Rb@0=0;2Rb@030000002l[<X0
_:c:00X0_:c:1000000=0=2_^@050000003Oa;d0glBm0=o4_@0000001P3/^Yh01@000000o]RB0000
003ZY2L000000?l0ooooJ`3oool002l0oooo0P00000703lcV`0300000028N;/0R7Rk00/0R7Rk00<0
000009n5]`0000000`0000090:>Jb`030000002`X/T0/:;900`0/:;900<000000;b/bP2l[<X0302l
[<X010000000a[S=00000000000:0=2_^@030000003Oa;d0glBm00<0glBm0P0000040>bjWP030000
003nf980o]RB00800000F03oool8000000@0Oc5Q00<000000:5>I`2QCVL0202QCVL00`000000_6=U
0;aSI@070;aSI@050000003DMET000000000002a:@000`00001M0?ooo`8000001`0o<i/00`000000
R7Rk08Qh^`0;08Qh^`030000002OQKL0000000<000002@2SV//00`000000/:;90;2Rb@0<0;2Rb@03
0000002l[<X0_:c:00`0_:c:00@000000<Jhc@00000000002P3@[kT00`000000glBm0=o4_@030=o4
_@800000103/^Yh00`000000o]RB0?kHTP0200000?l0ooooJ`3oool002l0oooo00<0000003lcV`0o
<i/01@0o<i/00`000000IfRo0000000<08Qh^`8000003@2SV//00`000000/:;90;2Rb@0;0;2Rb@03
0000002l[<X0_:c:00`0_:c:00<000000<Jhc@36^<d00P36^<d2000000P0d:ni00<000000=o4_@3O
a;d01@3Oa;d01@000000k;ZN0>bjWP3/^Yh000000080o]RB0P00001G0?ooo`H000001`1o<F400`00
0000XDiW0:5>I`080:5>I`030000002lHfD0_6=U00L0_6=U00@000000=AeF@3DMET0e7EI1@00001L
0?ooo`030000000o<i/0?c>K00D0?c>K00<0000006MX_`0000003028N;/2000000d0Xi[;00<00000
0;2Rb@2`X/T02`2`X/T00`000000_:c:0;b/bP0<0;b/bP0300000036^<d0a[S=0080a[S=0P000008
0=2_^@030000003Oa;d0glBm00D0glBm00D000000>bjWP3/^Yh0k;ZN000000020?kHTP800000o`3o
oom[0?ooo`00;`3oool00`000000?c>K03lcV`0403lcV`040000001WJ;l0IfRo000000X0R7Rk0P00
00000`2DTll000000:>Jb`0<0:>Jb`030000002`X/T0/:;900/0/:;900<000000;b/bP2l[<X0302l
[<X00`000000a[S=0<Jhc@040<Jhc@<00000103@[kT00`000000glBm0=o4_@070=o4_@040000003/
^Yh0k;ZN00000080o]RB0P00001G0?ooo`D00000201o<F400`000000XDiW0:5>I`080:5>I`030000
002lHfD0_6=U00L0_6=U00<000000=AeF@3DMET0103DMET3000005/0oooo00<0000003lcV`0o<i/0
100o<i/010000000IfRo06MX_`00000:08Qh^`80000000<0U9??0000002SV//0302SV//00`000000
/:;90;2Rb@0;0;2Rb@030000002l[<X0_:c:00`0_:c:00<000000<Jhc@36^<d01036^<d3000000@0
d:ni00<000000=o4_@3Oa;d01`3Oa;d010000000k;ZN0>bjWP0000020?kHTP800000o`3ooom[0?oo
o`00;`3oool2000000@0?c>K00<0000006MX_`1WJ;l00P1WJ;l00`000000R7Rk08Qh^`0508Qh^`80
00000`2DTll00`000000Xi[;0:>Jb`0;0:>Jb`030000002`X/T0/:;900/0/:;900<000000;b/bP2l
[<X0302l[<X00`000000a[S=0<Jhc@070<Jhc@8000000P3@[kT00`000000glBm0=o4_@080=o4_@80
0000103nf982000005D0oooo0`0000000`180Dd0000007laH@0807laH@030000002QCVL0XDiW00P0
XDiW00<000000;aSI@2lHfD01`2lHfD00`000000e7EI0=AeF@050=AeF@<00000FP3oool2000000@0
?c>K00<0000006MX_`1WJ;l00P1WJ;l00`000000R7Rk08Qh^`0508Qh^`8000000`2DTll00`000000
Xi[;0:>Jb`0;0:>Jb`030000002`X/T0/:;900/0/:;900<000000;b/bP2l[<X02`2l[<X00`000000
a[S=0<Jhc@080<Jhc@8000000P3@[kT00`000000glBm0=o4_@080=o4_@800000103nf98200000?l0
ooooJP3oool002l0oooo0P00000403lcV`030000001WJ;l0IfRo0080IfRo00<0000008Qh^`28N;/0
1028N;/00`000000U9??09BCc`0409BCc`030000002SV//0Xi[;00/0Xi[;00<000000;2Rb@2`X/T0
2P2`X/T00`000000_:c:0;b/bP0;0;b/bP0300000036^<d0a[S=00X0a[S=0P00000<0=o4_@030000
003nf980o]RB0080o]RB0P00001D0?ooo`8000000`180Dd00`000000Oc5Q07laH@0707laH@030000
002QCVL0XDiW00P0XDiW00<000000;aSI@2lHfD0202lHfD00`000000e7EI0=AeF@040=AeF@040000
003XPCP00000000005T0oooo0P00000403lcV`030000001WJ;l0IfRo0080IfRo00<0000008Qh^`28
N;/01028N;/00`000000U9??09BCc`0409BCc`030000002SV//0Xi[;00/0Xi[;00<000000;2Rb@2`
X/T02P2`X/T00`000000_:c:0;b/bP0;0;b/bP0300000036^<d0a[S=00X0a[S=0P00000<0=o4_@03
0000003nf980o]RB0080o]RB0P00003o0?ooofX0oooo000_0?ooo`8000000`0o<i/00`000000IfRo
06MX_`0406MX_`0400000028N;/0R7Rk08Qh^`8000001`2DTll00`000000Xi[;0:>Jb`0;0:>Jb`03
0000002`X/T0/:;900@0/:;92P00000:0;b/bP0300000036^<d0a[S=00X0a[S=00<000000<o7dP00
00002P3Oa;d2000000D0o]RB00<000000?ooo`3oool0D@3oool00`000000B05=04P1C@0304P1C@03
0000001o<F40Oc5Q00L0Oc5Q00<000000:5>I`2QCVL00`2QCVL8000000P0_6=U00<000000=AeF@3D
MET01@3DMET010000000j84h00000000001H0?ooo`8000000`0o<i/00`000000IfRo06MX_`0406MX
_`0400000028N;/0R7Rk08Qh^`8000001`2DTll00`000000Xi[;0:>Jb`0;0:>Jb`030000002`X/T0
/:;900@0/:;92@00000:0;b/bP0300000036^<d0a[S=00/0a[S=00<000000<o7dP0000002P3Oa;d2
000000D0o]RB00<000000?ooo`3oool0o`3ooomX0?ooo`00;`3oool200000080?c>K00<0000006MX
_`1WJ;l01@1WJ;l010000000R7Rk00000000000:09BCc`030000002SV//0Xi[;00T0Xi[;20000006
0:fdgP040000002b^Mh0/[WN0;:igPH000000`2l[<X00`000000a[S=0<Jhc@0;0<Jhc@040000003?
am80clOB000000T0glBm00<000000>kO`P000000103nf9800`000000oooo0?ooo`1@0?ooo`800000
1@180Dd00`000000Oc5Q07laH@0507laH@P000001@2[Khh00`000000`H6=0<61S@0600000080_6=U
00<000000=AeF@3DMET01@3DMET01@000000j84h0>R1>03XPCP0000005L0oooo0P00000203lcV`03
0000001WJ;l0IfRo00D0IfRo00@0000008Qh^`00000000002P2DTll00`000000Xi[;0:>Jb`090:>J
b`P000001P2]]=h00`000000/[WN0;:igP06000000@0_:c:00<000000<Jhc@36^<d02`36^<d01000
0000clOB0<o7dP0000090=o4_@030000003^gl80000000@0o]RB00<000000?ooo`3oool0o`3ooomX
0?ooo`00;P3oool00`000000001l0000O002000000T0IfRo00<0000009BCc`2DTll02`2DTll00`00
0000Xi[;0:>Jb`040:>Jb`@0000000<0Y[3O0000002]]=h02`2]]=h00`000000/[WN0;:igP070;:i
gPD000002`36^<d00`000000clOB0<o7dP020<o7dP030000003Oa;d0glBm00D0glBm00@000000>kO
`P3^gl800000103nf9800`000000oooo0?ooo`1?0?ooo`8000001@180Dd00`000000Oc5Q07laH@06
00000080TE^<00<000000:]_SP2[Khh0202[Khh00`000000`H6=0<61S@060<61S@@000001P3DMET0
0`000000j84h0>R1>0020>R1>0030000003oool0oooo05<0oooo00<000000000O00007`00P000009
06MX_`030000002DTll0U9??00/0U9??00<000000:>Jb`2SV//0102SV//4000000030:J`g`000000
[KCN00/0[KCN00<000000;:igP2b^Mh01P2b^Mh5000000`0a[S=00<000000<o7dP3?am800P3?am80
0`000000glBm0=o4_@050=o4_@040000003^gl80k]o2000000@0o]RB00<000000?ooo`3oool0o`3o
oomX0?ooo`00;P3oool010000000001l0000O000000906MX_`0300000021SMH0000000`0U9??00<0
00000:>Jb`2SV//0100000060:J`g`030000002]]=h0[KCN00T0[KCN00<000000;:igP2b^Mh02@2b
^Mh00`000000]l3P0;O0h002000000P0a[S=00<000000<o7dP3?am80103?am82000000@0glBm00<0
00000>kO`P3^gl800P3^gl800`000000o]RB0?kHTP0200000540oooo0P00000404P1C@@00000202A
Fh`00`000000Zfn>0:]_SP080:]_SP0300000031PHd0`H6=00P0`H6=00<000000=NDR`0000000P00
00030=AeF@030000003XPCP0j84h0080j84h00<000000?ooo`3oool0D`3oool010000000001l0000
O000000906MX_`0300000021SMH0000000`0U9??00<000000:>Jb`2SV//0100000060:J`g`030000
002]]=h0[KCN00T0[KCN00<000000;:igP2b^Mh02@2b^Mh00`000000]l3P00000002000000P0a[S=
00<000000<o7dP3?am80103?am82000000@0glBm00<000000>kO`P3^gl800P3^gl800`000000o]RB
0?kHTP0200000?l0ooooJP3oool002h0oooo00<000000000O00007`00P00000806MX_`0400000021
SMH0PHgF000000`0U9??0P00000:0:J`g`030000002]]=h0[KCN00P0[KCN00<000000;:igP2b^Mh0
2P2b^Mh00`000000]l3P0;O0h0020;O0h0<000001036^<d00`000000clOB0<o7dP070<o7dP040000
003Oa;d0glBm000000D0k]o200@000000?kHTP3nf9800000D@3oool2000000<0B05=0P0000000`1/
?XL00000095KS009095KS0030000002[Khh0Zfn>00P0Zfn>00<000000<61S@31PHd02031PHd00`00
0000eiB;0=NDR`020=NDR`<0000000<0e7EI0000003XPCP00`3XPCP00`000000oooo0?ooo`1B0?oo
o`030000000007`0001l00800000201WJ;l010000000PHgF086=eP00000<09BCc`8000002P2V/=l0
0`000000[KCN0:fdgP080:fdgP030000002b^Mh0/[WN00T0/[WN00<000000;O0h02g`>000`2g`>02
000000D0a[S=00<000000<o7dP3?am801`3?am8010000000glBm0=o4_@0000050>kO`P040000003n
f980o]RB00000?l0ooooJ`3oool002h0oooo00<000000000O00007`00P00000706MX_`0300000021
SMH0PHgF0080PHgF00<0000009BCc`2DTll01`2DTll20000000309j]hP000000Y[3O00X0Y[3O00<0
00000:fdgP2]]=h01`2]]=h00`000000/[WN0;:igP090;:igP030000002g`>00]l3P00H0]l3P0P00
00020<Jhc@030000003?am80clOB00P0clOB00<000000=o4_@0000001P3^gl800`000000o]RB0000
001@0?ooo`040000000001@0000004P1C@8000000`1/?XL00`000000TE^<095KS008095KS0030000
002[Khh0Zfn>00P0Zfn>00<000000<61S@31PHd02031PHd00`000000eiB;0=NDR`050=NDR`800000
103XPCP00`000000oooo0?ooo`1B0?ooo`030000000007`0001l008000001`1WJ;l00`000000PHgF
086=eP02086=eP030000002DTll0U9??00L0U9??0P0000000`2N[N8000000:J`g`090:J`g`030000
002]]=h0[KCN00P0[KCN00<000000;:igP2b^Mh02@2b^Mh00`000000]l3P0;O0h0050;O0h0<00000
0P36^<d00`000000clOB0<o7dP080<o7dP030000003Oa;d0000000H0k]o200<000000?kHTP000000
o`3ooom[0?ooo`00;P3oool01P000000001l0000O0000000;Do3000000D0IfRo00<00000086=eP21
SMH00`21SMH00`000000U9??09BCc`0509BCc`800000102N[N800`000000Y[3O0:J`g`080:J`g`03
0000002]]=h0[KCN00L0[KCN00<000000;:igP2b^Mh02@2b^Mh00`000000]l3P0;O0h0080;O0h080
0000303?am800`000000k]o20>kO`P050>kO`P030000003nf98000000500oooo1000000506`nQ`03
0000002AFh`0TE^<00P0TE^<00<000000:]_SP2[Khh0202[Khh00`000000`H6=0<61S@080<61S@03
0000003GU8/0eiB;00H0eiB;0`0000020>R1>0800000D`3oool01P000000001l0000O0000000;Do3
000000D0IfRo00<00000086=eP21SMH00`21SMH00`000000U9??09BCc`0509BCc`800000102N[N80
0`000000Y[3O0:J`g`070:J`g`030000002]]=h0[KCN00P0[KCN00<000000;:igP2b^Mh0202b^Mh0
0`000000]l3P0;O0h0090;O0h0800000303?am800`000000k]o20>kO`P050>kO`P030000003nf980
00000?l0ooooJ`3oool002h0oooo00@000000000O00007`000000P0]Cl<01@000000IfRo06MX_`1W
J;l0000000L0PHgF00<0000009BCc`2DTll00P2DTll2000000H0WZgR00<000000:J`g`2V/=l02@2V
/=l00`000000[KCN0:fdgP020:fdgPL00000202b^Mh00`000000]l3P0;O0h0090;O0h0030000002k
an@0000000X0clOB0P0000080>kO`P800000C`3oool00`000000000D0000000706`nQ`030000002A
Fh`0TE^<00P0TE^<00<000000:]_SP2[Khh0202[Khh00`000000`H6=0<61S@080<61S@030000003G
U8/0eiB;00H0eiB;00@000000>n[PP3_Zh8000000P3XPCP00`000000oooo0?ooo`1A0?ooo`040000
000007`0001l00000080;Do300D0000006MX_`1WJ;l0IfRo00000007086=eP030000002DTll0U9??
0080U9??0P00000609j]hP030000002V/=l0Y[3O00P0Y[3O00<000000:fdgP2]]=h00P2]]=h80000
00P0/[WN00<000000;O0h02g`>002@2g`>000`000000^lOT0000000:0<o7dP800000203^gl820000
0?l0ooooJ`3oool002l0oooo0P00000402e?``040000001WJ;l0IfRo000000P0PHgF00@0000009BC
c`00000000002@2N[N800`000000Y[3O0:J`g`060:J`g`L00000102ObOH00`000000W<Ke09c6m@05
000000<0/[WN00<000000;O0h02g`>00202g`>001@000000^lOT0;_7i02kan@0000000P0clOB00@0
00000=KJfP3Ff]X000001`3^gl82000004l0oooo0`00000706`nQ`030000002AFh`0TE^<00P0TE^<
00<000000:]_SP2[Khh0202[Khh00`000000`H6=0<61S@080<61S@030000003GU8/0eiB;00H0eiB;
00L000000>n[PP3_Zh80kj^20000003XPCP0000005@0oooo0P00000402e?``040000001WJ;l0IfRo
000000P0PHgF00@0000009BCc`00000000002@2N[N800`000000Y[3O0:J`g`050:J`g`L000001@2O
bOH00`000000W<Ke09c6m@0500000080/[WN00<000000;O0h02g`>002@2g`>001@000000^lOT0;_7
i02kan@0000000P0clOB00@000000=KJfP3Ff]X000001`3^gl8200000?l0ooooJ`3oool002l0oooo
0P00000402e?``030000001WJ;l0000000X0PHgF00<0000009j]hP2N[N802P2N[N8010000000Y[3O
0:J`g`2V/=l400000080X/_e00<0000009o9mP2ObOH01P2ObOH00`000000W<Ke09c6m@0509c6m@@0
00002@2g`>000`000000^lOT0;_7i0030;_7i08000001@3?am801@000000e][J0=KJfP3Ff]X00000
00H0k]o20P00001?0?ooo`@00000201/?XL00`000000TE^<095KS007095KS0030000002[Khh0Zfn>
00P0Zfn>00<000000<61S@31PHd02031PHd00`000000eiB;0=NDR`060=NDR`030000003_Zh80kj^2
0080kj^20`00001C0?ooo`800000100]Cl<00`000000IfRo0000000:086=eP030000002N[N80WZgR
00X0WZgR00<000000:J`g`2V/=l0100000030:;;m@030000002ObOH0WlWf00H0WlWf00<0000009c6
m@2La_D01@2La_D4000000T0]l3P00<000000;_7i02kan@00`2kan@2000000D0clOB00D000000=KJ
fP3Ff]X0e][J000000060>kO`P800000o`3ooom/0?ooo`00;`3oool2000000D0;Do300<00000086=
eP21SMH02021SMH010000000UZcV00000000000;09j]hP<000001`2RboD00`000000WlWf09o9mP05
09o9mP030000002La_D0W<Ke00H0W<Ke00<0000009_4m02Ka?@00P0000060;O0h0030000002kan@0
^lOT00H0^lOT00D000000<o7dP3?am80clOB000000050=KJfP030000003^gl80k]o20080k]o200<0
00000>[j_@000000C`3oool20000000302L;M`000000K3j700L0K3j700<00000095KS02AFh`01P2A
Fh`B000000D0`H6=00<000000=NDR`3GU8/01P3GU8/00`000000kj^20>n[PP040>n[PP030000003o
ool0oooo0540oooo0P00000502e?``0300000021SMH0PHgF00P0PHgF00@0000009J/iP0000000000
2`2N[N82000000L0X/_e00<0000009o9mP2ObOH01P2ObOH00`000000W<Ke09c6m@0609c6m@030000
002Ka?@0VlCd008000001P2g`>000`000000^lOT0;_7i0060;_7i0050000003?am80clOB0<o7dP00
00001@3Ff]X00`000000k]o20>kO`P020>kO`P030000003Zn[d000000?l0ooooK03oool00300oooo
00<0000002e?``0]Cl<00`0]Cl<3000000L0PHgF00<0000009J/iP2F[>H00P2F[>H00`000000WZgR
09j]hP0609j]hP80000000<0YLcd0000002RboD01`2RboD00`000000WlWf09o9mP0509o9mP030000
002La_D0W<Ke00D0W<Ke00<0000009_4m02Ka?@00`2Ka?@300000080]l3P00<000000;_7i02kan@0
202kan@00`000000clOB000000060=KJfP030000003^gl80k]o20080k]o20`00001?0?ooo`040000
000W2gL09`]g000000P0K3j700<00000095KS02AFh`00P2AFh`40000000309]eY`000000[hBW00T0
[hBW00<000000<:CY`32TjL00`32TjL7000000L0eiB;00<000000>n[PP3_Zh80103_Zh82000005<0
oooo00<0000002e?``0]Cl<00`0]Cl<3000000L0PHgF00<0000009J/iP2F[>H00P2F[>H00`000000
WZgR09j]hP0609j]hP80000000<0YLcd0000002RboD01`2RboD00`000000WlWf09o9mP0509o9mP03
0000002La_D0W<Ke00D0W<Ke00<0000009_4m02Ka?@00`2Ka?@300000080]l3P00<000000;_7i02k
an@0202kan@00`000000clOB000000060=KJfP030000003^gl80k]o20080k]o20`00003o0?ooof`0
oooo000`0?ooo`030000000]Cl<0;Do300<0;Do300@0000006N8g`1WR=l000001P21SMH00`000000
UZcV09J/iP0309J/iP030000002N[N80WZgR00<0WZgR0P0000040:G<m08000001P2RboD;000000@0
W<Ke00<0000009_4m02Ka?@01`2Ka?@2000000`0^lOT00<000000=KJfP3Ff]X01P3Ff]X01@000000
k]o20>kO`P000000j_Zm00800000CP3oool2000000809`]g00<0000006`nQ`1/?XL01P1/?XL00`00
0000TE^<00000002000000D0VgFW00<000000:n4Y`2_Q:L0202_Q:L00`000000`Y>W0<:CY`080<:C
Y`040000003DYJP00000000000D0eiB;00<000000>n[PP3_Zh80103_Zh82000005<0oooo00<00000
02e?``0]Cl<00`0]Cl<010000000IhSO06N8g`000006086=eP030000002F[>H0UZcV00<0UZcV00<0
000009j]hP2N[N800`2N[N82000000@0YLcd0P0000060:;;m@/00000102La_D00`000000VlCd09_4
m00709_4m0800000302kan@00`000000e][J0=KJfP060=KJfP050000003^gl80k]o20000003Zn[d0
0P00003o0?ooof`0oooo000a0?ooo`030000000]Cl<0;Do30080;Do300D0000006N8g`1WR=l0IhSO
00000004086=eP030000002F[>H0UZcV00D0UZcV0P0000000`2N[N800000000000080:G<m0030000
002RboD0X/_e00<0000000<0On3i000000000000101Rc_P010000000D;kh052nn01@__P5000000L0
VlCd0P00000209[1l`030000002kan@0^lOT00H0^lOT0P0000000`2lcnT000000=KJfP070=KJfP03
0000003^gl8000000080j_Zm00<000000?ooo`3oool0C@3oool00`0000009`]g02L;M`0202L;M`03
0000001/?XL0K3j700@0K3j70`00000809]eY`030000002_Q:L0[hBW00P0[hBW00<000000<:CY`32
TjL02032TjL010000000e:FX0=BUZ03DYJP2000000<0eiB;00<000000>n[PP3_Zh80103_Zh830000
05<0oooo00<0000002e?``0]Cl<00P0]Cl<01@000000IhSO06N8g`1WR=l0000000@0PHgF00<00000
09J/iP2F[>H01@2F[>H20000000309j]hP000000000000P0YLcd00<000000:;;m@2RboD00`000000
0`1oh?T000000000000406;>n0040000001@__P0D;kh052nn0D000001`2Ka?@200000080V/7c00<0
00000;_7i02kan@01P2kan@2000000030;c?j@000000e][J00L0e][J00<000000>kO`P0000000P3Z
n[d00`000000oooo0?ooo`3o0?ooof/0oooo000a0?ooo`8000000`0]Cl<00`000000IhSO06N8g`02
06N8g`80000000<0PHgF0000002F[>H02@2F[>H2000000T0YLcd2`0000000`38WZh0000000000005
000000<0Ck7j0P00000309_4m08000001@2J`O<2000000@0^lOT0P0000040;c?j@030000003Ff]X0
e][J00H0e][J00D000000>[j_@3Zn[d0j_Zm0000001?0?ooo`030000000W2gL09`]g00809`]g00<0
000006`nQ`1/?XL00P1/?XL20000000307mSZ0000000VgFW00P0VgFW00<000000:n4Y`2_Q:L0202_
Q:L00`000000`Y>W0<:CY`080<:CY`030000003DYJP0e:FX00<0e:FX0P0000000`3GU8/000000>n[
PP050>n[PP030000003m`680000005<0oooo0P00000302e?``030000001WR=l0IhSO0080IhSO0P00
00000`21SMH0000009J/iP0909J/iP8000002@2Uc?@;000000030<RN[P000000000000D000000`1?
/OX2000000<0VlCd0P00000509[1l`800000102kan@2000000@0_<oY00<000000=KJfP3Ff]X01P3F
f]X01@000000j_Zm0>[j_@3Zn[d000000?l0ooooK@3oool00380oooo00@0000002e?``0]Cl<00000
1`1WR=l2000000T0UZcV00<000000:W;lP2Ybo80100000030:G<m0800000102PjoX4000000030>S6
/`000000000000@0000000<0NfRb0000000000002@00000909[1l`040000002kan@00000000000H0
_<oY00<000000=KJfP3Ff]X0103Ff]X300000080j_Zm0P00001>0?ooo`800000100W2gL00`000000
K3j706`nQ`02000000<0Of>X00<0000009]eY`2KMJL01`2KMJL00`000000[hBW0:n4Y`080:n4Y`03
00000032TjL0`Y>W00L0`Y>W00<000000=BUZ03DYJP01P3DYJP2000000H0kj^200@000000?g0HP00
00000000D`3oool010000000;Do302e?``00000706N8g`8000002@2F[>H00`000000ZL_b0:W;lP04
000000<0YLcd0P0000040:3[nP<0000000<0m^Be0>S6/`0000001@0000000`1kJ;80000000000009
000000T0V/7c00@000000;_7i000000000001P2lcnT00`000000e][J0=KJfP040=KJfP<000000P3Z
n[d200000?l0ooooK@3oool00380oooo0P0000000`0]Cl<0000006N8g`0606N8g`040000002=[N`0
0000000000H0UZcV00<000000:W;lP2Ybo801@2Ybo8>000000030=R`/000000000000080000000<0
UGN_0000000000001@00000405VXn0030000002J`O<0V/7c00H0V/7c0`0000090;c?j@040000003F
f]X0e][J0=KJfP8000000P3Fk^@010000000j_Zm0>[j_@00001?0?ooo`800000100W2gL3000000H0
Of>X00<0000009]eY`2KMJL01P2KMJL00`000000[hBW0:n4Y`070:n4Y`0300000032TjL0`Y>W00P0
`Y>W00<000000=BUZ03DYJP01`3DYJP2000000@0kj^200D000000?g0HP3m`680oL1R0000001C0?oo
o`80000000<0;Do30000001WR=l01P1WR=l010000000SJg/00000000000609J/iP030000002Ybo80
ZL_b00D0ZL_b2`000000103QhM<000000000003H/;040000000309Eg[`000000000000D00000101I
Z?P00`000000V/7c09[1l`0609[1l`<000002@2lcnT010000000e][J0=KJfP3Ff]X200000080e^kT
00@000000>[j_@3Zn[d00000o`3ooom^0?ooo`00<`3oool3000000L0IhSO00@0000008f]k02=[N`0
SJg/0`00000209J/iP030000002Ybo80ZL_b00H0ZL_b00<000000;W/m@2ik?D0102ik?D300000003
0>7Qd`000000f/[:0080000000D0b9j^000000000000Z8>]09Eg[`040000000304ecf00000004fGJ
00@0000000<0FJSh0000000000000P2J`O<4000000<0Vkka00<000000;c?j@2lcnT01P2lcnT01000
0000e][J0000000000030=K^i0050000003Zn[d0j_Zm0>[j_@000000C`3oool2000000@09`]g00<0
000007mSZ01oHjP01P1oHjP00`000000VgFW09]eY`0709]eY`030000002_Q:L0[hBW00H0[hBW00<0
00000<:CY`32TjL02032TjL00`000000e:FX0=BUZ0060=BUZ0040000003W_:T0ikbY000000<0kj^2
00D000000?g0HP3m`680oL1R0000001D0?ooo`<000001`1WR=l010000000SJg/08f]k02=[N`30000
0080UZcV00<000000:W;lP2Ybo801P2Ybo800`000000^Nce0;W/m@040;W/m@<0000000<0hN7C0000
003Jb/X00P0000001@38WZh000000000002XPjd0UGN_00@0000000<0CG?H0000000CIMX010000000
0`1IZ?P000000000000209[1l`@000000`2K__400`000000_<oY0;c?j@060;c?j@040000003Ff]X0
0000000000<0e^kT00D000000>[j_@3Zn[d0j_Zm0000003o0?ooofh0oooo000c0?ooo`0300000000
7Z/0000000L0IhSO00<0000008f]k02=[N`0102=[N`5000000D0ZL_b00<000000;W/m@2ik?D01@00
00001`3Mn=/000000>7Qd`000000f/[:0000003?^<@01P0000000`2LS<80000008Z4a`0200000003
04ecf0000000000000<0JZ;a1@00000709^nl@030000002lcnT0_<oY00H0_<oY0P0000050=K^i004
0000003Zn[d0j_Zm000004l0oooo00<000000000>00000000`0W2gL2000000P0Of>X00<0000009]e
Y`2KMJL01`2KMJL00`000000[hBW0:n4Y`060:n4Y`0300000032TjL0`Y>W00P0`Y>W00<000000=BU
Z03DYJP01P3DYJP010000000ikbY0>NlZ@3W_:T2000000030>n[PP000000oL1R0080oL1R00<00000
0?ooo`3oool0DP3oool00`00000001j[0000000706N8g`030000002=[N`0SJg/00@0SJg/1@000005
0:W;lP030000002ik?D0^Nce00H000000P3QhM<010000000f/[:0000003?^<@60000000309b<`P00
0000RXC70080000000<0CG?H0000000000000`1ZX_45000000L0Vkka00<000000;c?j@2lcnT01P2l
cnT2000000D0e^kT00@000000>[j_@3Zn[d00000o`3ooom_0?ooo`00=03oool01000000001j[0000
0000000406N8g`030000002=[N`0SJg/00H0SJg/00@000000:_:l02[b_00Zl[`200000040<KSk@80
000000P0hN7C0000003Jb/X0f/[:0000003?^<@000000<>Z`080000000@0ZiBo0000002LS<800000
0P2:Q<L200000080CG?H0P00000506ZRl@030000002K__40Vkka00H0Vkka00<000000;c?j@2lcnT0
0P2lcnT3000000030;[Gk`000000e^kT00@0e^kT00@000000>[j_@0000000000C`3oool00`000000
000h0000000202L;M`040000001CBJP0DdVX000000L0Of>X00<0000009]eY`2KMJL01`2KMJL00`00
0000[hBW0:n4Y`060:n4Y`0300000032TjL0`Y>W00P0`Y>W00<000000=BUZ03DYJP01P3DYJP00`00
0000ikbY0>NlZ@030>NlZ@8000000`3m`6800`000000oooo0?ooo`1C0?ooo`04000000007Z/00000
000000@0IhSO00<0000008f]k02=[N`01P2=[N`010000000Zl[`0:_:l02[b_08000000@0a^?]00@0
00000>7Qd`3QhM<000000P3Jb/X010000000ckS400000033Z/02000000040:^D_`000000W8c20000
0080RXC70P00000204ecf08000001@1ZX_400`000000Vkka09^nl@0609^nl@030000002lcnT0_<oY
0080_<oY0`0000000`2jenl000000=K^i0040=K^i0040000003Zn[d0000000000?l0ooooK`3oool0
03@0oooo00@00000000NZ`000000@H?W0P00000206N8g`030000002=[N`0SJg/00H0SJg/00<00000
0:_:l02[b_001@2[b_000`000000a^?]0<KSk@030<KSk@8000000P3QhM<01P000000f/[:0=[:bP00
0000ckS400000080`j[00P0000001`2[U;l0000009b<`P2LS<80000008Z4a`0000000P1aO<h00`1=
LmP0000007ZNj0040000000306ZRl@000000Vkka00L0Vkka00<000000;c?j@2lcnT00P0000040;[G
k`030000003Fk^@0e^kT00<0e^kT0`00001@0?ooo`050000000003P0000002L;M`0000000`1CBJP0
0`000000Of>X07mSZ00507mSZ0030000002KMJL0VgFW00L0VgFW00<000000:n4Y`2_Q:L01P2_Q:L0
0`000000`Y>W0<:CY`080<:CY`030000003DYJP0e:FX00H0e:FX00<000000>NlZ@3W_:T0103W_:T0
1@000000oL1R0?g0HP3m`680000005D0oooo00@00000000NZ`000000@H?W0P00000206N8g`030000
002=[N`0SJg/00H0SJg/00<000000:_:l02[b_001@2[b_000`000000a^?]0<KSk@030<KSk@800000
0P3QhM<01P000000f/[:0=[:bP000000ckS400000080`j[00P0000001`2[U;l0000009b<`P2LS<80
000008Z4a`0000000P1aO<h00`1=LmP0000007ZNj0040000000306ZRl@000000Vkka00L0Vkka00<0
00000;c?j@2lcnT00P0000040;[Gk`030000003Fk^@0e^kT00<0e^kT0`00003o0?ooog00oooo000e
0?ooo`03000000007Z/000000080@H?W0`00000708f]k0030000002[b_00Zl[`00H0Zl[`00<00000
0<KSk@36hnd00`0000001039en@000000>7Qd`0000020=[:bP080000003?^<@0ckS400000033Z/00
00000;NN_`0000020:^D_`030000002LS<8000000080RXC700@00000075lcP1aO<h000001@1jW^P=
000000H0^]O_00<000000=K^i03Fk^@00P3Fk^@300000540oooo00@000000000>00000000000101C
BJP00`000000Of>X07mSZ00507mSZ0030000002KMJL0VgFW00L0VgFW00<000000:n4Y`2_Q:L00P2_
Q:L7000000L0`Y>W00<000000=BUZ03DYJP01P3DYJP00`000000ikbY0>NlZ@050>NlZ@80000000<0
oL1R0000003oool0EP3oool00`00000001j[000000020463i`<000001`2=[N`00`000000Zl[`0:_:
l0060:_:l00300000036hnd0a^?]00<0000000@0bMOT0000003QhM<000000P3Jb/X020000000ckS4
0<nha0000000`j[00000002gW[l000000P2[U;l00`000000W8c20000000208Z4a`040000001aO<h0
LGc>000000D0NYkX3@0000060;[Gk`030000003Fk^@0e^kT0080e^kT0`00003o0?ooog40oooo000f
0?ooo`8000001011PnL4000000@0SJg/00<000000:_:l02[b_001@2[b_0010000000a^?]00000000
00050<WGi0040000003Jb/X0f/[:00000080ckS400H000000<>Z`033Z/0000000;NN_`0000020:^D
_`040000002LS<80W8c200000080RXC700<00000075lcP0000000P00000507ZNj0030000002L_Nl0
W;g_00H0W;g_00<000000;[Gk`2jenl0102jenl00`000000e^kT0=K^i0020=K^i0<00000DP3oool0
0`000000000h0000000505=9Z0030000001oHjP0Of>X00H0Of>X00<0000009]eY`2KMJL0102KMJL7
000000@0/IJk00<000000;nR^`2oX[/01@0000020<:CY`030000003DYJP0e:FX00H0e:FX00<00000
0>NlZ@3W_:T0103W_:T01@000000n]ZV0000003m`680000005P0oooo0P0000040463i`@00000102=
[N`00`000000Zl[`0:_:l0050:_:l00400000036hnd00000000000D0bMOT00@000000=[:bP3Jb/X0
00000P3?^<@01P000000`j[00<>Z`0000000]ijo00000080ZiBo00@0000009b<`P2LS<8000000P2:
Q<L00`000000LGc>00000002000000D0NYkX00<0000009bmk`2L_Nl01P2L_Nl00`000000^]O_0;[G
k`040;[Gk`030000003Fk^@0e^kT0080e^kT0`00003o0?ooog80oooo000g0?ooo`8000000`11PnL0
10000000QK3b08F`lP25/?8>000000D0bMOT0P0000001037b]`000000=[:bP0000020<nha0040000
0033Z/00`j[000000080]ijo00<000000:^D_`0000000`2LS<8010000000RXC708Z4a`00000308VM
h08000000`1jW^P00`000000W;g_09bmk`0609bmk`030000002jenl0^]O_00@0^]O_00<000000=K^
i03Fk^@00`0000000`2IgHH000000?ooo`1A0?ooo`030000000003P0000000H0DdVX00<0000007mS
Z01oHjP01@1oHjP00`000000VgFW09]eY`0400000080X8Zl00<000000;6F^`2aU[/01P2aU[/00`00
0000_j:k0;nR^`050;nR^`@000001`3DYJP00`000000ikbY0>NlZ@040>NlZ@030000003jfZH0n]ZV
00800000F@3oool2000000<0@H?W00@0000008F`lP25/?80QK3b3P0000050<WGi080000000@0al[L
0000003Jb/X000000P3?^<@010000000`j[00<>Z`00000020;NN_`030000002[U;l0000000<0W8c2
00@0000008Z4a`2:Q<L000000`29WN02000000<0NYkX00<0000009bmk`2L_Nl01P2L_Nl00`000000
^]O_0;[Gk`040;[Gk`030000003Fk^@0e^kT00<0000000<0VMf60000003oool0o`3oooma0?ooo`00
>03oool00`000000@H?W0463i`020463i`0300000025/?80QK3b00@0QK3b00<000000:g8kP2]b>h0
1P2]b>h010000000bMOT0<WGi039en@2000000@0al[L0P0000000`3?^<@000000<>Z`0020<>Z`006
0000002gW[l0]ijo0000002[U;l000000`2LS<8010000000RXC70000002FW]T2000000<0RIgP0P00
00000`1jW^P0000009bmk`0609bmk`030000002jenl0^]O_00D0^]O_0`0000020<;kj0800000E03o
ool3000000D0DdVX00<0000007mSZ01oHjP0101oHjP4000000H0X8Zl00<000000;6F^`2aU[/01P2a
U[/00`000000_j:k0;nR^`070;nR^`040000003=/Kh00000000000D0e:FX00<000000>NlZ@3W_:T0
0`3W_:T010000000n]ZV0?[JYP3jfZH2000005X0oooo00<000000463i`11PnL00P11PnL00`000000
QK3b08F`lP0408F`lP030000002]b>h0[LS^00H0[LS^00@000000<WGi039en@0bMOT0P0000040<O:
g080000000<0ckS400000033Z/000P33Z/001P000000]ijo0;NN_`000000ZiBo000000<0W8c200@0
000008Z4a`000000UYkI0P00000308VMh080000000<0NYkX0000002L_Nl01P2L_Nl00`000000^]O_
0;[Gk`050;[Gk`<000000P32nnP200000?l0ooooL`3oool003T0oooo00D000000463i`11PnL0@H?W
0000000708F`lP030000002]b>h0[LS^00D0[LS^00@000000<WGi000000000001@37b]`00`000000
`[oG0<:oe`03000000030<>Z`0000000]ijo0080]ijo00<000000:^D_`2[U;l00P2LS<83000000@0
UYkI00<0000008VMh029WN000P29WN05000000@0W;g_00@000000;[Gk`2jenl0^]O_1@0000030<;k
j0800000E@3oool3000000D0DdVX00<0000007mSZ01oHjP00P1oHjP20000000308ao`0000000X8Zl
00P0X8Zl00<000000;6F^`2aU[/01@2aU[/00`000000_j:k0;nR^`060;nR^`030000003=/Kh0cK6n
0080cK6n0`0000000`3DYJP000000>NlZ@050>NlZ@030000003jfZH0n]ZV0080n]ZV00<000000?oo
o`3oool0F@3oool01@000000@H?W0463i`11PnL0000000L0QK3b00<000000:g8kP2]b>h01@2]b>h0
10000000bMOT0000000000050<O:g00300000032_mL0`[oG00<0000000<0`j[00000002gW[l00P2g
W[l00`000000ZiBo0:^D_`0209b<`P<00000102FW]T00`000000RIgP08VMh00208VMh0D00000102L
_Nl010000000^]O_0;[Gk`2jenl5000000<0`__X0P00003o0?ooog@0oooo000j0?ooo`8000000P11
PnL00`000000QK3b08F`lP0408F`lP030000002]b>h0[LS^00@0[LS^0`0000050<O:g08000000`32
_mL00`000000_;GC0;bed`0:000000<0XJ7D00<0000009JNf@2FW]T00P2FW]T01@000000RIgP08VM
h029WN00000000@0Wk_]200000030;CLm00400000032nnP0`__X0<;kj0800000EP3oool010000000
01NL000GW000000505=9Z0040000001oHjP00000000000@0S7o000<000000:2:_02PR[`01P2PR[`0
0`000000/IJk0;6F^`050;6F^`030000002oX[/0_j:k00H0_j:k00<000000<fa_P3=/Kh01@3=/Kh2
000000H0ikbY00<000000?[JYP3jfZH00P3jfZH00`000000oooo0?ooo`1J0?ooo`8000000P11PnL0
0`000000QK3b08F`lP0408F`lP030000002]b>h0[LS^00@0[LS^0`0000050<O:g08000000`32_mL0
0`000000_;GC0;bed`0:000000<0XJ7D00<0000009JNf@2FW]T00P2FW]T01@000000RIgP08VMh029
WN00000000@0Wk_]200000030;CLm00400000032nnP0`__X0<;kj0800000o`3ooome0?ooo`00>`3o
ool4000000L0QK3b00<000000:g8kP0000000`0000030:g6k00500000037b]`0al[L0<O:g0000000
1@32_mL01@000000_;GC0;bed`2l]M<0000000<0]:gA00@000000:^VdP2[Y]8000001@2QXM@00`00
0000UYkI09JNf@0209JNf@80000000<0RIgP0000002O^nd01P2O^nd00`000000]=cd0;CLm0040;CL
m00400000032nnP0`__X0<;kj0800000E`3oool01000000001NL000GW000000505=9Z08000001P2<
Ol000`000000X8Zl0:2:_0060:2:_0030000002aU[/0/IJk00D0/IJk00<000000;nR^`2oX[/01P2o
X[/00`000000cK6n0<fa_P060<fa_P800000103W_:T00`000000n]ZV0?[JYP020?[JYP800000G@3o
ool4000000L0QK3b00<000000:g8kP0000000`0000030:g6k00500000037b]`0al[L0<O:g0000000
1@32_mL01@000000_;GC0;bed`2l]M<0000000<0]:gA00@000000:^VdP2[Y]8000001@2QXM@00`00
0000UYkI09JNf@0209JNf@80000000<0RIgP0000002O^nd01P2O^nd00`000000]=cd0;CLm0040;CL
m00400000032nnP0`__X0<;kj0800000o`3ooomf0?ooo`00?03oool00`0000003gWS000000090000
00P0[LK/00<000000<O:g00000001@32_mL01@000000_;GC0;bed`2l]M<0000000@0]:gA00D00000
0:^VdP2[Y]80ZjKB000000050:6Qe0030000002FW]T0UYkI0080UYkI0`00000709nkk@030000002d
g?@0]=cd00@0]=cd00D000000<;kj032nnP0`__X0000001H0?ooo`04000000005i`001NL000000@0
DdVX00<0000006mcaP0000001P2<Ol000`000000X8Zl0:2:_0060:2:_0030000002aU[/0/IJk00D0
/IJk00<000000;nR^`2oX[/01P2oX[/00`000000cK6n0<fa_P050<fa_P030000003KaL<0flG30080
00000P3W_:T00`000000n]ZV0?[JYP020?[JYP800000GP3oool00`0000003gWS00000009000000P0
[LK/00<000000<O:g00000001@32_mL01@000000_;GC0;bed`2l]M<0000000@0]:gA00D000000:^V
dP2[Y]80ZjKB000000050:6Qe0030000002FW]T0UYkI0080UYkI0`00000709nkk@030000002dg?@0
]=cd00@0]=cd00D000000<;kj032nnP0`__X0000003o0?ooogL0oooo000m0?ooo`040000000?NN<0
3gWS000000H0OKKg00<000000:g6k02]a^`01P2]a^`3000000@0`[oG00<000000;bed`2l]M<00P2l
]M<00`000000]:gA0;B]d@020;B]d@050000002[Y]80ZjKB0:^VdP0000001P2QXM@010000000UYkI
0000000000030::kj`@000000P2O^nd00`000000]=cd0;CLm0040;CLm00300000032nnP0`__X0080
0000F@3oool01@00000001NL000GW0005i`000000080DdVX00@0000006mcaP1_LlH000001`2<Ol00
0`000000X8Zl0:2:_0050:2:_0030000002aU[/0/IJk00D0/IJk00<000000;nR^`2oX[/01@2oX[/0
0`000000cK6n0<fa_P060<fa_P030000003KaL<0flG30080flG30P0000040?[JYP800000H03oool0
100000003gWS00mih`00000607ffm`030000002]a^`0[LK/00H0[LK/0`0000040<:oe`030000002l
]M<0_;GC0080_;GC00<000000;B]d@2d[M400P2d[M401@000000ZjKB0:^VdP2[Y]80000000H0XJ7D
00@0000009JNf@00000000000`2R^n/400000080Wk_]00<000000;CLm02dg?@0102dg?@00`000000
`__X0<;kj00200000?l0ooooN03oool003h0oooo00@0000000mih`0?NN<000001P1m]_L2000000@0
[LK/0P0000030:g3jP8000000P32_mL00`000000_;GC0;bed`020;bed`030000002d[M40]:gA0080
]:gA00<000000:^VdP2[Y]800P2[Y]800`000000XJ7D0:6Qe0030:6Qe08000002@2R^n/4000000@0
]=cd1@00001K0?ooo`04000000005i`001NL00000080DdVX00D0000006mcaP1_LlH0Kg?600000006
08ao`0030000002PR[`0X8Zl00D0X8Zl00<000000;6F^`2aU[/01@2aU[/00`000000_j:k0;nR^`05
0;nR^`030000003=/Kh0cK6n00D0cK6n00<000000=_5``3KaL<0103KaL<00`000000n]ZV0?[JYP02
0?[JYP800000H@3oool0100000003gWS00mih`00000607ffm`800000102]a^`2000000<0[L?Z0P00
00020<:oe`030000002l]M<0_;GC0080_;GC00<000000;B]d@2d[M400P2d[M400`000000ZjKB0:^V
dP020:^VdP030000002QXM@0XJ7D00<0XJ7D0P0000090::kj`@00000102dg?@500000?l0ooooN@3o
ool003l0oooo00<0000000mih`0?NN<00P00000607ffm`040000002]a^`00000000000L0[L?Z0`00
00040;bed`030000002d[M40]:gA0080]:gA00<000000:^VdP2[Y]800P2[Y]800`000000XJ7D0:6Q
e00300000080Y;_Z00<000000::kj`2R^n/01@2R^n/2000000<0ZMoj1`00001M0?ooo`0400000000
5i`001NL000GW0800000101_LlH00`000000S7o008ao`00508ao`0030000002PR[`0X8Zl00D0X8Zl
00<000000;6F^`2aU[/0102aU[/00`000000_j:k0;nR^`050;nR^`030000003=/Kh0cK6n00D0cK6n
00<000000=_5``3KaL<00`3KaL<00`000000j=k9000000020?[JYP030000003XjH@000000680oooo
00<0000000mih`0?NN<00P00000607ffm`040000002]a^`00000000000L0[L?Z0`0000040;bed`03
0000002d[M40]:gA0080]:gA00<000000:^VdP2[Y]800P2[Y]800`000000XJ7D0:6Qe00300000080
Y;_Z00<000000::kj`2R^n/01@2R^n/2000000<0ZMoj1`00003o0?ooog/0oooo00100?ooo`<00000
00<03gWS0000001m]_L00P1m]_L4000000T0[L?Z00<000000:c1j@2/`NT00P0000000`2l]M<00000
0;B]d@040;B]d@030000002[Y]80ZjKB00D000001P2T^nX2000000@0X[_[00<000000:WOnP2YgoX0
102YgoX400000600oooo00@00000000GW0005i`000001P1_LlH00`000000S7o008ao`00408ao`003
0000002PR[`0X8Zl00D0X8Zl00<000000;6F^`2aU[/0102aU[/00`000000_j:k0;nR^`050;nR^`03
0000003=/Kh0cK6n00@0cK6n00<000000=_5``3KaL<0103KaL<00`000000j=k9000000020?[JYP03
0000003XjH@0000006<0oooo0`0000000`0?NN<0000007ffm`0207ffm`@000002@2]`nX00`000000
[<7Y0:c1j@02000000030;bed`000000]:gA00@0]:gA00<000000:^VdP2[Y]801@0000060:BkjP80
0000102R^n/00`000000ZMoj0:WOnP040:WOnP@00000o`3ooomm0?ooo`00@P3oool6000000@0N;cl
0P0000050:g3jP8000001@2/`NT:000000@0YkgY00<000000:BkjP2T^nX01P2T^nX010000000X[_[
0000000000050:WOnP@00000HP3oool00`00000001NL000GW002000000H0Kg?600<0000008ao`02<
Ol000`2<Ol000`000000X8Zl0:2:_0040:2:_0`000000`2oX[/00`000000cK6n0<fa_P050<fa_P03
0000003KaL<0flG300<0flG300@000000>SNb@3Xg/T0j=k90P0000000`3XjH@000000?ooo`1U0?oo
o`H00000101h_?`2000000D0[L?Z0P0000050:c1j@X00000102W_NT00`000000Y;_Z0:BkjP060:Bk
jP040000002R^n/00000000000D0ZMoj1000003o0?ooogl0oooo00140?ooo`@000001P1h_?`20000
0080[L?Z00<000000:c1j@2/`NT01P2/`NT00`000000ZKkY0:Vnj@030:Vnj@030000002W_NT0YkgY
00@0YkgY00<000000:BkjP2T^nX01@2T^nX5000000<0ZMoj1000001T0?ooo`80000000@001NL0000
0010HL`000001@1_LlH00`000000S7o008ao`00408ao`0030000002PR[`0000000<0000000<0Y9oA
0000002_Yll01@2_Yll010000000^[3@0;Z`d02j/=05000000D0cK6n00<000000=_5``3KaL<00`3K
aL<00`000000j=k90>SNb@030>SNb@030000003XjH@0000006P0oooo1000000607Rlo08000000P2]
`nX00`000000[<7Y0:c1j@060:c1j@030000002Y_^T0ZKkY00<0ZKkY00<000000:Nmj@2W_NT0102W
_NT00`000000Y;_Z0:BkjP060:BkjP@000000`2YgoX400000?l0ooooP@3oool004L0oooo0`000006
07Rlo0<000001`2/`NT00`000000ZKkY0:Vnj@040:Vnj@030000002W_NT0YkgY00D0YkgY00<00000
0:BkjP2T^nX01000000509_Mo@D00000I`3oool2000000<0@67<00<0000006mcaP1_LlH00`1_LlH0
0`000000S7o008ao`00208ao`0<000001@2TWm400`000000[jO?0:nWc`040:nWc`030000002j/=00
^[3@00@0^[3@00<000000<>ldP0000000P0000020<fa_P030000003KaL<0flG300<0flG300<00000
0>SNb@3Xg/T00P3Xg/T2000000030>SYQ0000000oooo06X0oooo0`00000607Rlo0<000001`2/`NT0
0`000000ZKkY0:Vnj@040:Vnj@030000002W_NT0YkgY00D0YkgY00<000000:BkjP2T^nX00P2T^nX3
000000@0Vmgm1@00003o0?oooh<0oooo00190?ooo`<000000P1h_?`2000000<0NLGn100000030:c1
j@030000002Y_^T0ZKkY00D0ZKkY00<000000:Nmj@2W_NT00`2W_NT4000000H0Vmgm1@00001Z0?oo
o`8000000`10HL`00`000000Kg?606mcaP0306mcaP030000002<Ol00S7o0008000000P2FVMD00`00
0000Y9oA0:BOd@040:BOd@030000002_Yll0[jO?00<0[jO?00<000000;Z`d02j/=000`2j/=000`00
0000`kcB0<>ldP030<>ldP8000001@3KaL<00`000000j=k90>SNb@020>SNb@040000003WnL`00000
000006h0oooo0`00000207Rlo08000000`1iaOh4000000<0[<7Y00<000000:Vnj@2Y_^T01@2Y_^T0
0`000000YkgY0:Nmj@040:Nmj@030000002T^nX0Y;_Z00800000102KgOd500000?l0ooooQP3oool0
04`0oooo0P00000907W5oPL00000102Y_^T00`000000YkgY00000003000000<0S=Oo0P00000209_M
o@H00000K@3oool00`000000@67<041Qc002041Qc0030000001_LlH0Kg?600<0Kg?60P00000409JI
e@030000002TWm40Y9oA00@0Y9oA00<000000:nWc`2_Yll00`2_Yll00`000000^[3@0;Z`d0030;Z`
d00300000033_=80`kcB00<0`kcB00<000000<c9f00000000`3KaL<00`000000j=k90>SNb@020>SN
b@030000003WnL`0ioW<00800000L@3oool2000000T0NLGn1`0000040:Vnj@040000002W_NT0YkgY
0:Nmj@H000000`2KgOd600000?l0ooooR03oool00500oooo1P00000307W5oP030000001oc_l0Olko
0080Olko1P00000708cGo`L00000L03oool2000000@0@67<00L0000006mcaP1_LlH0Kg?600000024
UM`0000000D0UYWE00<000000:BOd@2TWm400`2TWm400`000000[jO?0:nWc`030:nWc`030000002j
/=00^[3@0080^[3@00<000000<>ldP33_=800`33_=8010000000c<WH0<c9f03<bMP2000000030=_5
``000000j=k900<0j=k900@000000>Oic03WnL`00000MP3oool6000000<0NLGn00<0000007o>o`1o
c_l00P1oc_l8000000D0S=Oo1`00003o0?oooh/0oooo001D0?ooo`X00000101oc_l010000000S=Oo
08cGo`2<eol5000007P0oooo0P000004041Qc0030000001_LlH0000000<0Q9GL00<0000009JIe@2F
VMD00`2FVMD00`000000Y9oA0:BOd@020:BOd@030000002_Yll0[jO?0080[jO?00<000000;Z`d02j
/=000`2j/=000`000000`kcB0<>ldP020<>ldP030000003<bMP0c<WH00@0c<WH00<000000>SNb@3X
g/T00P3Xg/T01@000000ioW<0>Oic03WnL`0000007X0oooo2P00000407o>o`040000002<eol0S=Oo
08cGo`D00000o`3ooonB0?ooo`00GP3oool8000007d0oooo00<000000011a00000001010HL`00`00
0000Q9GL08BEg00308BEg0030000002FVMD0UYWE0080UYWE00<000000:BOd@2TWm400P2TWm400`00
0000[jO?0:nWc`020:nWc`030000002j/=00^[3@0080^[3@00<000000<>ldP33_=800`33_=800`00
0000c<WH0<c9f0030<c9f0030000003Af^0000000080j=k900D000000>Oic03WnL`0ioW<00000025
0?ooo`P00000o`3ooonG0?ooo`00i03oool00`000000047400000003041Qc08000001@24UM`00`00
0000UYWE09JIe@0209JIe@030000002TWm40Y9oA0080Y9oA00D000000:nWc`2_Yll0[jO?00000004
0;Z`d00300000033_=80`kcB0080`kcB00<000000<c9f03<bMP00P3<bMP200000080dM[P00<00000
0>SNb@0000000`3WnL`00`000000oooo0?ooo`3o0?ooool0oooo903oool00>D0oooo00<000000011
a00000000P10HL`010000000KY;T00000000000408BEg0030000002FVMD0UYWE0080UYWE00D00000
0:BOd@2TWm40Y9oA000000030:nWc`050000002j/=00^[3@0;Z`d00000001033_=800`000000c<WH
0<c9f0020<c9f0030000003Af^00dM[P00<0dM[P00<000000>Oic03WnL`00P00003o0?ooool0oooo
9`3oool00>H0oooo00@000000011a00000000000101^T^@00`000000Q9GL08BEg00208BEg0050000
002FVMD0UYWE09JIe@0000000P2TWm4;00000080`kcB00<000000<c9f03<bMP00P3<bMP00`000000
dM[P0=7Jh0020=7Jh0040000003?k>T000000>Oic0800000o`3ooooo0?ooobP0oooo003W0?ooo`@0
0000101^T^@00`000000Q9GL08BEg00208BEg0030000002FVMD0UYWE00<0000000<0XkSX0000002Y
^nL00P2Y^nL010000000[KoW0:foi`0000020;75j@8000000`3<bMP200000080dM[P0P0000030<o/
j@<00000o`3ooooo0?ooobT0oooo003Y0?ooo`@000000`1^T^@2000000<0Q9GL0P00000209ffjP04
0000002S^>P0XkSX00000080ZK_W00D000000:foi`2]_nL000000;75j@02000000040;?:j`000000
c<WH00000080dM[P0P0000050<o/j@800000o`3ooooo0?ooobX0oooo003Z0?ooo`030000001?Snd0
Cho]00<000000P1^T^@010000000Q9GL0000002G]^d200000080WKKZ00<000000:>hj00000000P2Y
^nL01@000000[KoW0000002aaNT0000000<0/l[[0P0000000`3Af^000000000000040<o/j@@00000
o`3ooooo0?ooob/0oooo003[0?ooo`8000000`1?Snd20000000306jBi0000000000000<0UkK]0P00
00000`2M]^X000000:>hj002000000040:foi`000000/LGY00000080/l[[0P0000000`2cd>l00000
000000030<o/j@<000000P2mmnh00`000000oooo0?ooo`3o0?ooool0oooo:P3oool00>`0oooo1000
000204n?k@L0000000<0UkK]000000000000300000000`2`eO<000000<o/j@02000000@0_OO^00<0
00000?ooo`3oool0o`3ooooo0?ooob/0oooo003]0?ooo`030000000XS>d0:8c]00@000000P2:^ODE
000000D0_OO^00<000000?ooo`3oool0o`3ooooo0?ooob`0oooo003^0?ooo`8000000`0XS>dA0000
00D0ZmSg1P00003o0?ooool0oooo<03oool00?00oooo0`0000000`0XS>d0000008Fmn@0208FmnA80
00000P2Cl>L00`000000oooo0?ooo`3o0?ooool0oooo<03oool00?80oooo1P0000000`22`_`00000
0000000208?8oP80000000<0SmCn0000000000000P2If?d700000?l0ooooo`3ooold0?ooo`00m@3o
ool500000080PlSn00D0000008O>o`27c_l0000008oDoP0700000?l0ooooo`3ooolg0?ooo`00n03o
ool;00000?l0ooooo`3oooll0?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oo
od00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3o
oooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0
ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03o
ool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0
oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo
0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00
o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom0
0?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0oooo
o`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?oo
ool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo
003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oo
od00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3o
oooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0
ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03o
ool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0
oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo
0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00
o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom0
0?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0oooo
o`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?oo
ool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo
003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oo
od00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3o
oooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0
ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03o
ool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0
oooo@03oool00?l0ooooo`3ooooo0?oood00oooo001F0?oooa000000o`3ooooo0?ooomT0oooo001D
0?ooo`@000001@14000?00000?l0ooooo`3ooooC0?ooo`00D@3oool<000000H0N`4<00@0000009hM
1@2N7@D0WQd52@00003o0?ooool0ooooc`3oool004l0oooo1@000002044000030000001k0@`0N`4<
00@0N`4<2P00000709hM1@@00000o`3ooooo0?ooold0oooo001<0?ooo`@0000010110009000000L0
UC9600<000000;E;@P2eBd801000000609hM1@@00000o`3ooooo0?ooolX0oooo001:0?ooo`800000
101100040000000306P:>@000000UC9600d0UC9600<000000;E;@P2eBd80102eBd8500000080WQd5
00<000000:lS000000000P00003o0?ooool0oooob03oool004T0oooo00@00000044000110000@@00
0`00000506P:>@030000002E<TH0UC9600`0UC9600<000000;E;@P2eBd802@2eBd8400000080[b<0
0`00003o0?ooool0ooooaP3oool004L0oooo1P00000706P:>@030000002E<TH0UC9600D0UC962`00
000;0;E;@P040000003>FR/0000000000080[b<00`00003o0?ooool0ooooa03oool004H0oooo0`00
000:06P:>@T00000202RD6T00`000000_FIW0;eVI`05000000L0]D]200<000000<iJ:`3>FR/00P00
00020:lS00800000o`3ooooo0?oool<0oooo00150?ooo`030000000F0140000000P0J0Xi0`000000
0`1m<6<000000:9@J@0>0:9@J@030000002mIVL0_FIW00D0_FIW1P0000000`2eBd8000000<iJ:`03
0<iJ:`8000000P2_8`000`000000oooo0?ooo`3o0?ooool0oooo`03oool004<0oooo0P0000000`0F
0140000006P:>@0506P:>@<00000101m<6<00`000000XU1Y0:9@J@0=0:9@J@030000002mIVL0_FIW
00/0_FIW100000040<iJ:`80000000<0[b<00000003oool0o`3ooooo0?oool00oooo00120?ooo`80
00000P0F014010000000J0Xi06P:>@1X2ST3000000L0OC1S00<000000:9@J@2RD6T03@2RD6T00`00
0000_FIW0;eVI`0=0;eVI`040000003HNE/00000000000@0cUX[0`00003o0?ooool0oooo`03oool0
0440oooo00H0000001H04@0F01405P0A0000001X2ST3000000T0OC1S00<000000:9@J@2RD6T03P2R
D6T00`000000_FIW0;eVI`0=0;eVI`040000003HNE/0f7UK0=QiF`800000103>FR/300000?l0oooo
o`3ooonn0?ooo`00?`3oool2000000@05P0A0P00000<07d`H`030000002RD6T0XU1Y00H0XU1Y2`00
000=0;eVI`030000003HNE/0f7UK00<0f7UK0P0000030<iJ:`<00000o`3ooooo0?oookd0oooo000n
0?ooo`8000000`0F0143000000`0OC1S2P0000080:QTP@0300000031N800`GR000H00000202mIVL0
0`000000f7UK0=QiF`040=QiF`8000000P3>FR/300000?l0ooooo`3ooonl0?ooo`00?@3oool00`00
00005P0A01H04@0201H04@040000000o04d0?`1=000000P0OC1S100000000`29Bgd000000:QTP@0?
0:QTP@0300000031N800`GR000H0`GR01P0000020;eVI`030000003HNE/0f7UK00H0f7UK0`000000
0`3?EP0000000000003o0?ooool0oooo^`3oool003`0oooo00@0000001H04@0F01405P0A0P000002
03l0C@030000001m<6<0OC1S00<0OC1S1000000508U;O@030000002XI840Z6B100h0Z6B100<00000
0<5hP031N8003031N804000000T0f7UK0P0000000`3?EP0000000000003o0?ooool0oooo^P3oool0
03`0oooo00@0000001H04@0000000000100o04d00`000000OC1S00000003000000T0RD]m00<00000
0:QTP@2XI8403P2XI8400`000000`GR00<5hP00>0<5hP0040000003JS7X00000000000P0f7UK0P00
00020<mF00030000003oool0oooo0?l0ooooo`3ooong0?ooo`00>`3oool00`0000005P0A00000006
03l0C@8000003@29Bgd00`000000Z6B10:QTP@0>0:QTP@0300000031N800`GR000h0`GR000@00000
0=Z<NP3JS7X0fXaj0P0000060=QiF`030000003[QcD000000080ceH000<000000?ooo`3oool0o`3o
oooo0?oookH0oooo000j0?ooo`<000001@0o04d3000000h0RD]m00<000000:QTP@2XI8401P2XI84;
000000h0`GR000<000000=Z<NP3JS7X00`3JS7X2000000@0f7UK00@000000>^7=@3[QcD000000P3?
EP000`000000oooo0?ooo`3o0?ooool0oooo]@3oool003X0oooo00<0000003l0C@0o04d0100o04d0
10000000FBAc05TTL`00000=08U;O@X00000202/LY800`000000`XFB0<:5TP06000000P0`GR000<0
00000=Z<NP3JS7X01@3JS7X2000000<0f7UK00H000000>^7=@3[QcD000000<mF0000003o0?ooool0
oooo]`3oool003T0oooo0P00000503l0C@050000001I97<0FBAc05TTL`0000002P29Bgd300000003
095NT@000000[7:B00l0[7:B00<000000<:5TP32QI801P32QI8600000080`GR000<000000=Z<NP3J
S7X01`3JS7X2000000030=QiF`000000jhLe0080jhLe00<000000<mF00000000o`3ooooo0?oookH0
oooo000h0?ooo`030000000000d0000000<0?`1=0P00000305TTL`0300000029Bgd0RD]m00D0RD]m
10000004095NT@030000002/LY80[7:B00h0[7:B00<000000<:5TP32QI803032QI84000000X0fXaj
0P0000040>^7=@800000o`3ooooo0?oookH0oooo000h0?ooo`030000000000d000000080?`1=00<0
000005TTL`1I97<00`1I97<00`000000RD]m08U;O@0208U;O@<00000202AGY400`000000[7:B0:ab
TP0>0:abTP0300000032QI80`XFB00h0`XFB00@000000=VIS`00000000002@3JS7X2000000@0jhLe
0P00003o0?ooool0oooo]@3oool003L0oooo00<0000000003@0000000P0o04d00`000000FBAc05TT
L`0405TTL`0300000029Bgd00000008000002`2AGY400`000000[7:B0:abTP0>0:abTP0300000032
QI80`XFB00h0`XFB00@000000=VIS`3IVHl0fIV?0P0000070=Z<NP030000003bXVL0000000@0jhLe
00<000000?ooo`3oool0o`3ooooo0?oook<0oooo000f0?ooo`80000000@0000=0000000000000000
1`1I97<2000000h0TEjA00<000000:abTP2/LY803P2/LY800`000000`XFB0<:5TP0>0<:5TP030000
003IVHl0fIV?00<0fIV?0`0000040=Z<NP040000003bXVL0lZ9W000000<0jhLe00<000000?ooo`3o
ool0o`3ooooo0?oook<0oooo000f0?ooo`040000000000d0000=000000L0FBAc0`00000?095NT@03
0000002/LY80[7:B00h0[7:B00<000000<:5TP32QI803P32QI800`000000fIV?0=VIS`060=VIS`80
00000`3JS7X00`000000lZ9W0?:RI`0200000080jhLe00<000000?ooo`3oool0o`3ooooo0?oook80
oooo000e0?ooo`030000000000d0000=008000001P1I97<010000000Jd6<06]1S000000?095NT@03
0000002/LY80[7:B00H0[7:B2`00000>0<:5TP030000003IVHl0fIV?00P0fIV?0P0000000`3JS7X0
00000?:RI`030?:RI`030000003[QcD000000?l0ooooo`3ooond0?ooo`00=@3oool01@000000000=
0000000004l0000000@0FBAc0P00000306]1S0030000002AGY40TEjA00`0TEjA2P0000080:inX003
00000032Sj00`XnP00H000002032QI800`000000fIV?0=VIS`0:0=VIS`8000001@3bXVL300000?l0
ooooo`3ooonc0?ooo`00=03oool01P000000000=00003@000000001?00000080FBAc0P00000606]1
S0030000002AGY40TEjA00L0TEjA100000000`2GKJ0000000:inX00?0:inX00300000032Sj00`XnP
00H0`XnP1P0000020<:5TP030000003IVHl0fIV?00/0fIV?0P0000050?:RI`800000o`3ooooo0?oo
ok<0oooo000d0?ooo`050000000000d000000000C`0000000P1I97<00`000000Jd6<06]1S00606]1
S0030000002AGY40TEjA00<0TEjA1000000509M]X0030000002^OZ00[WjP00h0[WjP00<000000<:?
X032Sj003032Sj04000000`0fIV?00<000000?6aQ`0000001@3bXVL200000?l0ooooo`3ooonb0?oo
o`00<`3oool00`000000000=000000020000C`<000002@1[@H`00`000000TEjA00000003000000T0
UffP00<000000:inX02^OZ003P2^OZ000`000000`XnP0<:?X00>0<:?X0040000003GXZ0000000000
00X0fIV?00@000000?6aQ`3a/HL00000103bXVL200000?l0ooooo`3ooonb0?ooo`00<`3oool20000
00<0001?00<0000006]1S01[@H`02@1[@H`2000000d0UffP00<000000:inX02^OZ003P2^OZ000`00
0000`XnP0<:?X00>0<:?X0040000003GXZ00ej:P0=NRX0<000001P3IVHl00`000000lK670?6aQ`02
0?6aQ`8000000P3bXVL300000?l0ooooo`3ooona0?ooo`00<`3oool200000080001?0P00000906]1
S0<000003`2GKJ000`000000[WjP0:inX00=0:inX00300000032Sj00`XnP00h0`XnP00<000000=NR
X03GXZ00103GXZ03000000<0fIV?00<000000?6aQ`3a/HL0103a/HL00`000000lZ9W000000020000
0?l0ooooo`3ooona0?ooo`00<P3oool2000000<0001?0P00000806]1S0040000001gEYl0MeJO0000
00l0UffP00<000000:inX02^OZ003@2^OZ000`000000`XnP0<:?X00>0<:?X0030000003GXZ00ej:P
00L0ej:P0P0000000`3IVHl000000?6aQ`060?6aQ`040000003bXVL0000000000?l0ooooo`3ooona
0?ooo`00<P3oool01`000000001?0000C`0004l00000024<O00000001P1[@H`2000000<0MeJO00<0
000009M]X02GKJ003@2GKJ000`000000[WjP0:inX0050:inX0/000003@32Sj000`000000ej:P0=NR
X00:0=NRX0800000203a/HL400000?l0ooooo`3ooon`0?ooo`00<P3oool010000000001?0000C`00
0003024<O0040000001[@H`0Jd6<06]1S08000001@1gEYl00`000000UffP09M]X00<09M]X0T00000
202`R:`00`000000`YR/0<:H[005000000P0`XnP00<000000=NRX03GXZ002`3GXZ02000000P0lK67
00<000000>^U9`000000o`3ooooo0?oook00oooo000b0?ooo`040000000004l0001?000000<08@al
00@0000006]1S01[@H`00000201gEYl00`000000UffP09M]X00709M]X0@0000000<0VgV/0000002`
R:`03P2`R:`00`000000`YR/0<:H[0050<:H[0H000000P32Sj000`000000ej:P0=NRX00;0=NRX003
0000003]^Yh0000000L0lK6700<000000>^U9`000000o`3ooooo0?oook00oooo000b0?ooo`030000
000004l0000000@08@al0`00000907MFW`030000002GKJ00UffP00<0UffP1000000509]i[0030000
002`R:`0/8R/00d0/8R/00<000000<:H[032V:`02`32V:`4000000`0ej:P00@000000>fjWP3]^Yh0
00001P3a/HL2000000030>^U9`000000oooo0?l0ooooo`3ooon^0?ooo`00<P3oool2000000D08@al
00<0000007MFW`1gEYl02@1gEYl00`000000UffP00000003000000T0VgV/00<000000;28[02`R:`0
3@2`R:`00`000000`YR/0<:H[00=0<:H[0040000003CZJd00000000000X0ej:P00@000000>fjWP3]
^Yh0kKZN0P0000040?6aQ`80000000<0jjDW0000003oool0o`3ooooo0?ooojh0oooo000a0?ooo`<0
0000100Q37`2000000/0MeJO0P00000=09]i[0030000002`R:`0/8R/00d0/8R/00<000000<:H[032
V:`03@32V:`010000000djV]0=>Y[@3CZJd3000000H0ej:P00<000000>fjWP3]^Yh0103]^Yh02000
0000lK670?6aQ`000000oLMV0000003[YBL00000o`3ooooo0?ooojl0oooo000a0?ooo`800000100Q
37`00`000000?S:J0000000907MFW`<000003`2KNJ`00`000000/8R/0;28[00<0;28[00300000032
V:`0`YR/00`0`YR/00<000000=>Y[@3CZJd01@3CZJd3000000<0ej:P00<000000>fjWP3]^Yh01@3]
^Yh01`000000lK670000003mafH000000>^U9`000000o`3ooooo0?ooojl0oooo000a0?ooo`800000
100Q37`00`000000?S:J0000000807MFW`0400000020J:h0P6R^000000l0VgV/00<000000;28[02`
R:`0302`R:`00`000000`YR/0<:H[00<0<:H[0030000003CZJd0djV]00P0djV]0P0000000`3GXZ00
00000>fjWP070>fjWP8000000P3mafH200000?l0ooooo`3ooon_0?ooo`00<@3oool2000000<08@al
00@0000003hbVP0n<YX000001P1gEYl2000000@0P6R^00<0000009]i[02KNJ`0302KNJ`00`000000
/8R/0;28[00<0;28[00300000032V:`0`YR/00`0`YR/00<000000=>Y[@3CZJd02P3CZJd2000000T0
kKZN00<000000?g7IP3mafH00P00003o0?ooool0oooo[`3oool00340oooo0P000002024<O0030000
000n<YX0?S:J0080?S:J00@0000007MFW`1gEYl0MeJO0P000006081X[P030000002KNJ`0VgV/00`0
VgV/00<000000;28[02`R:`01@2`R:`;000000/0`YR/00<000000=>Y[@3CZJd02`3CZJd2000000P0
kKZN00<000000?g7IP3mafH00P00003o0?ooool0oooo[`3oool00340oooo0P0000000`0Q37`00000
03hbVP0403hbVP040000001gEYl0MeJO000000P0P6R^00<0000009]i[02KNJ`02`2KNJ`9000000L0
/96f00@000000<6O]P31WkH0`Inf1`0000030<:H[0030000003CZJd0djV]00/0djV]00@000000>O1
[`3W`Jl000001`3]^Yh200000080oLMV00<000000?ooo`3oool0o`3ooooo0?ooojd0oooo000a0?oo
o`80000000<08@al0000000n<YX0100n<YX3000000T0P6R^00<0000009]i[02KNJ`01`2KNJ`40000
000309j4]`000000/96f00d0/96f00<000000<6O]P31WkH02031WkH5000000`0djV]00D000000>O1
[`3W`Jl0il6_000000050>fjWP030000003nf94000000080oLMV00<000000?ooo`3oool0o`3ooooo
0?ooojd0oooo000a0?ooo`<000001P0n<YX00`000000P6R^081X[P0:081X[P030000002KNJ`0VgV/
00<0VgV/0`00000509j4]`030000002`TKH0/96f00`0/96f00<000000<6O]P31WkH02`31WkH01000
0000d:ni00000000000:0=>Y[@030000003W`Jl0il6_0080il6_00<000000>fjWP3]^Yh00P3]^Yh0
1P000000o]RA0?kHT@000000oLMV00000?l0ooooo`3ooon_0?ooo`00<@3oool2000000H0?S:J0P00
000<081X[P030000002KNJ`0000000<00000202NQ;L00`000000/96f0;2A]P0<0;2A]P0300000031
WkH0`Inf00/0`Inf00@000000=2_^@3@[kT0d:ni0P0000070=>Y[@030000003W`Jl0il6_00@0il6_
00D000000>fjWP3]^Yh0kKZN000000020?kHT@030000003mafH000000?l0ooooo`3ooon_0?ooo`00
<@3oool2000000H0?S:J00<0000005A?/00000002P20J:h3000000`0WXBg00<000000;2A]P2`TKH0
2`2`TKH00`000000`Inf0<6O]P0;0<6O]P030000003@[kT0d:ni00@0d:ni0`0000040=>Y[@030000
003W`Jl0il6_00D0il6_00@000000>fjWP3]^Yh000000`3nf94200000?l0ooooo`3ooon_0?ooo`00
<@3oool3000000@0?S:J00@0000005A?/01DCk0000002020J:h20000000308Mg^`000000WXBg00d0
WXBg00<000000;2A]P2`TKH02P2`TKH00`000000`Inf0<6O]P0;0<6O]P030000003@[kT0d:ni00L0
d:ni0P0000000`3CZJd000000>O1[`080>O1[`800000103nf94200000?l0ooooo`3ooon_0?ooo`00
<@3oool3000000<0?S:J00<0000005A?/01DCk000P1DCk000`000000P6R^081X[P03081X[P800000
1027Mk/00`000000WXBg09j4]`0;09j4]`030000002`TKH0/96f00X0/96f00<000000<6O]P31WkH0
2`31WkH00`000000d:ni0=2_^@090=2_^@8000002P3W`Jl00`000000o]RA0?kHT@030?kHT@030000
003oool0oooo0?l0ooooo`3ooon]0?ooo`00<@3oool300000080?S:J00<0000005A?/01DCk000`1D
Ck0010000000P6R^081X[P20J:h2000000H0QgNk00<0000009j4]`2NQ;L02`2NQ;L00`000000/96f
0;2A]P0:0;2A]P0300000031WkH0`Inf00/0`Inf00<000000=2_^@3@[kT02P3@[kT2000000T0il6_
00<000000?kHT@3nf9400`3nf9400`000000oooo0?ooo`3o0?ooool0oooo[@3oool00340oooo00<0
00000000N`0000000P0n<YX00`000000E4n`05A?/00405A?/0<000002027Mk/00`000000WXBg09j4
]`0;09j4]`030000002`TKH0/96f00@0/96f2P0000090<6O]P030000003@[kT0d:ni00X0d:ni00@0
00000>35_@3PaKd000001`3W`Jl00`000000n=n^000000040?kHT@030000003oool0oooo0?l0oooo
o`3ooon]0?ooo`00<@3oool00`000000001k0000N`02000000L0E4n`00<0000008Mg^`27Mk/02@27
Mk/00`000000WXBg09j4]`0809j4]`T000001P2`V/0010000000_ZK10;jV`@2nY/46000000<0`Inf
00<000000=2_^@3@[kT02P3@[kT01@000000h<Fm0>35_@3PaKd0000000H0il6_00<000000?SO[P00
00000`3nf94200000?l0ooooo`3ooon_0?ooo`00<@3oool010000000001k0000N`00000705A?/080
00002`27Mk/00`000000WXBg09j4]`0409j4]`@000000P2QSl800`000000/9[00;2J`00:0;2J`003
0000002nY/40_ZK100L0_ZK11@00000;0=2_^@030000003PaKd0h<Fm0080h<Fm0P0000030>O1[`05
0000003hgjh0n=n^0?SO[P0000000P3nf9400`000000oooo0?ooo`3o0?ooool0oooo[P3oool00340
oooo00<000000000N`0007/00P00000605A?/0030000001UIkl0000000/0QgNk00<0000009j4]`00
00000`0000060:6?`P030000002`V/00/9[000X0/9[000<000000;jV`@2nY/402P2nY/400`000000
c;G300000002000000L0d:ni00<000000>35_@3PaKd01@3PaKd010000000il6_0>O1[`0000030?SO
[P040000003nf940o]RA00000?l0ooooo`3ooon`0?ooo`00<@3oool00`000000001k0000N`020000
00D0E4n`00@0000006EW_`1UIkl000002`27Mk/2000000/0XHo200<000000;2J`02`V/002@2`V/00
0`000000_ZK10;jV`@090;jV`@030000003<]L<0c;G300<0c;G30P0000050=2_^@030000003PaKd0
h<Fm00H0h<Fm0P0000050?SO[P030000003nf94000000?l0ooooo`3ooon`0?ooo`00<@3oool01P00
0000001k0000N`000000026V000000<0E4n`00<0000006EW_`1UIkl00P1UIkl00`000000QgNk08Mg
^`0608Mg^`<00000302QSl800`000000/9[00;2J`0090;2J`0030000002nY/40_ZK100T0_ZK100<0
00000<be``3<]L<01@3<]L<3000000030=2_^@000000h<Fm00T0h<Fm00<000000?SO[P3hgjh00`3h
gjh300000?l0ooooo`3ooon`0?ooo`00<P3oool00`000000001k00000002000QYP030000001DCk00
000000D0IFNo00<0000008Mg^`27Mk/01027Mk/2000000<0SHG600<000000:6?`P2QSl802@2QSl80
0`000000/9[00;2J`0090;2J`0030000002nY/40_ZK100T0_ZK100<000000<be``3<]L<0203<]L<2
000000T0h<Fm0P0000060?SO[P030000003oool0oooo0?l0ooooo`3ooon_0?ooo`00<P3oool20000
00<0026V00<0000005A?/00000001P1UIkl010000000QgNk08Mg^`27Mk/2000000D0SHG600<00000
0:6?`P2QSl802@2QSl800`000000/9[00;2J`0090;2J`0030000002nY/40_ZK100P0_ZK100<00000
0<be``3<]L<02@3<]L<00`000000fLO9000000080>35_@030000003^hL80000000@0n=n^0P00003o
0?ooool0oooo/@3oool00380oooo0P000004000QYP030000001UIkl0IFNo00D0IFNo00@0000008Mg
^`0000000000202=QLH00`000000XHo20:6?`P090:6?`P030000002`V/00/9[000P0/9[000<00000
0;jV`@2nY/40202nY/400`000000c;G30<be``090<be``040000003IalT0fLO9000000H0h<Fm00@0
00000>kQ`P3^hL800000103hgjh200000?l0ooooo`3ooona0?ooo`00<`3oool00`000000026V000Q
YP02000QYP8000001`1UIkl00`000000SHG608f5aP0808f5aP030000002QSl80XHo200T0XHo200<0
00000;2J`02`V/000`2`V/08000000P0_ZK100<000000<be``3<]L<0203<]L<00`000000fLO90=W7
b@020=W7b@800000103PaKd01@000000k^720>kQ`P3^hL8000000080n=n^0`00003o0?ooool0oooo
/@3oool003<0oooo00<00000000QYP008JH00P008JH2000000H0IFNo00<00000079kc00000002P2=
QLH00`000000XHo20:6?`P060:6?`PP000001@2`XlX00`000000_:g;0;b]b`0500000080_ZK100<0
00000<be``3<]L<02@3<]L<00`000000fLO90=W7b@040=W7b@040000003PaKd0h<Fm000000@0k^72
00D000000?SO[P000000iNn@0000003o0?ooool0oooo/P3oool003<0oooo0P000003000QYP030000
000XC<80000000@0IFNo00@00000079kc01bNl`000002P2=QLH010000000XHo20:6?`P2QSl850000
0080Xi[<00<000000;2SbP2`XlX0202`XlX00`000000_:g;0;b]b`050;b]b`@000002@3<]L<00`00
0000fLO90=W7b@060=W7b@030000003PaKd0000000D0k^720P0000000`3Uki0000000?ooo`3o0?oo
ool0oooo/@3oool003@0oooo00L00000000QYP008JH0026V0000000XC<80000000@0IFNo00D00000
079kc01bNl`0LW_<0000000908f5aP@000001`2SV/`00`000000/:?:0;2SbP080;2SbP030000002l
[L/0_:g;00L0_:g;00<000000<NjcP0000000P0000050<be``030000003IalT0fLO900P0fLO900<0
00000>kQ`P3^hL80103^hL8010000000iNn@0>G_T000003o0?ooool0oooo/P3oool003@0oooo0P00
00000`008JH0000002Q<`P0202Q<`P040000001UIkl0IFNo000000D0LW_<00<0000008f5aP2=QLH0
102=QLH200000080Ti?@00<000000:>Jc02SV/`01`2SV/`00`000000/:?:0;2SbP070;2SbP030000
002l[L/0_:g;00H0_:g;00<000000<NjcP37^/h00`37^/h300000080c;G300<000000=W7b@3IalT0
1`3IalT2000000D0k^720P0000000`3Uki0000000?ooo`3o0?ooool0oooo/P3oool003D0oooo0`00
000302Q<`P030000001UIkl0000000L0LW_<00@0000008f5aP2=QLH0SHG60P00000409>Cd0030000
002SV/`0Xi[<00L0Xi[<00<000000;2SbP2`XlX01P2`XlX00`000000_:g;0;b]b`070;b]b`030000
0037^/h0ak[>00H0ak[>0P0000090=W7b@040000003Sgm00hmo@000000@0k^720P0000000`3Uki00
00000?ooo`3o0?ooool0oooo/P3oool003D0oooo0`00000402Q<`P030000001bNl`0LW_<00H0LW_<
00@0000008f5aP00000000001`2CTm000`000000Xi[<0:>Jc0060:>Jc0030000002`XlX0/:?:00H0
/:?:00<000000;b]b`2l[L/01P2l[L/00`000000ak[>0<NjcP070<NjcP040000003@bM<000000000
00H0fLO900D000000>?Od03Sgm00hmo@000000030>kQ`P040000003Ynk/0000000000?l0ooooo`3o
oond0?ooo`00=P3oool2000000@0:4c20P000008079kc0030000002CTm00Ti?@00L0Ti?@00<00000
0:>Jc02SV/`01P2SV/`00`000000/:?:0;2SbP060;2SbP030000002l[L/0_:g;00H0_:g;00<00000
0<NjcP37^/h01`37^/h01@000000d<WC0=39d`3@bM<0000000@0fLO900<000000>?Od03Sgm000`3S
gm001`000000k^720000003Ynk/000000>G_T0000000o`3ooooo0?oook@0oooo000f0?ooo`<00000
0`0XC<800`000000B6gD00000006079kc0030000001nS=L0000000T0Ti?@00<000000:>Jc02SV/`0
1P2SV/`010000000/:?:0;2SbP2`XlX8000000@0_:g;00<000000<NjcP37^/h01`37^/h00`000000
d<WC0=39d`030=39d`80000000<0fLO90000003Sgm001@3Sgm0010000000k^720000003Ynk/20000
0?l0ooooo`3ooone0?ooo`00=`3oool300000080:4c200@0000004Q]e018KM@00000101bNl`01@00
0000OXcG07j<e`1nS=L0000000P0Ti?@00<000000:>Jc02SV/`00P2SV/`8000000@0[jcE00@00000
0;Rde@2h]=D0^;CE1P0000070<NjcP030000003@bM<0d<WC00H0d<WC00<000000>?Od03Sgm001P3S
gm000`000000jO^k0>Wk^`0200000?l0ooooo`3ooone0?ooo`00>03oool20000000302Q<`P000000
B6gD00<0B6gD00D00000079kc01bNl`0LW_<0000000407j<e`030000002CTm00Ti?@00D0Ti?@1@00
00040:BUe`030000002_[=D0[jcE00D0[jcE00<000000;Rde@2h]=D01@2h]=D010000000`;kH0000
000000040<NjcP030000003@bM<0d<WC00H0d<WC0P0000070>?Od08000000P3Ynk/00`000000oooo
0?ooo`3o0?ooool0oooo]03oool003P0oooo1000000504Q]e0030000001bNl`0000000H0OXcG00<0
000009>Cd02CTm000P2CTm0200000080Uj3J00<000000:BUe`2TYML01@2TYML00`000000[jcE0:n/
e@040:n/e@030000002h]=D0^;CE00@0^;CE00<000000<2nf030_]P00P30_]P200000080ak[>00<0
00000=39d`3@bM<01@3@bM<010000000emgK0=OMf`0000050>?Od0050000003RnMD000000>Wk^`00
0000o`3ooooo0?oookL0oooo000i0?ooo`03000000006:H0000000H0B6gD00<0000007j<e`1nS=L0
1P1nS=L010000000Ti?@00000000000409NPfP030000002TYML0Y:GG00D0Y:GG00<000000:n/e@2_
[=D0102_[=D00`000000^;CE0;Rde@040;Rde@0300000030_]P0`;kH00@0`;kH0P0000070=39d`05
0000003GgM/0emgK0=OMf`000000103Sgm000`000000h_WE0>;ie@0300000?l0ooooo`3ooong0?oo
o`00>@3oool4000000D0B6gD0`00000707j<e`030000002GX=X0Uj3J00D0Uj3J00<000000:BUe`2T
YML0102TYML00`000000[jcE0:n/e@030:n/e@030000002h]=D0^;CE00@0^;CE00<000000<2nf030
_]P01@30_]P010000000a/_M0000000000040=39d`030000003GgM/0emgK00<0emgK00@000000>?O
d03Sgm0000000P3RnMD00`000000jO^k0000003o0?ooool0oooo^03oool003X0oooo00@00000000H
YP00000000001018KM@010000000HHKP0666h000000507j<e`0300000028WN40000000L0Uj3J00<0
00000:BUe`2TYML00`2TYML00`000000[jcE0:n/e@030:n/e@030000002h]=D0^;CE00@0^;CE00<0
00000<2nf030_]P01030_]P00`000000a/_M0<K;g@020<K;g@80000000<0d<WC0000003GgM/01@3G
gM/00`000000hmo@000000030>;ie@800000o`3ooooo0?oookT0oooo000k0?ooo`80000000D00EC@
000000000000B6gD000000040666h0030000001nS=L0OXcG0080OXcG00@0000008RMh@28WN400000
1`2GX=X00`000000Y:GG0:BUe`030:BUe`030000002_[=D0[jcE0080[jcE00<000000;Rde@2h]=D0
0`2h]=D00`000000`;kH0<2nf0050<2nf00300000036bmd0a/_M00@0a/_M00<000000=OMf`3GgM/0
1P3GgM/00`000000h_WE0>;ie@020>;ie@030000003oool0oooo0?l0ooooo`3ooonh0?ooo`00?03o
ool2000000800EC@0P0000050666h080000000<0OXcG00000028WN400`28WN42000000D0Uj3J00@0
00000:BUe`2TYML0Y:GG3`0000050<2nf00300000036bmd0a/_M00<0a/_M0`0000060=OMf`<00000
0`3RnMD200000?l0ooooo`3ooonj0?ooo`00?@3oool01@0000000EC@005Dd001E=00000000L0HHKP
00<0000008RMh@28WN401@28WN400`000000Uj3J09NPfP0209NPfP@000000P2T/N800`000000ZkKQ
0:^fh@020:^fh@030000002b_>40/[cQ0080/[cQ00<000000;O3h`2g`n<00P0000020<2nf0030000
0036bmd0a/_M00<0a/_M00D000000<[Ii03:fN@0b]WT000000030=OMf`8000000P3FlN@00`000000
h_WE0000000200000?l0ooooo`3ooonk0?ooo`00?P3oool00`0000000EC@005Dd003000000D0HHKP
0`00000608RMh@040000002GX=X0000000000080VjoU00<000000:BahP2T/N800P2T/N801@000000
ZkKQ0:^fh@2[]^40000000@0/[cQ00<000000;O3h`2g`n<00P2g`n<2000000D0a/_M00<000000<[I
i03:fN@00P3:fN@010000000emgK0000000000030=Kai0050000003RnMD000000;?h`0000000o`3o
oooo0?oook`0oooo000o0?ooo`0500000001E=000EC@0000000gO^H00P0000030666h0030000001f
W>T0MYcY008000001@28WN400`000000VjoU09^_i@0309^_i@050000002T/N80Y;7R0:BahP000000
0`2[]^401@000000/[cQ0;:lh@2b_>40000000D0]l?S00D000000;[;i`00000000000<K;g@020000
00H0b]WT00<000000=Kai03FlN@00`3FlN@2000000030;?h`0000000oooo0?l0ooooo`3ooonl0?oo
o`00@03oool3000000<0=gkV0`00000507JLj@80000000@0R9gQ000000000000TZkY0P00000309^_
i@050000002T/N80Y;7R0:BahP0000000`2[]^4010000000/[cQ0;:lh@0000040;O3h`800000102j
bnL00`000000b]WT0<[Ii0030<[Ii080000000<0anO]0000003FlN@00`3FlN@2000000030;?h`000
0000oooo0?l0ooooo`3ooonm0?ooo`00@@3oool3000000@0=gkV0P00000607JLj@030000002B[^T0
TZkY00<0TZkY00D0000009^_i@2K[nD0VjoU000000030:BahP040000002[]^40ZkKQ00000080/[cQ
00D000000;O3h`2g`n<0]l?S000000040;[;i`<000000`3:fN@2000000<0anO]00<000000=Kai03F
lN@00`0000000`2cn<0000000?ooo`3o0?ooool0oooo_P3oool004<0oooo0P00000303MniP040000
001OW?400000000000@0MYcY0`00000409:^j@80000000<0VjoU0000000000002@0000020;O3h`04
0000002jbnL0^/_W0;[;i`8000000`2kdn`3000000D0anO]0`000000102mo>D0000000000000003o
0?ooool0oooo`03oool004@0oooo0`00000203MniP030000001OW?40Gica0080000000<0MYcY0000
0028[^l00P28[^l2000000@0TZkY00H0000009nok`2O_nl000000::okP0000020:G1kP8000000P2Y
a^h200000080^/_W0P0000050;_Ck00300000037ind0anO]00D0anO]00<000000;gli@2mo>D00P00
003o0?ooool0oooo`P3oool004D0oooo1@00000405nLl@@000000`28[^l200000080TZkY0`000000
1@2O_nl000000::okP000000YL7^0080000000@0ZLK^000000000000Z/W`0P0000000`2kdn`00000
0000000200000080^=_b00<000000<OWk@0000000`0000001@2jlO<000000;gli@2mo>D000000?l0
ooooo`3oooo40?ooo`00AP3oool6000000@0Gica00<0000007fam@0000000`0000001028[^l00000
00000000000209^nl@H0000000<0ZLK^0000000000001@0000060;SKlP8000001@2jlO<300000?l0
ooooo`3oooo50?ooo`00B03oool9000000D0OK7e400000020:S>m0030000002hfo80000000<00000
00<0/>7h0000002jlO<01@2jlO<200000?l0ooooo`3oooo70?ooo`00BP3oool400000080A9gd6P00
00050;3Qn0030000002jlO<0^_7c00D00000o`3ooooo0?ooolP0oooo001<0?ooo`D0000000<0A9gd
0000001c]_X00P1c]_XL0000000309__l`00000000000?l0ooooo`3oooo:0?ooo`00CP3oool80000
00@0K;cm0`00000209?9nP040000002Fc?X0000000000080WM3i100000030:?So08000000`2Kko<2
00000?l0ooooo`3oooo<0?ooo`00D03oool30000000302^Nk`00000000000080K;cm0P00000306_4
oPP00000102Agoh800000?l0ooooo`3oooo>0?ooo`00DP3oool8000000<0JlCn00D00000077=oP1a
cOh0LLgn0000000207oGoPD000000P1_g^X400000?l0ooooo`3oooo@0?ooo`00E`3oool=00000080
@lCN1@00003o0?ooool0ooooe03oool005h0oooo2000003o0?ooool0oooof@3oool00?l0ooooo`3o
oooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0
ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03o
ool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0
oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo
0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00
o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom0
0?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0oooo
o`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo003o0?oo
ool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oood00oooo
003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3ooooo0?oo
od00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0ooooo`3o
oooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03oool00?l0
ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00o`3ooooo0?ooool0oooo@03o
ool00?l0ooooo`3ooooo0?oood00oooo003o0?ooool0ooooo`3ooom00?ooo`00\
\>"],
  ImageRangeCache->{{{0, 828}, {534.75, 0}} -> {-0.127344, -0.0808007, \
0.00634625, 0.00634625}, {{20.0625, 165.938}, {522, 362.812}} -> {-0.130999, \
-0.151891, 0.00652931, 0.00652931}, {{180.5, 326.438}, {522, 362.812}} -> \
{-1.00938, -0.0760481, 0.00586576, 0.00586576}, {{341, 486.938}, {522, \
362.812}} -> {-2.08544, -0.070639, 0.00622694, 0.00622694}, {{501.5, \
647.438}, {522, 362.812}} -> {-2.89228, -0.0760481, 0.00586576, 0.00586576}, \
{{662, 807.875}, {522, 362.812}} -> {-4.32241, -0.151891, 0.00652931, \
0.00652931}, {{20.0625, 165.938}, {346.938, 187.75}} -> {-0.130933, -1.29329, \
0.00652602, 0.00652602}, {{180.5, 326.438}, {346.938, 187.75}} -> {-1.08885, \
-1.16424, 0.006237, 0.006237}, {{341, 486.938}, {346.938, 187.75}} -> \
{-2.22442, -1.29255, 0.00652322, 0.00652322}, {{20.0625, 165.938}, {171.875, \
12.6875}} -> {-0.0671511, -2.12566, 0.00585729, 0.00585729}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell["E&M: Boundary Value Problems", "Title"],

Cell["Moving Charge Movie:", "Section"],

Cell["Moving Charge Movie:", "Section"],

Cell[CellGroupData[{

Cell["Problem 2: Potential in a rectangular groove ", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Clear[\"Global`*\"];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    FormBox[
      RowBox[{\(Clear::"wrsym"\), \(\(:\)\(\ \)\), "\<\"Symbol \
\\!\\(TraditionalForm\\`Monopole\\) is Protected.\"\>"}], 
      TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{\(Clear::"wrsym"\), \(\(:\)\(\ \)\), "\<\"Symbol \
\\!\\(TraditionalForm\\`TrigToP\\) is Protected.\"\>"}], 
      TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{\(Clear::"wrsym"\), \(\(:\)\(\ \)\), "\<\"Symbol \
\\!\\(TraditionalForm\\`TrigToY\\) is Protected.\"\>"}], 
      TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(TraditionalForm\\`\\(Clear :: \\\"wrsym\\\"\\)\\) will be suppressed \
during this calculation.\"\>"}], TraditionalForm]], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell["\<\
A[V_,m_]:= 2/a Integrate[V Sin[\[Pi] m x/a],{x,0,a}];\
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(pot[V_, n_]\), ":=", 
        RowBox[{"Sum", "[", 
          RowBox[{
            RowBox[{\(A[V, m]\), " ", 
              
              FormBox[\(\[ExponentialE]\^\(-\(\(m\ \[Pi]\ y\)\/a\)\)\ \
\(sin(\(m\ \[Pi]\ x\)\/a)\)\),
                "TraditionalForm"]}], ",", \({m, 1, n}\)}], "]"}]}], 
      ";"}]], "Input",
  Hyphenation->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["\<\
  pot[Sin[x],3] 
 \
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm\`\(2\ \[ExponentialE]\^\(-\(\(\[Pi]\ y\)\/a\)\)\ \((\(a\
\ \(sin(a)\)\)\/\(2\ \((\[Pi] - a)\)\) + \(a\ \(sin(a)\)\)\/\(2\ \((a + \
\[Pi])\)\))\)\ \(sin(\(\[Pi]\ x\)\/a)\)\)\/a + \(2\ \[ExponentialE]\^\(-\(\(2\
\ \[Pi]\ y\)\/a\)\)\ \((\(-\(\(a\ \(sin(a)\)\)\/\(2\ \((2\ \[Pi] - a)\)\)\)\) \
- \(a\ \(sin(a)\)\)\/\(2\ \((a + 2\ \[Pi])\)\))\)\ \(sin(\(2\ \[Pi]\ \
x\)\/a)\)\)\/a + \(2\ \[ExponentialE]\^\(-\(\(3\ \[Pi]\ y\)\/a\)\)\ \((\(a\ \
\(sin(a)\)\)\/\(2\ \((3\ \[Pi] - a)\)\) + \(a\ \(sin(a)\)\)\/\(2\ \((a + 3\ \
\[Pi])\)\))\)\ \(sin(\(3\ \[Pi]\ x\)\/a)\)\)\/a\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(Plot3D[
        pot[Sin[x], 30] /. a \[Rule] 1 // Evaluate, \[IndentingNewLine]{x, 0, 
          1}, {y, 0, 0.5}, 
        AxesLabel \[Rule] {\ x\ , y\ , V\ }];\)\)\)], "Input",
  Hyphenation->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.49366e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -9.8125 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 18 3.14607 ]
[.91861 .21225 0 -6.57576 ]
[.91861 .21225 10.0625 3.23674 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01494 .32259 -18 -2.79092 ]
[.01494 .32259 0 6.20908 ]
[.00542 .38225 -18 -2.84157 ]
[.00542 .38225 0 6.15843 ]
[-0.00447 .44424 -18 -2.89438 ]
[-0.00447 .44424 0 6.10562 ]
[-0.05457 .39542 -10 -3.08918 ]
[-0.05457 .39542 0 6.72332 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.1)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.2)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.3)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.4)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(0.5)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70252 .02109 m
.69885 .02251 L
s
.71605 .04178 m
.71237 .04318 L
s
.72932 .06208 m
.72564 .06347 L
s
.74235 .08201 m
.73866 .08339 L
s
.7677 .12078 m
.764 .12213 L
s
.78003 .13965 m
.77633 .14098 L
s
.79214 .15817 m
.78843 .1595 L
s
.80404 .17637 m
.80033 .17768 L
s
.82721 .21182 m
.82349 .21311 L
s
.8385 .22909 m
.83478 .23037 L
s
.8496 .24606 m
.84587 .24733 L
s
.86051 .26275 m
.85677 .264 L
s
.88178 .29529 m
.87804 .29651 L
s
.89215 .31115 m
.88841 .31237 L
s
.90235 .32676 m
.89861 .32797 L
s
.91239 .34211 m
.90864 .34331 L
s
.93198 .37208 m
.92823 .37326 L
s
.94155 .38671 m
.93779 .38788 L
s
.95096 .40111 m
.9472 .40226 L
s
.96022 .41528 m
.95646 .41643 L
s
gsave
.91861 .21225 -61 -10.5758 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02721 .31793 m
.03334 .3156 L
s
[(0.2)] .01494 .32259 1 -0.37979 Mshowa
.01773 .37772 m
.02389 .37545 L
s
[(0.4)] .00542 .38225 1 -0.36854 Mshowa
.00789 .43983 m
.01407 .43762 L
s
[(0.6)] -0.00447 .44424 1 -0.3568 Mshowa
.125 Mabswid
.03409 .27453 m
.03776 .27311 L
s
.03182 .28886 m
.03549 .28745 L
s
.02952 .30333 m
.0332 .30192 L
s
.02487 .33267 m
.02856 .33128 L
s
.02252 .34754 m
.0262 .34616 L
s
.02014 .36256 m
.02383 .36119 L
s
.01531 .39302 m
.01901 .39167 L
s
.01286 .40847 m
.01656 .40713 L
s
.01039 .42407 m
.01409 .42274 L
s
.00537 .45573 m
.00908 .45442 L
s
.00283 .47179 m
.00654 .47049 L
s
.00026 .48801 m
.00397 .48672 L
s
gsave
-0.05457 .39542 -71 -7.08918 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(V) show
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.584 .718 .936 r
.38313 .58323 .40512 .60371 .44174 .59874 .42 .57862 Metetra
.584 .724 .94 r
.42 .57862 .44174 .59874 .479 .59351 .45755 .57374 Metetra
.587 .732 .943 r
.45755 .57374 .479 .59351 .51691 .58781 .49577 .56839 Metetra
.593 .74 .946 r
.49577 .56839 .51691 .58781 .55547 .58144 .53468 .56234 Metetra
.602 .749 .947 r
.53468 .56234 .55547 .58144 .59468 .57419 .57427 .55536 Metetra
.614 .758 .948 r
.57427 .55536 .59468 .57419 .63451 .5658 .61451 .54717 Metetra
.629 .769 .947 r
.61451 .54717 .63451 .5658 .67494 .55601 .65539 .53749 Metetra
.647 .779 .944 r
.65539 .53749 .67494 .55601 .71593 .54456 .69684 .52599 Metetra
.668 .788 .938 r
.69684 .52599 .71593 .54456 .7574 .5312 .73881 .51236 Metetra
.69 .795 .93 r
.73881 .51236 .7574 .5312 .7993 .51571 .7812 .49632 Metetra
.711 .8 .92 r
.7812 .49632 .7993 .51571 .84155 .49801 .82393 .47773 Metetra
.729 .8 .908 r
.82393 .47773 .84155 .49801 .88409 .47824 .86692 .45667 Metetra
.741 .795 .896 r
.86692 .45667 .88409 .47824 .92691 .45676 .91014 .43356 Metetra
.746 .785 .885 r
.91014 .43356 .92691 .45676 .97003 .43424 .95362 .4092 Metetra
.574 .715 .938 r
.36056 .56222 .38313 .58323 .42 .57862 .39769 .55802 Metetra
.575 .722 .942 r
.39769 .55802 .42 .57862 .45755 .57374 .43551 .55354 Metetra
.578 .729 .946 r
.43551 .55354 .45755 .57374 .49577 .56839 .47405 .54858 Metetra
.584 .738 .949 r
.47405 .54858 .49577 .56839 .53468 .56234 .5133 .5429 Metetra
.593 .748 .951 r
.5133 .5429 .53468 .56234 .57427 .55536 .55327 .53625 Metetra
.606 .759 .952 r
.55327 .53625 .57427 .55536 .61451 .54717 .59394 .52834 Metetra
.622 .77 .951 r
.59394 .52834 .61451 .54717 .65539 .53749 .63527 .51883 Metetra
.643 .782 .948 r
.63527 .51883 .65539 .53749 .69684 .52599 .67721 .50735 Metetra
.666 .792 .942 r
.67721 .50735 .69684 .52599 .73881 .51236 .71968 .49351 Metetra
.691 .801 .934 r
.71968 .49351 .73881 .51236 .7812 .49632 .76259 .47695 Metetra
.715 .807 .922 r
.76259 .47695 .7812 .49632 .82393 .47773 .80582 .45741 Metetra
.737 .807 .908 r
.80582 .45741 .82393 .47773 .86692 .45667 .84929 .43492 Metetra
.752 .802 .893 r
.84929 .43492 .86692 .45667 .91014 .43356 .89292 .40994 Metetra
.757 .791 .88 r
.89292 .40994 .91014 .43356 .95362 .4092 .93675 .38345 Metetra
.564 .711 .94 r
.33741 .54067 .36056 .56222 .39769 .55802 .37478 .53692 Metetra
.564 .718 .945 r
.37478 .53692 .39769 .55802 .43551 .55354 .41288 .53289 Metetra
.567 .727 .949 r
.41288 .53289 .43551 .55354 .47405 .54858 .45172 .52837 Metetra
.573 .736 .952 r
.45172 .52837 .47405 .54858 .5133 .5429 .49131 .52313 Metetra
.583 .747 .955 r
.49131 .52313 .5133 .5429 .55327 .53625 .53166 .51688 Metetra
.596 .758 .956 r
.53166 .51688 .55327 .53625 .59394 .52834 .57275 .50931 Metetra
.614 .771 .955 r
.57275 .50931 .59394 .52834 .63527 .51883 .61454 .50006 Metetra
.636 .784 .953 r
.61454 .50006 .63527 .51883 .67721 .50735 .65698 .48869 Metetra
.662 .797 .947 r
.65698 .48869 .67721 .50735 .71968 .49351 .69999 .47472 Metetra
.691 .808 .937 r
.69999 .47472 .71968 .49351 .76259 .47695 .74344 .45767 Metetra
.72 .815 .924 r
.74344 .45767 .76259 .47695 .80582 .45741 .78721 .43716 Metetra
.746 .817 .908 r
.78721 .43716 .80582 .45741 .84929 .43492 .83116 .4131 Metetra
.764 .811 .89 r
.83116 .4131 .84929 .43492 .89292 .40994 .87521 .38597 Metetra
.771 .798 .875 r
.87521 .38597 .89292 .40994 .93675 .38345 .91939 .35695 Metetra
.552 .707 .943 r
.31365 .51855 .33741 .54067 .37478 .53692 .35125 .51529 Metetra
.552 .715 .948 r
.35125 .51529 .37478 .53692 .41288 .53289 .38961 .51176 Metetra
.555 .723 .952 r
.38961 .51176 .41288 .53289 .45172 .52837 .42874 .50775 Metetra
.561 .733 .956 r
.42874 .50775 .45172 .52837 .49131 .52313 .46868 .503 Metetra
.571 .745 .959 r
.46868 .503 .49131 .52313 .53166 .51688 .50941 .49722 Metetra
.585 .757 .96 r
.50941 .49722 .53166 .51688 .57275 .50931 .55092 .49009 Metetra
.604 .772 .96 r
.55092 .49009 .57275 .50931 .61454 .50006 .59319 .48119 Metetra
.628 .787 .958 r
.59319 .48119 .61454 .50006 .65698 .48869 .63614 .47004 Metetra
.657 .802 .952 r
.63614 .47004 .65698 .48869 .69999 .47472 .6797 .45605 Metetra
.69 .815 .942 r
.6797 .45605 .69999 .47472 .74344 .45767 .72373 .4386 Metetra
.725 .824 .927 r
.72373 .4386 .74344 .45767 .78721 .43716 .76807 .41712 Metetra
.756 .827 .907 r
.76807 .41712 .78721 .43716 .83116 .4131 .81254 .39134 Metetra
.778 .821 .886 r
.81254 .39134 .83116 .4131 .87521 .38597 .85702 .3617 Metetra
.786 .806 .868 r
.85702 .3617 .87521 .38597 .91939 .35695 .90152 .32967 Metetra
.54 .703 .945 r
.28926 .49583 .31365 .51855 .35125 .51529 .32707 .49312 Metetra
.539 .71 .951 r
.32707 .49312 .35125 .51529 .38961 .51176 .36567 .49015 Metetra
.541 .719 .955 r
.36567 .49015 .38961 .51176 .42874 .50775 .4051 .48669 Metetra
.547 .73 .959 r
.4051 .48669 .42874 .50775 .46868 .503 .44536 .4825 Metetra
.557 .742 .963 r
.44536 .4825 .46868 .503 .50941 .49722 .48647 .47728 Metetra
.572 .756 .965 r
.48647 .47728 .50941 .49722 .55092 .49009 .52841 .47068 Metetra
.592 .772 .965 r
.52841 .47068 .55092 .49009 .59319 .48119 .57116 .46224 Metetra
.618 .789 .964 r
.57116 .46224 .59319 .48119 .63614 .47004 .61464 .45144 Metetra
.65 .806 .958 r
.61464 .45144 .63614 .47004 .6797 .45605 .65878 .43758 Metetra
.688 .823 .947 r
.65878 .43758 .6797 .45605 .72373 .4386 .70342 .41986 Metetra
.729 .835 .93 r
.70342 .41986 .72373 .4386 .76807 .41712 .74836 .39746 Metetra
.766 .839 .907 r
.74836 .39746 .76807 .41712 .81254 .39134 .79339 .36981 Metetra
.794 .832 .881 r
.79339 .36981 .81254 .39134 .85702 .3617 .83831 .33726 Metetra
.804 .814 .86 r
.83831 .33726 .85702 .3617 .90152 .32967 .88312 .30158 Metetra
.525 .697 .948 r
.2642 .4725 .28926 .49583 .32707 .49312 .30221 .47038 Metetra
.524 .705 .953 r
.30221 .47038 .32707 .49312 .36567 .49015 .34105 .46802 Metetra
.526 .714 .958 r
.34105 .46802 .36567 .49015 .4051 .48669 .38075 .46518 Metetra
.532 .725 .963 r
.38075 .46518 .4051 .48669 .44536 .4825 .42134 .46162 Metetra
.542 .738 .967 r
.42134 .46162 .44536 .4825 .48647 .47728 .46281 .45704 Metetra
.556 .753 .969 r
.46281 .45704 .48647 .47728 .52841 .47068 .50518 .45106 Metetra
.577 .771 .971 r
.50518 .45106 .52841 .47068 .57116 .46224 .5484 .44323 Metetra
.605 .79 .97 r
.5484 .44323 .57116 .46224 .61464 .45144 .59243 .43294 Metetra
.64 .81 .965 r
.59243 .43294 .61464 .45144 .65878 .43758 .63717 .4194 Metetra
.683 .83 .954 r
.63717 .4194 .65878 .43758 .70342 .41986 .68246 .40161 Metetra
.731 .846 .935 r
.68246 .40161 .70342 .41986 .74836 .39746 .72806 .3784 Metetra
.777 .853 .907 r
.72806 .3784 .74836 .39746 .79339 .36981 .77369 .3488 Metetra
.812 .846 .875 r
.77369 .3488 .79339 .36981 .83831 .33726 .81907 .31283 Metetra
.825 .825 .848 r
.81907 .31283 .83831 .33726 .88312 .30158 .86416 .27265 Metetra
.51 .691 .95 r
.23846 .44853 .2642 .4725 .30221 .47038 .27664 .44705 Metetra
.508 .699 .956 r
.27664 .44705 .30221 .47038 .34105 .46802 .3157 .44534 Metetra
.509 .709 .961 r
.3157 .44534 .34105 .46802 .38075 .46518 .35566 .44318 Metetra
.514 .72 .966 r
.35566 .44318 .38075 .46518 .42134 .46162 .39655 .44032 Metetra
.524 .734 .97 r
.39655 .44032 .42134 .46162 .46281 .45704 .43839 .43647 Metetra
.538 .75 .974 r
.43839 .43647 .46281 .45704 .50518 .45106 .48118 .43123 Metetra
.559 .768 .976 r
.48118 .43123 .50518 .45106 .5484 .44323 .52489 .42415 Metetra
.588 .79 .976 r
.52489 .42415 .5484 .44323 .59243 .43294 .56947 .41456 Metetra
.626 .813 .972 r
.56947 .41456 .59243 .43294 .63717 .4194 .61483 .40158 Metetra
.674 .838 .962 r
.61483 .40158 .63717 .4194 .68246 .40161 .6608 .384 Metetra
.731 .859 .941 r
.6608 .384 .68246 .40161 .72806 .3784 .70712 .36025 Metetra
.788 .869 .908 r
.70712 .36025 .72806 .3784 .77369 .3488 .75342 .32867 Metetra
.832 .862 .867 r
.75342 .32867 .77369 .3488 .81907 .31283 .7993 .28869 Metetra
.849 .836 .833 r
.7993 .28869 .81907 .31283 .86416 .27265 .84462 .24283 Metetra
.492 .684 .952 r
.212 .42389 .23846 .44853 .27664 .44705 .25034 .4231 Metetra
.49 .692 .958 r
.25034 .4231 .27664 .44705 .3157 .44534 .28959 .4221 Metetra
.49 .702 .963 r
.28959 .4221 .3157 .44534 .35566 .44318 .32979 .42068 Metetra
.494 .714 .969 r
.32979 .42068 .35566 .44318 .39655 .44032 .37098 .41859 Metetra
.503 .728 .973 r
.37098 .41859 .39655 .44032 .43839 .43647 .41317 .41554 Metetra
.517 .744 .978 r
.41317 .41554 .43839 .43647 .48118 .43123 .45636 .41117 Metetra
.537 .764 .981 r
.45636 .41117 .48118 .43123 .52489 .42415 .50055 .40499 Metetra
.566 .787 .982 r
.50055 .40499 .52489 .42415 .56947 .41456 .54569 .39632 Metetra
.606 .814 .98 r
.54569 .39632 .56947 .41456 .61483 .40158 .59169 .38421 Metetra
.659 .844 .971 r
.59169 .38421 .61483 .40158 .6608 .384 .63839 .36723 Metetra
.725 .872 .95 r
.63839 .36723 .6608 .384 .70712 .36025 .6855 .34335 Metetra
.797 .887 .91 r
.6855 .34335 .70712 .36025 .75342 .32867 .73255 .30999 Metetra
.855 .88 .857 r
.73255 .30999 .75342 .32867 .7993 .28869 .77897 .26534 Metetra
.877 .849 .812 r
.77897 .26534 .7993 .28869 .84462 .24283 .82447 .21208 Metetra
.473 .676 .954 r
.18479 .39856 .212 .42389 .25034 .4231 .22326 .3985 Metetra
.47 .684 .96 r
.22326 .3985 .25034 .4231 .28959 .4221 .26268 .39825 Metetra
.469 .694 .965 r
.26268 .39825 .28959 .4221 .32979 .42068 .30311 .39762 Metetra
.472 .706 .971 r
.30311 .39762 .32979 .42068 .37098 .41859 .34457 .39638 Metetra
.48 .72 .976 r
.34457 .39638 .37098 .41859 .41317 .41554 .38708 .39424 Metetra
.492 .737 .981 r
.38708 .39424 .41317 .41554 .45636 .41117 .43068 .39085 Metetra
.511 .757 .985 r
.43068 .39085 .45636 .41117 .50055 .40499 .47534 .38573 Metetra
.539 .782 .988 r
.47534 .38573 .50055 .40499 .54569 .39632 .52103 .37822 Metetra
.579 .813 .988 r
.52103 .37822 .54569 .39632 .59169 .38421 .56769 .36732 Metetra
.635 .848 .981 r
.56769 .36732 .59169 .38421 .63839 .36723 .61516 .35147 Metetra
.712 .884 .96 r
.61516 .35147 .63839 .36723 .6855 .34335 .66312 .32814 Metetra
.801 .908 .915 r
.66312 .32814 .6855 .34335 .73255 .30999 .71105 .29353 Metetra
.878 .902 .843 r
.71105 .29353 .73255 .30999 .77897 .26534 .75809 .2436 Metetra
.909 .862 .783 r
.75809 .2436 .77897 .26534 .82447 .21208 .80369 .18035 Metetra
.452 .667 .955 r
.1568 .3725 .18479 .39856 .22326 .3985 .19537 .37321 Metetra
.448 .675 .961 r
.19537 .37321 .22326 .3985 .26268 .39825 .23494 .37377 Metetra
.446 .685 .967 r
.23494 .37377 .26268 .39825 .30311 .39762 .27556 .37398 Metetra
.448 .696 .972 r
.27556 .37398 .30311 .39762 .34457 .39638 .31727 .37365 Metetra
.454 .71 .978 r
.31727 .37365 .34457 .39638 .38708 .39424 .3601 .3725 Metetra
.464 .727 .983 r
.3601 .3725 .38708 .39424 .43068 .39085 .40407 .37021 Metetra
.481 .748 .988 r
.40407 .37021 .43068 .39085 .47534 .38573 .44918 .36633 Metetra
.506 .774 .992 r
.44918 .36633 .47534 .38573 .52103 .37822 .49543 .36023 Metetra
.543 .806 .994 r
.49543 .36023 .52103 .37822 .56769 .36732 .54275 .35095 Metetra
.599 .846 .991 r
.54275 .35095 .56769 .36732 .61516 .35147 .59101 .33685 Metetra
.683 .893 .974 r
.59101 .33685 .61516 .35147 .66312 .32814 .63991 .31506 Metetra
.794 .93 .923 r
.63991 .31506 .66312 .32814 .71105 .29353 .68886 .28039 Metetra
.899 .927 .827 r
.68886 .28039 .71105 .29353 .75809 .2436 .73668 .22497 Metetra
.943 .875 .74 r
.73668 .22497 .75809 .2436 .80369 .18035 .78223 .14761 Metetra
.429 .657 .955 r
.128 .34568 .1568 .3725 .19537 .37321 .16664 .3472 Metetra
.423 .665 .961 r
.16664 .3472 .19537 .37321 .23494 .37377 .20632 .3486 Metetra
.421 .674 .967 r
.20632 .3486 .23494 .37377 .27556 .37398 .24711 .34972 Metetra
.421 .685 .973 r
.24711 .34972 .27556 .37398 .31727 .37365 .28904 .35035 Metetra
.425 .699 .978 r
.28904 .35035 .31727 .37365 .3601 .3725 .33215 .35028 Metetra
.432 .715 .984 r
.33215 .35028 .3601 .3725 .40407 .37021 .37647 .34919 Metetra
.445 .736 .989 r
.37647 .34919 .40407 .37021 .44918 .36633 .42203 .34672 Metetra
.465 .761 .994 r
.42203 .34672 .44918 .36633 .49543 .36023 .46881 .34229 Metetra
.497 .793 .998 r
.46881 .34229 .49543 .36023 .54275 .35095 .51678 .33503 Metetra
.547 .836 .998 r
.51678 .33503 .54275 .35095 .59101 .33685 .56584 .32341 Metetra
.63 .892 .987 r
.56584 .32341 .59101 .33685 .63991 .31506 .61575 .30451 Metetra
.762 .95 .938 r
.61575 .30451 .63991 .31506 .68886 .28039 .6659 .27199 Metetra
.91 .955 .811 r
.6659 .27199 .68886 .28039 .73668 .22497 .71479 .21235 Metetra
.975 .883 .675 r
.71479 .21235 .73668 .22497 .78223 .14761 .76008 .1138 Metetra
.404 .645 .955 r
.09834 .31807 .128 .34568 .16664 .3472 .13702 .32043 Metetra
.397 .653 .961 r
.13702 .32043 .16664 .3472 .20632 .3486 .17679 .32272 Metetra
.393 .662 .966 r
.17679 .32272 .20632 .3486 .24711 .34972 .21771 .32477 Metetra
.392 .672 .972 r
.21771 .32477 .24711 .34972 .28904 .35035 .25983 .32644 Metetra
.393 .685 .977 r
.25983 .32644 .28904 .35035 .33215 .35028 .30319 .32751 Metetra
.397 .7 .982 r
.30319 .32751 .33215 .35028 .37647 .34919 .34784 .32774 Metetra
.405 .719 .988 r
.34784 .32774 .37647 .34919 .42203 .34672 .3938 .32681 Metetra
.418 .742 .993 r
.3938 .32681 .42203 .34672 .46881 .34229 .44109 .32428 Metetra
.439 .772 .997 r
.44109 .32428 .46881 .34229 .51678 .33503 .48969 .31945 Metetra
.474 .813 .999 r
.48969 .31945 .51678 .33503 .56584 .32341 .53955 .31108 Metetra
.54 .871 .993 r
.53955 .31108 .56584 .32341 .61575 .30451 .5905 .29664 Metetra
.672 .95 .955 r
.5905 .29664 .61575 .30451 .6659 .27199 .64205 .26983 Metetra
.885 .988 .805 r
.64205 .26983 .6659 .27199 .71479 .21235 .69254 .21141 Metetra
.994 .876 .578 r
.69254 .21141 .71479 .21235 .76008 .1138 .73719 .07886 Metetra
.377 .633 .954 r
.0678 .28963 .09834 .31807 .13702 .32043 .10648 .29282 Metetra
.37 .639 .959 r
.10648 .29282 .13702 .32043 .17679 .32272 .1463 .29599 Metetra
.364 .647 .964 r
.1463 .29599 .17679 .32272 .21771 .32477 .18731 .29902 Metetra
.36 .657 .969 r
.18731 .29902 .21771 .32477 .25983 .32644 .22958 .30178 Metetra
.357 .668 .974 r
.22958 .30178 .25983 .32644 .30319 .32751 .27316 .3041 Metetra
.357 .682 .979 r
.27316 .3041 .30319 .32751 .34784 .32774 .31809 .30578 Metetra
.358 .698 .983 r
.31809 .30578 .34784 .32774 .3938 .32681 .36442 .30659 Metetra
.361 .717 .987 r
.36442 .30659 .3938 .32681 .44109 .32428 .41218 .30621 Metetra
.368 .742 .989 r
.41218 .30621 .44109 .32428 .48969 .31945 .46138 .30416 Metetra
.379 .772 .988 r
.46138 .30416 .48969 .31945 .53955 .31108 .51201 .29967 Metetra
.403 .815 .977 r
.51201 .29967 .53955 .31108 .5905 .29664 .564 .29116 Metetra
.471 .882 .939 r
.564 .29116 .5905 .29664 .64205 .26983 .61707 .27436 Metetra
.704 .982 .807 r
.61707 .27436 .64205 .26983 .69254 .21141 .67 .23151 Metetra
.984 .842 .457 r
.67 .23151 .69254 .21141 .73719 .07886 .71353 .04274 Metetra
.378 .633 .954 r
.03634 .26033 .0678 .28963 .10648 .29282 .07516 .2631 Metetra
.372 .63 .954 r
.07516 .2631 .10648 .29282 .1463 .29599 .11509 .26623 Metetra
.36 .626 .954 r
.11509 .26623 .1463 .29599 .18731 .29902 .15617 .26992 Metetra
.34 .625 .957 r
.15617 .26992 .18731 .29902 .22958 .30178 .19846 .27423 Metetra
.314 .628 .961 r
.19846 .27423 .22958 .30178 .27316 .3041 .24207 .27903 Metetra
.284 .635 .964 r
.24207 .27903 .27316 .3041 .31809 .30578 .2871 .28396 Metetra
.254 .648 .964 r
.2871 .28396 .31809 .30578 .36442 .30659 .33365 .28848 Metetra
.228 .665 .956 r
.33365 .28848 .36442 .30659 .41218 .30621 .38181 .29191 Metetra
.215 .685 .94 r
.38181 .29191 .41218 .30621 .46138 .30416 .43161 .29348 Metetra
.217 .709 .921 r
.43161 .29348 .46138 .30416 .51201 .29967 .48304 .29241 Metetra
.237 .739 .9 r
.48304 .29241 .51201 .29967 .564 .29116 .53606 .28783 Metetra
.274 .775 .869 r
.53606 .28783 .564 .29116 .61707 .27436 .5905 .27817 Metetra
.368 .835 .793 r
.5905 .27817 .61707 .27436 .67 .23151 .64593 .25701 Metetra
.989 .808 .421 r
.64593 .25701 .67 .23151 .71353 .04274 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00_@3oool4000005l0oooo002o0?ooo`030000003oool0oooo05h0oooo002o0?ooo`030000
003oool0oooo05h0oooo002o0?ooo`030000003oool0oooo05h0oooo002o0?ooo`030000003oool0
oooo05h0oooo002m0?ooo`<00000203oool2000005H0oooo002o0?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`3oool00000E@3oool00<L0oooo00@000000?ooo`3oool00000E@3oool00<L0
oooo00@000000?ooo`3oool00000E@3oool00<L0oooo00@000000?ooo`3oool00000E@3oool00<80
oooo0P0000030?ooo`040000003oool0oooo000005D0oooo00300?ooo`80000000<0oooo00000000
00000`3oool2000005H0oooo002m0?ooo`<000000`3oool2000005/0oooo002j0?ooo`<000001P3o
ool3000005X0oooo002@0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000006P3oool2
000000030?ooo`000000oooo00H0oooo00@000000?g>J`0000000000F@3oool008l0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000F0?ooo`<000002P3oool200000080oLi[
0P00001H0?ooo`00S`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001@0
oooo0P00000=0?ooo`8000000P3mcV/2000005P0oooo002?0?ooo`040000003oool0oooo000000T0
oooo0P00000B0?ooo`<000003`3oool2000000<0oLi[0P00001G0?ooo`00S`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000l0oooo0P0000020?ooo`030000003oool0oooo
00d0oooo00<000000?g>J`0000000`3mcV/00`000000oooo0?ooo`1E0?ooo`00S`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000`0oooo0`00000D0?ooo`030000003mcV/0
000000<0oLi[0P00001F0?ooo`00T03oool2000000X0oooo0P00000:0?ooo`<000005`3oool00`00
0000oLi[000000040?g>J`800000E@3oool00:H0oooo0P0000000`3oool000000?ooo`0F0?ooo`04
0000003mcV/0oLi[000000@0oLi[0P00001E0?ooo`00F@3oool2000000030?ooo`000000000004D0
oooo0`00000K0?ooo`040000003mcV/0oLi[000000@0oLi[0`00001D0?ooo`00FP3oool00`000000
oooo000000140?ooo`8000007P3oool010000000oLi[0?g>J`0000030?g>J`030000003keg@0nmMd
00800000D`3oool005/0oooo00<000000?ooo`3oool0@03oool300000200oooo00@000000?g>J`3m
cV/000000`3mcV/01@000000nmMd0?_GM03keg@0000005<0oooo001J0?ooo`030000003oool00000
03h0oooo0`0000020?ooo`030000003oool0oooo01h0oooo00@000000?g>J`3mcV/000000`3mcV/0
10000000nmMd0?_GM03keg@200000580oooo001I0?ooo`80000000<0oooo000000000000>`3oool2
000002H0oooo00@000000?g>J`3mcV/000000`3mcV/00`000000nmMd0?_GM0020?_GM0030000003o
ool0oooo0500oooo002F0?ooo`<000009`3oool01@000000oLi[0?g>J`3mcV/0000000<0oLi[00<0
00000?_GM03keg@00`3keg@00`000000oooo0?ooo`1?0?ooo`00K@3oool2000000@0oooo00<00000
0?ooo`3oool00`3oool2000001T0oooo0P0000000`3oool000000?ooo`0W0?ooo`050000003mcV/0
oLi[0?g>J`0000000P3mcV/00`000000nmMd0?_GM0040?_GM0800000D03oool006`0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000E0?ooo`<00000;03oool01@000000oLi[
0?g>J`3mcV/000000080oLi[00<000000?_GM03keg@01@3keg@00`000000oooo0?ooo`1>0?ooo`00
K03oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000180oooo0`00000_0?oo
o`050000003mcV/0oLi[0?g>J`0000000P3mcV/00`000000nmMd0?_GM0050?_GM0<000001`3oool2
000000@0oooo00<000000?ooo`3oool00P3oool4000003P0oooo001/0?ooo`040000003oool0oooo
000000P0oooo0`00000A0?ooo`@00000<03oool01@000000oLi[0?g>J`3mcV/000000080oLi[00<0
00000?_GM03keg@0103keg@010000000o^2C0000000000060?ooo`040000003oool0oooo000000X0
oooo00<000000?ooo`3oool0=`3oool006`0oooo00@000000?ooo`3oool00000203oool00`000000
oooo0?ooo`0>0?ooo`<00000=03oool01@000000oLi[0?g>J`3mcV/000000080oLi[00<000000?_G
M03keg@0103keg@010000000o^2C0?kPT`0000060?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool0=`3oool006`0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?oo
o`0<0?ooo`800000=`3oool00`000000oLi[0?g>J`020?g>J`8000001`3keg@01@000000o^2C0?kP
T`3nh9<0000000D0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0g0?ooo`00
K@3oool2000000X0oooo0`0000080?ooo`<00000>03oool00`000000oLi[0?g>J`030?g>J`800000
1P3keg@00`000000o^2C0?kPT`020?kPT`800000103oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo03L0oooo00220?ooo`8000000P3oool00`000000oooo0?ooo`0f0?ooo`030000
003mcV/0oLi[00<0oLi[0P0000060?_GM0030000003nh9<0o^2C00<0o^2C0P0000030?ooo`040000
003oool0oooo000000P0oooo0`00000i0?ooo`00O`3oool3000003d0oooo00<000000?g>J`3mcV/0
0`3mcV/2000000H0nmMd00<000000?kPT`3nh9<0103nh9<00`000000oooo0?ooo`020?ooo`800000
2`3oool00`000000oooo0?ooo`0g0?ooo`00O03oool300000400oooo00<000000?g>J`3mcV/00`3m
cV/00`000000nmMd0?_GM0040?_GM0030000003nh9<0o^2C00D0o^2C0P00001:0?ooo`00NP3oool2
00000080oooo00<000000?ooo`3oool0?P3oool00`000000oLi[0?g>J`030?g>J`030000003keg@0
nmMd00@0nmMd00<000000?kPT`3nh9<01P3nh9<00`000000oooo0?ooo`180?ooo`00M`3oool30000
04D0oooo00<000000?g>J`3mcV/00`3mcV/00`000000nmMd0?_GM0040?_GM0030000003nh9<0o^2C
00H0o^2C0P0000190?ooo`00B`3oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0J0?ooo`800000A`3oool00`000000oLi[0?g>J`040?g>J`030000003keg@0nmMd00<0
nmMd00<000000?kPT`3nh9<01P3nh9<010000000nN:/0000000000180?ooo`00BP3oool010000000
oooo0?ooo`00000:0?ooo`030000003oool0oooo01L0oooo0`0000000`3oool000000?ooo`160?oo
o`030000003mcV/0oLi[00@0oLi[00<000000?_GM03keg@00`3keg@00`000000o^2C0?kPT`060?kP
T`040000003ihZ`0nN:/000004P0oooo001:0?ooo`040000003oool0oooo000000L0oooo1@00000E
0?ooo`<00000C03oool00`000000oLi[0?g>J`030?g>J`8000001@3keg@00`000000o^2C0?kPT`05
0?kPT`030000003ihZ`0nN:/0080nN:/00<000000?ooo`3oool0A@3oool004X0oooo00@000000?oo
o`3oool000001`3oool010000000oooo0?ooo`00000D0?ooo`800000C`3oool00`000000oLi[0?g>
J`030?g>J`800000103keg@00`000000o^2C0?kPT`060?kPT`030000003ihZ`0nN:/0080nN:/0P00
00160?ooo`00BP3oool010000000oooo0?ooo`0000080?ooo`030000003oool000000140oooo1@00
001?0?ooo`030000003mcV/0oLi[00<0oLi[0P0000040?_GM0030000003nh9<0o^2C00D0o^2C00<0
00000?WR[03ihZ`0103ihZ`00`000000oooo0?ooo`140?ooo`00BP3oool010000000oooo0?ooo`00
00090?ooo`8000003`3oool2000005@0oooo00<000000?g>J`3mcV/00`3mcV/2000000@0nmMd00<0
00000?kPT`3nh9<01@3nh9<00`000000nN:/0?WR[0050?WR[0030000003oool0oooo04<0oooo001;
0?ooo`8000002`3oool00`000000oooo0?ooo`0:0?ooo`<00000E@3oool00`000000oLi[0?g>J`04
0?g>J`800000103keg@00`000000o^2C0?kPT`040?kPT`030000003ihZ`0nN:/00H0nN:/0P000014
0?ooo`00HP3oool3000005P0oooo00<000000?g>J`3mcV/00`3mcV/00`000000nmMd000000030?_G
M0030000003nh9<0o^2C00D0o^2C00<000000?WR[03ihZ`01`3ihZ`00`000000oooo0?ooo`120?oo
o`00H03oool2000005/0oooo00<000000?g>J`3mcV/00`3mcV/00`000000nmMd000000030?_GM003
0000003nh9<0o^2C00D0o^2C00<000000?WR[03ihZ`01P3ihZ`00`000000lMnm000000130?ooo`00
G@3oool3000005d0oooo00<000000?g>J`3mcV/00`3mcV/010000000nmMd0?_GM00000020?_GM003
0000003nh9<0o^2C00@0o^2C00<000000?WR[03ihZ`01`3ihZ`010000000lMnm0000000000120?oo
o`00F`3oool3000005l0oooo00<000000?g>J`3mcV/00`3mcV/01P000000nmMd0?_GM0000000nmMd
000000L0o^2C00<000000?WR[03ihZ`01P3ihZ`01@000000lMnm0?7O_@3agkd000000480oooo001H
0?ooo`<000000`3oool00`000000oooo0?ooo`1L0?ooo`030000003mcV/0oLi[00<0oLi[00H00000
0?_GM03keg@000000?_GM00000060?kPT`030000003ihZ`0nN:/00H0nN:/00<000000?7O_@3agkd0
0P3agkd200000440oooo001F0?ooo`800000I03oool00`000000oLi[0?g>J`030?g>J`070000003k
eg@0nmMd0?_GM0000000nmMd000000060?kPT`030000003ihZ`0nN:/00H0nN:/00<000000?7O_@3a
gkd00`3agkd00`000000oooo0?ooo`0o0?ooo`00;03oool2000000@0oooo00<000000?ooo`3oool0
0P3oool4000001P0oooo0`00001V0?ooo`030000003mcV/0oLi[00<0oLi[00@000000?_GM03keg@0
nmMd0P0000060?kPT`030000003ihZ`0nN:/00H0nN:/00<000000?7O_@3agkd01@3agkd00`000000
oooo0?ooo`0n0?ooo`00:`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo01H0
oooo0`0000030?ooo`030000003oool0oooo06<0oooo00<000000?g>J`3mcV/00`3mcV/010000000
nmMd0?_GM03keg@2000000H0o^2C00<000000?WR[03ihZ`01P3ihZ`00`000000lMnm0?7O_@050?7O
_@8000001`3oool2000000@0oooo00<000000?ooo`3oool00P3oool4000002T0oooo000[0?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool04`3oool2000006`0oooo00<000000?g>
J`3mcV/00`3mcV/010000000nmMd0?_GM03keg@2000000H0o^2C00<000000?WR[03ihZ`01@3ihZ`0
0`000000lMnm0?7O_@070?7O_@030000003oool0oooo00@0oooo00@000000?ooo`3oool00000203o
ool00`000000oooo0?ooo`0Z0?ooo`00:`3oool010000000oooo0?ooo`00000:0?ooo`030000003o
ool0oooo00l0oooo0`00001^0?ooo`030000003mcV/0oLi[00<0oLi[00D000000?_GM03keg@0nmMd
000000060?kPT`030000003ihZ`0nN:/00D0nN:/00<000000?7O_@3agkd01`3agkd00`000000j=c8
000000050?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0:@3oool002/0oooo
00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0<0?ooo`8000000`3oool00`000000
oooo0?ooo`1[0?ooo`030000003mcV/0oLi[0080oLi[00<000000?_GM03keg@00P3keg@00`000000
o^2C0?kPT`040?kPT`030000003ihZ`0nN:/00D0nN:/00<000000?7O_@3agkd01`3agkd010000000
j=c80000000000040?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0:03oool0
02/0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000;0?ooo`<00000L`3o
ool00`000000oLi[0?g>J`020?g>J`030000003keg@0nmMd0080nmMd00<000000?kPT`3nh9<00`3n
h9<00`000000nN:/0?WR[0050?WR[0030000003agkd0lMnm00L0lMnm00@000000>SLb03Xg<P0j=c8
0P0000030?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool01P3oool2000001l0
oooo000/0?ooo`8000002P3oool2000000T0oooo1000001d0?ooo`030000003mcV/0oLi[00<0oLi[
00@000000?_GM03keg@0nmMd0P0000050?kPT`030000003ihZ`0nN:/00@0nN:/00<000000?7O_@3a
gkd01`3agkd00`000000j=c80>SLb0020>SLb08000000`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0703oool00440oooo0P0000030?oo
o`030000003oool0oooo0780oooo00<000000?g>J`3mcV/00`3mcV/010000000nmMd0?_GM03keg@2
000000@0o^2C00<000000?WR[03ihZ`01@3ihZ`00`000000lMnm0?7O_@070?7O_@030000003Xg<P0
j=c800<0j=c80P0000030?ooo`8000002P3oool2000000/0oooo0P00000M0?ooo`00?P3oool30000
07X0oooo00<000000?g>J`3mcV/00P3mcV/00`000000nmMd0?_GM0020?_GM0800000103nh9<00`00
0000nN:/0?WR[0040?WR[0030000003agkd0lMnm00L0lMnm00<000000>SLb03Xg<P01@3Xg<P00`00
0000oooo0?ooo`0I0?ooo`040000003oool0oooo000001`0oooo000l0?ooo`<00000O03oool00`00
0000oLi[0?g>J`020?g>J`070000003keg@0nmMd0?_GM0000000o^2C000000030?kPT`030000003i
hZ`0nN:/00D0nN:/00<000000?7O_@3agkd01P3agkd00`000000j=c80>SLb0060>SLb08000006P3o
ool010000000oooo0?ooo`00000L0?ooo`00>@3oool3000000<0oooo00<000000?ooo`3oool0N@3o
ool00`000000oLi[0?g>J`020?g>J`040000003keg@0nmMd0?_GM0L000001P3ihZ`00`000000lMnm
0?7O_@070?7O_@030000003Xg<P0j=c800L0j=c80P00000I0?ooo`040000003oool0oooo000001`0
oooo000f0?ooo`<00000PP3oool00`000000oLi[0?g>J`020?g>J`040000003keg@0nmMd000000<0
h_c>00@000000>;lcP000000j?C?0P0000030?WR[0030000003agkd0lMnm00L0lMnm00<000000>SL
b03Xg<P01`3Xg<P00`000000h=W?0000000H0?ooo`80000000<0oooo000000000000703oool001X0
oooo0P00000H0?ooo`<00000P`3oool00`000000oLi[0?g>J`030?g>J`030000003keg@0000000@0
h_c>0P0000040>Sdc`80000000<0nN:/0000003agkd01`3agkd00`000000j=c80>SLb0070>SLb003
0000003PfLl0h=W?00800000>03oool001T0oooo00@000000?ooo`3oool00000503oool3000000<0
oooo00<000000?ooo`3oool0P03oool00`000000oLi[0?g>J`020?g>J`030000003keg@0000000D0
h_c>0P0000060>Sdc`030000003agkd0lMnm00H0lMnm00<000000>SLb03Xg<P01`3Xg<P00`000000
h=W?0>3Ic`020>3Ic`800000=`3oool001T0oooo00@000000?ooo`3oool000004P3oool2000008T0
oooo00<000000?g>J`3mcV/00P3mcV/3000000D0h_c>00<000000>Sdc`3Xm<l0103Xm<l00`000000
i^gC000000070?7O_@030000003Xg<P0j=c800L0j=c800<000000>3Ic`3PfLl00`3PfLl2000003H0
oooo000I0?ooo`040000003oool0oooo000000l0oooo1@0000290?ooo`030000003mcV/0oLi[0080
oLi[0P0000050>;lcP8000001@3Xm<l01@000000i^gC0>K]d`3VkM<0000000D0lMnm00<000000>SL
b03Xg<P01`3Xg<P00`000000h=W?0>3Ic`050>3Ic`030000003oool0oooo03@0oooo000I0?ooo`04
0000003oool0oooo000000d0oooo0P00002>0?ooo`040000003mcV/0oLi[0?g>J`8000001@3Ro<h0
0`000000j?C?000000040>Sdc`030000003VkM<0i^gC00<0i^gC0P0000020?7O_@030000003Xg<P0
j=c800L0j=c800<000000>3Ic`3PfLl01P3PfLl2000003D0oooo000I0?ooo`040000003oool0oooo
000000X0oooo0`00002@0?ooo`030000003mcV/0oLi[008000001@3Ro<h010000000j?C?0>Sdc`00
00040>Sdc`030000003VkM<0i^gC00D0i^gC00<000000?7O_@000000203Xg<P00`000000h=W?0>3I
c`080>3Ic`030000003oool0oooo03<0oooo000J0?ooo`800000203oool300000980oooo00<00000
0?g>J`3mcV/00P0000060>;lcP040000003Xm<l00000000000<0j?C?00<000000>K]d`3VkM<01`3V
kM<00`000000j=c80>SLb0060>SLb0030000003PfLl0h=W?00P0h=W?00<000000=WFe@000000=03o
ool00280oooo0P00002E0?ooo`040000003mcV/00000000000H0h_c>0`0000020>Sdc`030000003X
m<l0000000T0i^gC00<000000>3Ve`0000001P3Xg<P00`000000h=W?0>3Ic`080>3Ic`030000003I
e]D0fMKE00800000<`3oool00200oooo0P00002F0?ooo`@00000103Ro<h3000000D0j?C?0P000009
0>K]d`050000003Pi]L0h>KG0>3Ve`0000001@3Xg<P00`000000h=W?0>3Ic`070>3Ic`030000003I
e]D0fMKE0080fMKE00<000000?ooo`3oool0<@3oool00200oooo0`00002C0?ooo`@0000000<0]?_>
0000003Ro<h00`0000000`3Ro<h000000>Sdc`050>Sdc`800000203VkM<00`000000h>KG0>3Ve`03
0>3Ve`050000003Xg<P0j=c80>SLb00000002@3PfLl00`000000fMKE0=WFe@030=WFe@800000<P3o
ool00200oooo3`0000260?ooo`<000000P2dnlh3000000<0h_c>00<000000>Sdc`3Xm<l0103Xm<l0
10000000i^gC0>K]d`0000060>K]d`030000003Pi]L0h>KG00D0h>KG00<000000>SLb00000002@3P
fLl00`000000fMKE0=WFe@050=WFe@8000001`3oool2000000@0oooo00<000000?ooo`3oool00`3o
ool2000001`0oooo000I0?ooo`8000001@3oool2000000T0H:;d00@0000005nQm01OXO@0Gj7d2P00
001i0?ooo`<000000`2dnlh3000000D0h_c>00<000000>Sdc`3Xm<l00`3Xm<l00`000000i^gC0>K]
d`020>K]d`030000003VkM<0i^gC0080i^gC00<000000>3Ve`3Pi]L01`3Pi]L00`000000h=W?0>3I
c`080>3Ic`030000003Ie]D0fMKE00H0fMKE00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000001/0oooo000H0?ooo`040000003oool0oooo000000<0
oooo00@000000?ooo`3oool000002@1PX_@00`000000Gj7d05nQm00605nQm0040000001LX?@0G:3d
05bPm0/00000K03oool4000000030;CkcP000000000000@00000103Ro<h00`000000j?C?0>Sdc`04
0>Sdc`030000003VkM<0i^gC0080i^gC00D000000>K]d`3VkM<0i^gC000000090>3Ve`030000003J
hM/0000000P0h=W?00<000000=WFe@3Ie]D01`3Ie]D2000000D0oooo00@000000?ooo`3oool00000
2`3oool00`000000oooo0?ooo`0I0?ooo`00603oool010000000oooo0?ooo`0000030?ooo`<00000
00<0oooo0000001PX_@0201PX_@00`000000Gj7d05nQm00605nQm0030000001LX?@0G:3d00H0G:3d
00<0000005NOm01GWo@00P1GWo@;000005h0oooo200000000`1hhO000000000000030:ccm0D00000
1@3Xm<l00`000000i^gC0>K]d`040>K]d`030000003VkM<0000000T0h>KG00D000000=[Qf`3JhM/0
f^7K000000060>3Ic`030000003Ie]D0fMKE00T0fMKE00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000090?ooo`800000703oool001P0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`020?ooo`800000201PX_@00`000000Gj7d05nQm00605nQm0030000001LX?@0G:3d
00H0G:3d00<0000005NOm01GWo@01`1GWo@00`000000D:3f052PmP02052PmPP00000DP3oool90000
0080N>7`0P0000060:ccm08000000P33lo0200000080j?C?00<000000>K]d`3VkM<01P3VkM<00`00
0000h>KG0>3Ve`070>3Ve`030000003JhM/0f^7K0080f^7K00<000000>3Ic`3PfLl00`3PfLl00`00
0000fMKE0=WFe@090=WFe@040000003CdmT00000000000<0oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0?ooo`0I0?ooo`00603oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00@0oooo00<00000062Rm01PX_@01P1PX_@00`000000Gj7d05nQm00605nQm0030000001L
X?@0G:3d00H0G:3d00<0000005NOm01GWo@01`1GWo@00`000000D:3f052PmP07052PmP0300000018
X_H0000000D00000A`3oool;000000<0N>7`0P0000060:ccm08000001P33lo02000000P0i^gC00<0
00000>3Ve`0000001`3Pi]L00`000000f^7K0=[Qf`040=[Qf`050000003PfLl0h=W?0>3Ic`000000
2`3Ie]D00`000000dm?I0=?Cf@02000000<0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000K0?ooo`00603oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00D0oooo00<00000062Rm01PX_@01P1PX_@00`000000Gj7d05nQm00605nQm0030000001LX?@0G:3d
00H0G:3d0P00000805NOm0030000001@X?H0D:3f00L0D:3f00<0000004RRmP18X_H01018X_H80000
03/0oooo1000000204K6gPH00000101hhO02000000L0[??d00<000000<?cl033lo001@33lo020000
00030<_^k0000000000000D0i^gC00@000000>3Ve`3Pi]L000001@3Pi]L2000000P0f^7K00<00000
0>3Ic`0000002`3Ie]D00`000000dm?I0=?Cf@020=?Cf@030000003oool0oooo0080oooo0P00000:
0?ooo`800000703oool001T0oooo0P0000040?ooo`8000001`3oool5000000@0H:;d00<0000005nQ
m01OXO@01P1OXO@00`000000G:3d05bPm00705bPm0030000001GWo@0Eiod00H0Eiod0P000008052P
mP0300000018X_H0B:;f00H0B:;f0P000003046UmP`000009P3ooolB000000D0N>7`0P0000070:cc
m08000001`33lo000`000000bnk/0<_^k0030<_^k08000000P3VkM<00`000000h>KG0>3Ve`020>3V
e`050000003Pi]L0h>KG0>3Ve`0000002`3JhM/00`000000fMKE0=WFe@090=WFe@030000003CdmT0
dm?I00@0dm?I00<000000?ooo`3oool0:`3oool001h0oooo00<000000?ooo`3oool0203oool01000
0000H:;d062Rm01PX_@:000000@0Gj7d00<0000005bPm01LX?@01`1LX?@00`000000Eiod05NOm007
05NOm0030000001@X?H0D:3f00H0D:3f00<0000004RRmP18X_H01`18X_H00`000000@JGf046UmP07
046UmP8000000`0jZ_@V000000L0?;gV100000000`1Wd?X000000000000500000080N>7`0P000008
0:ccm00300000033lo00`o?`00D0`o?`0P0000080<_^k08000001P3Pi]L00`000000h>KG0000000;
0=[Qf`030000003Dg=d0000000P0fMKE0P0000080=?Cf@030000003oool0oooo02X0oooo000N0?oo
o`030000003oool0oooo00T0oooo00<00000062Rm01PX_@01P1PX_@010000000GZ?e05jSm@1NXoDE
000000@0Eiod00<00000052PmP1@X?H01P1@X?H00`000000B:;f04RRmP0704RRmP8000002@11YOH2
000000T0>Z[d0P00000:03N_l08000002`0g]N/4000000@0?;gV1000000306O@nP8000001P1Wd?X4
000000L0[??d0P0000070<?cl0030000003;k^`0bnk/00L0bnk/0P0000000`3=j>X000000>3Ve`04
0>3Ve`8000002P3JhM/2000000<0e=cM00<000000=WFe@3Ie]D0103Ie]D00`000000dm?I0=?Cf@08
0=?Cf@030000003oool0oooo02X0oooo000N0?ooo`8000002`3oool00`000000H:;d062Rm006062R
m0030000001NXoD0GZ?e00H0GZ?e00<0000005fUmP1MYOH01`1MYOH00`000000G:Sh05bXn00205bX
n0X00000101@X?H00`000000B:;f04RRmP0804RRmP8000002@11YOH2000000T0>Z[d0P00000:03N_
l0800000200g]N/9000000@0Im3j0`00000406O@nP@00000102:g_h300000080[??d0P0000070<?c
l08000002@3;k^`00`000000cNSZ0<gXjP020<gXjP8000000`3Pi]L2000000T0f^7K00<000000=CL
g@3Dg=d00`3Dg=d00`000000fMKE0=WFe@030=WFe@030000003CdmT0dm?I00X0dm?I00<000000?oo
o`3oool0:@3oool001h0oooo0P00000<0?ooo`8000001`1PX_@00`000000GZ?e05jSm@0605jSm@03
0000001MYOH0GJGf00L0GJGf00<0000005bXn01LZ?P01`1LZ?P010000000Fj_i05^[n@1KZoTk0000
00P0HLGl1@00000306O@nP@000002`2:g_h3000000L0`o?`00<000000<_^k03;k^`0203;k^`00`00
0000cNSZ0<gXjP050<gXjP030000003Pi]L000000080f^7K00<000000=[Qf`3JhM/01@3JhM/00`00
0000e=cM0=CLg@050=CLg@050000003Ie]D0fMKE0=WFe@000000303CdmT00`000000cM3L0000000Z
0?ooo`007P3oool00`000000oooo0?ooo`0=0?ooo`030000001PX_@0H:;d00D0H:;d00<0000005jS
m@1NXoD01P1NXoD2000000P0GJGf00<0000005bXn01LZ?P01`1LZ?P00`000000Fj_i05^[n@0605^[
n@030000001K[_X0Fjkj00T0Fjkj00<0000005^bn`1K/_/0201K/_/2000000X0G;Ol0P00000:05jm
o@8000002`1QaO`3000000030675o0000000000000<000003@2:g_h2000000<0XNCl0`0000020<?c
l08000002@3;k^`2000000T0cNSZ00<000000=[Qf`3JhM/00P3JhM/00`000000f^7K0=[Qf`030=[Q
f`030000003Dg=d0e=cM00L0e=cM00<000000=WFe@0000002`3CdmT200000080cM3L0P00000Y0?oo
o`007P3oool00`000000oooo0?ooo`0>0?ooo`030000001PX_@0H:;d00D0H:;d00<0000005jSm@1N
XoD01`1NXoD00`000000GJGf05fUmP0605fUmP800000201LZ?P2000000L0Fj_i0P00000:05^^nP03
0000001K/_/0Fk;k00T0Fk;k00<0000005bgo01L]o`02@1L]o`00`000000G[gm05jmo@0905jmo@80
00001P1QaO`7000000<0NM3o0P00000:08[NoP<00000202Qi?`2000000X0bnk/00<000000<gXjP3=
j>X01`3=j>X2000000030<cSj0000000f^7K0080f^7K00<000000=[Qf`3JhM/00P3JhM/00`000000
e=cM0=CLg@090=CLg@030000003CdmT0dm?I00T0dm?I00<000000<g@g03=d=`00`3=d=`00`000000
oooo0?ooo`0W0?ooo`007P3oool200000100oooo1@000003062Rm0030000001NXoD0GZ?e00L0GZ?e
00<0000005fUmP1MYOH01`1MYOH00`000000G:Sh05bXn00705bXn0030000001KZoT0Fj_i00H0Fj_i
00<0000005^^nP1K[_X0201K[_X2000000X0Fk;k0P00000:05bgo0030000001N_Od0G[gm00X0G[gm
0P0000000`1QaO`0000000000004000000T0NM3o0P00000608[NoP8000002@2Qi?`200000080[^Ci
0P0000070<_^k0030000003=j>X0cNSZ00L0cNSZ00<000000<cSj03<hnP00P3<hnP01P000000f^7K
0=[Qf`3JhM/000000=[Qf`8000002P3Dg=d2000000030<oHg`000000dm?I00P0dm?I00<000000<g@
g03=d=`0103=d=`2000002P0oooo000;0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`@0
00000`3oool00`000000oooo0?ooo`0A0?ooo`040000001WYO@0IjGd06NUm1@00000101MYOH00`00
0000G:Sh05bXn00705bXn0030000001KZoT0Fj_i00H0Fj_i00<0000005^^nP1K[_X02@1K[_X00`00
0000Fk;k05^bn`0905^bn`8000002@1L]o`2000000L0G[gm2000000?07W@o`8000000P2:g_h20000
00T0XNCl0P0000060:kTn@030000003;k^`0bnk/0080bnk/0P0000090<gXjP030000003<hnP0c>?X
00@0c>?X00D000000=[Qf`3JhM/0f^7K0000000;0=CLg@030000003?f=l0cmSO0080cmSO00<00000
0=?Cf@3CdmT01@3CdmT00`000000cM3L0<g@g0060<g@g0030000003oool0oooo02H0oooo000:0?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B
0?ooo`030000001WYO@0IjGd00D0IjGd00<0000006FWmP1UYoH01`1UYoH00`000000I:Wg06BYm`02
06BYmaD000000`1KZoT2000000X0Fjkj00<0000005^bn`1K/_/0101K/_/K000000@0L<Go0P00000=
07W@o`D000002@2Qi?`2000000T0[^Ci0P0000000`3;k^`000000<gXjP080<gXjP800000203<hnP0
1@000000f^7K0000003Dg=d0000000T0e=cM00<000000<oHg`3?f=l00`3?f=l00`000000dm?I0=?C
f@040=?Cf@030000003=d=`0cM3L00L0cM3L0`00000V0?ooo`002P3oool010000000oooo0?ooo`00
00090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000IjGd06NU
m00506NUm0030000001UYoH0IJOf00L0IJOf00<0000006BYm`1TZOL01`1TZOL00`000000I:ch06B/
n00706B/n0030000001T[oX0I:oj0080I:oj5P00000706Nho08000002@1[_Oh2000000040735o`00
00000000000000T0L<Go0P00000507W@o`H00000102<e_l2000000H0XNCl0P00000<0:kTn@800000
2@3=j>X00`000000c>?X0<cSj0090<cSj0040000003Dg=d0e=cM000000L0e=cM0P0000070<oHg`04
0000003CdmT0dm?I0=?Cf@8000002`3=d=`2000002H0oooo000:0?ooo`040000003oool0oooo0000
00X0oooo00<000000?ooo`3oool00P3oool2000001D0oooo00<0000006NUm01WYO@01@1WYO@00`00
0000IJOf06FWmP0706FWmP030000001TZOL0I:Wg00L0I:Wg00<0000006B/n01T[?P01`1T[?P00`00
0000I:oj06B_nP0706B_nP8000002@1U/o/2000000`0IkSl00<0000006^moP1[_Oh01`1[_Oh30000
00/0L<Go1`00000<08cFo`8000000P2Qi?`2000000`0[^Ci0P0000020;KRm@030000003=j>X0cNSZ
00D0cNSZ00<000000<cSj03<hnP0203<hnP2000000050<WNj0000000e=cM0=CLg@0000001@3Dg=d0
0`000000cmSO0<oHg`080<oHg`030000003CdmT0000000/0cM3L0P0000000`39c]h000000?ooo`0U
0?ooo`002P3oool010000000oooo0?ooo`00000;0?ooo`050000003oool0oooo0?ooo`0000005`3o
ool00`000000IjGd06NUm00506NUm0800000201UYoH2000000P0I:Wg0P00000806B/n08000002@1T
[oX00`000000IK?k06Fcn`0806Fcn`030000001W^?`0IkSl00X0IkSl00<0000006^moP1[_Oh00`1[
_Oh3000000<0Jkgn0P0000030735o`H00000101obol2000000h0S=Ko0`00000<0:kTn@8000001@2f
h_D2000000<0cNSZ0P00000:0<cSj00300000039g^P0bMkX0080bMkX00@000000=CLg@3Dg=d00000
0`3Dg=d00`000000cmSO0<oHg`0:0<oHg`030000003=d=`0cM3L00T0cM3L00@000000<W>gP39c]h0
bLkN0P0000080?ooo`800000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0
oooo000:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`0F0?ooo`030000001WYO@0IjGd00H0IjGd00<0000006FWmP1UYoH01`1UYoH00`00
0000I:Wg06BYm`0706BYm`030000001T[?P0I:ch00L0I:ch00<0000006B_nP1T[oX01`1T[oX00`00
0000IK?k06Fcn`0806Fcn`030000001W^?`0IkSl00X0IkSl1@00000306^moPP00000301obol20000
00P0S=Ko1000000309WHo@800000202^i?T2000000T0]^;e00<000000<gXjP0000002`3<hnP00`00
0000bMkX0<WNj0040<WNj0040000003Dg=d000000=CLg@8000002`3?f=l2000000030<_Dh@000000
cM3L00P0cM3L00<000000<W>gP39c]h00`39c]h2000000H0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0=0?ooo`002`3oool2000000X0oooo0P0000030?ooo`030000003oool0
000001P0oooo1@00000406NUm0030000001UYoH0IJOf00L0IJOf00<0000006BYm`1TZOL01`1TZOL0
0`000000I:ch06B/n00706B/n0030000001T[oX0I:oj00L0I:oj0P00000906Fcn`8000001P1W^?`<
000000H0Ml;n0P00000>07o;o`8000000P2<e_l4000000T0VMSm00<000000:kTn@2^i?T00`2^i?T2
000000`0]^;e00<000000<cSj03<hnP0203<hnP2000000P0bMkX00<000000=CLg@000000303?f=l0
1@000000bmCQ0<_Dh@3;e>40000000L0cM3L0P0000070<W>gP030000003oool0oooo00@0oooo00@0
00000?ooo`3oool000001`3oool5000000h0oooo000L0?ooo`8000006P3oool010000000KJSd06fX
m01]Z?A2000000@0LKcm00<0000007O2oP1g`_h02P1g`_h00`000000Ol_o07o;o`0;07o;o`@00000
3P2If?d2000000030:kTn@000000000000`0]^;e0P0000000`2igo<00000000000070<cSj0030000
0039g^P0bMkX00T0bMkX00<000000<oHg`0000002@3?f=l2000000D0bmCQ00<000000<g@g03=d=`0
0`3=d=`00`000000bLkN0<W>gP080<W>gP030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00001`3oool010000000oooo0?ooo`00000?0?ooo`00703oool00`000000oooo0?ooo`0J0?ooo`03
0000001]Z?@0KJSd00H0KJSd00<0000006bZmP1/Z_H01`1/Z_H00`000000Jjcg06^/m`0706^/m`03
0000001[[oT0Jjoi00L0Jjoi00<0000006bbnP1//_X0201//_X00`000000K[Ok06jgn`0806jgn`D0
0000201a_?d00`000000Ml;n07O2oP0:07O2oP030000001obol0Ol_o00H0Ol_o1000000308_>oP03
0000002If?d0VMSm00d0VMSm0P00000<0;KRm@8000001@2igo<00`000000c>?X0<cSj0030<cSj003
00000039g^P0bMkX00P0bMkX0P0000001036f^P000000<oHg`0000070<oHg`030000003;e>40bmCQ
00H0bmCQ00D000000<g@g03=d=`0cM3L0000000;0<W>gP800000103oool010000000oooo0?ooo`00
00080?ooo`030000003oool0000000l0oooo000L0?ooo`030000003oool0oooo01/0oooo00<00000
06fXm01]Z?@01P1]Z?@00`000000K:[f06bZmP0706bZmP030000001[[?L0Jjcg00L0Jjcg00<00000
06^_n@1[[oT01`1[[oT00`000000K;;j06bbnP0806bbnP030000001^]o/0K[Ok00H0K[Ok1000000;
076lo@8000002`1g`_h200000080Ol_o1000000808_>oP030000002If?d0VMSm00T0VMSm0`000002
0:;In`800000202fh_D2000000P0^Moc0P0000000`3<hnP000000000000:0<WNj00300000036f^P0
a][X0080a][X0P0000050<oHg`8000002@3;e>4010000000cM3L00000000000=0<W>gP8000000`3o
ool010000000oooo0?ooo`0000090?ooo`8000003`3oool001`0oooo0P00000M0?ooo`030000001]
Z?@0KJSd00H0KJSd0P00000806bZmP800000201[[?L2000000P0Jjoi0P00000906bbnP8000000`1^
]o/3000000@0K[Ok00<00000076lo@1a_?d02P1a_?d00`000000Ml;n07O2oP0407O2oPP000003@2;
c_h2000000H0VMSm0`0000070:;In`030000002fh_D0]^;e00<0]^;e0P00000;0;WOl`8000002P39
g^P2000000H0a][X0P0000030<oHg`030000003;e>40bmCQ00X0bmCQ00<000000<W>gP39c]h02`39
c]h2000000030<G<g`000000oooo00<0oooo0P00000;0?ooo`030000003oool0oooo00d0oooo000L
0?ooo`030000003oool0oooo01d0oooo00<0000006fXm01]Z?@01`1]Z?@00`000000K:[f06bZmP07
06bZmP030000001[[?L0Jjcg00L0Jjcg00<0000006^_n@1[[oT01`1[[oT00`000000K;;j06bbnP08
06bbnP<00000201^]o/2000000H0LKcm2`0000070876o@8000003P2;c_h00`000000VMSm09WHo@03
000000/0X]Wk0P0000000`2fh_D000000000000;0;WOl`8000000P2kfo000`000000bMkX0<WNj005
0<WNj08000002@36f^P4000000/0bmCQ0P0000000`37d^8000000<W>gP0:0<W>gP0400000035c=l0
aLcO0<G<g`800000803oool001`0oooo00<000000?ooo`3oool07P3oool00`000000KJSd06fXm007
06fXm0030000001/Z_H0K:[f00L0K:[f00<0000006^/m`1[[?L01`1[[?L00`000000Jjoi06^_n@07
06^_n@030000001//_X0K;;j00D0K;;j0P0000000`1//_X0000006jgn`0506jgn`/000001P1k_o`2
000000`0PLKm00<0000008_>oP2;c_h02@2;c_h5000000l0X]Wk0P00000;0;WOl`8000001@2kfo02
000000@0bMkX00<000000<KJj036f^P02P36f^P00`000000bmCQ0<_Dh@0:0<_Dh@0300000037d^80
am;R0080am;R00<000000<W>gP39c]h01P39c]h2000000D0aLcO00<000000?ooo`3oool07P3oool0
01/0oooo00<000000?ooo`3oool0803oooli000000H0M[[k0P00000;07^oo00300000021a_d0PLKm
00X0PLKm0P00000308_>oPH00000102Dd?`2000000/0X]Wk0`0000020:SHn0030000002igo<0^Moc
00H0^Moc0P0000090;_Kl00400000039g^P00000000000/0a][X0P0000000`34e^P000000<_Dh@09
0<_Dh@0300000037d^80am;R00<0am;R00<000000<W>gP39c]h01039c]h2000000L0aLcO0P00000O
0?ooo`006`3oool300000240oooo00<0000007>Zm01cZ_@01`1cZ_@00`000000LZcf07:/mP0707:/
mP030000001b[oL0LZog00L0LZog00<0000007:bn01b/_P01`1b/_P3000000P0M;Gj0P00000;07Jj
n`030000001k_o`0Nkol00T0Nkol00<000000876o@21a_d02@21a_d5000000`0U=3l00<000000:;I
n`2RfO/01@2RfO/3000000H0Z=Sh0P0000040;WOl`800000302kfo000`000000a][X0<KJj00:0<KJ
j00300000034e^P0a=KX0080a=KX00<000000<_Dh@3;e>401@3;e>42000000L0am;R00<000000<W>
gP39c]h00P39c]h00`000000aLcO0<G<g`080<G<g`030000003oool0oooo01d0oooo00080?ooo`80
0000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool08P3oool00`000000Lj[d07>Zm00707>Zm0030000001b[?H0LZcf00L0LZcf00<0000007:_m`1b
[oL01`1b[oL00`000000L[;h07:bn00307:bn0<0000000<0L[;h0000001d]OX02P1d]OX00`000000
M[[k07Jjn`0907Jjn`030000001k_o`0Nkol00T0Nkol0P0000030876o@H000000`29b?`00`000000
U=3l09C@o00<09C@o08000000P2RfO/3000000/0Z=Sh00@000000;WOl`0000000000302kfo020000
00030;_Hk`000000a][X00P0a][X0P0000050<CFj08000001@3;e>400`000000am;R0<OBhP080<OB
hP0400000039c]h00000000000/0aLcO0P00000N0?ooo`001`3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool08`3oool2000000P0Lj[d0P000008
07:/mP800000201b[oL5000000D0L[;h0P00000:07BenP030000001f^_/0M[[k00T0M[[k0P000006
07^oo0P000002P29b?`00`000000U=3l09C@o00;09C@o0@000003P2Xf?P2000000`0^m_`0P000004
0;_Hk`0300000036f^P0a][X00@0a][X0P0000080<CFj0030000003;e>40bmCQ0080bmCQ00<00000
0<OBhP37d^802P37d^800`000000aLcO0<G<g`0<0<G<g`8000007@3oool000L0oooo00@000000?oo
o`3oool000001`3oool5000000@0oooo00<000000?ooo`3oool09@3oool00`000000Lj[d07>Zm007
07>Zm0030000001b[?H0LZcf00L0LZcf00<0000007:_m`1b[oL0101b[oL4000000T0L[;h00<00000
07BenP1d]OX0201d]OX2000000H0M[[k2`00000608;1o00300000029b?`0RLSl00X0RLSl0P000007
09C@o0@000000`2Kd?X2000000X0Z=Sh0`0000020:cFmP800000202kfo02000000L0^mS_00<00000
0<KJj036f^P00P36f^P00`000000a=KX0<CFj0090<CFj0040000003;e>400000000000/0am;R0P00
00000`33cn<000000<G<g`0:0<G<g`80000000<0`L[Q0000003oool0703oool000L0oooo00@00000
0?ooo`3oool000001`3oool010000000oooo0?ooo`0000050?ooo`8000009`3oool00`000000Lj[d
07>Zm00707>Zm0030000001b[?H0LZcf00L0LZcf00<0000007:_m`1b[oL00`00000407:_m`030000
001b/_P0L[;h00L0L[;h00<0000007BenP1d]OX0101d]OX;000000H0OKck00<0000008;1o022`O`0
2@22`O`00`000000RLSl08W8o00;08W8o0030000002Dd?`0U=3l00@000002@2Kd?X00`000000Z=Sh
0:SHn0050:SHn08000001`2/e_H00`000000^m_`0;_Kl0030;_Kl08000002P2kf>l010000000a][X
00000000000=0<CFj00300000037d^80am;R00X0am;R00D000000<??h`33cn<0`loS000000090<G<
g`8000000`31b^42000001`0oooo00040?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool01P3oool00`000000oooo000000050?ooo`030000003oool0oooo02L0oooo;P00000607Zh
n@030000001m_?/0OKck00T0OKck00<0000008;1o022`O`02@22`O`2000000X0RLSl1000000>09_@
nP8000000P2Xf?P3000000X0[=Kf0P0000000`2kfo0000000000000=0;_Hk`0300000034e^P0a=KX
00/0a=KX0P0000000`31dnP000000<OBhP080<OBhP8000001@33cn<00`000000aLcO0<G<g`040<G<
g`8000001P31b^42000001/0oooo00030?ooo`050000003oool000000?ooo`0000000P3oool00`00
0000oooo0?ooo`070?ooo`800000103oool00`000000oooo0?ooo`0Y0?ooo`030000001i[O@0NJgd
00L0NJgd00<0000007R_m@1h[oD00`1h[oD200000080N:oe00<0000007Ram`1h/OL01`1h/OL00`00
0000N;Ch07Rdn00707Rdn08000002P1j^?T00`000000OKck07fln`0907fln`8000002`22`O`01000
0000RLSl08W8o029b?`6000000<0T<Wk0P00000=09_@nP@000003P2/e_H2000000d0^mS_0P000000
0`2jeNh000000<CFj0090<CFj08000000`31dnP2000000H0am;R0P0000080<??h`0400000035c=l0
aLcO0<G<g`8000002@31b^42000001X0oooo00030?ooo`030000003oool000000080oooo0P00000;
0?ooo`030000003oool0oooo0080oooo0P00000[0?ooo`030000001i[O@0NJgd00L0NJgd00<00000
07R_m@0000000P00000507R_m@030000001h/OL0N;7g00L0N;7g00<0000007Rdn01h]?P0201h]?P0
0`000000N[Si07Zhn@0807Zhn@030000001m_?/0OKck00X0OKck00<0000008;1o022`O`01022`O`8
000000/0T<Wk00<0000009_@nP2Kd?X01P2Kd?X4000000<0X=3h00<000000:cFmP2/e_H02P2/e_H2
00000080[]Cd00<000000;_Hk`2kf>l0202kf>l2000000@0^]G^00<000000<CFj034e^P01@34e^P2
000000H0`M?X0P0000040<OBhP0300000033cn<0`loS00P0`loS00@000000<G<g`00000000002`31
b^42000001X0oooo00030?ooo`030000003oool0000001@0oooo00<000000?ooo`3oool0:`3oool0
0`000000NJgd07V]m00507V]m0@00000201h[oD2000000P0N;7g0P00000907Rdn0030000001j^?T0
N[Si00P0N[Si00<0000007fln`1m_?/0201m_?/8000000H0RL?k00<000000939n`2@bO/02`2@bO/2
00000080Vm3j100000080:3@n0030000002/e_H0[=Kf00H0[=Kf0`0000050:kDm0030000002kf>l0
^mS_00D0^mS_0P0000070;[EkP0300000034e^P0a=KX0080a=KX0P0000090<7Cj080000000<0am;R
0000000000003033cn<00`000000`L[Q0<7:h@0<0<7:h@8000006@3oool00080oooo00D000000?oo
o`3oool0oooo0000000C0?ooo`030000003oool0oooo02`0oooo00@0000007V]m01i[O@0NJgd0`00
000407V]m0030000001h[oD0N:oe00L0N:oe00<0000007Ram`1h/OL01`1h/OL00`000000N;Ch07Rd
n00707Rdn08000002@1j^?T010000000OKck07fln`1m_?/6000000<0Q;kj00<0000008W3n`29`o/0
2@29`o/00`000000T<Wk0939n`0;0939n`<000003@2Pd?P00`000000[=Kf0:cFmP030:cFmP800000
2@2^e?@00`000000^mS_0;_Hk`020;_Hk`8000002P2jeNh010000000a=KX00000000000;0<7Cj003
00000031dnP0000000`0`loS0P0000000`30cN@000000<7:h@0:0<7:h@80000000<0_/SR0000003o
ool01`3oool2000000@0oooo00<000000?ooo`3oool00P3oool3000000<0oooo00020?ooo`800000
00<0oooo0000000000004`3oool00`000000oooo0?ooo`0]0?ooo`<00000201i[O@00`000000N:oe
07R_m@0707R_m@030000001h/OL0N;7g00L0N;7g00<0000007Rdn01h]?P00`1h]?PB000000X0Q;kj
00<0000008W3n`29`o/02@29`o/2000000L0T<Wk1000000209K:n@030000002Pd?P0X=3h00`0X=3h
00<000000:cFmP2/e_H00P00000<0:kDm0040000002kf>l00000000000`0^]G^0P00000=0<7Cj080
000000<0_]7X00000033cn<02033cn<2000000@0`<gT00<000000<7:h@31b^401P31b^42000000@0
_/SR00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000;0?ooo`4000000@3oool10?oo
o`006P3oool2000002/0oooo0`0000000`3oool0000007V]m00407V]m1h000001P1n]_P00`000000
P;[i082jn@07082jn@8000002`24__X00`000000RL?k08W3n`0:08W3n`030000002@bO/0T<Wk00@0
00001`2Fb_T00`000000X=3h0:3@n00;0:3@n0<000003P2^e?@2000000`0^]G^0P0000020;WBk@03
00000031dnP0`M?X00P0`M?X0P0000020;kAj0030000002ndNP0000000H0`loS0P0000060<3=i003
00000031b^40`L[Q00D0`L[Q00<000000;k8hP2nb>80102nb>82000000D0oooo00@000000?ooo`3o
ool000002`3oool100000040oooo0@3oool001T0oooo0P00000Y0?ooo`<000001@3oool5000000H0
OJoc00<0000007fam@1m/OD01`1m/OD00`000000OK?f07fcmP0707fcmP030000001n]_P0O[Kh00P0
O[Kh00<00000082jn@20^_T02020^_T00`000000Q;kj08BnnP0908BnnP0300000029`o/0RL?k00P0
RL?k1000000<09K:n@8000001`2Pd?P400000080Xlog0P00000:0:kDm0<000000P2`d_800`000000
^]G^0;[EkP070;[EkP8000001@2id^d00`000000`M?X0<7Cj0050<7Cj08000001@2ndNP2000000@0
`loS0P0000090<3=i00300000031b^40`L[Q0080`L[Q0P0000080;k8hP030000003oool0oooo00<0
oooo00@000000?ooo`3oool00000203oool3000000<0oooo000I0?ooo`030000003oool0oooo02D0
oooo0`0000090?ooo`030000001m[o<0OJoc00P0OJoc00<0000007fam@1m/OD01`1m/OD00`000000
OK?f07fcmP0707fcmP030000001n]_P0O[Kh00P0O[Kh00<00000082jn@20^_T02020^_T00`000000
Q;kj08BnnP0908BnnP0400000029`o/0RL?k08W3n`H000000`2?a?T2000000d0U/[i00<000000:3@
n02Pd?P0100000080:??m`030000002^e?@0[]Cd00D0[]Cd0P0000060;3BlP8000001@2jeNh20000
00P0^M;]00<000000<7Cj031dnP00P31dnP2000000L0_]7X00@000000;kAj0000000`loS0P00000<
0<3=i00400000031b^400000000000/0_/SR00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000080?ooo`030000003oool0oooo00<0oooo000I0?ooo`030000003oool0oooo0280oooo0`00
000=0?ooo`030000001m[o<0OJoc00P0OJoc00<0000007fam@1m/OD01`1m/OD00`000000OK?f07fc
mP0707fcmP8000002@1n]_P00`000000P;[i082jn@08082jn@8000001@24__X8000000/0SlCi00<0
000009K:n@2Fb_T02@2Fb_T4000000d0Xlog0P0000020:kDm0<000002P2`d_800`000000^]G^0;[E
kP02000000/0^M;]00@000000<7Cj000000000002P2ndNP00`000000_]7X0000000?0<3=i0030000
002nb>80_/SR00/0_/SR0P0000030?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3o
ool00`3oool001T0oooo0`00000P0?ooo`8000004@3oool2000000T0OJoc00<0000007fam@1m/OD0
1`1m/OD00`000000OK?f07fcmP0807fcmP030000001n]_P0O[Kh00L0O[Kh00<00000082jn@20^_T0
1020^_T:000000H0RKoi0P00000<08o4n@8000000`2Fb_T6000000<0V/[h00<000000:??m`2ScoL0
302ScoL3000000d0/=;b0`00000=0;WBk@800000302ndNP2000000030;c>j0000000`<gT00/0`<gT
0P0000000`2mbnD000000;k8hP0:0;k8hP8000001@3oool2000000T0oooo100000020?ooo`006@3o
ool00`000000oooo0?ooo`0M0?ooo`<000005@3oool00`000000OJoc07f_l`0707f_l`030000001m
/OD0OK7e00L0OK7e00<0000007fcmP1m/oH00`1m/oHE000000H0Q[_h00<0000008Von@29_oT02@29
_oT00`000000SlCi08o4n@0908o4n@D000002P2Jb_P00`000000Xlog0:??m`080:??m`<000000P2V
c_D00`000000/=;b0;3BlP090;3BlP8000000P2`d?400`000000^M;]0;WBk@090;WBk@8000000P2h
d>`00`000000_]7X0;kAj0070;kAj08000000P2lc^P00`000000_<kX000000090<3=i08000000`2m
bnD00`000000_/SR0;k8hP070;k8hP80000000<0oooo0000003oool05@3oool000H0oooo0P000004
0?ooo`030000003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo01X0oooo0`00000I
0?ooo`030000001m[o<0OJoc00<0OJoc4`00000608:emP0300000023^?L0PkSg00L0PkSg00<00000
08Jkn026^oP02@26^oP00`000000RKoi08Von@0908Von@8000000`2?a?T6000000<0TlGh00<00000
09[:n02Jb_P02P2Jb_P2000000H0Xlog0P0000060:K>m@030000002`d_80/=;b00H0/=;b0P000005
0;3@l@030000002id^d0^M;]00H0^M;]0P0000050;S@k0030000002ndNP0_]7X00@0_]7X0P000004
0;c>j0030000002lc^P0000000L0`<gT0P0000060;g;i@030000002nb>80_/SR00@0_/SR0P000004
0?ooo`030000003oool0oooo01<0oooo00050?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0G0?ooo`<000007@3oool5000000D0P[3c00<0
000008:bm022/_@01`22/_@00`000000P[Gf08:emP0808:emP0300000023^?L0PkSg00L0PkSg00<0
000008Jkn026^oP02@26^oP2000000T0RKoi1@00000:09?5n0030000002Jb_P0V/[h00/0V/[h00<0
00000:??m`2ScoL00`0000090:K>m@030000002`d_80/=;b00<0/=;b0P0000080;3@l@030000002i
d^d0^M;]00<0^M;]0P0000070;S@k0030000002ndNP0_]7X0080_]7X0P0000070;c>j0030000002l
c^P0000000@0`<gT0P0000090;g;i@040000002nb>80_/SR0;k8hP8000001P3oool00`000000oooo
0?ooo`0C0?ooo`001@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0
oooo0P00000F0?ooo`<000008@3oool00`000000P[3c08:`l`0708:`l`0300000022/_@0P[;d00L0
P[;d00<0000008:emP22]OH02022]OH00`000000PkSg08>hm`0708>hm`8000002`26^oP010000000
RKoi08Von@29_oT5000000<0S/3h00<0000009?5n02CaOP02P2CaOP2000000X0V/[h1000000=0:K>
m@030000002`d_80/=;b008000002`2`d?400`000000^M;]0;WBk@02000000X0^=3/00@000000;kA
j000000000002P2lc^P010000000_<kX00000030cN@2000000/0_L_U00@000000;k8hP0000000000
203oool00`000000oooo0?ooo`0C0?ooo`001@3oool010000000oooo0?ooo`0000080?ooo`<00000
103oool00`000000oooo0?ooo`0B0?ooo`<000009@3oool00`000000P[3c08:`l`0708:`l`800000
2022/_@00`000000P[Gf08:emP0808:emP0300000023^?L0PkSg00P0PkSg00<0000008Jkn026^oP0
1026^oP8000000T0S/3h00<0000009?5n02CaOP02`2CaOP010000000V/[h09[:n02Jb_P6000000<0
W/Wf00<000000:K>m@2Vc_D02`2Vc_D3000000d0/=3a0`00000<0;S@k0800000302lc^P010000000
_<kX00000000000=0;g;i@8000002P3oool00`000000oooo0?ooo`0C0?ooo`001@3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool30000
02T0oooo00<0000008:`l`22/?<02022/?<00`000000P[;d08:bm00608:bm00300000022]OH0P[Gf
00P0P[Gf00<0000008>hm`23^?L00`23^?L;000000H0R[cg00<0000008k0n02>`?P02@2>`?P20000
00X0TlGh1@00000:09k9mP8000001`2Vc_D400000080Z<gc00<000000;3@l@2`d?40202`d?430000
0080/<k_00<000000;S@k02hd>`0202hd>`200000080]lk/00<000000;c>j02lc^P02@2lc^P20000
0080^/cX00<000000;g;i@2mbnD0202mbnD2000000`0oooo00<000000?ooo`3oool04`3oool000D0
oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00`0oooo0`00000]0?ooo`0300000022/?<0P[3c00P0P[3c00<0000008:bm022/_@01P22/_@00`00
0000P[Gf08:emP0308:emPX000001P28^OH00`000000R[cg08Zlm`0908Zlm`030000002>`?P0S/3h
00X0S/3h00@0000009?5n02CaOP0TlGh1P00000309O5m`030000002NbOH0W/Wf00/0W/Wf00<00000
0:K>m@2Vc_D0100000070:S=l`8000001P2`d?42000000H0/<k_00<000000;S@k02hd>`01@2hd>`2
000000D0]lk/00<000000;c>j02lc^P01P2lc^P200000080^/cX00@000000;[<j02jc>P000001`2m
bnD2000000h0oooo00<000000?ooo`3oool04`3oool000H0oooo0P00000:0?ooo`<000000`3oool2
000000X0oooo0`00000a0?ooo`0300000022/?<0P[3c00<0P[3c4`00000608Jfm@0300000028^OH0
R;Wf00P0R;Wf00<0000008Zlm`2:_?L02@2:_?L2000000T0S/3h1@00000:09O5m`030000002NbOH0
W/Wf00X0W/Wf0`00000=0:S=l`030000002`d?40/=3a00<000002@2`c^l00`000000^=3/0;S@k002
0;S@k0800000202gc^`00`000000_<kX0;c>j0030;c>j08000001@2jc>P00`000000^/cX00000005
0;g;i@800000403oool00`000000oooo0?ooo`0C0?ooo`00603oool00`000000oooo0?ooo`070?oo
o`800000=@3oool5000000H0Q[;b00<0000008Jdl`26]?<01P26]?<2000000T0Q[Ke00<0000008Ri
mP28^OH02028^OH2000000/0R[cg00@0000008k0n02>`?P0S/3h1@00000309;1m`030000002GaOL0
UlGg00X0UlGg00<0000009k9mP2NbOH01@2NbOH400000080X<We00<000000:S=l`2XcO<02`2XcO<3
000000d0/<k_00@000000;S@k000000000002`2gc^`00`000000_<kX0;c>j002000000L0^/cX00@0
00000;[<j02jc>P000000P2mbnD2000001<0oooo00<000000?ooo`3oool04P3oool001L0oooo00<0
00000?ooo`3oool01@3oool3000003P0oooo00<0000008JblP26/_802026/_800`000000Q[Cc08Jd
l`0708Jdl`0300000026]_D0Q[Ke00L0Q[Ke0P00000:08RimP030000002:_?L0R[cg00@0R[cg2000
000909;1m`030000002GaOL0UlGg00X0UlGg00<0000009k9mP2NbOH0100000070:39m@030000002X
cO<0Z<gc00L0Z<gc0`0000020:W<lP030000002`c^l0/<k_00/0/<k_0P00000=0;O>k0<000002P2j
c>P00`000000^/cX00000002000001D0oooo00<000000?ooo`3oool04P3oool001L0oooo00<00000
0?ooo`3oool00P3oool3000003`0oooo00<0000008JblP26/_802026/_800`000000Q[Cc08Jdl`07
08Jdl`0300000026]_D0Q[Ke00P0Q[Ke00<0000008RimP28^OH00`28^OH;000000H0S[gf00<00000
09;1m`2B`OL02@2B`OL2000000T0UlGg1000000<0:39m@030000002XcO<0Z<gc00@0Z<gc0P000006
0:W<lP030000002`c^l0/<k_00L0/<k_0`0000020;3=k`030000002gc^`0]lk/00P0]lk/0P000002
0;K<j`030000002jc>P0^/cX00P0^/cX0P00000H0?ooo`030000003oool0oooo0180oooo000G0?oo
o`D00000@03oool00`000000Q[;b08JblP0808JblP0300000026]?<0Q[Cc00L0Q[Cc0P00000508Jf
m@T000001P2<^_D00`000000S[gf08jmmP0908jmmP030000002B`OL0T/7g00X0T/7g00@0000009O5
m`2GaOL0UlGg1@00000309[5m@030000002PbOD0X<We00/0X<We00<000000:S=l`2XcO<00`000009
0:W<lP030000002`c^l0/<k_00@0/<k_0P0000060;3=k`030000002gc^`0]lk/00D0]lk/0P000005
0;K<j`030000002jc>P0^/cX00D0^/cX0P0000020?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool04P3oool001L0oooo0P0000140?ooo`0300000026/_80Q[;b00P0Q[;b00<0000008Jd
l`26]?<00`26]?<:000000D0R[Sd00<0000008bjm@2<^_D0202<^_D00`000000S[gf08jmmP0908jm
mP030000002B`OL0T/7g00P0T/7g1@00000909[5m@030000002PbOD0X<We00X0X<We0`00000=0:W<
lP030000002`c^l0/<k_00<00000202`cNl00`000000]lk/0;O>k0030;O>k08000001`2fc>/00`00
0000^/cX0;[<j0030;[<j0800000103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0180oooo000H0?ooo`030000003oool0oooo04<0oooo00<0000008JblP26/_800`26/_8:000000H0
RKGc00<0000008Zhm02:^?@01`2:^?@00`000000S;[e08bjm@0808bjm@8000002P2>_OH010000000
T/7g09;1m`2B`OL6000000<0UL7e00<0000009[5m@2JaOD02@2JaOD2000000H0X<We100000020:;8
l`030000002Yc?80ZLcb00/0ZLcb0`00000<0;3=k`030000002gc^`0]lk/008000002P2fc>/00`00
0000^/cX0;[<j002000000L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0B0?oo
o`006@3oool2000004@0oooo1@00000608Zcl@0300000029]O<0RKGc00P0RKGc00<0000008Zhm02:
^?@01`2:^?@00`000000S;[e08bjm@0908bjm@030000002>_OH0S[gf00<0S[gf2000000:09G1m@03
0000002JaOD0V/Ge00X0V/Ge00<000000:39m@2PbOD00`0000070:;8l`030000002Yc?80ZLcb00L0
ZLcb0`0000020:[:l@030000002`cNl0/<g_00X0/<g_0`00000<0;K<j`<000002P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo000K0?ooo`030000003oool0oooo0480oooo
0P00000908Zcl@0300000029]O<0RKGc00L0RKGc00<0000008Zhm02:^?@0202:^?@00`000000S;[e
08bjm@0708bjm@L000001P2B__D00`000000UL7e09G1m@0:09G1m@030000002JaOD0V/Ge00P0V/Ge
1000000;0:;8l`030000002Yc?80ZLcb00@0ZLcb0P0000060:[:l@030000002`cNl0/<g_00L0/<g_
0P0000020;3;kP030000002fc>/0]/c[00P0]/c[0P00000=0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool04@3oool001`0oooo00<000000?ooo`3oool0@`3oool00`000000R[?a08Zc
l@0708Zcl@0300000029]O<0RKGc00L0RKGc00<0000008Zhm02:^?@0202:^?@010000000S;[e08bj
m@2<^_D5000000<0Sk_d00<0000009:nm@2B__D0202B__D00`000000UL7e09G1m@0:09G1m@040000
002JaOD0V/Ge09[5m@H000000`2MaO@00`000000X/Sc0:;8l`0:0:;8l`030000002Yc?80ZLcb00<0
00002@2Zb_400`000000/<g_0;3=k`030;3=k`<000001@2`bnh00`000000]/c[0;K<j`050;K<j`80
0000403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo000M0?ooo`030000
003oool0oooo04<0oooo00<0000008Zcl@2:/o401`2:/o400`000000RKGc08Vel`0708Vel`030000
002:^?@0R[Sd00<0R[Sd2000000908nkm0030000002B__D0T[ke00P0T[ke0P00000909G1m@D00000
2P2MaO@2000000T0X/Sc1000000=0:[:l@030000002`cNl0/<g_008000002@2`bnh00`000000]/c[
0;K<j`020;K<j`8000004`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo
000N0?ooo`800000A03oool2000000P0R[?a00<0000008Vel`29]O<00`29]O<9000000H0S[Wc00<0
000008nkm02?^o@02@2?^o@2000000X0T[ke00@0000009G1m@2E`OD0UL7e1@00000309S2m0030000
002MaO@0WLGd00/0WLGd00@000000:;8l`2Rb?<0X/Sc1@0000030:C8lP030000002Zb_40Z/[a00/0
Z/[a0`00000<0;3;kP040000002fc>/00000000001H0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`00803oool00`000000oooo0?ooo`130?ooo`h000001@2=]o800`000000
S[Wc08jil`0808jil`030000002?^o@0Sk_d00X0Sk_d00<0000009:nm@2B__D00`2B__D8000000T0
V<;d00<0000009g5m02MaO@02P2MaO@4000000T0Y<Sb0P0000070:[:l@@000000P2[bO000`000000
/<_^0;3;kP0:0;3;kP800000603oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140
oooo000Q0?ooo`030000003oool0oooo04<0oooo00<0000008fdl@2=]?401P2=]?400`000000SKOb
08fglP0708fglP030000002>^O<0S[Wc00P0S[Wc0P00000908nkm0L000001P2E_o@00`000000V<;d
09S2m00909S2m08000001P2MaO@400000080WlGc00<000000:C8lP2Tb?802P2Tb?800`000000Z/[a
0:[:l@04000000L0ZlW`00<000000;3;kP2`bnh01@2`bnh4000001/0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`130?ooo`030000002=
]?40SKCa00H0SKCa00<0000008fglP2=]o801`2=]o82000000X0S[Wc00@0000008nkm02?^o@0Sk_d
1@00000309:ll`030000002E_o@0UKod00P0UKod00<0000009S2m02H`_@02P2H`_@00`000000WLGd
09g5m003000000L0WlGc00<000000:C8lP2Tb?802@2Tb?83000000`0ZlW`00<000000;3;kP2`bnh0
1000000P0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool002<0oooo0P00
00130?ooo`030000002=]?40SKCa00L0SKCa0P00000908fglP030000002>^O<0S[Wc00<0S[Wc2000
000909:ll`030000002E_o@0UKod00P0UKod00<0000009S2m02H`_@0202H`_@4000000/0WlGc00<0
00000:C8lP2Tb?80102Tb?8400000080YLOa00<000000:_9l02[bO002P2[bO03000002D0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`009@3oool00`000000oooo0?ooo`11
0?ooo`030000002=]?40SKCa00P0SKCa00<0000008fglP2=]o800`2=]o89000000H0TK[b00<00000
09:ll`2B_?<02@2B_?<00`000000UKod09Fom00809Fom0040000002H`_@0V<;d09S2m0H000000`2K
`_<00`000000WlGc09o5l`0:09o5l`030000002Tb?80Y<Sb00<000001`2Uao400`000000ZlW`0:_9
l0070:_9l0800000:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo000V
0?ooo`030000003oool0oooo0440oooo00<0000008fdl@2=]?400`2=]?4:000000D0T;Oa00<00000
096jlP2A^_80202A^_800`000000T[cc09:ll`0909:ll`030000002E_o@0UKod00<0UKod2000000:
09_2l`8000002@2OaO<4000000/0YLOa00<000000:_9l02[bO000`2[bO03000002/0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0@0?ooo`009`3oool00`000000oooo0?ooo`110?oo
o`D000001P2@]_000`000000T;Oa092gl@07092gl@030000002A^_80TK[b00P0TK[b0P00000809:l
l`L000001P2G_o<00`000000Vl;c09_2l`0;09_2l`040000002OaO<0WlGc09o5l`D000000`2Qa?80
0`000000YLOa0:G7l@0:0:G7l@030000002[bO00ZlW`00800000;`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0100oooo000X0?ooo`800000@P3oool00`000000T;K`092fl008092f
l0030000002@]o40T;Oa00L0T;Oa0P00000:096jlP040000002B_?<0T[cc09:ll`@000000`2E_?80
0`000000Ukoc09Nol`0809Nol`030000002K`_<0Vl;c00X0Vl;c100000090:74lP030000002Uao40
YLOa00T0YLOa0`00000a0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool0
02X0oooo00<000000?ooo`3oool0@03oool00`000000T;K`092fl008092fl08000002@2@]o400`00
0000TK[b096jlP03096jlPP00000202E_?800`000000Ukoc09Nol`0809Nol`8000001P2K`_<40000
0080WL;b00<000000:74lP2Qa?802@2Qa?800`000000YLOa0:G7l@040:G7l@@00000=@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo000[0?ooo`030000003oool0oooo0400
oooo0P00000:092fl0030000002@]o40T;Oa00<0T;Oa2@00000609>jlP030000002E_?80UKcb00P0
UKcb0P00000:09Nol`030000002K`_<0Vl;c00<000001`2M`_800`000000XLCb0:74lP090:74lP03
0000002Uao40YLOa00<00000>P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0100
oooo000/0?ooo`030000003oool0oooo0440oooo00<00000092fl02@]_000`2@]_0:000000D0TkSa
00<0000009>jlP2C^_80202C^_800`000000UKcb09FllP0909FllP030000002G_o<0Ukoc00<0Ukoc
1`00000;09g2lP030000002Qa?80XLCb00L0XLCb1000000n0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool03`3oool002d0oooo0P0000120?ooo`D000001P2B]o000`000000TkSa09>h
l@0709>hl@030000002C^_80Tk[b00P0Tk[b00<0000009FllP2E_?801`2E_?87000000H0V[ob00<0
000009g2lP2M`_802P2M`_8010000000XLCb0:74lP2Qa?8500000480oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0?0?ooo`00;`3oool00`000000oooo0?ooo`100?ooo`030000002B
]o00T[O`00P0T[O`00<0000009>hl@2C^?401`2C^?400`000000Tk[b09>jlP0809>jlP040000002E
_?80UKcb09FllPD000000`2G_O800`000000V[ob09ZolP0809ZolP8000002@2M`_85000004P0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`00<03oool00`000000oooo0?oo
o`100?ooo`030000002B]o00T[O`00P0T[O`00<0000009>hl@2C^?401`2C^?400`000000Tk[b09>j
lP0309>jlPP000002@2G_O800`000000V[ob09ZolP0909ZolP040000002M`_80WL;b09g2lPD00000
CP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo000a0?ooo`030000003o
ool0oooo0400oooo0P00000909:gl0030000002C^?40TkSa00<0TkSa2@00000609Jkl@030000002G
_O80Ukgb00T0Ukgb00<0000009ZolP2J_o801`2J_o85000005<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0?0?ooo`00<P3oool200000480oooo00<0000009:gl02B]o000`2B]o09
000000D0UKW`00<0000009Jkl@2F^o40202F^o400`000000Ukgb09NmlP0909NmlP040000002J_o80
V[ob09ZolPD00000F@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00l0oooo000d
0?ooo`030000003oool0oooo0400oooo1@00000509Fgk`030000002E^O00UKW`00L0UKW`00<00000
09Jkl@2F^o40202F^o400`000000Ukgb09NmlP0709NmlPD00000G`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00l0oooo000e0?ooo`030000003oool0oooo0400oooo00<0000009Fg
k`2E]nl01`2E]nl00`000000UKW`09Fil00709Fil08000002@2F^o4010000000Ukgb09NmlP2G_O85
000006D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`00=P3oool00`00
0000oooo0?ooo`100?ooo`030000002E]nl0UKO_00L0UKO_0P00000909Fil0030000002F^o40U[_a
00<0U[_a1`00001Z0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool003L0
oooo0P0000100?ooo`030000002E]nl0UKO_00T0UKO_00<0000009Fil02E^O000`2E^O0900000780
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`00>@3oool00`000000oooo
0?ooo`0n0?ooo`030000002E]nl0UKO_00L0UKO_1`00001l0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool03P3oool003X0oooo00<000000?ooo`3oool0?P3oool010000000UKO_09Fg
k`2E]nl5000008@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`00>`3o
ool00`000000oooo0?ooo`0n0?ooo`<00000R@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00h0oooo000l0?ooo`800000?P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool03P3oool003h0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`2;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool003l0
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03@3oool00400oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00440oooo0P00
000i0?ooo`030000003oool0oooo08d0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`00@`3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo08h0oooo00@000000?ooo`3oool00000
3`3oool004@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2>0?ooo`040000003o
ool0oooo000000l0oooo00150?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0S`3o
ool00`000000oooo0000000?0?ooo`00AP3oool2000003@0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0000000>0?ooo`00B03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
0940oooo0P00000>0?ooo`00B@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0940
oooo0P00000>0?ooo`00BP3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0940oooo
0P00000>0?ooo`00B`3oool2000002l0oooo00<000000?ooo`3oool0S@3oool400000100oooo001=
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0R@3oool4000001@0oooo001>0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0Q@3oool4000001P0oooo001?0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0P@3oool4000001`0oooo001@0?ooo`800000
:P3oool00`000000oooo0?ooo`1m0?ooo`@00000803oool00580oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`1i0?ooo`@00000903oool005<0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`1f0?ooo`<00000:03oool005@0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`1b0?ooo`@00000:`3oool005D0oooo0P00000U0?ooo`030000003oool0oooo06h0
oooo1000000_0?ooo`00E`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo06X0oooo
1000000c0?ooo`00F03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06H0oooo1000
000g0?ooo`00F@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0680oooo1000000k
0?ooo`00FP3oool2000001l0oooo00<000000?ooo`3oool0H03oool3000003l0oooo001L0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0G03oool400000480oooo001M0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0F03oool4000004H0oooo001N0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0E03oool4000004X0oooo001O0?ooo`8000006P3oool0
0`000000oooo0?ooo`1@0?ooo`@00000CP3oool00640oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`1<0?ooo`@00000DP3oool00680oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`180?ooo`@00000EP3oool006<0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`150?ooo`<00000FP3oool006@0oooo0P00000E0?ooo`030000003oool0oooo0440oooo1000
001M0?ooo`00IP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03d0oooo1000001Q
0?ooo`00I`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03T0oooo1000001U0?oo
o`00J03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03D0oooo1000001Y0?ooo`00
J@3oool200000100oooo00<000000?ooo`3oool0<@3oool4000006d0oooo001[0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0;P3oool300000740oooo001/0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0:P3oool4000007@0oooo001]0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool09P3oool4000007P0oooo001^0?ooo`8000002`3oool00`000000
oooo0?ooo`0R0?ooo`@00000O03oool00700oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0N0?ooo`@00000P03oool00740oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0J0?ooo`@00000Q03oool00780oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0F
0?ooo`@00000R03oool007<0oooo0P0000060?ooo`030000003oool0oooo01<0oooo0`00002<0?oo
o`00M@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo1000002?0?ooo`00
MP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo1000002C0?ooo`00M`3o
ool01@000000oooo0?ooo`3oool0000000T0oooo1000002G0?ooo`00N03oool2000000030?ooo`00
0000oooo00@0oooo1000002K0?ooo`00NP3oool2000000030?ooo`000000000000800000W`3oool0
07/0oooo0P00002S0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0901094, -0.0145889, \
0.00381216, 0.00381216}}]
}, Open  ]],

Cell[BoxData[
    \(\(pot15 = pot[Sin[x], 15] /. a \[Rule] 1;\)\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(VEPlot[pot15, {x, 0, 1}, {y, 0, 0.5}\ ];\)\)], "Input",
  Hyphenation->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .52051 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0555556 0.888889 0.0319444 0.888889 [
[ 0 0 0 0 ]
[ 1 .52051 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.0001 w
[ ] 0 setdash
.05556 .03194 m
.02381 .03194 L
s
% Start of user PostScript
0 0 -0.0357143 0 MAarrowhead1
% End of user PostScript
.05556 .06369 m
.02381 .06369 L
s
% Start of user PostScript
0 0.0357143 -0.0357143 0.0357143 MAarrowhead1
% End of user PostScript
.05556 .09544 m
.02381 .09544 L
s
% Start of user PostScript
0 0.0714286 -0.0357143 0.0714286 MAarrowhead1
% End of user PostScript
.05556 .12718 m
.02381 .12718 L
s
% Start of user PostScript
0 0.107143 -0.0357143 0.107143 MAarrowhead1
% End of user PostScript
.05556 .15893 m
.02381 .15893 L
s
% Start of user PostScript
0 0.142857 -0.0357143 0.142857 MAarrowhead1
% End of user PostScript
.05556 .19067 m
.02381 .19067 L
s
% Start of user PostScript
0 0.178571 -0.0357143 0.178571 MAarrowhead1
% End of user PostScript
.05556 .22242 m
.02381 .22242 L
s
% Start of user PostScript
0 0.214286 -0.0357143 0.214286 MAarrowhead1
% End of user PostScript
.05556 .25417 m
.02381 .25417 L
s
% Start of user PostScript
0 0.25 -0.0357143 0.25 MAarrowhead1
% End of user PostScript
.05556 .28591 m
.02381 .28591 L
s
% Start of user PostScript
0 0.285714 -0.0357143 0.285714 MAarrowhead1
% End of user PostScript
.05556 .31766 m
.02381 .31766 L
s
% Start of user PostScript
0 0.321429 -0.0357143 0.321429 MAarrowhead1
% End of user PostScript
.05556 .3494 m
.02381 .3494 L
s
% Start of user PostScript
0 0.357143 -0.0357143 0.357143 MAarrowhead1
% End of user PostScript
.05556 .38115 m
.02381 .38115 L
s
% Start of user PostScript
0 0.392857 -0.0357143 0.392857 MAarrowhead1
% End of user PostScript
.05556 .4129 m
.02381 .4129 L
s
% Start of user PostScript
0 0.428571 -0.0357143 0.428571 MAarrowhead1
% End of user PostScript
.05556 .44464 m
.02381 .44464 L
s
% Start of user PostScript
0 0.464286 -0.0357143 0.464286 MAarrowhead1
% End of user PostScript
.05556 .47639 m
.02381 .47639 L
s
% Start of user PostScript
0 0.5 -0.0357143 0.5 MAarrowhead1
% End of user PostScript
.11905 .03194 m
.09404 .01239 L
s
% Start of user PostScript
0.0714286 0 0.043291 -0.0219951 MAarrowhead1
% End of user PostScript
.11905 .06369 m
.08743 .06657 L
s
% Start of user PostScript
0.0714286 0.0357143 0.0358614 0.0389528 MAarrowhead1
% End of user PostScript
.11905 .09544 m
.08757 .09952 L
s
% Start of user PostScript
0.0714286 0.0714286 0.036011 0.0760228 MAarrowhead1
% End of user PostScript
.11905 .12718 m
.08761 .1316 L
s
% Start of user PostScript
0.0714286 0.107143 0.0360614 0.11211 MAarrowhead1
% End of user PostScript
.11905 .15893 m
.08764 .16354 L
s
% Start of user PostScript
0.0714286 0.142857 0.0360929 0.148044 MAarrowhead1
% End of user PostScript
.11905 .19067 m
.08766 .19545 L
s
% Start of user PostScript
0.0714286 0.178571 0.036121 0.183946 MAarrowhead1
% End of user PostScript
.11905 .22242 m
.08769 .22736 L
s
% Start of user PostScript
0.0714286 0.214286 0.0361487 0.219839 MAarrowhead1
% End of user PostScript
.11905 .25417 m
.08771 .25926 L
s
% Start of user PostScript
0.0714286 0.25 0.0361761 0.255725 MAarrowhead1
% End of user PostScript
.11905 .28591 m
.08774 .29115 L
s
% Start of user PostScript
0.0714286 0.285714 0.0362034 0.291605 MAarrowhead1
% End of user PostScript
.11905 .31766 m
.08776 .32304 L
s
% Start of user PostScript
0.0714286 0.321429 0.0362302 0.327477 MAarrowhead1
% End of user PostScript
.11905 .3494 m
.08778 .35492 L
s
% Start of user PostScript
0.0714286 0.357143 0.0362564 0.363342 MAarrowhead1
% End of user PostScript
.11905 .38115 m
.08781 .38679 L
s
% Start of user PostScript
0.0714286 0.392857 0.0362819 0.399199 MAarrowhead1
% End of user PostScript
.11905 .4129 m
.08783 .41865 L
s
% Start of user PostScript
0.0714286 0.428571 0.0363064 0.435048 MAarrowhead1
% End of user PostScript
.11905 .44464 m
.08785 .45051 L
s
% Start of user PostScript
0.0714286 0.464286 0.0363299 0.470888 MAarrowhead1
% End of user PostScript
.11905 .47639 m
.08787 .48236 L
s
% Start of user PostScript
0.0714286 0.5 0.0363522 0.50672 MAarrowhead1
% End of user PostScript
.18254 .03194 m
.15386 .04556 L
s
% Start of user PostScript
0.142857 0 0.110595 0.0153178 MAarrowhead1
% End of user PostScript
.18254 .06369 m
.15238 .07359 L
s
% Start of user PostScript
0.142857 0.0357143 0.108924 0.0468516 MAarrowhead1
% End of user PostScript
.18254 .09544 m
.15206 .1043 L
s
% Start of user PostScript
0.142857 0.0714286 0.108562 0.0813962 MAarrowhead1
% End of user PostScript
.18254 .12718 m
.15206 .13608 L
s
% Start of user PostScript
0.142857 0.107143 0.108573 0.117148 MAarrowhead1
% End of user PostScript
.18254 .15893 m
.15214 .16809 L
s
% Start of user PostScript
0.142857 0.142857 0.108662 0.153163 MAarrowhead1
% End of user PostScript
.18254 .19067 m
.15224 .20014 L
s
% Start of user PostScript
0.142857 0.178571 0.108768 0.189221 MAarrowhead1
% End of user PostScript
.18254 .22242 m
.15234 .23219 L
s
% Start of user PostScript
0.142857 0.214286 0.108877 0.225279 MAarrowhead1
% End of user PostScript
.18254 .25417 m
.15243 .26423 L
s
% Start of user PostScript
0.142857 0.25 0.108987 0.261327 MAarrowhead1
% End of user PostScript
.18254 .28591 m
.15253 .29627 L
s
% Start of user PostScript
0.142857 0.285714 0.109095 0.297361 MAarrowhead1
% End of user PostScript
.18254 .31766 m
.15262 .32828 L
s
% Start of user PostScript
0.142857 0.321429 0.109202 0.33338 MAarrowhead1
% End of user PostScript
.18254 .3494 m
.15272 .36029 L
s
% Start of user PostScript
0.142857 0.357143 0.109306 0.369384 MAarrowhead1
% End of user PostScript
.18254 .38115 m
.15281 .39227 L
s
% Start of user PostScript
0.142857 0.392857 0.109407 0.405371 MAarrowhead1
% End of user PostScript
.18254 .4129 m
.15289 .42425 L
s
% Start of user PostScript
0.142857 0.428571 0.109504 0.441341 MAarrowhead1
% End of user PostScript
.18254 .44464 m
.15297 .45621 L
s
% Start of user PostScript
0.142857 0.464286 0.109596 0.477294 MAarrowhead1
% End of user PostScript
.18254 .47639 m
.15305 .48815 L
s
% Start of user PostScript
0.142857 0.5 0.109684 0.513231 MAarrowhead1
% End of user PostScript
.24603 .03194 m
.22052 .01305 L
s
% Start of user PostScript
0.214286 0 0.185586 -0.0212569 MAarrowhead1
% End of user PostScript
.24603 .06369 m
.21554 .07252 L
s
% Start of user PostScript
0.214286 0.0357143 0.179981 0.0456474 MAarrowhead1
% End of user PostScript
.24603 .09544 m
.21665 .10746 L
s
% Start of user PostScript
0.214286 0.0714286 0.181232 0.0849542 MAarrowhead1
% End of user PostScript
.24603 .12718 m
.21704 .14012 L
s
% Start of user PostScript
0.214286 0.107143 0.181672 0.121699 MAarrowhead1
% End of user PostScript
.24603 .15893 m
.21729 .17242 L
s
% Start of user PostScript
0.214286 0.142857 0.181955 0.158031 MAarrowhead1
% End of user PostScript
.24603 .19067 m
.21752 .20463 L
s
% Start of user PostScript
0.214286 0.178571 0.182209 0.194276 MAarrowhead1
% End of user PostScript
.24603 .22242 m
.21774 .23682 L
s
% Start of user PostScript
0.214286 0.214286 0.182459 0.230489 MAarrowhead1
% End of user PostScript
.24603 .25417 m
.21796 .26899 L
s
% Start of user PostScript
0.214286 0.25 0.182706 0.26668 MAarrowhead1
% End of user PostScript
.24603 .28591 m
.21818 .30114 L
s
% Start of user PostScript
0.214286 0.285714 0.182949 0.302847 MAarrowhead1
% End of user PostScript
.24603 .31766 m
.21839 .33327 L
s
% Start of user PostScript
0.214286 0.321429 0.183187 0.33899 MAarrowhead1
% End of user PostScript
.24603 .3494 m
.21859 .36537 L
s
% Start of user PostScript
0.214286 0.357143 0.183419 0.375108 MAarrowhead1
% End of user PostScript
.24603 .38115 m
.21879 .39746 L
s
% Start of user PostScript
0.214286 0.392857 0.183641 0.411199 MAarrowhead1
% End of user PostScript
.24603 .4129 m
.21898 .42951 L
s
% Start of user PostScript
0.214286 0.428571 0.183855 0.447265 MAarrowhead1
% End of user PostScript
.24603 .44464 m
.21916 .46155 L
s
% Start of user PostScript
0.214286 0.464286 0.184058 0.483306 MAarrowhead1
% End of user PostScript
.24603 .47639 m
.21933 .49356 L
s
% Start of user PostScript
0.214286 0.5 0.184249 0.519322 MAarrowhead1
% End of user PostScript
.30952 .03194 m
.28946 .05654 L
s
% Start of user PostScript
0.285714 0 0.263139 0.0276745 MAarrowhead1
% End of user PostScript
.30952 .06369 m
.28384 .08235 L
s
% Start of user PostScript
0.285714 0.0357143 0.25682 0.0567057 MAarrowhead1
% End of user PostScript
.30952 .09544 m
.28271 .11243 L
s
% Start of user PostScript
0.285714 0.0714286 0.255546 0.0905432 MAarrowhead1
% End of user PostScript
.30952 .12718 m
.28279 .1443 L
s
% Start of user PostScript
0.285714 0.107143 0.255639 0.126405 MAarrowhead1
% End of user PostScript
.30952 .15893 m
.28312 .17656 L
s
% Start of user PostScript
0.285714 0.142857 0.256012 0.162688 MAarrowhead1
% End of user PostScript
.30952 .19067 m
.2835 .20886 L
s
% Start of user PostScript
0.285714 0.178571 0.256441 0.199031 MAarrowhead1
% End of user PostScript
.30952 .22242 m
.28389 .24115 L
s
% Start of user PostScript
0.285714 0.214286 0.256881 0.23536 MAarrowhead1
% End of user PostScript
.30952 .25417 m
.28428 .27342 L
s
% Start of user PostScript
0.285714 0.25 0.257318 0.27166 MAarrowhead1
% End of user PostScript
.30952 .28591 m
.28466 .30566 L
s
% Start of user PostScript
0.285714 0.285714 0.257747 0.307926 MAarrowhead1
% End of user PostScript
.30952 .31766 m
.28504 .33786 L
s
% Start of user PostScript
0.285714 0.321429 0.258165 0.344156 MAarrowhead1
% End of user PostScript
.30952 .3494 m
.28539 .37003 L
s
% Start of user PostScript
0.285714 0.357143 0.258568 0.38035 MAarrowhead1
% End of user PostScript
.30952 .38115 m
.28574 .40217 L
s
% Start of user PostScript
0.285714 0.392857 0.258954 0.416508 MAarrowhead1
% End of user PostScript
.30952 .4129 m
.28606 .43428 L
s
% Start of user PostScript
0.285714 0.428571 0.25932 0.452631 MAarrowhead1
% End of user PostScript
.30952 .44464 m
.28637 .46636 L
s
% Start of user PostScript
0.285714 0.464286 0.259667 0.488721 MAarrowhead1
% End of user PostScript
.30952 .47639 m
.28666 .49841 L
s
% Start of user PostScript
0.285714 0.5 0.259993 0.524778 MAarrowhead1
% End of user PostScript
.37302 .03194 m
.34266 .02266 L
s
% Start of user PostScript
0.357143 0 0.32299 -0.0104435 MAarrowhead1
% End of user PostScript
.37302 .06369 m
.34511 .07883 L
s
% Start of user PostScript
0.357143 0.0357143 0.325748 0.0527407 MAarrowhead1
% End of user PostScript
.37302 .09544 m
.34779 .11471 L
s
% Start of user PostScript
0.357143 0.0714286 0.328763 0.0931107 MAarrowhead1
% End of user PostScript
.37302 .12718 m
.34882 .14773 L
s
% Start of user PostScript
0.357143 0.107143 0.329923 0.130264 MAarrowhead1
% End of user PostScript
.37302 .15893 m
.34952 .18028 L
s
% Start of user PostScript
0.357143 0.142857 0.33071 0.166874 MAarrowhead1
% End of user PostScript
.37302 .19067 m
.35016 .2127 L
s
% Start of user PostScript
0.357143 0.178571 0.331426 0.203353 MAarrowhead1
% End of user PostScript
.37302 .22242 m
.35078 .24507 L
s
% Start of user PostScript
0.357143 0.214286 0.332122 0.23977 MAarrowhead1
% End of user PostScript
.37302 .25417 m
.35138 .2774 L
s
% Start of user PostScript
0.357143 0.25 0.332804 0.276136 MAarrowhead1
% End of user PostScript
.37302 .28591 m
.35197 .30968 L
s
% Start of user PostScript
0.357143 0.285714 0.333466 0.312453 MAarrowhead1
% End of user PostScript
.37302 .31766 m
.35254 .34192 L
s
% Start of user PostScript
0.357143 0.321429 0.334105 0.348719 MAarrowhead1
% End of user PostScript
.37302 .3494 m
.35308 .37411 L
s
% Start of user PostScript
0.357143 0.357143 0.334717 0.384938 MAarrowhead1
% End of user PostScript
.37302 .38115 m
.3536 .40626 L
s
% Start of user PostScript
0.357143 0.392857 0.335297 0.42111 MAarrowhead1
% End of user PostScript
.37302 .4129 m
.35408 .43838 L
s
% Start of user PostScript
0.357143 0.428571 0.335843 0.457239 MAarrowhead1
% End of user PostScript
.37302 .44464 m
.35454 .47046 L
s
% Start of user PostScript
0.357143 0.464286 0.336356 0.493327 MAarrowhead1
% End of user PostScript
.37302 .47639 m
.35496 .5025 L
s
% Start of user PostScript
0.357143 0.5 0.336833 0.529377 MAarrowhead1
% End of user PostScript
.43651 .03194 m
.42893 .06277 L
s
% Start of user PostScript
0.428571 0 0.420049 0.0346825 MAarrowhead1
% End of user PostScript
.43651 .06369 m
.41745 .08908 L
s
% Start of user PostScript
0.428571 0.0357143 0.407131 0.0642766 MAarrowhead1
% End of user PostScript
.43651 .09544 m
.41546 .1192 L
s
% Start of user PostScript
0.428571 0.0714286 0.40489 0.0981625 MAarrowhead1
% End of user PostScript
.43651 .12718 m
.41581 .15125 L
s
% Start of user PostScript
0.428571 0.107143 0.405283 0.13422 MAarrowhead1
% End of user PostScript
.43651 .15893 m
.41661 .18366 L
s
% Start of user PostScript
0.428571 0.142857 0.406184 0.170684 MAarrowhead1
% End of user PostScript
.43651 .19067 m
.41749 .21609 L
s
% Start of user PostScript
0.428571 0.178571 0.407178 0.207169 MAarrowhead1
% End of user PostScript
.43651 .22242 m
.41838 .24848 L
s
% Start of user PostScript
0.428571 0.214286 0.408174 0.243602 MAarrowhead1
% End of user PostScript
.43651 .25417 m
.41924 .28081 L
s
% Start of user PostScript
0.428571 0.25 0.409146 0.279969 MAarrowhead1
% End of user PostScript
.43651 .28591 m
.42007 .31307 L
s
% Start of user PostScript
0.428571 0.285714 0.410082 0.31627 MAarrowhead1
% End of user PostScript
.43651 .31766 m
.42087 .34528 L
s
% Start of user PostScript
0.428571 0.321429 0.410974 0.352506 MAarrowhead1
% End of user PostScript
.43651 .3494 m
.42161 .37744 L
s
% Start of user PostScript
0.428571 0.357143 0.411816 0.388683 MAarrowhead1
% End of user PostScript
.43651 .38115 m
.42232 .40955 L
s
% Start of user PostScript
0.428571 0.392857 0.412607 0.424805 MAarrowhead1
% End of user PostScript
.43651 .4129 m
.42297 .44161 L
s
% Start of user PostScript
0.428571 0.428571 0.413343 0.460876 MAarrowhead1
% End of user PostScript
.43651 .44464 m
.42358 .47364 L
s
% Start of user PostScript
0.428571 0.464286 0.414026 0.496904 MAarrowhead1
% End of user PostScript
.43651 .47639 m
.42414 .50563 L
s
% Start of user PostScript
0.428571 0.5 0.414655 0.532891 MAarrowhead1
% End of user PostScript
.5 .03194 m
.46842 .03516 L
s
% Start of user PostScript
0.5 0 0.464469 0.00361401 MAarrowhead1
% End of user PostScript
.5 .06369 m
.47661 .08516 L
s
% Start of user PostScript
0.5 0.0357143 0.473688 0.0598631 MAarrowhead1
% End of user PostScript
.5 .09544 m
.48091 .1208 L
s
% Start of user PostScript
0.5 0.0714286 0.478525 0.0999655 MAarrowhead1
% End of user PostScript
.5 .12718 m
.48281 .15387 L
s
% Start of user PostScript
0.5 0.107143 0.480665 0.137171 MAarrowhead1
% End of user PostScript
.5 .15893 m
.4842 .18647 L
s
% Start of user PostScript
0.5 0.142857 0.482229 0.173836 MAarrowhead1
% End of user PostScript
.5 .19067 m
.48547 .2189 L
s
% Start of user PostScript
0.5 0.178571 0.483659 0.210328 MAarrowhead1
% End of user PostScript
.5 .22242 m
.48669 .25124 L
s
% Start of user PostScript
0.5 0.214286 0.485026 0.246709 MAarrowhead1
% End of user PostScript
.5 .25417 m
.48785 .2835 L
s
% Start of user PostScript
0.5 0.25 0.486331 0.282995 MAarrowhead1
% End of user PostScript
.5 .28591 m
.48895 .31567 L
s
% Start of user PostScript
0.5 0.285714 0.487566 0.319194 MAarrowhead1
% End of user PostScript
.5 .31766 m
.48998 .34778 L
s
% Start of user PostScript
0.5 0.321429 0.488724 0.355316 MAarrowhead1
% End of user PostScript
.5 .3494 m
.49093 .37983 L
s
% Start of user PostScript
0.5 0.357143 0.489801 0.39137 MAarrowhead1
% End of user PostScript
.5 .38115 m
.49182 .41182 L
s
% Start of user PostScript
0.5 0.392857 0.490795 0.427365 MAarrowhead1
% End of user PostScript
.5 .4129 m
.49263 .44378 L
s
% Start of user PostScript
0.5 0.428571 0.491707 0.46331 MAarrowhead1
% End of user PostScript
.5 .44464 m
.49337 .47569 L
s
% Start of user PostScript
0.5 0.464286 0.49254 0.499212 MAarrowhead1
% End of user PostScript
.5 .47639 m
.49404 .50757 L
s
% Start of user PostScript
0.5 0.5 0.493297 0.53508 MAarrowhead1
% End of user PostScript
.56349 .03194 m
.56988 .06304 L
s
% Start of user PostScript
0.571429 0 0.578616 0.0349837 MAarrowhead1
% End of user PostScript
.56349 .06369 m
.55216 .09334 L
s
% Start of user PostScript
0.571429 0.0357143 0.558679 0.0690754 MAarrowhead1
% End of user PostScript
.56349 .09544 m
.54995 .12415 L
s
% Start of user PostScript
0.571429 0.0714286 0.556196 0.103731 MAarrowhead1
% End of user PostScript
.56349 .12718 m
.55097 .15635 L
s
% Start of user PostScript
0.571429 0.107143 0.557341 0.139961 MAarrowhead1
% End of user PostScript
.56349 .15893 m
.55254 .18873 L
s
% Start of user PostScript
0.571429 0.142857 0.55911 0.17638 MAarrowhead1
% End of user PostScript
.56349 .19067 m
.55417 .22102 L
s
% Start of user PostScript
0.571429 0.178571 0.56094 0.212711 MAarrowhead1
% End of user PostScript
.56349 .22242 m
.55573 .2532 L
s
% Start of user PostScript
0.571429 0.214286 0.562701 0.248917 MAarrowhead1
% End of user PostScript
.56349 .25417 m
.5572 .28528 L
s
% Start of user PostScript
0.571429 0.25 0.564355 0.285007 MAarrowhead1
% End of user PostScript
.56349 .28591 m
.55857 .31727 L
s
% Start of user PostScript
0.571429 0.285714 0.565888 0.320996 MAarrowhead1
% End of user PostScript
.56349 .31766 m
.55982 .34919 L
s
% Start of user PostScript
0.571429 0.321429 0.567294 0.356903 MAarrowhead1
% End of user PostScript
.56349 .3494 m
.56095 .38105 L
s
% Start of user PostScript
0.571429 0.357143 0.568573 0.392743 MAarrowhead1
% End of user PostScript
.56349 .38115 m
.56198 .41286 L
s
% Start of user PostScript
0.571429 0.392857 0.569729 0.428531 MAarrowhead1
% End of user PostScript
.56349 .4129 m
.56291 .44464 L
s
% Start of user PostScript
0.571429 0.428571 0.57077 0.46428 MAarrowhead1
% End of user PostScript
.56349 .44464 m
.56374 .47639 L
s
% Start of user PostScript
0.571429 0.464286 0.571703 0.499999 MAarrowhead1
% End of user PostScript
.56349 .47639 m
.56448 .50812 L
s
% Start of user PostScript
0.571429 0.5 0.572538 0.535697 MAarrowhead1
% End of user PostScript
.62698 .03194 m
.59941 .04767 L
s
% Start of user PostScript
0.642857 0 0.611832 0.0176896 MAarrowhead1
% End of user PostScript
.62698 .06369 m
.6104 .09076 L
s
% Start of user PostScript
0.642857 0.0357143 0.624205 0.066171 MAarrowhead1
% End of user PostScript
.62698 .09544 m
.61605 .12524 L
s
% Start of user PostScript
0.642857 0.0714286 0.63056 0.104959 MAarrowhead1
% End of user PostScript
.62698 .12718 m
.61908 .15793 L
s
% Start of user PostScript
0.642857 0.107143 0.633966 0.141733 MAarrowhead1
% End of user PostScript
.62698 .15893 m
.62146 .19019 L
s
% Start of user PostScript
0.642857 0.142857 0.636639 0.178026 MAarrowhead1
% End of user PostScript
.62698 .19067 m
.62359 .22224 L
s
% Start of user PostScript
0.642857 0.178571 0.639037 0.214081 MAarrowhead1
% End of user PostScript
.62698 .22242 m
.62554 .25413 L
s
% Start of user PostScript
0.642857 0.214286 0.641228 0.249963 MAarrowhead1
% End of user PostScript
.62698 .25417 m
.6273 .28591 L
s
% Start of user PostScript
0.642857 0.25 0.643212 0.285713 MAarrowhead1
% End of user PostScript
.62698 .28591 m
.62888 .3176 L
s
% Start of user PostScript
0.642857 0.285714 0.644991 0.321365 MAarrowhead1
% End of user PostScript
.62698 .31766 m
.63029 .34923 L
s
% Start of user PostScript
0.642857 0.321429 0.646573 0.356949 MAarrowhead1
% End of user PostScript
.62698 .3494 m
.63153 .38082 L
s
% Start of user PostScript
0.642857 0.357143 0.647972 0.392489 MAarrowhead1
% End of user PostScript
.62698 .38115 m
.63263 .41239 L
s
% Start of user PostScript
0.642857 0.392857 0.649204 0.428003 MAarrowhead1
% End of user PostScript
.62698 .4129 m
.63359 .44395 L
s
% Start of user PostScript
0.642857 0.428571 0.650287 0.463504 MAarrowhead1
% End of user PostScript
.62698 .44464 m
.63443 .4755 L
s
% Start of user PostScript
0.642857 0.464286 0.651237 0.499003 MAarrowhead1
% End of user PostScript
.62698 .47639 m
.63517 .50706 L
s
% Start of user PostScript
0.642857 0.5 0.65207 0.534506 MAarrowhead1
% End of user PostScript
.69048 .03194 m
.70962 .05727 L
s
% Start of user PostScript
0.714286 0 0.73582 0.0284917 MAarrowhead1
% End of user PostScript
.69048 .06369 m
.68702 .09525 L
s
% Start of user PostScript
0.714286 0.0357143 0.710395 0.071216 MAarrowhead1
% End of user PostScript
.69048 .09544 m
.6862 .12689 L
s
% Start of user PostScript
0.714286 0.0714286 0.709476 0.106818 MAarrowhead1
% End of user PostScript
.69048 .12718 m
.68861 .15887 L
s
% Start of user PostScript
0.714286 0.107143 0.712188 0.142795 MAarrowhead1
% End of user PostScript
.69048 .15893 m
.69135 .19066 L
s
% Start of user PostScript
0.714286 0.142857 0.715266 0.178558 MAarrowhead1
% End of user PostScript
.69048 .19067 m
.69389 .22224 L
s
% Start of user PostScript
0.714286 0.178571 0.718129 0.214078 MAarrowhead1
% End of user PostScript
.69048 .22242 m
.69614 .25366 L
s
% Start of user PostScript
0.714286 0.214286 0.720661 0.249426 MAarrowhead1
% End of user PostScript
.69048 .25417 m
.69809 .28498 L
s
% Start of user PostScript
0.714286 0.25 0.722856 0.284671 MAarrowhead1
% End of user PostScript
.69048 .28591 m
.69977 .31627 L
s
% Start of user PostScript
0.714286 0.285714 0.72474 0.319864 MAarrowhead1
% End of user PostScript
.69048 .31766 m
.7012 .34754 L
s
% Start of user PostScript
0.714286 0.321429 0.726348 0.355044 MAarrowhead1
% End of user PostScript
.69048 .3494 m
.70242 .37882 L
s
% Start of user PostScript
0.714286 0.357143 0.727718 0.390235 MAarrowhead1
% End of user PostScript
.69048 .38115 m
.70345 .41012 L
s
% Start of user PostScript
0.714286 0.392857 0.728886 0.425451 MAarrowhead1
% End of user PostScript
.69048 .4129 m
.70434 .44146 L
s
% Start of user PostScript
0.714286 0.428571 0.729884 0.4607 MAarrowhead1
% End of user PostScript
.69048 .44464 m
.7051 .47282 L
s
% Start of user PostScript
0.714286 0.464286 0.730737 0.495985 MAarrowhead1
% End of user PostScript
.69048 .47639 m
.70575 .50422 L
s
% Start of user PostScript
0.714286 0.5 0.73147 0.531308 MAarrowhead1
% End of user PostScript
.75397 .03194 m
.73528 .05761 L
s
% Start of user PostScript
0.785714 0 0.764694 0.0288731 MAarrowhead1
% End of user PostScript
.75397 .06369 m
.74698 .09466 L
s
% Start of user PostScript
0.785714 0.0357143 0.77785 0.0705521 MAarrowhead1
% End of user PostScript
.75397 .09544 m
.75406 .12718 L
s
% Start of user PostScript
0.785714 0.0714286 0.78582 0.107143 MAarrowhead1
% End of user PostScript
.75397 .12718 m
.75868 .15858 L
s
% Start of user PostScript
0.785714 0.107143 0.79101 0.142462 MAarrowhead1
% End of user PostScript
.75397 .15893 m
.76226 .18957 L
s
% Start of user PostScript
0.785714 0.142857 0.795043 0.177332 MAarrowhead1
% End of user PostScript
.75397 .19067 m
.76516 .22038 L
s
% Start of user PostScript
0.785714 0.178571 0.798307 0.211992 MAarrowhead1
% End of user PostScript
.75397 .22242 m
.76751 .25113 L
s
% Start of user PostScript
0.785714 0.214286 0.800947 0.246589 MAarrowhead1
% End of user PostScript
.75397 .25417 m
.7694 .28191 L
s
% Start of user PostScript
0.785714 0.25 0.803074 0.281211 MAarrowhead1
% End of user PostScript
.75397 .28591 m
.77092 .31275 L
s
% Start of user PostScript
0.785714 0.285714 0.804789 0.315908 MAarrowhead1
% End of user PostScript
.75397 .31766 m
.77216 .34368 L
s
% Start of user PostScript
0.785714 0.321429 0.806178 0.350699 MAarrowhead1
% End of user PostScript
.75397 .3494 m
.77316 .37469 L
s
% Start of user PostScript
0.785714 0.357143 0.80731 0.385588 MAarrowhead1
% End of user PostScript
.75397 .38115 m
.77399 .40579 L
s
% Start of user PostScript
0.785714 0.392857 0.808239 0.420572 MAarrowhead1
% End of user PostScript
.75397 .4129 m
.77467 .43696 L
s
% Start of user PostScript
0.785714 0.428571 0.809008 0.455644 MAarrowhead1
% End of user PostScript
.75397 .44464 m
.77524 .46821 L
s
% Start of user PostScript
0.785714 0.464286 0.809648 0.490794 MAarrowhead1
% End of user PostScript
.75397 .47639 m
.77572 .49951 L
s
% Start of user PostScript
0.785714 0.5 0.810186 0.526012 MAarrowhead1
% End of user PostScript
.81746 .03194 m
.84569 .04647 L
s
% Start of user PostScript
0.857143 0 0.888902 0.0163365 MAarrowhead1
% End of user PostScript
.81746 .06369 m
.82263 .09501 L
s
% Start of user PostScript
0.857143 0.0357143 0.862959 0.0709518 MAarrowhead1
% End of user PostScript
.81746 .09544 m
.82642 .12589 L
s
% Start of user PostScript
0.857143 0.0714286 0.867222 0.105691 MAarrowhead1
% End of user PostScript
.81746 .12718 m
.83106 .15587 L
s
% Start of user PostScript
0.857143 0.107143 0.872447 0.139412 MAarrowhead1
% End of user PostScript
.81746 .15893 m
.83468 .1856 L
s
% Start of user PostScript
0.857143 0.142857 0.87652 0.172858 MAarrowhead1
% End of user PostScript
.81746 .19067 m
.83731 .21545 L
s
% Start of user PostScript
0.857143 0.178571 0.879477 0.20644 MAarrowhead1
% End of user PostScript
.81746 .22242 m
.83921 .24554 L
s
% Start of user PostScript
0.857143 0.214286 0.881613 0.2403 MAarrowhead1
% End of user PostScript
.81746 .25417 m
.8406 .2759 L
s
% Start of user PostScript
0.857143 0.25 0.883177 0.274449 MAarrowhead1
% End of user PostScript
.81746 .28591 m
.84164 .30648 L
s
% Start of user PostScript
0.857143 0.285714 0.884345 0.308857 MAarrowhead1
% End of user PostScript
.81746 .31766 m
.84243 .33726 L
s
% Start of user PostScript
0.857143 0.321429 0.885235 0.343482 MAarrowhead1
% End of user PostScript
.81746 .3494 m
.84305 .3682 L
s
% Start of user PostScript
0.857143 0.357143 0.885926 0.378286 MAarrowhead1
% End of user PostScript
.81746 .38115 m
.84353 .39927 L
s
% Start of user PostScript
0.857143 0.392857 0.886472 0.413236 MAarrowhead1
% End of user PostScript
.81746 .4129 m
.84392 .43044 L
s
% Start of user PostScript
0.857143 0.428571 0.88691 0.448306 MAarrowhead1
% End of user PostScript
.81746 .44464 m
.84424 .4617 L
s
% Start of user PostScript
0.857143 0.464286 0.887266 0.483472 MAarrowhead1
% End of user PostScript
.81746 .47639 m
.8445 .49303 L
s
% Start of user PostScript
0.857143 0.5 0.887558 0.518719 MAarrowhead1
% End of user PostScript
.88095 .03194 m
.87443 .06301 L
s
% Start of user PostScript
0.928571 0 0.921229 0.0349513 MAarrowhead1
% End of user PostScript
.88095 .06369 m
.89147 .09364 L
s
% Start of user PostScript
0.928571 0.0357143 0.940401 0.0694125 MAarrowhead1
% End of user PostScript
.88095 .09544 m
.90099 .12006 L
s
% Start of user PostScript
0.928571 0.0714286 0.95111 0.099133 MAarrowhead1
% End of user PostScript
.88095 .12718 m
.90544 .14738 L
s
% Start of user PostScript
0.928571 0.107143 0.956122 0.129869 MAarrowhead1
% End of user PostScript
.88095 .15893 m
.9077 .17603 L
s
% Start of user PostScript
0.928571 0.142857 0.958657 0.162102 MAarrowhead1
% End of user PostScript
.88095 .19067 m
.90896 .20562 L
s
% Start of user PostScript
0.928571 0.178571 0.960083 0.19538 MAarrowhead1
% End of user PostScript
.88095 .22242 m
.90974 .2358 L
s
% Start of user PostScript
0.928571 0.214286 0.960958 0.22934 MAarrowhead1
% End of user PostScript
.88095 .25417 m
.91025 .26639 L
s
% Start of user PostScript
0.928571 0.25 0.961533 0.263751 MAarrowhead1
% End of user PostScript
.88095 .28591 m
.9106 .29725 L
s
% Start of user PostScript
0.928571 0.285714 0.96193 0.298469 MAarrowhead1
% End of user PostScript
.88095 .31766 m
.91086 .3283 L
s
% Start of user PostScript
0.928571 0.321429 0.962218 0.333406 MAarrowhead1
% End of user PostScript
.88095 .3494 m
.91105 .3595 L
s
% Start of user PostScript
0.928571 0.357143 0.962432 0.3685 MAarrowhead1
% End of user PostScript
.88095 .38115 m
.9112 .3908 L
s
% Start of user PostScript
0.928571 0.392857 0.962596 0.403712 MAarrowhead1
% End of user PostScript
.88095 .4129 m
.91131 .42218 L
s
% Start of user PostScript
0.928571 0.428571 0.962725 0.439015 MAarrowhead1
% End of user PostScript
.88095 .44464 m
.9114 .45362 L
s
% Start of user PostScript
0.928571 0.464286 0.962827 0.474387 MAarrowhead1
% End of user PostScript
.88095 .47639 m
.91148 .48511 L
s
% Start of user PostScript
0.928571 0.5 0.962911 0.509815 MAarrowhead1
% End of user PostScript
.94444 .03194 m
.97619 .03194 L
s
% Start of user PostScript
1. 0 1.03571 0 MAarrowhead1
% End of user PostScript
.94444 .06369 m
.97619 .06369 L
s
% Start of user PostScript
1. 0.0357143 1.03571 0.0357143 MAarrowhead1
% End of user PostScript
.94444 .09544 m
.97619 .09544 L
s
% Start of user PostScript
1. 0.0714286 1.03571 0.0714286 MAarrowhead1
% End of user PostScript
.94444 .12718 m
.97619 .12718 L
s
% Start of user PostScript
1. 0.107143 1.03571 0.107143 MAarrowhead1
% End of user PostScript
.94444 .15893 m
.97619 .15893 L
s
% Start of user PostScript
1. 0.142857 1.03571 0.142857 MAarrowhead1
% End of user PostScript
.94444 .19067 m
.97619 .19067 L
s
% Start of user PostScript
1. 0.178571 1.03571 0.178571 MAarrowhead1
% End of user PostScript
.94444 .22242 m
.97619 .22242 L
s
% Start of user PostScript
1. 0.214286 1.03571 0.214286 MAarrowhead1
% End of user PostScript
.94444 .25417 m
.97619 .25417 L
s
% Start of user PostScript
1. 0.25 1.03571 0.25 MAarrowhead1
% End of user PostScript
.94444 .28591 m
.97619 .28591 L
s
% Start of user PostScript
1. 0.285714 1.03571 0.285714 MAarrowhead1
% End of user PostScript
.94444 .31766 m
.97619 .31766 L
s
% Start of user PostScript
1. 0.321429 1.03571 0.321429 MAarrowhead1
% End of user PostScript
.94444 .3494 m
.97619 .3494 L
s
% Start of user PostScript
1. 0.357143 1.03571 0.357143 MAarrowhead1
% End of user PostScript
.94444 .38115 m
.97619 .38115 L
s
% Start of user PostScript
1. 0.392857 1.03571 0.392857 MAarrowhead1
% End of user PostScript
.94444 .4129 m
.97619 .4129 L
s
% Start of user PostScript
1. 0.428571 1.03571 0.428571 MAarrowhead1
% End of user PostScript
.94444 .44464 m
.97619 .44464 L
s
% Start of user PostScript
1. 0.464286 1.03571 0.464286 MAarrowhead1
% End of user PostScript
.94444 .47639 m
.97619 .47639 L
s
% Start of user PostScript
1. 0.5 1.03571 0.5 MAarrowhead1
% End of user PostScript
.5 Mabswid
.90314 .03194 m
.89002 .03558 L
.87188 .03272 L
.86983 .03194 L
s
.91216 .03194 m
.90816 .03385 L
.89042 .04101 L
.89002 .0411 L
.87361 .04101 L
.87188 .04062 L
.85676 .03194 L
s
.91936 .03194 m
.90816 .03889 L
.90482 .04101 L
.89002 .04763 L
.87188 .04972 L
.85374 .04522 L
.84666 .04101 L
.84011 .03194 L
s
.81124 .03194 m
.79932 .04082 L
.79887 .04101 L
.78118 .04539 L
.76304 .04358 L
.75639 .04101 L
.7449 .0325 L
.74463 .03194 L
s
.92362 .03194 m
.91379 .04101 L
.90816 .04491 L
.90065 .05008 L
.89002 .05552 L
.8785 .05916 L
.87188 .06046 L
.85374 .06155 L
.8356 .06098 L
.81746 .06242 L
.79932 .06584 L
.78118 .06812 L
.76304 .06774 L
.7449 .0641 L
.73174 .05916 L
.72676 .05699 L
.71182 .05008 L
.70862 .04921 L
.69048 .04809 L
.67234 .04874 L
.6542 .04553 L
.64434 .04101 L
.63605 .03488 L
.63341 .03194 L
s
.92585 .03194 m
.92035 .04101 L
.91101 .05008 L
.90816 .05241 L
.90224 .05916 L
.89002 .06536 L
.88448 .06823 L
.87188 .07358 L
.86096 .0773 L
.85374 .07928 L
.8356 .0841 L
.82704 .08637 L
.81746 .08885 L
.79932 .09324 L
.78937 .09544 L
.78118 .09656 L
.76304 .09843 L
.7449 .09882 L
.72676 .09796 L
.70862 .09626 L
.70143 .09544 L
.69048 .09402 L
.67234 .09111 L
.6542 .087 L
.65191 .08637 L
.63605 .08095 L
.62758 .0773 L
.61791 .07232 L
.61096 .06823 L
.59977 .06108 L
.59668 .05916 L
.58163 .05145 L
.57688 .05008 L
.56349 .04759 L
.54535 .04295 L
.53824 .04101 L
.52721 .03195 L
.52721 .03194 L
s
.92696 .03194 m
.9263 .03692 L
.92471 .04101 L
.91898 .05008 L
.91107 .05916 L
.90816 .06208 L
.90291 .06823 L
.89129 .0773 L
.89002 .07819 L
.87853 .08637 L
.87188 .09031 L
.86317 .09544 L
.85374 .10047 L
.84595 .10451 L
.8356 .10954 L
.82695 .11358 L
.81746 .11767 L
.80509 .12265 L
.79932 .12473 L
.78118 .13059 L
.77739 .13172 L
.76304 .13522 L
.7449 .13866 L
.729 .14079 L
.72676 .14098 L
.70862 .14224 L
.69048 .14245 L
.67234 .14161 L
.66218 .14079 L
.6542 .13966 L
.63605 .13655 L
.61791 .13225 L
.61595 .13172 L
.59977 .12677 L
.58811 .12265 L
.58163 .12016 L
.56597 .11358 L
.56349 .11246 L
.54709 .10451 L
.54535 .1036 L
.53087 .09544 L
.52721 .09317 L
.51709 .08637 L
.50907 .08025 L
.5055 .0773 L
.49577 .06823 L
.49093 .0631 L
.4875 .05916 L
.48056 .05008 L
.47366 .04101 L
Mistroke
.47279 .0396 L
.45465 .03564 L
.43651 .03348 L
.43219 .03194 L
Mfstroke
.92784 .03194 m
.92782 .04101 L
.9263 .04628 L
.92476 .05008 L
.91986 .05916 L
.9137 .06823 L
.90816 .07541 L
.90684 .0773 L
.89931 .08637 L
.89059 .09544 L
.89002 .09599 L
.88142 .10451 L
.87188 .11305 L
.87129 .11358 L
.86059 .12265 L
.85374 .12809 L
.84908 .13172 L
.83666 .14079 L
.8356 .14153 L
.82322 .14986 L
.81746 .15347 L
.80836 .15893 L
.79932 .16394 L
.7916 .168 L
.78118 .17301 L
.77212 .17707 L
.76304 .18075 L
.7482 .18614 L
.7449 .18721 L
.72676 .19244 L
.71522 .19521 L
.70862 .19651 L
.69048 .19942 L
.67234 .2012 L
.6542 .20185 L
.63605 .20139 L
.61791 .19981 L
.59977 .1971 L
.59015 .19521 L
.58163 .19323 L
.56349 .18817 L
.55719 .18614 L
.54535 .1819 L
.5334 .17707 L
.52721 .17434 L
.51402 .168 L
.50907 .16542 L
.49739 .15893 L
.49093 .15507 L
.48268 .14986 L
Mistroke
.47279 .14319 L
.46939 .14079 L
.45721 .13172 L
.45465 .12972 L
.4459 .12265 L
.43651 .11464 L
.4353 .11358 L
.42537 .10451 L
.41837 .09775 L
.41607 .09544 L
.4075 .08637 L
.40023 .07784 L
.39979 .0773 L
.3931 .06823 L
.38762 .05916 L
.38358 .05008 L
.38209 .04527 L
.38146 .04101 L
.38111 .03194 L
Mfstroke
.92941 .03194 m
.93063 .04101 L
.92937 .05008 L
.92667 .05916 L
.9263 .06014 L
.92298 .06823 L
.9186 .0773 L
.91369 .08637 L
.90836 .09544 L
.90816 .09575 L
.90282 .10451 L
.89683 .11358 L
.89048 .12265 L
.89002 .12328 L
.88388 .13172 L
.87691 .14079 L
.87188 .14706 L
.8696 .14986 L
.86194 .15893 L
.85385 .168 L
.85374 .16811 L
.84534 .17707 L
.83629 .18614 L
.8356 .18681 L
.82671 .19521 L
.81746 .20339 L
.81642 .20428 L
.80539 .21335 L
.79932 .21804 L
.79344 .22242 L
.78118 .23094 L
.78035 .23149 L
.76587 .24056 L
.76304 .24221 L
.74955 .24963 L
.7449 .25199 L
.73062 .2587 L
.72676 .26036 L
.70862 .26739 L
.70754 .26777 L
.69048 .27314 L
.67617 .27684 L
.67234 .27768 L
.6542 .28102 L
.63605 .28319 L
.61791 .28423 L
.59977 .28412 L
.58163 .28287 L
.56349 .28046 L
.54535 .27689 L
Mistroke
.54513 .27684 L
.52721 .27212 L
.5137 .26777 L
.50907 .26611 L
.49093 .25881 L
.49069 .2587 L
.47279 .25015 L
.47179 .24963 L
.45551 .24056 L
.45465 .24005 L
.44108 .23149 L
.43651 .2284 L
.42806 .22242 L
.41837 .21509 L
.41615 .21335 L
.40518 .20428 L
.40023 .19996 L
.39498 .19521 L
.38545 .18614 L
.38209 .1828 L
.3765 .17707 L
.36808 .168 L
.36395 .16336 L
.36011 .15893 L
.35256 .14986 L
.3458 .14135 L
.34537 .14079 L
.3385 .13172 L
.33192 .12265 L
.32766 .1166 L
.32557 .11358 L
.31944 .10451 L
.31346 .09544 L
.30952 .08935 L
.30763 .08637 L
.30201 .0773 L
.29665 .06823 L
.29178 .05916 L
.29138 .05836 L
.28761 .05008 L
.28441 .04101 L
.28237 .03194 L
Mfstroke
.93255 .03194 m
.93408 .04101 L
.93387 .05008 L
.93265 .05916 L
.93076 .06823 L
.9284 .0773 L
.9263 .08438 L
.92569 .08637 L
.92269 .09544 L
.91948 .10451 L
.91607 .11358 L
.9125 .12265 L
.90878 .13172 L
.90816 .13318 L
.90493 .14079 L
.90092 .14986 L
.89675 .15893 L
.89242 .168 L
.89002 .17287 L
.88793 .17707 L
.88327 .18614 L
.87842 .19521 L
.87338 .20428 L
.87188 .2069 L
.86813 .21335 L
.86267 .22242 L
.85696 .23149 L
.85374 .23643 L
.851 .24056 L
.84477 .24963 L
.83824 .2587 L
.8356 .26225 L
.8314 .26777 L
.8242 .27684 L
.81746 .28493 L
.81662 .28591 L
.80862 .29498 L
.80014 .30405 L
.79932 .3049 L
.79115 .31312 L
.78154 .32219 L
.78118 .32252 L
.77126 .33126 L
.76304 .33804 L
.76016 .34033 L
.7481 .3494 L
.7449 .35168 L
.73488 .35848 L
.72676 .3636 L
.72017 .36755 L
Mistroke
.70862 .37395 L
.70348 .37662 L
.69048 .38281 L
.68393 .38569 L
.67234 .3903 L
.65968 .39476 L
.6542 .39647 L
.63605 .40138 L
.62496 .40383 L
.61791 .40507 L
.59977 .40757 L
.58163 .40891 L
.56349 .40909 L
.54535 .40812 L
.52721 .40599 L
.51447 .40383 L
.50907 .40267 L
.49093 .39815 L
.47976 .39476 L
.47279 .39238 L
.45553 .38569 L
.45465 .38531 L
.43651 .37688 L
.43599 .37662 L
.4193 .36755 L
.41837 .367 L
.40459 .35848 L
.40023 .35558 L
.39138 .3494 L
.38209 .34247 L
.37934 .34033 L
.36826 .33126 L
.36395 .32754 L
.35798 .32219 L
.3484 .31312 L
.3458 .31056 L
.33942 .30405 L
.33096 .29498 L
.32766 .2913 L
.32298 .28591 L
.31542 .27684 L
.30952 .26942 L
.30825 .26777 L
.30143 .2587 L
.29493 .24963 L
.29138 .2445 L
.28873 .24056 L
.2828 .23149 L
.27713 .22242 L
.27324 .21597 L
Mistroke
.27169 .21335 L
.26649 .20428 L
.26149 .19521 L
.25669 .18614 L
.2551 .18306 L
.25207 .17707 L
.24764 .168 L
.24337 .15893 L
.23925 .14986 L
.23696 .14465 L
.23529 .14079 L
.23146 .13172 L
.22776 .12265 L
.22416 .11358 L
.22063 .10451 L
.21882 .09981 L
.21714 .09544 L
.21362 .08637 L
.20996 .0773 L
.20599 .06823 L
.20145 .05916 L
.20068 .05775 L
.19624 .05008 L
.1902 .04101 L
.18407 .03194 L
Mfstroke
.81206 .47639 m
.81746 .46787 L
.8178 .46732 L
.8233 .45825 L
.82856 .44918 L
.83361 .44011 L
.8356 .43642 L
.83845 .43104 L
.8431 .42197 L
.84757 .4129 L
.85186 .40383 L
.85374 .39975 L
.856 .39476 L
.85998 .38569 L
.86381 .37662 L
.86751 .36755 L
.87107 .35848 L
.87188 .35635 L
.8745 .3494 L
.87781 .34033 L
.88101 .33126 L
.8841 .32219 L
.88708 .31312 L
.88995 .30405 L
.89002 .30383 L
.89273 .29498 L
.89542 .28591 L
.89802 .27684 L
.90053 .26777 L
.90296 .2587 L
.90531 .24963 L
.90759 .24056 L
.90816 .23821 L
.90979 .23149 L
.91192 .22242 L
.91398 .21335 L
.91598 .20428 L
.91791 .19521 L
.91979 .18614 L
.9216 .17707 L
.92336 .168 L
.92506 .15893 L
.9263 .15209 L
.9267 .14986 L
.92829 .14079 L
.92982 .13172 L
.93129 .12265 L
.9327 .11358 L
.93403 .10451 L
.93528 .09544 L
Mistroke
.93642 .08637 L
.93744 .0773 L
.9383 .06823 L
.93894 .05916 L
.93927 .05008 L
.93913 .04101 L
.93817 .03194 L
Mfstroke
.24694 .47639 m
.2412 .46732 L
.23696 .46035 L
.23571 .45825 L
.23045 .44918 L
.2254 .44011 L
.22056 .43104 L
.21882 .42768 L
.21592 .42197 L
.21145 .4129 L
.20716 .40383 L
.20303 .39476 L
.20068 .38945 L
.19905 .38569 L
.19522 .37662 L
.19153 .36755 L
.18798 .35848 L
.18455 .3494 L
.18254 .34393 L
.18124 .34033 L
.17805 .33126 L
.17497 .32219 L
.172 .31312 L
.16913 .30405 L
.16635 .29498 L
.1644 .28839 L
.16368 .28591 L
.16109 .27684 L
.15858 .26777 L
.15616 .2587 L
.15383 .24963 L
.15156 .24056 L
.14938 .23149 L
.14726 .22242 L
.14626 .21803 L
.14521 .21335 L
.14323 .20428 L
.14131 .19521 L
.13946 .18614 L
.13766 .17707 L
.13592 .168 L
.13424 .15893 L
.13262 .14986 L
.13105 .14079 L
.12954 .13172 L
.12812 .1228 L
.12809 .12265 L
.1267 .11358 L
.12538 .10451 L
.12413 .09544 L
Mistroke
.12297 .08637 L
.1219 .0773 L
.12097 .06823 L
.12021 .05916 L
.11972 .05008 L
.1198 .04101 L
.12488 .03194 L
Mfstroke
0 0 m
1 0 L
1 .52051 L
0 .52051 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 149.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000UB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`006`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0=h0oooo000L0?ooo`8000008P3oool200000=h0oooo000L0?ooo`@000008@3oool3
00000=`0oooo000M0?ooo`@00000803oool4000001d0oooo1`00002g0?ooo`002`3oool200000100
oooo1000000Q0?ooo`<000007P3oool600000:P0oooo0P00000=0?ooo`002@3oool400000140oooo
00@000000?ooo`3oool000008@3oool00`000000oooo0000000O0?ooo`D00000803oool2000008D0
oooo1@00000:0?ooo`001`3oool:00000140oooo00<000000?ooo`000000303oool00`000000oooo
0000000200000100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`0=0?ooo`@00000
203oool8000000L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`060000
003oool000000000003oool000003`3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo
000000l0oooo00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo0?ooo`@00000103oool5000000030?ooo`000000000000@0000000<0oooo000000000000
200000080?ooo`002P3oool3000001H0oooo00<000000?ooo`3oool02P3oool300000080oooo00<0
00000?ooo`3oool06@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0000000<0oooo000000000000
1@00000;0?ooo`8000001`3oool00`000000oooo0?ooo`0;0?ooo`<00000103oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00d0oooo0P00000>0?ooo`8000000`3oool400000080oooo
00<000000?ooo`3oool00P3oool2000000@0oooo1`0000020?ooo`P00000103oool3000000`0oooo
000R0?ooo`030000003oool0oooo00T0oooo1@0000030?ooo`030000003oool0oooo01P0oooo00@0
00000?ooo`3oool0oooo0`00000E0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1@3oool3000000030?ooo`0000000000008000003@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00T0oooo1@0000050?ooo`8000003P3oool3000000X0oooo0`0000000`3oool00000
0?ooo`090?ooo`<000001P3oool5000000030?ooo`000000oooo00@0oooo2@0000000`3oool00000
00000002000000030?ooo`000000000000<0000000<0oooo0000003oool04@3oool00280oooo00<0
00000?ooo`3oool0203oool6000000@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`04000001D0oooo00<000000?ooo`3oool02`3oool3000000X0oooo00<000000?ooo`3oool0403o
ool4000000030?ooo`000000000000800000203oool6000000L0oooo0P00000;0?ooo`@000002P3o
ool4000000030?ooo`000000000000800000103oool2000000T0oooo1P0000000`3oool000000?oo
o`050?ooo`@000000P3oool200000080oooo00@000000?ooo`000000oooo100000000`3oool00000
0?ooo`0A0?ooo`008P3oool00`000000oooo0?ooo`070?ooo`<00000203oool00`000000oooo0?oo
o`0H0?ooo`030000003oool00000008000005P3oool00`000000oooo0?ooo`0;0?ooo`<000002P3o
ool00`000000oooo0?ooo`0D0?ooo`D000001`3oool3000000d0oooo0`0000050?ooo`P00000203o
ool4000000H0oooo1000000>0?ooo`@0000000@0oooo00000000000000000`3oool6000000<0oooo
00<000000?ooo`3oool00P0000001P3oool00000000000000000oooo00000180oooo000R0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool05`3oool010000000oooo00000000000H0?oo
o`030000003oool0oooo00X0oooo0P00000<0?ooo`030000003oool0oooo01D0oooo1P00000G0?oo
o`D000001@3oool5000000H0oooo0`00000Q0?ooo`H000001@3oool01@000000oooo0?ooo`000000
oooo0080000000D0oooo000000000000oooo0000000B0?ooo`008P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01L0oooo0`00000I0?ooo`030000003oool0oooo00X0oooo0P00000=
0?ooo`030000003oool0oooo01@0oooo0`0000030?ooo`8000008@3oool2000000030?ooo`000000
000000<0oooo0P00000V0?ooo`<000000`3oool200000080oooo00H000000?ooo`000000oooo0000
003oool2000000030?ooo`000000oooo0140oooo000;0?ooo`8000005@3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`090?ooo`8000003@3oool00`000000oooo0?ooo`0E0?ooo`8000001@3oool200000200oooo00@0
00000?ooo`3oool0oooo0P0000000`3oool000000?ooo`0V0?ooo`80000000@0oooo000000000000
00000`3oool00`000000oooo0?ooo`02000000060?ooo`000000oooo0000003oool000000`3oool2
000000d0oooo00090?ooo`@000004@3oool200000080oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0503oool20000
00L0oooo0P00000T0?ooo`8000005@3ooolE000000@0oooo0P0000002`3oool000000000003oool0
00000?ooo`000000oooo0000003oool0000000<0oooo1@00000:0?ooo`001`3oool:000000X0oooo
2000000>0?ooo`040000003oool00000000000D0oooo00<000000?ooo`3oool0103oool6000000d0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080
00000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000h0oooo00@000000?ooo`3o
ool000004@3oool00`000000oooo000000090?ooo`800000103oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00/0oooo1P0000090?ooo`H000000P3oool00`000000oooo0?ooo`0=0?oo
o`040000003oool000000?ooo`<000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool000000?ooo`/00000203oool000X0oooo0`00000<0?ooo`L000000`3oool00`000000oooo0?oo
o`090?ooo`@00000203oool010000000oooo0?ooo`3oool600000100oooo00@000000?ooo`000000
00003@3oool4000000H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`<0
00004P3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`00
0000oooo0?ooo`0@0?ooo`X00000203oool00`000000oooo0?ooo`0?0?ooo`800000103oool01000
0000oooo0?ooo`0000020?ooo`050000003oool000000?ooo`000000103oool3000000`0oooo000L
0?ooo`@000000`3oool00`000000oooo0?ooo`070?ooo`D000002@3oool00`000000oooo0?ooo`07
000000l0oooo0`00000>0?ooo`@00000203oool00`000000oooo0?ooo`060?ooo`8000003`3oool3
000000030?ooo`000000oooo00l0oooo00<000000?ooo`3oool03@3oool300000180oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00d0oooo0P000000
0`3oool000000?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0000
003oool0000001<0oooo000S0?ooo`030000003oool0oooo00H0oooo0`00000=0?ooo`030000003o
ool0oooo01@0oooo1@00000<0?ooo`D00000203oool00`000000oooo0?ooo`050?ooo`@000003@3o
ool400000080oooo00<000000?ooo`3oool0303oool2000000l0oooo1000000@0?ooo`<000003P3o
ool400000100oooo1000000;0?ooo`8000000`3oool2000000030?ooo`000000oooo0080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0000000C0?ooo`008`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01<0oooo1@00000<0?ooo`<00000303oool00`000000oooo0?oo
o`040?ooo`<000003P3oool3000000@0oooo00<000000?ooo`3oool02`3oool3000000h0oooo1@00
000?0?ooo`<000003P3oool400000100oooo100000060?ooo`D00000103oool4000000<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0000001<0oooo000S0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool04P3oool2000000@0oooo00<000000?ooo`3oool06@3o
ool2000000<0oooo0`00000>0?ooo`8000001`3oool00`000000oooo0?ooo`0:0?ooo`8000003`3o
ool2000000<0oooo0`00000<0?ooo`8000003`3oool300000180oooo0`0000040?ooo`8000002@3o
ool3000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0000001<0oooo
000S0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0J0?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool0203oool2000000T0oooo
0`00000>0?ooo`<000001P3oool3000000T0oooo0P00000?0?ooo`<000004P3oool7000000T0oooo
0P0000001P3oool00000000000000000oooo000000<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`8000007@3oool2000000L0oooo0P00000?0?oo
o`8000002P3oool3000000H0oooo0P00000@0?ooo`800000403oool4000000d0oooo00<000000?oo
o`3oool00P3oool3000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0140oooo000:0?ooo`<00000403oool2000000@0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool50000
00030?ooo`000000oooo0100oooo00<000000?ooo`3oool02`3oool4000000<0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`040?ooo`8000000`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool00`3oool3000000`0oooo00070?ooo`X000002P3oool90000
00`0oooo1@0000090?ooo`030000003oool0oooo0080oooo00@000000?ooo`00000000004P3oool2
00000100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool03@3oool;000000P0oooo00<000000?ooo`000000103oool7
000000H0oooo0P00000:0?ooo`800000103oool010000000oooo0?ooo`0000040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:000000P0oooo000:0?ooo`<00000303o
ool7000000<0oooo00<000000?ooo`3oool01`3oool5000000d0oooo00<000000?ooo`0000000`00
000@0?ooo`060000003oool000000000003oool00000303oool010000000oooo00000000000=0?oo
o`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`080?ooo`8000001P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool?
000000d0oooo00<000000?ooo`3oool01`3oool2000000L0oooo0P0000040?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000001@3oool3000000`0oooo000L0?ooo`@00000103oool0
0`000000oooo0?ooo`040?ooo`L000003@3oool6000000l0oooo0`0000040?ooo`030000003oool0
oooo00P0oooo0`00000@0?ooo`<00000403oool00`000000oooo0000000<0?ooo`80000000@0oooo
0000003oool000004@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo0`00
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0B0?ooo`00903o
ool00`000000oooo0?ooo`0G0?ooo`L000003P3oool4000000@0oooo00<000000?ooo`3oool01`3o
ool5000000l0oooo1000000?0?ooo`<000003@3oool500000100oooo0P00000A0?ooo`<000003`3o
ool400000140oooo0P0000040?ooo`8000002@3oool5000000030?ooo`000000oooo00<0oooo00D0
00000?ooo`3oool0oooo0000000D0?ooo`00903oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo0100oooo0`0000070?ooo`030000003oool0oooo00D0oooo1000000A0?ooo`<000003`3o
ool300000100oooo1000000?0?ooo`<00000403oool3000000l0oooo1000000?0?ooo`@0000000@0
oooo00000000000000002@3oool200000080oooo0`0000000`3oool000000?ooo`030?ooo`050000
003oool0oooo0?ooo`000000503oool002@0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0>0?ooo`8000002P3oool00`000000oooo0?ooo`030?ooo`8000004`3oool3000000030?oo
o`000000000000d0oooo0P00000A0?ooo`D000003P3oool200000140oooo0P00000A0?ooo`<00000
403oool4000000/0oooo00<000000?ooo`3oool00`3oool3000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00T0oooo0P00000A0?ooo`<000000`3oool2000000/0oooo0`00000A0?ooo`8000004@3o
ool3000000l0oooo1000000;0?ooo`030000003oool0oooo00D0oooo0P0000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo0P0000060?ooo`8000002@3oool2
00000180oooo0P00000A0?ooo`8000003P3oool200000080oooo0P00000:0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01<0oooo000:0?ooo`<00000403oool2000000H0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`070?ooo`<000001P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool02@3oool3000000@0oooo0P0000080?ooo`800000203oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool30000
00`0oooo00070?ooo`X000002P3oool800000080oooo00<000000?ooo`3oool0203oool200000003
0?ooo`000000000000`0oooo00@000000?ooo`000000oooo0P00000B0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo
0?ooo`0000003@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo10000005
0?ooo`030000003oool0oooo00h0oooo0P00000B0?ooo`030000003oool0oooo00H0oooo0`000006
0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo00000006
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo2P0000080?ooo`002P3oool3
000000`0oooo1`0000050?ooo`030000003oool0oooo00H0oooo1@00000?0?ooo`<00000403oool0
10000000oooo0000000000080?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
4@3oool00`000000oooo0?ooo`030?ooo`8000002P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00X0oooo1P00000A0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool0
oooo1@0000090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo000000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool3000000`0
oooo000L0?ooo`@000001@3oool00`000000oooo0?ooo`040?ooo`H000003P3oool5000000l0oooo
0`00000;0?ooo`040000003oool0oooo0?ooo`@00000403oool2000000P0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0000000A0?ooo`030000003oool0oooo0100oooo0P00000@0?ooo`03
0000003oool0oooo0100oooo1000000?0?ooo`030000003oool0000000<0oooo0P0000090?ooo`03
0000003oool00000008000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0
oooo000U0?ooo`030000003oool0oooo00<0oooo0`00000A0?ooo`H000003P3oool4000000/0oooo
00@000000?ooo`3oool0oooo1000000?0?ooo`<000002@3oool00`000000oooo0?ooo`040?ooo`80
0000403oool300000100oooo0P0000020?ooo`@000002`3oool4000000/0oooo2000000@0?ooo`<0
00000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000<000000P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo01H0oooo
0`0000020?ooo`030000003oool0oooo00`0oooo0`00000>0?ooo`030000003oool0000000<00000
403oool4000000T0oooo00<000000?ooo`3oool00P3oool4000000l0oooo1000000?0?ooo`@00000
103ooolJ000000@0oooo1000000?0?ooo`H000002`3oool010000000oooo0?ooo`3oool300000003
0?ooo`000000oooo00D0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0:0?ooo`8000004@3oool300000140oooo1000000;0?ooo`800000
0P3oool300000100oooo0`00000@0?ooo`<00000403oool300000100oooo1000000@0?ooo`<00000
303oool00`000000oooo0?ooo`040?ooo`<000001P3oool00`000000oooo0?ooo`0C0?ooo`009P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01d0oooo0P00000B0?ooo`8000003`3o
ool400000140oooo0`00000@0?ooo`<00000403oool300000140oooo0`00000@0?ooo`@000002P3o
ool00`000000oooo0?ooo`060?ooo`8000001@3oool00`000000oooo0?ooo`0D0?ooo`009P3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0@0?ooo`8000004P3oool200000140oooo0P00000B0?ooo`8000004@3oool2
00000140oooo00@000000?ooo`00000000002@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0503oool000X0oooo0`00000@0?ooo`8000001`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0000000A0?ooo`030000003oool0oooo0100oooo0P00000B0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool03@3oool2000000<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool3
000000`0oooo00070?ooo`X000002P3oool8000000<0oooo00<000000?ooo`3oool0203oool01000
0000oooo00000000000>0?ooo`040000003oool0000000000180oooo00<000000?ooo`3oool02`3o
ool01@000000oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool03@3oool300000140oooo
00<000000?ooo`3oool03@3oool00`000000oooo0000000A0?ooo`030000003oool0oooo0100oooo
0P00000=0?ooo`80000000<0oooo0000003oool02`3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`020?ooo`X00000203oool000T0oooo
1000000<0?ooo`L000001P3oool00`000000oooo0?ooo`060?ooo`@000003`3oool3000000030?oo
o`000000oooo00d0oooo00@000000?ooo`00000000003P3oool2000000030?ooo`000000oooo0100
oooo00<000000?ooo`3oool03`3oool300000100oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool200000003
0?ooo`000000oooo00L0oooo00<000000?ooo`3oool01@3oool5000000X0oooo000;0?ooo`800000
3`3oool4000000L0oooo00<000000?ooo`3oool00`3oool5000000h0oooo1@0000020?ooo`030000
003oool0oooo00X0oooo0`00000?0?ooo`@00000403oool200000100oooo00<000000?ooo`000000
0P3oool2000000d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool02@3oool2000000D0oooo00<000000?ooo`000000
1`3oool00`000000oooo0?ooo`070?ooo`<000001P3oool00`000000oooo0?ooo`060?ooo`800000
3@3oool002L0oooo00<000000?ooo`3oool00P3oool300000100oooo1P0000020?ooo`030000003o
ool0oooo00T0oooo1000000?0?ooo`@000003`3oool300000100oooo0`0000040?ooo`8000002P3o
ool200000100oooo0`00000A0?ooo`<000004@3oool2000000H0oooo0`0000070?ooo`<000001P3o
ool00`000000oooo0?ooo`070?ooo`D000001@3oool00`000000oooo0?ooo`0E0?ooo`009`3oool0
0`000000oooo0?ooo`0D0?ooo`<000001P3oool00`000000oooo0?ooo`080?ooo`<00000403oool4
000000030?ooo`000000000000d0oooo1000000>0?ooo`D000001@3oool3000000L0oooo0`00000?
0?ooo`@000003`3oool4000000l0oooo100000030?ooo`<000002@3oool5000000@0oooo00<00000
0?ooo`3oool02@3oool5000000@0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`060?ooo`8000004P3oool2000000D0oooo00<000000?oo
o`3oool02@3oool4000000l0oooo100000090?ooo`8000001@3oool200000100oooo1000000?0?oo
o`@00000403oool3000000030?ooo`000000000000d0oooo100000030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00<000000?ooo`3oool05@3oool002L0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool02@3oool200000140oooo0`00000<0?ooo`8000000`3oool200000100
oooo0`00000A0?ooo`<00000403oool400000100oooo0`0000020?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0@0?ooo`800000403oool400000180oooo0P00000A0?ooo`800000403oool4000001<0oooo
0`00000<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05P3oool000X0oooo0`00
000A0?ooo`800000203oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0A0?ooo`D000003`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00/0oooo0`0000020?ooo`800000503oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool3000000`0oooo0007
0?ooo`X000002`3oool7000000D0oooo00<000000?ooo`3oool01P3oool010000000oooo00000000
000>0?ooo`040000003oool00000000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0?0?ooo`040000003oool0oooo0?ooo`800000303oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00`0oooo00D000000?ooo`3oool000000?ooo`02000000d0oooo0P00000A0?oo
o`8000002`3oool2000000@0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`020000
00d0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00@0oooo2P000008
0?ooo`002@3oool4000000d0oooo1P0000080?ooo`030000003oool0oooo00@0oooo1000000?0?oo
o`<000001P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000000000h0oooo00@00000
0?ooo`3oool000001P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool03`3oool010000000oooo0?ooo`3oool6000000P0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`040?ooo`H000001P3oool00`000000oooo0?ooo`0@0?ooo`800000
3P3oool00`000000oooo00000004000000D0oooo00<000000?ooo`3oool01`3oool5000000X0oooo
000;0?ooo`800000303oool7000000P0oooo00<000000?ooo`3oool00P3oool5000000h0oooo1@00
00060?ooo`030000003oool0oooo00H0oooo0`00000?0?ooo`@000001`3oool00`000000oooo0?oo
o`060?ooo`8000004P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo1000
00040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01000000=0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`0000003@3oool010000000oooo0?ooo`3oool4000000@0oooo
00<000000?ooo`3oool01`3oool2000000d0oooo000Y0?ooo`030000003oool0oooo00H000003@3o
ool6000000L0oooo00<000000?ooo`3oool0103oool5000000h0oooo0`0000090?ooo`030000003o
ool0oooo00@0oooo0`00000@0?ooo`<00000403oool2000000h0oooo6@00000A0?ooo`800000403o
ool3000000`0oooo00@000000?ooo`3oool0oooo1P0000020?ooo`030000003oool0oooo01L0oooo
000Y0?ooo`030000003oool0oooo0180oooo0`00000;0?ooo`030000003oool0oooo00<0oooo1000
000?0?ooo`D000002@3oool2000000@0oooo1000000?0?ooo`@000003`3oool300000100oooo0`00
000?0?ooo`@000003`3oool4000000l0oooo1@00000;0?ooo`030000003oool0oooo00@0oooo1000
00000`3oool000000?ooo`0H0?ooo`00:@3oool00`000000oooo0?ooo`0Q0?ooo`040000003oool0
oooo0?ooo`8000004P3oool3000000d0oooo00<000000?ooo`3oool01000000@0?ooo`<00000403o
ool200000140oooo0`00000?0?ooo`@00000403oool3000000d0oooo0P0000020?ooo`<000002P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0503oool200000100oooo00@000000?ooo`00000000004@3o
ool300000140oooo0P00000A0?ooo`8000004@3oool300000140oooo0P00000<0?ooo`030000003o
ool0oooo00<0oooo0`0000090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0603o
ool002X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0V0?ooo`8000004P3oool2
00000140oooo0P00000B0?ooo`8000004@3oool200000180oooo0`00000:0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01P0oooo000:0?ooo`<000004@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0100oooo0P00000B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool20000
00P0oooo0P00000B0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool30000
00`0oooo00070?ooo`X000002`3oool3000000040?ooo`0000000000000000L0oooo00<000000?oo
o`3oool0103oool010000000oooo00000000000>0?ooo`040000003oool00000000000P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo00@0
00000?ooo`3oool000004@3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo00000100
oooo0P00000A0?ooo`8000004@3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`060?ooo`X00000203oool000T0oooo1000000=0?oo
o`H000002P3oool00`000000oooo0?ooo`020?ooo`@000003`3oool3000000/0oooo00<000000?oo
o`3oool00P3oool010000000oooo00000000000A0?ooo`030000003oool0oooo00h0oooo0P00000B
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01P3oool2000000P0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`D000000`3oool00`000000oooo0?ooo`09
0?ooo`D000002P3oool000/0oooo0P00000<0?ooo`L000002`3oool00`000000oooo000000040000
00h0oooo1@00000;0?ooo`040000003oool0oooo0?ooo`<00000403oool00`000000oooo0000000@
0?ooo`040000003oool0000000000100oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00T0oooo0P0000080?ooo`030000003oool0oooo00H0oooo1000
00000`3oool000000?ooo`0;0?ooo`8000003@3oool002/0oooo1`00000=0?ooo`H00000303oool0
0`000000oooo00000004000000h0oooo0`00000A0?ooo`8000000P3oool00`000000oooo0?ooo`0;
0?ooo`<00000403oool200000180oooo00<000000?ooo`3oool0403oool200000140oooo0P000003
0?ooo`800000303oool3000000H0oooo00<000000?ooo`3oool01P3oool7000001/0oooo000[0?oo
o`030000003oool0oooo0100oooo0`00000A0?ooo`@00000403oool4000000l0oooo100000020?oo
o`8000002`3oool4000000l0oooo1000000?0?ooo`@000003`3oool300000100oooo0`0000000`3o
ool000000000000=0?ooo`@000001@3oool00`000000oooo0?ooo`0:0?ooo`@000006`3oool002/0
oooo00<000000?ooo`3oool0903oool200000140oooo1000000@0?ooo`<000001@3oool2000000T0
oooo0`00000@0?ooo`<00000403oool4000000l0oooo0`00000A0?ooo`<00000403oool4000000<0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0I0?ooo`00:`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool000000140oooo0P00000B0?ooo`800000203oool2000000H0oooo
0`00000A0?ooo`<00000403oool300000140oooo0P00000A0?ooo`<000004P3oool2000000<0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool2000000/0oooo0P00
00040?ooo`8000004P3oool200000180oooo0P00000A0?ooo`8000003`3oool200000080oooo0P00
000C0?ooo`030000003oool000000100oooo00<000000?ooo`3oool06P3oool000X0oooo0`00000A
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`8000004P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3o
ool3000000`0oooo00070?ooo`X000002`3oool3000000040?ooo`0000000000000000T0oooo00<0
00000?ooo`3oool00P3oool010000000oooo00000000000A0?ooo`030000003oool0oooo00`0oooo
00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0203oool2000000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000A0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`000000303oool200000080oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00P0oooo2P0000080?ooo`002@3oool4000000d0
oooo1P00000=0?ooo`030000003oool0000000<00000403oool3000000l0oooo00@000000?ooo`00
000000004@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo0P0000030?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00X0oooo0P0000040?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`090?ooo`H000003P3oool5000000X0oooo000;0?ooo`80
0000303oool7000000d0oooo1@00000@0?ooo`800000403oool300000100oooo00<000000?ooo`00
0000403oool00`000000oooo0000000?0?ooo`<000004P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool01P3oool3000000L0oooo00<000000?ooo`3o
ool0403oool200000080oooo00<000000?ooo`3oool0303oool4000000h0oooo0P00000=0?ooo`00
;03oool6000000h0oooo1@00000>0?ooo`D000003P3oool300000140oooo0P00000@0?ooo`D00000
3P3oool200000180oooo00<000000?ooo`3oool0403oool3000000@0oooo0P00000:0?ooo`800000
4@3oool4000000h0oooo1P00000L0?ooo`00;@3oool00`000000oooo0?ooo`0?0?ooo`@00000403o
ool6000000d0oooo1000000?0?ooo`@000003`3oool4000000030?ooo`0000000000008000002P3o
ool4000000l0oooo1000000?0?ooo`P000002`3oool300000100oooo1000000B0?ooo`@000006`3o
ool002d0oooo00<000000?ooo`3oool03P3oool200000180oooo100000030?ooo`030000003oool0
oooo00T0oooo1000000@0?ooo`<00000403oool3000000H0oooo100000060?ooo`<00000403oool4
00000100oooo0`00000@0?ooo`<00000403oool400000180oooo00<000000?ooo`3oool06`3oool0
02h0oooo00<000000?ooo`3oool0803oool2000000H0oooo00<000000?ooo`3oool02@3oool20000
0180oooo0P00000A0?ooo`<000002P3oool2000000@0oooo0`00000@0?ooo`<000003P3oool60000
0140oooo0P00000A0?ooo`<000004@3oool00`000000oooo0?ooo`0L0?ooo`00;P3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool200000180
oooo0P00000=0?ooo`H000004P3oool2000000T0oooo1@0000040?ooo`8000004P3oool2000000l0
oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo01`0oooo000:0?ooo`<0
00008@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool04@3oool200000140oooo1@00000?0?ooo`030000003oool0oooo00<0oooo1@0000090?ooo`80
00004`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool03@3oool3000000`0oooo00070?ooo`X00000303oool2000000040?ooo`0000000000000000`0
oooo00@000000?ooo`000000oooo0P00000A0?ooo`030000003oool0oooo0100oooo00@000000?oo
o`3oool000003P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo00@00000
0?ooo`3oool000003`3oool00`000000oooo000000020?oooaD00000303oool010000000oooo0?oo
o`00000?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool01@000000oooo
0?ooo`3oool0000000d0oooo2P0000080?ooo`002@3oool4000000h0oooo1@00000?0?ooo`@00000
403oool3000000l0oooo00@000000?ooo`0000000000103oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`0000004@3oool2000000030?ooo`000000000000l0
oooo1@00000:0?ooo`002`3oool2000000`0oooo1`00000=0?ooo`D00000403oool200000100oooo
0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000004P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0303oool010000000oooo
0?ooo`3oool200000140oooo1000000>0?ooo`8000003@3oool002`0oooo1P00000>0?ooo`D00000
3P3oool4000000P0oooo00<000000?ooo`3oool01@3oool200000140oooo0P00000@0?ooo`<00000
4P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo0`00000@0?ooo`<00000
2`3oool00`000000oooo0?ooo`020?ooo`<00000403oool5000001`0oooo000`0?ooo`030000003o
ool0oooo00`0oooo1000000@0?ooo`D00000203oool00`000000oooo0?ooo`030?ooo`@00000403o
ool3000000l0oooo1000000?0?ooo`@000003`3oool4000000l0oooo1000000?0?ooo`@000002P3o
ool00`000000oooo0?ooo`020?ooo`D000003`3oool00`000000oooo0?ooo`03000001/0oooo000`
0?ooo`030000003oool0oooo00/0oooo0P00000B0?ooo`@000002P3oool00`000000oooo0?ooo`03
0?ooo`<00000403oool300000100oooo0`00000@0?ooo`@000003`3oool400000100oooo0`00000@
0?ooo`<000002P3oool00`000000oooo0?ooo`040?ooo`@000003P3oool00`000000oooo0?ooo`0N
0?ooo`00<03oool00`000000oooo0?ooo`0N0?ooo`8000003P3oool010000000oooo0?ooo`3oool2
00000180oooo0P00000A0?ooo`<00000403oool300000140oooo0`00000@0?ooo`<000004@3oool3
000000P0oooo00<000000?ooo`3oool0203oool2000000d0oooo00<000000?ooo`3oool07P3oool0
0300oooo00<000000?ooo`3oool0;`3oool2000000030?ooo`000000oooo0140oooo0P00000B0?oo
o`8000004P3oool200000140oooo0P00000B0?ooo`8000004P3oool2000000H0oooo0P00000J0?oo
o`030000003oool0oooo01h0oooo000:0?ooo`<00000903oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool200000180oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0@0?ooo`8000004`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0403oool3000000`0oooo00070?ooo`X00000
303oool2000000040?ooo`0000000000000000h0oooo00@000000?ooo`00000000004@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000403oool2
00000140oooo0P00000@0?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo0`0000000`3oool000000?oo
o`0<0?ooo`X00000203oool000T0oooo1000000>0?ooo`D00000403oool300000100oooo0`00000B
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000003`3oool5000000l0oooo1@00000:
0?ooo`002`3oool2000000`0oooo1`00000>0?ooo`D000003`3oool200000140oooo00<000000?oo
o`0000003P3oool2000000030?ooo`000000oooo0140oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0000000<0oooo0P00000;0?ooo`<000003P3oool00`00
0000oooo00000004000000d0oooo0P00000=0?ooo`00;@3oool6000000d0oooo1@00000?0?ooo`<0
0000403oool300000100oooo0P00000A0?ooo`8000004P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0100oooo0`00000@0?ooo`<000000P3oool00`000000oooo0?ooo`0;0?ooo`@0
00003@3oool00`000000oooo00000005000001/0oooo000/0?ooo`<00000103oool00`000000oooo
0?ooo`090?ooo`@000004@3oool4000000h0oooo1@00000?0?ooo`<00000403oool3000000l0oooo
1000000?0?ooo`@000003`3oool4000000l0oooo1P00000>0?ooo`@00000303oool00`000000oooo
0?ooo`030?ooo`@000006P3oool003<0oooo00<000000?ooo`3oool0203oool2000001<0oooo0`00
000@0?ooo`D000003P3oool300000140oooo0P00000@0?ooo`@000003`3oool400000100oooo0`00
000@0?ooo`@000004@3oool3000000/0oooo00<000000?ooo`3oool08@3oool003@0oooo00<00000
0?ooo`3oool06`3oool200000140oooo0`0000030?ooo`030000003oool0oooo00/0oooo0P00000B
0?ooo`800000403oool300000140oooo0`00000A0?ooo`8000004@3oool3000001<0oooo0P000009
0?ooo`030000003oool0oooo0280oooo000d0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`8000004P3oool200000180oooo0P00000A0?oo
o`<000004@3oool3000000l0oooo00<000000?ooo`3oool00P00000M0?ooo`030000003oool0oooo
0280oooo000;0?ooo`8000009`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool04@3oool200000180oooo00<000000?ooo`3oool0403oool2000001<0
oooo0P00000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0C0?ooo`8000003@3oool000T0oooo1000000@0?ooo`8000004P3oool010000000oooo
0?ooo`00000i0?ooo`800000703oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`D000002P3oool000L0oooo
2P00000:0?ooo`P000003@3oool2000000040?ooo`0000000000000000d0oooo00@000000?ooo`3o
ool000004P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03`3oool200000100oooo00<000000?ooo`3oool03@3oool2000000030?ooo`000000oooo
0100oooo00@000000?ooo`3oool00000303oool00`000000oooo00000002000000040?ooo`000000
0000000000/0oooo2P0000080?ooo`002P3oool3000000`0oooo1`00000>0?ooo`D000000P3oool0
0`000000oooo0?ooo`0:0?ooo`@000003`3oool010000000oooo00000000000>0?ooo`040000003o
ool0oooo000000H0oooo0P00000:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
2`3oool2000000@0oooo00<000000?ooo`0000003`3oool4000000/0oooo00<000000?ooo`3oool0
0P3oool6000000`0oooo0`00000<0?ooo`00703oool4000000d0oooo1@0000040?ooo`030000003o
ool0oooo00P0oooo1000000?0?ooo`<00000403oool3000000T0oooo0P0000050?ooo`030000003o
ool000000100oooo0P00000B0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403o
ool3000000T0oooo00<000000?ooo`3oool0103oool300000100oooo100000090?ooo`030000003o
ool0oooo00<0oooo1`00000J0?ooo`00;03oool3000000L0oooo00<000000?ooo`3oool01`3oool5
000000l0oooo1000000>0?ooo`D000002P3oool00`000000oooo0?ooo`020?ooo`<00000403oool3
000000l0oooo1000000?0?ooo`@000003`3oool4000000P0oooo00<000000?ooo`3oool01@3oool4
000000l0oooo100000090?ooo`030000003oool0oooo02@0oooo000g0?ooo`030000003oool0oooo
00D0oooo0`00000A0?ooo`<00000403oool4000000`0oooo0P0000020?ooo`8000004@3oool20000
0100oooo1000000?0?ooo`@00000403oool3000000H0oooo0P0000090?ooo`<000004@3oool30000
00L0oooo00<000000?ooo`3oool09@3oool003L0oooo00<000000?ooo`3oool0603oool200000180
oooo0`00000?0?ooo`@000004@3oool200000100oooo0`00000A0?ooo`<000004@3oool2000000D0
oooo00<000000?ooo`3oool02P3oool2000001<0oooo0P0000060?ooo`030000003oool0oooo02D0
oooo000g0?ooo`030000003oool0oooo02/0oooo0P00000B0?ooo`<00000403oool200000140oooo
0`00000A0?ooo`<000004@3oool300000080oooo0P00000>0?ooo`8000006P3oool00`000000oooo
0?ooo`0U0?ooo`002`3oool2000002/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`0A0?ooo`80000000<0oooo0000000000003P3oool200000180oooo0P00000B0?ooo`8000004P3o
ool400000140oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0G0?ooo`8000003@3o
ool000T0oooo1000000@0?ooo`8000006@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo0080oooo0P00000<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool2
00000100oooo0P0000000`3oool000000?ooo`0/0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool03P3oool5000000X0oooo00070?ooo`X000002P3oool8000000h0oooo00@000000?oo
o`0000000000103oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo00000180oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo008000003@3o
ool00`000000oooo0?ooo`0>0?ooo`8000004@3oool00`000000oooo0000000?0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo00<0oooo0`000000103oool0000000000000000;0?ooo`X00000203oool000X0oooo
0`00000<0?ooo`L000003`3oool4000000H0oooo00<000000?ooo`3oool01P3oool4000000l0oooo
00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo
0080oooo0P00000;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0<0?ooo`@000004`3oool00`000000oooo0000000?0?ooo`@000001`3oool00`00
0000oooo0?ooo`060?ooo`H00000303oool3000000`0oooo000L0?ooo`@000003@3oool6000000H0
oooo00<000000?ooo`3oool01@3oool4000000l0oooo1000000?0?ooo`<00000403oool3000000L0
oooo0P0000090?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0:0?ooo`800000103oool300000100oooo0`00000@0?ooo`@000001P3oool00`000000
oooo0?ooo`060?ooo`L000006P3oool002`0oooo0`00000:0?ooo`030000003oool0oooo00@0oooo
1@00000?0?ooo`@000003P3oool5000000l0oooo100000080?ooo`8000001@3oool4000000l0oooo
0`00000?0?ooo`@00000203oool2000000H0oooo0`00000@0?ooo`@000003`3oool4000000D0oooo
00<000000?ooo`3oool0:03oool003X0oooo00<000000?ooo`3oool00P3oool300000140oooo1000
000?0?ooo`@00000403oool3000000/0oooo0`0000020?ooo`<00000403oool3000000l0oooo1000
00030?ooo`D000002@3oool200000140oooo0`00000A0?ooo`<00000103oool00`000000oooo0?oo
o`0X0?ooo`00>P3oool00`000000oooo0?ooo`0F0?ooo`8000004@3oool300000140oooo0P00000?
0?ooo`D00000403oool300000100oooo1P00000>0?ooo`8000004P3oool2000001<0oooo0P000002
0?ooo`030000003oool0oooo02T0oooo000k0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0403oool200000180oooo0`00000A0?ooo`P000002`3oool3000000`0oooo1`00000B0?oo
o`8000004P3oool2000001H0oooo00<000000?ooo`3oool0:@3oool000/0oooo0P00000^0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool04@3oool200000180oooo0P0000060?ooo`X0
00000P3oool00`000000oooo0?ooo`050?ooo`H000001@3oool200000180oooo0P00000C0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool06`3oool2000000d0oooo00090?ooo`@00000
403oool2000001d0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00l0oooo2P00000;0?ooo`8000004`3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool5000000X0oooo00070?ooo`X000002P3o
ool8000000h0oooo00@000000?ooo`00000000001`3oool00`000000oooo0?ooo`040?ooo`040000
003oool0oooo00000180oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0000000l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool01`3oool3000000040?ooo`0000000000
000000/0oooo2P0000080?ooo`002P3oool3000000`0oooo1`00000?0?ooo`@000002P3oool00`00
0000oooo0?ooo`020?ooo`@000003`3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
000000l0oooo100000030?ooo`030000003oool0oooo00X0oooo1P00000<0?ooo`<00000303oool0
01`0oooo1000000=0?ooo`H000002`3oool00`000000oooo0?ooo`04000000l0oooo1000000?0?oo
o`<00000403oool300000180oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0100oooo0`00000A0?ooo`800000403oool4000000030?ooo`000000oooo
00`0oooo1`00000J0?ooo`00;03oool3000000l0oooo00<000000?ooo`0000001000000?0?ooo`@0
00003`3oool4000000l0oooo1000000?0?ooo`@000003`3oool300000100oooo0`00000@0?ooo`<0
0000403oool4000000l0oooo100000000`3oool000000?ooo`0]0?ooo`00?`3oool300000140oooo
1000000?0?ooo`@00000403oool300000100oooo1000000?0?ooo`<00000403oool300000140oooo
0P00000A0?ooo`<000004@3oool3000002l0oooo000o0?ooo`030000003oool0oooo0140oooo0P00
000A0?ooo`<000004@3oool200000140oooo0`00000@0?ooo`<000004@3oool200000140oooo0P00
000B0?ooo`<000004P3oool2000002h0oooo000o0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0403oool200000180oooo0`00000A0?ooo`<00000403oool300000140oooo0P00000B
0?ooo`8000004`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02h0oooo000;0?oo
o`800000<`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0140oooo0P00000B0?oo
o`8000004P3oool00`000000oooo0?ooo`0@0?ooo`8000004P3oool2000001@0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0O0?ooo`8000003@3oool000T0oooo1000000@0?ooo`80
00008@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0140oooo0P00000B0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool5000000X0oooo00070?ooo`X00000
2P3oool8000000h0oooo00@000000?ooo`0000000000303oool00`000000oooo000000020?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`0000004@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0000000l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo008000003@3oool3000000040?ooo`0000000000000000/0oooo2P0000080?oo
o`002P3oool3000000`0oooo1`00000?0?ooo`@000003`3oool4000000l0oooo00@000000?ooo`3o
ool000004@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0403oool00`000000oooo0000000?0?ooo`@00000403oool6000000`0oooo0`00000<0?oo
o`00703oool4000000d0oooo1P00000>0?ooo`@000003`3oool400000100oooo0P00000@0?ooo`<0
00004P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0403oool300000140oooo0P00000@0?ooo`@000003`3oool7000001X0oooo000/0?ooo`<00000
4P3oool4000000l0oooo1000000?0?ooo`@000003`3oool4000000l0oooo1000000?0?ooo`@00000
3`3oool300000100oooo0`00000@0?ooo`@000003`3oool400000300oooo00100?ooo`D000003P3o
ool400000100oooo0`00000@0?ooo`<00000403oool4000000l0oooo1000000?0?ooo`<000004@3o
ool300000100oooo0`00000>0?ooo`030000003oool0oooo00<00000;`3oool003l0oooo0P000003
0?ooo`030000003oool0oooo00`0oooo0P00000A0?ooo`<000004@3oool200000140oooo0`00000@
0?ooo`<000004@3oool200000180oooo0P00000A0?ooo`<000003@3oool00`000000oooo0?ooo`02
0?ooo`800000;P3oool004D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0100oooo0`00000A0?ooo`<00000403oool300000140oooo0P00000B0?oo
o`8000004`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03<0oooo00160?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool04@3oool200000180oooo0P00000B0?ooo`80
00004@3oool2000001<0oooo0P00000C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0=03oool000X0oooo0`00000A0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0A0?ooo`8000004P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00h0oooo0`00000<0?ooo`001`3oool:000000/0oooo0`000000103oool000000000
0000000>0?ooo`040000003oool0000000000140oooo0P00000A0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000140
oooo00<000000?ooo`3oool03`3oool00`000000oooo0000000?0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool03@3oool00`000000oooo000000020?ooo`030000003oool0oooo00`0
oooo0`000000103oool0000000000000000;0?ooo`X00000203oool000X0oooo0`00000=0?ooo`H0
00003`3oool400000100oooo0`00000?0?ooo`040000003oool0oooo00000140oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`0000003`3oool400000100oooo1P00000<0?ooo`<00000303oool001T0oooo1`00000=0?ooo`H0
00003`3oool200000100oooo1000000@0?ooo`030000003oool0000000l0oooo00<000000?ooo`00
00004P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0000000A0?ooo`<000003`3oool4000000l0oooo1`00000J0?ooo`00
;03oool300000180oooo1000000?0?ooo`@00000403oool3000000l0oooo0`00000@0?ooo`@00000
3`3oool400000100oooo0`00000@0?ooo`800000403oool4000000l0oooo1@00000_0?ooo`00@03o
ool300000100oooo1000000@0?ooo`<00000403oool4000000l0oooo1000000?0?ooo`@000003`3o
ool4000000l0oooo1000000@0?ooo`@00000403oool4000002h0oooo000o0?ooo`8000004P3oool2
00000180oooo0P00000A0?ooo`<00000403oool300000100oooo0`00000A0?ooo`<00000403oool3
00000180oooo0P00000C0?ooo`800000;@3oool00580oooo00<000000?ooo`3oool04@3oool20000
0140oooo0`00000A0?ooo`<00000403oool300000140oooo0`00000A0?ooo`800000503oool00`00
0000oooo0?ooo`0o0?ooo`00IP3oool00`000000oooo0?ooo`0@0?ooo`8000004P3oool200000180
oooo0P00000B0?ooo`8000004P3oool2000005D0oooo001i0?ooo`030000003oool0oooo0140oooo
0P00000B0?ooo`030000003oool0oooo0140oooo0P00000C0?ooo`030000003oool0oooo05<0oooo
002=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`1W0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {148.875, 0}} -> {-0.0644322, -0.0359374, \
0.00393332, 0.00393332}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part c", "Subsubsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell["eq1=pot[V0,\[Infinity]] ", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm\`\(-\(\(\[ImaginaryI]\ V0\ \((log(
                  1 - \[ExponentialE]\^\(\(-\(\(\[ImaginaryI]\ \[Pi]\ \
x\)\/a\)\) - \(\[Pi]\ y\)\/a\)) - 
                log(1 + \[ExponentialE]\^\(\(-\(\(\[ImaginaryI]\ \[Pi]\ \
x\)\/a\)\) - \(\[Pi]\ y\)\/a\)) - 
                log(1 - \[ExponentialE]\^\(\(\[ImaginaryI]\ \[Pi]\ x\)\/a - \
\(\[Pi]\ y\)\/a\)) + 
                log(1 + \[ExponentialE]\^\(\(\[ImaginaryI]\ \[Pi]\ x\)\/a - \
\(\[Pi]\ y\)\/a\)))\)\)\/\[Pi]\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"potV0", "=", " ", 
      RowBox[{
        RowBox[{"eq1", "//.", " ", 
          RowBox[{"{", 
            
            FormBox[\(log(1 - a_) \[Rule] 
                log(\(1 - a\)\/\(a + 1\)) + log(a + 1)\),
              "TraditionalForm"], "}"}]}], " ", "//", " ", "FullSimplify", 
        " "}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(TraditionalForm\`\(\[ImaginaryI]\ V0\ \((log(tanh(\(\[Pi]\ \((y - \
\[ImaginaryI]\ x)\)\)\/\(2\ a\))) - log(tanh(\(\[Pi]\ \((\[ImaginaryI]\ x + \
y)\)\)\/\(2\ a\))))\)\)\/\[Pi]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[\(potV0 /. a \[Rule] 1\) /. V0 \[Rule] 1\ , {x, 0.0001, 
          0.9999}, {y, 0, 0.5}, 
        AxesLabel \[Rule] {\ x\ , y\ , V\ }];\)\)], "Input",
  Hyphenation->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.72135e-17 1.04977 -0.0679587 1.04977 [
[.14594 .19959 -17.8862 -9 ]
[.14594 .19959 .11381 0 ]
[.27012 .15074 -17.1355 -9 ]
[.27012 .15074 .86454 0 ]
[.40047 .09947 -16.3847 -9 ]
[.40047 .09947 1.61526 0 ]
[.53747 .04562 -15.634 -9 ]
[.53747 .04562 2.36598 0 ]
[.29165 .07573 -9.31117 -9.8125 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 18 3.14607 ]
[.91861 .21225 0 -6.57576 ]
[.91861 .21225 10.0625 3.23674 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01568 .31795 -24 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00696 .37264 -18 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00208 .42927 -24 -2.88161 ]
[-0.00208 .42927 0 6.11839 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -3.08918 ]
[-0.05457 .39542 0 6.72332 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.15516 .20893 m
.15977 .2136 L
s
[(0.2)] .14594 .19959 .98735 1 Mshowa
.27892 .16047 m
.28332 .16534 L
s
[(0.4)] .27012 .15074 .90394 1 Mshowa
.4088 .10962 m
.41296 .11469 L
s
[(0.6)] .40047 .09947 .82053 1 Mshowa
.54525 .05618 m
.54915 .06146 L
s
[(0.8)] .53747 .04562 .73711 1 Mshowa
.125 Mabswid
.06611 .2438 m
.06896 .24652 L
s
.09545 .23231 m
.09827 .23506 L
s
.12513 .22069 m
.12792 .22346 L
s
.18555 .19703 m
.18829 .19986 L
s
.2163 .18499 m
.21901 .18785 L
s
.24742 .1728 m
.2501 .17569 L
s
.3108 .14799 m
.3134 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37573 .12256 m
.37826 .12558 L
s
.44227 .09651 m
.44473 .09958 L
s
.47617 .08323 m
.47859 .08634 L
s
.51049 .06979 m
.51287 .07293 L
s
.58046 .0424 m
.58275 .0456 L
s
.61611 .02844 m
.61836 .03167 L
s
.65223 .0143 m
.65443 .01756 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.1)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.2)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.3)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.4)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(0.5)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70252 .02109 m
.69885 .02251 L
s
.71605 .04178 m
.71237 .04318 L
s
.72932 .06208 m
.72564 .06347 L
s
.74235 .08201 m
.73866 .08339 L
s
.7677 .12078 m
.764 .12213 L
s
.78003 .13965 m
.77633 .14098 L
s
.79214 .15817 m
.78843 .1595 L
s
.80404 .17637 m
.80033 .17768 L
s
.82721 .21182 m
.82349 .21311 L
s
.8385 .22909 m
.83478 .23037 L
s
.8496 .24606 m
.84587 .24733 L
s
.86051 .26275 m
.85677 .264 L
s
.88178 .29529 m
.87804 .29651 L
s
.89215 .31115 m
.88841 .31237 L
s
.90235 .32676 m
.89861 .32797 L
s
.91239 .34211 m
.90864 .34331 L
s
.93198 .37208 m
.92823 .37326 L
s
.94155 .38671 m
.93779 .38788 L
s
.95096 .40111 m
.9472 .40226 L
s
.96022 .41528 m
.95646 .41643 L
s
gsave
.91861 .21225 -61 -10.5758 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02795 .31328 m
.03408 .31095 L
s
[(0.25)] .01568 .31795 1 -0.38067 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0.5)] .00696 .37264 1 -0.37036 Mshowa
.01027 .42483 m
.01644 .42261 L
s
[(0.75)] -0.00208 .42927 1 -0.35964 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03468 .27078 m
.03835 .26935 L
s
.03301 .2813 m
.03669 .27988 L
s
.03134 .29189 m
.03501 .29047 L
s
.02965 .30255 m
.03332 .30114 L
s
.02623 .32409 m
.02991 .3227 L
s
.02451 .33497 m
.02819 .33359 L
s
.02277 .34593 m
.02646 .34455 L
s
.02102 .35697 m
.02471 .35559 L
s
.01749 .37927 m
.02118 .37791 L
s
.0157 .39054 m
.0194 .38919 L
s
.0139 .40189 m
.0176 .40054 L
s
.01209 .41332 m
.01579 .41198 L
s
.00843 .43642 m
.01214 .4351 L
s
.00658 .4481 m
.01029 .44678 L
s
.00472 .45986 m
.00843 .45855 L
s
.00284 .4717 m
.00656 .4704 L
s
gsave
-0.05457 .39542 -71 -7.08918 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(V) show
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.47 .675 .954 r
.38312 .58325 .40512 .60373 .4416 .60449 .41979 .58536 Metetra
.474 .694 .964 r
.41979 .58536 .4416 .60449 .47885 .60447 .45729 .58655 Metetra
.494 .718 .971 r
.45729 .58655 .47885 .60447 .51687 .60297 .49562 .586 Metetra
.526 .744 .975 r
.49562 .586 .51687 .60297 .55563 .59952 .53474 .58318 Metetra
.563 .767 .974 r
.53474 .58318 .55563 .59952 .59508 .5938 .57459 .57779 Metetra
.599 .786 .97 r
.57459 .57779 .59508 .5938 .63516 .58567 .61511 .56971 Metetra
.633 .801 .963 r
.61511 .56971 .63516 .58567 .67579 .57505 .65622 .5589 Metetra
.664 .811 .954 r
.65622 .5589 .67579 .57505 .71691 .56189 .69784 .54532 Metetra
.692 .818 .942 r
.69784 .54532 .71691 .56189 .75844 .54617 .73987 .52895 Metetra
.717 .821 .929 r
.73987 .52895 .75844 .54617 .80031 .52793 .78224 .50975 Metetra
.738 .82 .915 r
.78224 .50975 .80031 .52793 .84243 .50725 .82484 .4878 Metetra
.754 .815 .9 r
.82484 .4878 .84243 .50725 .88476 .48439 .86762 .46334 Metetra
.764 .806 .887 r
.86762 .46334 .88476 .48439 .92729 .45984 .91054 .43687 Metetra
.767 .794 .875 r
.91054 .43687 .92729 .45984 .97003 .43426 .95363 .40922 Metetra
.432 .658 .955 r
.36056 .56225 .38312 .58325 .41979 .58536 .39739 .56597 Metetra
.437 .68 .967 r
.39739 .56597 .41979 .58536 .45729 .58655 .43512 .56857 Metetra
.464 .71 .975 r
.43512 .56857 .45729 .58655 .49562 .586 .47374 .5691 Metetra
.504 .741 .98 r
.47374 .5691 .49562 .586 .53474 .58318 .51322 .56698 Metetra
.548 .769 .98 r
.51322 .56698 .53474 .58318 .57459 .57779 .55349 .56194 Metetra
.59 .791 .976 r
.55349 .56194 .57459 .57779 .61511 .56971 .59446 .55391 Metetra
.629 .807 .968 r
.59446 .55391 .61511 .56971 .65622 .5589 .63606 .54291 Metetra
.664 .818 .958 r
.63606 .54291 .65622 .5589 .69784 .54532 .67819 .5289 Metetra
.695 .825 .945 r
.67819 .5289 .69784 .54532 .73987 .52895 .72075 .51184 Metetra
.722 .829 .931 r
.72075 .51184 .73987 .52895 .78224 .50975 .76365 .49165 Metetra
.746 .828 .915 r
.76365 .49165 .78224 .50975 .82484 .4878 .80676 .46834 Metetra
.764 .823 .898 r
.80676 .46834 .82484 .4878 .86762 .46334 .85 .44211 Metetra
.776 .813 .883 r
.85 .44211 .86762 .46334 .91054 .43687 .89332 .41349 Metetra
.779 .8 .869 r
.89332 .41349 .91054 .43687 .95363 .40922 .93675 .38347 Metetra
.383 .635 .954 r
.33741 .54069 .36056 .56225 .39739 .56597 .37436 .54635 Metetra
.39 .662 .967 r
.37436 .54635 .39739 .56597 .43512 .56857 .41228 .55063 Metetra
.426 .7 .978 r
.41228 .55063 .43512 .56857 .47374 .5691 .45119 .55238 Metetra
.478 .738 .985 r
.45119 .55238 .47374 .5691 .51322 .56698 .49103 .55101 Metetra
.532 .771 .985 r
.49103 .55101 .51322 .56698 .55349 .56194 .53172 .54631 Metetra
.581 .796 .981 r
.53172 .54631 .55349 .56194 .59446 .55391 .57317 .53833 Metetra
.625 .813 .973 r
.57317 .53833 .59446 .55391 .63606 .54291 .61527 .52711 Metetra
.663 .825 .962 r
.61527 .52711 .63606 .54291 .67819 .5289 .65794 .51267 Metetra
.697 .833 .948 r
.65794 .51267 .67819 .5289 .72075 .51184 .70106 .49492 Metetra
.727 .837 .933 r
.70106 .49492 .72075 .51184 .76365 .49165 .74451 .47371 Metetra
.754 .837 .915 r
.74451 .47371 .76365 .49165 .80676 .46834 .78816 .44896 Metetra
.775 .832 .896 r
.78816 .44896 .80676 .46834 .85 .44211 .83189 .42078 Metetra
.789 .821 .878 r
.83189 .42078 .85 .44211 .89332 .41349 .87563 .38973 Metetra
.792 .806 .863 r
.87563 .38973 .89332 .41349 .93675 .38347 .91939 .35697 Metetra
.319 .603 .949 r
.31365 .51858 .33741 .54069 .37436 .54635 .35066 .52658 Metetra
.329 .636 .963 r
.35066 .52658 .37436 .54635 .41228 .55063 .38875 .53283 Metetra
.379 .685 .979 r
.38875 .53283 .41228 .55063 .45119 .55238 .42793 .53595 Metetra
.447 .734 .988 r
.42793 .53595 .45119 .55238 .49103 .55101 .46813 .53536 Metetra
.513 .773 .99 r
.46813 .53536 .49103 .55101 .53172 .54631 .50925 .53099 Metetra
.571 .801 .986 r
.50925 .53099 .53172 .54631 .57317 .53833 .55118 .52301 Metetra
.62 .82 .977 r
.55118 .52301 .57317 .53833 .61527 .52711 .59382 .51156 Metetra
.661 .833 .966 r
.59382 .51156 .61527 .52711 .65794 .51267 .63704 .49667 Metetra
.698 .842 .952 r
.63704 .49667 .65794 .51267 .70106 .49492 .68075 .47824 Metetra
.732 .847 .935 r
.68075 .47824 .70106 .49492 .74451 .47371 .72479 .45603 Metetra
.762 .847 .915 r
.72479 .45603 .74451 .47371 .78816 .44896 .76902 .42978 Metetra
.787 .842 .893 r
.76902 .42978 .78816 .44896 .83189 .42078 .81327 .39947 Metetra
.803 .83 .872 r
.81327 .39947 .83189 .42078 .87563 .38973 .85743 .36565 Metetra
.807 .812 .855 r
.85743 .36565 .87563 .38973 .91939 .35697 .90152 .3297 Metetra
.233 .557 .934 r
.28926 .49586 .31365 .51858 .35066 .52658 .32626 .50674 Metetra
.249 .599 .951 r
.32626 .50674 .35066 .52658 .38875 .53283 .36446 .51532 Metetra
.321 .665 .974 r
.36446 .51532 .38875 .53283 .42793 .53595 .4039 .51996 Metetra
.411 .728 .99 r
.4039 .51996 .42793 .53595 .46813 .53536 .44446 .52014 Metetra
.493 .775 .995 r
.44446 .52014 .46813 .53536 .50925 .53099 .48602 .51604 Metetra
.561 .807 .991 r
.48602 .51604 .50925 .53099 .55118 .52301 .52845 .508 Metetra
.614 .827 .982 r
.52845 .508 .55118 .52301 .59382 .51156 .57163 .49629 Metetra
.659 .841 .97 r
.57163 .49629 .59382 .51156 .63704 .49667 .61545 .48097 Metetra
.699 .851 .955 r
.61545 .48097 .63704 .49667 .68075 .47824 .65977 .4619 Metetra
.736 .857 .937 r
.65977 .4619 .68075 .47824 .72479 .45603 .70445 .4387 Metetra
.77 .858 .915 r
.70445 .4387 .72479 .45603 .76902 .42978 .7493 .41094 Metetra
.799 .853 .891 r
.7493 .41094 .76902 .42978 .81327 .39947 .79411 .37834 Metetra
.818 .84 .866 r
.79411 .37834 .81327 .39947 .85743 .36565 .83871 .34134 Metetra
.823 .819 .845 r
.83871 .34134 .85743 .36565 .90152 .3297 .88312 .30162 Metetra
.115 .487 .901 r
.2642 .47254 .28926 .49586 .32626 .50674 .30108 .487 Metetra
.144 .544 .923 r
.30108 .487 .32626 .50674 .36446 .51532 .33935 .49835 Metetra
.249 .637 .961 r
.33935 .49835 .36446 .51532 .4039 .51996 .37902 .50461 Metetra
.371 .721 .988 r
.37902 .50461 .4039 .51996 .44446 .52014 .41995 .5055 Metetra
.473 .778 .997 r
.41995 .5055 .44446 .52014 .48602 .51604 .46197 .50154 Metetra
.55 .813 .995 r
.46197 .50154 .48602 .51604 .52845 .508 .50493 .49335 Metetra
.609 .835 .986 r
.50493 .49335 .52845 .508 .57163 .49629 .54868 .48133 Metetra
.656 .849 .974 r
.54868 .48133 .57163 .49629 .61545 .48097 .59311 .4656 Metetra
.699 .86 .959 r
.59311 .4656 .61545 .48097 .65977 .4619 .63809 .44594 Metetra
.739 .867 .94 r
.63809 .44594 .65977 .4619 .70445 .4387 .68345 .42187 Metetra
.777 .869 .916 r
.68345 .42187 .70445 .4387 .7493 .41094 .72896 .39264 Metetra
.811 .865 .887 r
.72896 .39264 .7493 .41094 .79411 .37834 .77438 .3576 Metetra
.835 .851 .857 r
.77438 .3576 .79411 .37834 .83871 .34134 .81946 .31696 Metetra
.842 .827 .833 r
.81946 .31696 .83871 .34134 .88312 .30162 .86416 .27269 Metetra
0 .382 .834 r
.23845 .44858 .2642 .47254 .30108 .487 .27508 .46761 Metetra
.005 .463 .868 r
.27508 .46761 .30108 .487 .33935 .49835 .31334 .48222 Metetra
.161 .6 .935 r
.31334 .48222 .33935 .49835 .37902 .50461 .35323 .49013 Metetra
.327 .713 .982 r
.35323 .49013 .37902 .50461 .41995 .5055 .39454 .49155 Metetra
.453 .782 .998 r
.39454 .49155 .41995 .5055 .46197 .50154 .43704 .48755 Metetra
.541 .82 .997 r
.43704 .48755 .46197 .50154 .50493 .49335 .48054 .47908 Metetra
.603 .842 .989 r
.48054 .47908 .50493 .49335 .54868 .48133 .52489 .4667 Metetra
.653 .857 .978 r
.52489 .4667 .54868 .48133 .59311 .4656 .56997 .45058 Metetra
.696 .868 .963 r
.56997 .45058 .59311 .4656 .63809 .44594 .61563 .43046 Metetra
.739 .877 .944 r
.61563 .43046 .63809 .44594 .68345 .42187 .66172 .40566 Metetra
.783 .881 .918 r
.66172 .40566 .68345 .42187 .72896 .39264 .70797 .37511 Metetra
.824 .878 .884 r
.70797 .37511 .72896 .39264 .77438 .3576 .75407 .33759 Metetra
.854 .864 .848 r
.75407 .33759 .77438 .3576 .81946 .31696 .79965 .29274 Metetra
.863 .836 .818 r
.79965 .29274 .81946 .31696 .86416 .27269 .84462 .24288 Metetra
0 .228 .71 r
.21199 .42395 .23845 .44858 .27508 .46761 .24815 .44897 Metetra
0 .349 .769 r
.24815 .44897 .27508 .46761 .31334 .48222 .2863 .46741 Metetra
.061 .551 .891 r
.2863 .46741 .31334 .48222 .35323 .49013 .32642 .47683 Metetra
.284 .706 .97 r
.32642 .47683 .35323 .49013 .39454 .49155 .36814 .47846 Metetra
.437 .788 .997 r
.36814 .47846 .39454 .49155 .43704 .48755 .41114 .47414 Metetra
.533 .828 .999 r
.41114 .47414 .43704 .48755 .48054 .47908 .45522 .46521 Metetra
.598 .849 .992 r
.45522 .46521 .48054 .47908 .52489 .4667 .50019 .45241 Metetra
.648 .864 .981 r
.50019 .45241 .52489 .4667 .56997 .45058 .54595 .43593 Metetra
.692 .876 .967 r
.54595 .43593 .56997 .45058 .61563 .43046 .59234 .41548 Metetra
.737 .887 .948 r
.59234 .41548 .61563 .43046 .66172 .40566 .63921 .39022 Metetra
.786 .894 .921 r
.63921 .39022 .66172 .40566 .70797 .37511 .68628 .35866 Metetra
.835 .893 .882 r
.68628 .35866 .70797 .37511 .75407 .33759 .73313 .31875 Metetra
.874 .878 .836 r
.73313 .31875 .75407 .33759 .79965 .29274 .77928 .26911 Metetra
.887 .846 .798 r
.77928 .26911 .79965 .29274 .84462 .24288 .82448 .21213 Metetra
.487 0 0 r
.18478 .39863 .21199 .42395 .24815 .44897 .22014 .43178 Metetra
0 .203 .616 r
.22014 .43178 .24815 .44897 .2863 .46741 .2581 .45455 Metetra
0 .497 .825 r
.2581 .45455 .2863 .46741 .32642 .47683 .29846 .46505 Metetra
.249 .702 .954 r
.29846 .46505 .32642 .47683 .36814 .47846 .34065 .46636 Metetra
.427 .796 .994 r
.34065 .46636 .36814 .47846 .41114 .47414 .38421 .46133 Metetra
.529 .836 .999 r
.38421 .46133 .41114 .47414 .45522 .46521 .42889 .45173 Metetra
.594 .856 .993 r
.42889 .45173 .45522 .46521 .50019 .45241 .47452 .43842 Metetra
.642 .87 .984 r
.47452 .43842 .50019 .45241 .54595 .43593 .52098 .42163 Metetra
.685 .883 .972 r
.52098 .42163 .54595 .43593 .59234 .41548 .56815 .40105 Metetra
.73 .896 .954 r
.56815 .40105 .59234 .41548 .63921 .39022 .61584 .37569 Metetra
.784 .907 .926 r
.61584 .37569 .63921 .39022 .68628 .35866 .6638 .34363 Metetra
.843 .91 .882 r
.6638 .34363 .68628 .35866 .73313 .31875 .71154 .30177 Metetra
.894 .894 .822 r
.71154 .30177 .73313 .31875 .77928 .26911 .75833 .24677 Metetra
.914 .857 .771 r
.75833 .24677 .77928 .26911 .82448 .21213 .80369 .18042 Metetra
.7 .196 0 r
.15679 .37258 .18478 .39863 .22014 .43178 .19082 .41731 Metetra
.524 0 0 r
.19082 .41731 .22014 .43178 .2581 .45455 .22852 .44457 Metetra
0 .449 .745 r
.22852 .44457 .2581 .45455 .29846 .46505 .26923 .45517 Metetra
.231 .709 .936 r
.26923 .45517 .29846 .46505 .34065 .46636 .31196 .45534 Metetra
.427 .809 .991 r
.31196 .45534 .34065 .46636 .38421 .46133 .35615 .44912 Metetra
.53 .846 .998 r
.35615 .44912 .38421 .46133 .42889 .45173 .40148 .43858 Metetra
.591 .863 .994 r
.40148 .43858 .42889 .45173 .47452 .43842 .4478 .42467 Metetra
.634 .875 .986 r
.4478 .42467 .47452 .43842 .52098 .42163 .49499 .40763 Metetra
.674 .888 .976 r
.49499 .40763 .52098 .42163 .56815 .40105 .54295 .38714 Metetra
.718 .903 .961 r
.54295 .38714 .56815 .40105 .61584 .37569 .59154 .36214 Metetra
.774 .919 .935 r
.59154 .36214 .61584 .37569 .6638 .34363 .64047 .3304 Metetra
.844 .929 .885 r
.64047 .3304 .6638 .34363 .71154 .30177 .68923 .28758 Metetra
.913 .914 .806 r
.68923 .28758 .71154 .30177 .75833 .24677 .73682 .22701 Metetra
.943 .867 .733 r
.73682 .22701 .75833 .24677 .80369 .18042 .78224 .1477 Metetra
.841 .38 0 r
.12798 .3458 .15679 .37258 .19082 .41731 .15977 .40796 Metetra
.632 .068 0 r
.15977 .40796 .19082 .41731 .22852 .44457 .19728 .43864 Metetra
.164 0 0 r
.19728 .43864 .22852 .44457 .26923 .45517 .23855 .44748 Metetra
.243 .732 .923 r
.23855 .44748 .26923 .45517 .31196 .45534 .28197 .44541 Metetra
.442 .827 .987 r
.28197 .44541 .31196 .45534 .35615 .44912 .32686 .43742 Metetra
.536 .857 .997 r
.32686 .43742 .35615 .44912 .40148 .43858 .3729 .42566 Metetra
.589 .869 .994 r
.3729 .42566 .40148 .43858 .4478 .42467 .41994 .41105 Metetra
.626 .879 .988 r
.41994 .41105 .4478 .42467 .49499 .40763 .4679 .39383 Metetra
.66 .89 .981 r
.4679 .39383 .49499 .40763 .54295 .38714 .51668 .37367 Metetra
.698 .907 .969 r
.51668 .37367 .54295 .38714 .59154 .36214 .56618 .34959 Metetra
.752 .929 .947 r
.56618 .34959 .59154 .36214 .64047 .3304 .61618 .31925 Metetra
.832 .949 .896 r
.61618 .31925 .64047 .3304 .68923 .28758 .66615 .27737 Metetra
.925 .937 .791 r
.66615 .27737 .68923 .28758 .73682 .22701 .71479 .21233 Metetra
.973 .875 .678 r
.71479 .21233 .73682 .22701 .78224 .1477 .76009 .11392 Metetra
.911 .507 .188 r
.09832 .31825 .12798 .3458 .15977 .40796 .12616 .40846 Metetra
.648 .109 0 r
.12616 .40846 .15977 .40796 .19728 .43864 .16403 .43797 Metetra
.12 0 0 r
.16403 .43797 .19728 .43864 .23855 .44748 .20626 .44208 Metetra
.295 .776 .92 r
.20626 .44208 .23855 .44748 .28197 .44541 .25057 .43646 Metetra
.471 .85 .985 r
.25057 .43646 .28197 .44541 .32686 .43742 .29625 .42609 Metetra
.549 .868 .995 r
.29625 .42609 .32686 .43742 .3729 .42566 .34306 .41284 Metetra
.59 .874 .993 r
.34306 .41284 .3729 .42566 .41994 .41105 .39086 .39744 Metetra
.618 .881 .99 r
.39086 .39744 .41994 .41105 .4679 .39383 .4396 .38007 Metetra
.642 .891 .985 r
.4396 .38007 .4679 .39383 .51668 .37367 .48923 .3605 Metetra
.67 .907 .977 r
.48923 .3605 .51668 .37367 .56618 .34959 .53968 .33791 Metetra
.713 .933 .961 r
.53968 .33791 .56618 .34959 .61618 .31925 .59079 .3103 Metetra
.791 .966 .917 r
.59079 .3103 .61618 .31925 .66615 .27737 .64215 .27239 Metetra
.916 .968 .789 r
.64215 .27239 .66615 .27737 .71479 .21233 .69233 .20764 Metetra
.993 .872 .595 r
.69233 .20764 .71479 .21233 .76009 .11392 .7372 .07905 Metetra
.937 .583 .321 r
.06775 .29 .09832 .31825 .12616 .40846 .08846 .42697 Metetra
.524 .01 0 r
.08846 .42697 .12616 .40846 .16403 .43797 .12844 .44306 Metetra
.12844 .44306 .16403 .43797 .20626 .44208 .17221 .43869 Metetra
.387 .836 .93 r
.17221 .43869 .20626 .44208 .25057 .43646 .21763 .4282 Metetra
.514 .875 .984 r
.21763 .4282 .25057 .43646 .29625 .42609 .26423 .41491 Metetra
.567 .879 .993 r
.26423 .41491 .29625 .42609 .34306 .41284 .31187 .39991 Metetra
.593 .879 .993 r
.31187 .39991 .34306 .41284 .39086 .39744 .36047 .38363 Metetra
.609 .881 .991 r
.36047 .38363 .39086 .39744 .4396 .38007 .41002 .36617 Metetra
.621 .888 .989 r
.41002 .36617 .4396 .38007 .48923 .3605 .4605 .34737 Metetra
.633 .901 .985 r
.4605 .34737 .48923 .3605 .53968 .33791 .5119 .32678 Metetra
.65 .924 .975 r
.5119 .32678 .53968 .33791 .59079 .3103 .56415 .30322 Metetra
.692 .961 .943 r
.56415 .30322 .59079 .3103 .64215 .27239 .61703 .27315 Metetra
.821 1 .82 r
.61703 .27315 .64215 .27239 .69233 .20764 .66952 .22147 Metetra
.991 .848 .484 r
.66952 .22147 .69233 .20764 .7372 .07905 .71355 .04313 Metetra
.434 .135 .356 r
.00095 .48363 .06775 .29 .08846 .42697 .04527 .46819 Metetra
.147 0 0 r
.04527 .46819 .08846 .42697 .12844 .44306 .09038 .45247 Metetra
.311 .798 .759 r
.09038 .45247 .12844 .44306 .17221 .43869 .13631 .43646 Metetra
.503 .897 .945 r
.13631 .43646 .17221 .43869 .21763 .4282 .18308 .42016 Metetra
.565 .897 .983 r
.18308 .42016 .21763 .4282 .26423 .41491 .23072 .40356 Metetra
.589 .888 .99 r
.23072 .40356 .26423 .41491 .31187 .39991 .27924 .38665 Metetra
.599 .882 .992 r
.27924 .38665 .31187 .39991 .36047 .38363 .32868 .36942 Metetra
.601 .88 .992 r
.32868 .36942 .36047 .38363 .41002 .36617 .37905 .35186 Metetra
.599 .882 .992 r
.37905 .35186 .41002 .36617 .4605 .34737 .43039 .33397 Metetra
.589 .888 .99 r
.43039 .33397 .4605 .34737 .5119 .32678 .48273 .31573 Metetra
.565 .897 .983 r
.48273 .31573 .5119 .32678 .56415 .30322 .53609 .29714 Metetra
.503 .897 .945 r
.53609 .29714 .56415 .30322 .61703 .27315 .5905 .27817 Metetra
.311 .798 .759 r
.5905 .27817 .61703 .27315 .66952 .22147 .646 .25883 Metetra
.147 0 0 r
.646 .25883 .66952 .22147 .71355 .04313 .70262 .2391 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.15516 .20893 m
.15977 .2136 L
s
[(0.2)] .14594 .19959 .98735 1 Mshowa
.27892 .16047 m
.28332 .16534 L
s
[(0.4)] .27012 .15074 .90394 1 Mshowa
.4088 .10962 m
.41296 .11469 L
s
[(0.6)] .40047 .09947 .82053 1 Mshowa
.54525 .05618 m
.54915 .06146 L
s
[(0.8)] .53747 .04562 .73711 1 Mshowa
.125 Mabswid
.06611 .2438 m
.06896 .24652 L
s
.09545 .23231 m
.09827 .23506 L
s
.12513 .22069 m
.12792 .22346 L
s
.18555 .19703 m
.18829 .19986 L
s
.2163 .18499 m
.21901 .18785 L
s
.24742 .1728 m
.2501 .17569 L
s
.3108 .14799 m
.3134 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37573 .12256 m
.37826 .12558 L
s
.44227 .09651 m
.44473 .09958 L
s
.47617 .08323 m
.47859 .08634 L
s
.51049 .06979 m
.51287 .07293 L
s
.58046 .0424 m
.58275 .0456 L
s
.61611 .02844 m
.61836 .03167 L
s
.65223 .0143 m
.65443 .01756 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00b@3oool2000005D0oooo0038
0?ooo`040000003oool0oooo000005@0oooo00380?ooo`040000003oool0oooo000005@0oooo0038
0?ooo`040000003oool0oooo000005@0oooo00380?ooo`040000003oool0oooo000005@0oooo0033
0?ooo`8000000`3oool010000000oooo0?ooo`00001D0?ooo`00`@3oool2000000030?ooo`000000
000000<0oooo0P00001E0?ooo`00_P3oool3000000<0oooo0P00001J0?ooo`00^`3oool3000000H0
oooo00<000000?ooo`000000F@3oool00900oooo0P0000040?ooo`030000003oool0oooo00<0oooo
0P00000K0?ooo`<00000203oool010000000oooo0?ooo`00001H0?ooo`00S`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000001L0oooo0`00000;0?ooo`040000003oool0oooo
000005P0oooo002?0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000005@3o
ool2000000h0oooo00D000000?ooo`000000oooo0000001G0?ooo`00S`3oool010000000oooo0?oo
o`0000090?ooo`8000004`3oool300000100oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1D0?ooo`00S`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000100
oooo0P0000000`3oool000000?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0E03oool008l0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000=0?oo
o`<000005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05<0oooo002@0?ooo`80
00002P3oool2000000/0oooo0`00000H0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0D`3oool00:L0oooo0P00000L0?ooo`040000003oool0oooo0?ooo`<00000E03oool00:@0oooo
0`00000N0?ooo`030000003oool0oooo0080oooo0`00001C0?ooo`00F@3oool2000000030?ooo`00
0000000004@0oooo0P00000Q0?ooo`030000003oool0oooo0080oooo0`00001C0?ooo`00FP3oool0
0`000000oooo000000120?ooo`<000008`3oool010000000oooo0?ooo`3oool2000000030?gIN`00
000000000580oooo001K0?ooo`030000003oool0oooo03h0oooo0`0000020?ooo`030000003oool0
oooo0240oooo00@000000?ooo`3oool0oooo0P0000020?gIN`800000D@3oool005X0oooo00<00000
0?ooo`000000?@3oool2000002T0oooo00@000000?ooo`3oool0oooo0P0000020?gIN`800000D@3o
ool005T0oooo0P0000000`3oool000000000000i0?ooo`<00000:`3oool010000000oooo0?ooo`3o
ool2000000<0oMUk0P00001@0?ooo`00K@3oool2000000@0oooo00<000000?ooo`3oool00`3oool2
000001X0oooo0P0000000`3oool000000?ooo`0[0?ooo`060000003oool0oooo0000000U00000000
103mfG/2000004l0oooo001/0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00005P3oool300000300oooo00H000000?ooo`3oool0000002D0000000040?gIN`800000C`3oool0
06`0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000C0?ooo`<00000<`3o
ool00`000000oooo0?ooo`02000000H0oMUk0P0000070?ooo`800000103oool00`000000oooo0?oo
o`020?ooo`@00000>03oool006`0oooo00@000000?ooo`3oool00000203oool300000180oooo0P00
000f0?ooo`030000003oool0oooo008000001P3mfG/3000000D0oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`0g0?ooo`00K03oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo00l0oooo0`00000h0?ooo`050000003oool0000002D0000000001@3mfG/010000000
o]nH0000000000050?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0=`3oool0
06`0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0=0?ooo`800000>`3oool0
1@000000oooo0000000U0000000000D0oMUk00<000000?kOV03ngiP00P0000040?ooo`040000003o
ool0oooo000000X0oooo00<000000?ooo`3oool0=`3oool006d0oooo0P00000:0?ooo`<000002@3o
ool3000003d0oooo00D000000?ooo`0000009@00000000050?gIN`030000003ngiP0o]nH00800000
103oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo03L0oooo00230?ooo`800000
0P3oool00`000000oooo0?ooo`0k0?ooo`050000003oool0000002D000000000103mfG/00`000000
o]nH0?kOV0020?kOV08000000`3oool010000000oooo0?ooo`0000080?ooo`<00000>@3oool00800
oooo0`0000120?ooo`8000000P0U00000`000000oMUk0?gIN`020?gIN`030000003ngiP0o]nH00<0
o]nH0P0000030?ooo`8000002`3oool00`000000oooo0?ooo`0g0?ooo`00O@3oool3000004D0oooo
0P00000202D000050000003mfG/0oMUk0?gIN`0000001P3ngiP2000004X0oooo001k0?ooo`800000
00<0oooo0000003oool0A@3oool2000000809@0000D000000?gIN`3mfG/0oMUk000000070?kOV080
0000B@3oool007P0oooo0`0000040?ooo`030000003oool0oooo04<0oooo0P00000202D000050000
003mfG/0oMUk0?gIN`0000001`3ngiP3000004P0oooo001<0?ooo`800000103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01X0oooo0P00001=0?ooo`050000000U00009@0002D00000
00000P3mfG/00`000000o]nH0?kOV0050?kOV0040000003igjd00000000004P0oooo001;0?ooo`04
0000003oool0oooo000000X0oooo00<000000?ooo`3oool05`3oool4000004h0oooo0P00000202D0
00040000003mfG/0oMUk000000L0o]nH00<000000?WO[@3igjd00P0000170?ooo`00B`3oool01000
0000oooo0?ooo`0000070?ooo`D000005@3oool300000580oooo0P00000202D000040000003mfG/0
oMUk000000H0o]nH00<000000?WO[@3igjd00P3igjd2000004H0oooo001;0?ooo`040000003oool0
oooo000000L0oooo00@000000?ooo`3oool00000503oool2000005D0oooo0P00000202D000030000
003mfG/0000000L0o]nH00<000000?WO[@3igjd00P3igjd2000004H0oooo001;0?ooo`040000003o
ool0oooo000000P0oooo00<000000?ooo`0000004@3oool4000005D0oooo00<0000002D000000000
0P0U00000`000000oMUk000000060?kOV0030000003igjd0nMn]00@0nMn]0P0000150?ooo`00B`3o
ool010000000oooo0?ooo`0000090?ooo`8000003`3oool2000005T0oooo00<0000002D000000000
0P0U0002000000L0o]nH00<000000?WO[@3igjd01@3igjd2000004@0oooo001<0?ooo`8000002`3o
ool00`000000oooo0?ooo`0:0?ooo`<00000F`3oool01`0000009@000000000U000000000?gIN`00
00001P3ngiP00`000000nMn]0?WO[@060?WO[@800000A03oool006<0oooo0`00001N0?ooo`070000
000U0000000002D000000000oMUk000000060?kOV0030000003igjd0nMn]00L0nMn]0P0000130?oo
o`00H@3oool2000000<0oooo00<000000?ooo`3oool0FP3oool01@0000009@0002D0000000009@00
008000001`3ngiP00`000000nMn]0?WO[@060?WO[@040000003agK/0000000000480oooo001N0?oo
o`<00000HP3oool01@0000009@0002D0000000009@00008000001P3ngiP00`000000nMn]0?WO[@07
0?WO[@040000003agK/0000000000480oooo001L0?ooo`800000I@3oool01@0000009@0002D00000
00009@00008000001P3ngiP00`000000nMn]0?WO[@060?WO[@040000003agK/0lMfk0?7M^`800000
@@3oool005T0oooo0`0000020?ooo`800000H`3oool01P0000009@0002D0000000009@00000000H0
o]nH00<000000?WO[@3igjd01P3igjd00`000000lMfk0?7M^`020?7M^`800000@@3oool005L0oooo
0P00001Y0?ooo`070000000U00009@0002D0000000009@00000000060?kOV0030000003igjd0nMn]
00H0nMn]00<000000?7M^`3agK/00`3agK/200000400oooo000/0?ooo`800000103oool00`000000
oooo0?ooo`020?ooo`@000006@3oool3000006/0oooo00L0000002D0000U00009@000000000U0000
000000D0o]nH00<000000?WO[@3igjd01P3igjd00`000000lMfk0?7M^`050?7M^`800000?`3oool0
02/0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0G0?ooo`<000000P3oool0
0`000000oooo0?ooo`1Y0?ooo`070000000U00009@0002D0000000009@00000000050?kOV0030000
003igjd0nMn]00H0nMn]00<000000?7M^`3agK/01@3agK/2000000L0oooo0P0000040?ooo`030000
003oool0oooo0080oooo1000000Y0?ooo`00:`3oool010000000oooo0?ooo`0000090?ooo`030000
003oool0oooo01@0oooo0P00001a0?ooo`070000000U00009@0002D0000000009@00000000050?kO
V0030000003igjd0nMn]00D0nMn]00<000000?7M^`3agK/01`3agK/2000000D0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool010000000oooo0?ooo`00000:
0?ooo`030000003oool0oooo0100oooo0`00001b0?ooo`030000000U00009@0000809@0000<00000
02D000000000103ngiP00`000000nMn]0?WO[@050?WO[@030000003agK/0lMfk00L0lMfk00@00000
0>WKa@0000000000103oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo02T0oooo
000[0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool03@3oool2000000<0oooo
00<000000?ooo`3oool0K`3oool00`0000009@0002D0000202D000030000000U0000000000@0o]nH
00<000000?WO[@3igjd01@3igjd00`000000lMfk0?7M^`070?7M^`040000003YflD00000000000@0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0X0?ooo`00:`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000`0oooo0`00001g0?ooo`030000000U0000
9@0000809@0000<0000002D0000000000`3ngiP00`000000nMn]0?WO[@050?WO[@030000003agK/0
lMfk00L0lMfk00@000000>WKa@3YflD0jM_50P0000030?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool01P3oool2000001l0oooo000/0?ooo`8000002P3oool2000000X0oooo0`00
001j0?ooo`030000000U00009@0000809@0000<0000002D0000000000`3ngiP00`000000nMn]0?WO
[@040?WO[@030000003agK/0lMfk00L0lMfk00<000000>WKa@3YflD00P3YflD00`000000oooo0000
00020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000002P3oool00`000000
oooo0?ooo`0L0?ooo`00@P3oool2000000<0oooo00<000000?ooo`3oool0MP3oool00`0000009@00
02D0000302D000030000000U000000000080o]nH00<000000?WO[@3igjd01@3igjd00`000000lMfk
0?7M^`070?7M^`030000003YflD0jM_500<0jM_50P0000030?ooo`8000002P3oool2000000/0oooo
0P00000M0?ooo`00?`3oool3000007h0oooo00<0000002D0000U0000100U000200000080o]nH00<0
00000?WO[@3igjd0103igjd00`000000lMfk0?7M^`070?7M^`030000003YflD0jM_500D0jM_50P00
000J0?ooo`040000003oool0oooo000001`0oooo000m0?ooo`<00000P03oool00`0000009@0002D0
000402D000040000003ngiP0o]nH000000L0nMn]00<000000?7M^`3agK/01P3agK/00`000000jM_5
0>WKa@060>WKa@030000003oool0000001T0oooo00@000000?ooo`3oool00000703oool003X0oooo
0`0000030?ooo`030000003oool0oooo07d0oooo00<0000002D0000U0000100U0004000000H0nMn]
00<000000?7M^`3agK/01`3agK/00`000000jM_50>WKa@070>WKa@8000006@3oool010000000oooo
0?ooo`00000L0?ooo`00=`3oool3000008D0oooo00<0000002D0000U00001@0U000010000000j_O9
0000003/klX2000000<0nMn]00<000000?7M^`3agK/01`3agK/00`000000jM_50>WKa@070>WKa@04
0000003Sf<`00000000001L0oooo0P0000000`3oool000000000000L0?ooo`00=@3oool3000008L0
oooo00<0000002D0000U00001@0U00000`000000j_O9000000030>c_bP80000000<0nMn]0000003a
gK/01`3agK/00`000000jM_50>WKa@070>WKa@030000003Sf<`0hmS<00800000>03oool00380oooo
0`0000030?ooo`030000003oool0oooo08<0oooo00<0000002D0000U00001P0U0002000000H0k>o:
00<000000?7M^`3agK/01P3agK/00`000000jM_50>WKa@080>WKa@040000003Sf<`0hmS<0>?Hc080
0000=`3oool00300oooo0P00002;0?ooo`800000200U00000`000000k>o:0>c_bP040>c_bP030000
003YjLh0000000L0lMfk00<000000>WKa@3YflD01`3YflD00`000000hmS<0>?Hc0030>?Hc0800000
=P3oool002d0oooo0`00002<0?ooo`8000002@0U00000`000000k>o:0>c_bP040>c_bP040000003Y
jLh0jNW>000000D0lMfk00<000000>WKa@3YflD01`3YflD00`000000hmS<0>?Hc0050>?Hc0030000
003oool0oooo03@0oooo000[0?ooo`800000SP3oool2000000T09@000P0000050>c_bP030000003Y
jLh0jNW>0080jNW>0P0000020?7M^`030000003YflD0jM_500L0jM_500<000000>?Hc03Sf<`01P3S
f<`2000003D0oooo000X0?ooo`<00000S`3oool00`000000Clc20000000602D000<0000000<0k>o:
0000003/klX00`3/klX00`000000jNW>0>WYcP050>WYcP030000003agK/0000000T0jM_500<00000
0>?Hc03Sf<`01`3Sf<`2000003@0oooo000U0?ooo`D00000S`3oool00`000000Clc20000000402D0
00<0000000<0j_O90000003/klX00P0000040>c_bP030000003YjLh0jNW>00H0jNW>00<000000>WK
a@3YflD01`3YflD00`000000hmS<0>?Hc0070>?Hc0040000003Le]400000000003<0oooo000S0?oo
o`800000T`3oool00`000000Clc20000000302D0008000000`3ZmlT300000080k>o:00@000000>c_
bP3/klX00000203YjLh00`000000i>CB000000070>WKa@030000003Sf<`0hmS<00L0hmS<00<00000
0=cFd@3Le]400P00000c0?ooo`008@3oool2000009@0oooo00<0000004o<`P1?c<80100000020>[g
b@@00000103/klX00`000000k>o:000000080>WYcP050000003Ti=80i>CB0>CTdP0000001@3YflD0
0`000000hmS<0>?Hc0070>?Hc0030000003Le]40g=KA0080g=KA0P00000b0?ooo`008@3oool30000
0980oooo00<0000004o<`P0000000`000000103ZmlT000000000000000020>[gb@030000003/klX0
k>o:00@0k>o:0P0000070>WYcP030000003Ti=80i>CB0080i>CB00<000000>WKa@3YflD00P3YflD0
0`000000hmS<0>?Hc0080>?Hc0030000003Le]40g=KA0080g=KA0P00000b0?ooo`008@3oool00`00
0000oooo0000002A0?ooo`<000000P3Bom43000000@0j_O900<000000>c_bP3/klX01@3/klX20000
00L0jNW>00<000000>CTdP3Ti=800`3Ti=801@000000jM_50>WKa@3YflD0000000T0hmS<00<00000
0=cFd@3Le]40103Le]42000000L0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P00000L
0?ooo`006P3oool2000000D0oooo00@000000?ooo`3oool00000S@3oool3000000<0d_oA0`000005
0>[gb@030000003/klX0k>o:00D0k>o:00@000000>WYcP3YjLh000001@3YjLh00`000000i>CB0>CT
dP050>CTdP030000003YflD0000000T0hmS<00<000000=cFd@3Le]401P3Le]42000000D0oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`00000K0?ooo`006@3oool010000000oooo
0?ooo`0000030?ooo`<000000P3oool00`000000oooo0?ooo`280?ooo`80000000<0Clc20000003B
om400`0000000`3Bom4000000>[gb@050>[gb@030000003/klX0k>o:00@0k>o:00D000000>WYcP3Y
jLh0jNW>000000040>WYcP030000003Ti=80i>CB00L0i>CB00<000000>?Hc03Sf<`01`3Sf<`00`00
0000g=KA0=cFd@070=cFd@8000001@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo01T0oooo000I0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`240?ooo`h00000103ZmlT00`000000k>o:0>c_bP050>c_bP030000003YjLh0
jNW>0080jNW>00@000000>WYcP3YjLh000002@3Ti=800`000000gn3F000000070>?Hc0030000003L
e]40g=KA00T0g=KA0P0000040?ooo`040000003oool0oooo000000T0oooo0P00000L0?ooo`006@3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
P03oool8000000@0/OKa0P0000030<[gjP@000001`3/klX00`000000jNW>0>WYcP040>WYcP800000
2@3Ti=801@000000gn3F0=oPeP3Oh=H0000000D0hmS<00<000000=cFd@3Le]402@3Le]4010000000
em?E0000000000030?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool06@3oool0
01T0oooo00@000000?ooo`3oool000000`3oool2000000H0oooo0P00001m0?ooo`<000000P20iO43
000000H0/OKa00<000000<[gjP3:mnX01@3:mnX010000000e?;U0000000000040>c_bP030000003Y
jLh0jNW>00D0jNW>0P0000080>CTdP030000003Oh=H0gn3F0080gn3F00<000000>?Hc03Sf<`00`3S
f<`00`000000g=KA0=cFd@080=cFd@030000003GdmD0em?E008000000`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000001/0oooo000I0?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1g0?ooo`<000000P20iO44000000H0
/OKa0P0000060<[gjP800000103Dl^D200000080k>o:00<000000>WYcP3YjLh0103YjLh00`000000
i>CB000000070>CTdP030000003Oh=H0gn3F00@0gn3F00D000000>?Hc03Sf<`0hmS<0000000:0=cF
d@030000003GdmD0em?E0080em?E0P0000030?ooo`8000002P3oool2000001`0oooo000J0?ooo`80
0000103oool2000000L0oooo00<000000?ooo`000000MP3oool2000000<0P>Ga100000070;7fl@03
0000003:mnX0b_OZ00D0b_OZ00<000000=Cbi@3Dl^D01P3Dl^D2000000L0jNW>00@000000>CTdP3T
i=8000001@3Ti=800`000000gn3F0=oPeP060=oPeP030000003Sf<`0000000X0g=KA00<000000=OC
e@3GdmD0103GdmD00`000000oooo0?ooo`0[0?ooo`007`3oool2000000P0oooo0P0000000`3oool0
00000?ooo`1a0?ooo`<000000P20iO45000000P0/OKa00<000000<[gjP3:mnX01@3:mnX00`000000
e?;U0=Cbi@070=Cbi@040000003HkN800000000000@0jNW>00<000000>CTdP3Ti=800P3Ti=800`00
0000i>CB0>CTdP020>CTdP030000003Oh=H0gn3F00L0gn3F00<000000=cFd@3Le]40203Le]400`00
0000em?E0=OCe@060=OCe@800000:`3oool001l0oooo00<000000?ooo`3oool01P3oool200000004
0>nEDP000000oooo000006h0oooo200000000`20iO400000000000080;7fl@8000001P3:mnX20000
00P0e?;U0P0000040=S]hP80000000<0jNW>0000003Ti=80103Ti=801@000000i>CB0>CTdP3Ti=80
000000T0gn3F00<000000=[Mf@000000203Le]400`000000em?E0=OCe@070=OCe@800000:`3oool0
01l0oooo0P0000070?ooo`8000000P3_UE800`000000oooo0000001[0?ooo`8000000P2@iO/80000
00P0/OKa00<000000<[gjP3:mnX01@3:mnX00`000000e?;U0=Cbi@070=Cbi@030000003HkN80f>gR
00H0f>gR00<000000>CTdP3Ti=801@3Ti=800`000000i>CB000000090=oPeP050000003JgMT0f]gI
0=[Mf@0000001P3Le]400`000000em?E0=OCe@090=OCe@030000003oool0oooo02T0oooo000O0?oo
o`030000003oool0oooo00H0oooo00<0000006lRF`0000000P3_UE83000006L0oooo0`000000102@
iO/00000000000000003093Un`8000000`2Vk?T400000080/OKa0P0000070<[gjP030000003Dl^D0
e?;U00L0e?;U00<000000=S]hP3HkN801P3HkN8010000000enSQ0000000000060>CTdP030000003O
h=H0gn3F00L0gn3F00<000000=[Mf@3JgMT00P3JgMT00`000000g=KA0=cFd@030=cFd@030000003G
dmD0em?E00T0em?E00<000000=;Af0000000:P3oool001l0oooo0`0000050?ooo`040000001_8U/0
Kb9K000000@0kiEB0P00001S0?ooo`<0000000@0T>Gk0000000000000000102@iO/2000000T0Y^ci
0`0000060<[gjP800000203Dl^D2000000P0f>gR00<000000=OXh@3Gj>400P3Gj>400`000000i>CB
0>CTdP020>CTdP030000003Oh=H0000000L0gn3F00<000000=[Mf@3JgMT0103JgMT01@000000g=KA
0=cFd@3Le]40000000/0em?E00<000000=;Af03BdMP00P00000Y0?ooo`007`3oool00`000000oooo
0?ooo`050?ooo`040000001_8U/0Kb9K000000D0kiEB0P00001P0?ooo`80000000@0T>Gk00000000
000000001@2@iO/2000000X0Y^ci0P0000020;K^mP<000000P3:mnX00`000000e?;U0=Cbi@070=Cb
i@030000003HkN80f>gR00L0f>gR00<000000=OXh@3Gj>40103Gj>42000000050>CTdP000000gn3F
0=oPeP0000001P3Oh=H00`000000f]gI0=[Mf@060=[Mf@030000003Le]40000000/0em?E00<00000
0=;Af03BdMP00P3BdMP00`000000oooo0?ooo`0W0?ooo`001P3oool2000000@0oooo00<000000?oo
o`3oool00P3oool400000080oooo0`0000050?ooo`030000003oool0oooo00D0oooo00@0000006lR
F`1_8U/000001P3_UE82000005`0oooo1P000006093Un`8000002P2Vk?T2000000L0]^kf0P000009
0=Cbi@030000003HkN80f>gR00L0f>gR00<000000=OXh@3Gj>401`3Gj>400`000000gn3F0=oPeP02
0=oPeP030000003Oh=H0gn3F0080gn3F00<000000=[Mf@3JgMT0203JgMT00`000000em?E0=OCe@09
0=OCe@030000003BdMP0d]7H00<0d]7H0P00000X0?ooo`001@3oool010000000oooo0?ooo`000008
0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`050000001_
8U/0Kb9K06lRF`0000001P3_UE83000005P0oooo0`0000000`2Fhod0000000000004000000<0T>Gk
0P00000:0:K/n@800000202fk_H2000000030<3]lP000000000000D0e?;U0P0000080=S]hP800000
2@3Gj>400`000000eNCQ000000040=oPeP040000003Oh=H0gn3F000000X0f]gI00<000000=GIf`00
0000203GdmD2000000L0d]7H0P00000W0?ooo`001@3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo00D0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`050000001_8U/0Kb9K
06lRF`0000001`3_UE83000005<0oooo10000000102Fhod0000000000000000609KSo@<000002P2V
k?T2000000T0]^kf00<000000<3]lP30kO800`30kO8200000080e?;U00<000000=S]hP3HkN801`3H
kN800`000000enSQ0=OXh@070=OXh@8000000`3Ei>400`000000gn3F0=oPeP020=oPeP8000002P3J
gMT01@000000eMWK0=GIf`3EfM/0000000H0em?E00<000000=;Af03BdMP01`3BdMP3000002H0oooo
00050?ooo`040000003oool0oooo000000X0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`03
0000003oool0oooo00@0oooo00<0000006lRF`1_8U/00P1_8U/00`000000kiEB0>nEDP050>nEDP04
0000003YPC000000000004l0oooo0`00000209KSo@<000001`2Fhod2000000<0X^Kl0P0000060:K/
n@8000002@2fk_H2000000P0`>gb0P0000090=S]hP030000003Gj>40enSQ00L0enSQ00<000000=GT
h@3Ei>40103Ei>401@000000gn3F0=oPeP3Oh=H0000000X0f]gI00<000000=GIf`3EfM/00P3EfM/0
0`000000em?E0=OCe@030=OCe@030000003BdMP0d]7H00T0d]7H0P00000V0?ooo`001@3oool01000
0000oooo0?ooo`00000;0?ooo`040000003oool0oooo000000H0oooo0P0000050?ooo`030000001_
8U/0Kb9K00<0Kb9K00<000000>nEDP3_UE80103_UE800`000000jH4`0>V1<002000004/0oooo0`00
000209KSo@<000001`2Fhod3000000L0X^Kl0P0000020:K/n@8000002P2fk_H00`000000`>gb0<3]
lP070<3]lP80000000<0a^__0000000000001P3HkN800`000000enSQ0=OXh@070=OXh@030000003E
i>40eNCQ00H0eNCQ00D000000=oPeP000000f]gI000000080=[Mf@030000003EfM/0eMWK00@0eMWK
00D000000=OCe@3GdmD0em?E0000000;0=;Af0040000003>cmX00000000002D0oooo00050?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<0000006lRF`1_8U/00`1_8U/00`000000kiEB0>nEDP04
0>nEDP040000003YPC00jH4`0>V1<0800000B03oool200000080VN7m0`00000809KSo@800000302R
i_`3000000T0]^kf0P0000090<3]lP0300000036jnl0a^__00<0a^__00<000000=S]hP3HkN800P3H
kN800`000000enSQ0=OXh@070=OXh@030000003Ei>40eNCQ00P0eNCQ00D000000=[Mf@3JgMT0f]gI
000000050=[Mf@800000203EfM/00`000000em?E0000000;0=;Af0030000003>cmX0c/oJ00800000
203oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`001P3o
ool2000000X0oooo0P0000030?ooo`@000000`3oool00`000000oooo0?ooo`030?ooo`030000001_
8U/0Kb9K00@0Kb9K00<000000>nEDP3_UE801@3_UE8010000000jH4`0>V1<03YPC03000004<0oooo
0`000000102IhOd0000000000000000309WQo@<000000`2Fhod2000000`0X^Kl0P0000030:_XnP80
00001P2fk_H00`000000`>gb0<3]lP070<3]lP8000001`36jnl2000000030=S]hP000000enSQ00P0
enSQ00<000000=GTh@3Ei>401`3Ei>42000000050=;PhP000000f]gI0=[Mf@000000103JgMT00`00
0000eMWK0=GIf`090=GIf`030000003BdMP0d]7H00T0d]7H00<000000<k?fP3>cmX00P3>cmX20000
00H0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0=0?ooo`007@3oool30000
00@0oooo00<0000006lRF`1_8U/0101_8U/00`000000kiEB0>nEDP050>nEDP030000003YPC00jH4`
0080jH4`00<000000?ooo`000000?`3oool30000000409WQo@0000000000000000T0VN7m0`00000<
0:;Vo08000001`2[j?X200000080]^kf0P0000090<3]lP0300000036jnl0a^__00T0a^__00<00000
0=OXh@3Gj>401P3Gj>42000000T0eNCQ00<000000=;PhP3Bh>800P3Bh>8010000000f]gI0=[Mf@00
00020=[Mf@030000003EfM/0eMWK00T0eMWK00<000000=7Gg@000000203BdMP2000000H0c/oJ00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`0000070?ooo`D000003P3oool001d0oooo00<0
00000?ooo`3oool0103oool00`000000Kb9K06lRF`0406lRF`030000003_UE80kiEB00D0kiEB00<0
00000>V1<03YPC000P3YPC02000000030?ooo`000000oooo03/0oooo0P000000102IhOd000000000
0000000:09WQo@8000000P2Nhod2000000T0X^Kl0P00000;0:_XnP8000002@30kO82000000X0a^__
0P0000000`38j>d00000000000050=OXh@030000003Ei>40eNCQ00P0eNCQ00<000000=;PhP3Bh>80
103Bh>800`000000f]gI0=[Mf@02000000X0eMWK0P0000030=7Gg@030000003BdMP0d]7H00@0d]7H
00<000000<k?fP3>cmX01`3>cmX00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000L0
oooo00@000000?ooo`3oool000003`3oool001d0oooo0P0000040?ooo`030000001_8U/0Kb9K00D0
Kb9K00<000000>nEDP3_UE801@3_UE800`000000jH4`0>V1<0030>V1<080000000<0oooo0000003o
ool0=`3oool30000000309WQo@000000000000X0VN7m0`00000609kSo@8000001@2Ri_`2000000/0
ZnSj0P0000020;;Xn08000001P30kO800`000000a^__0<K[k`090<K[k`0300000038j>d0b>S]00<0
b>S]0P0000020=OXh@030000003Ei>40eNCQ00L0eNCQ0P0000080=;PhP040000003JgMT000000000
00T0eMWK00<000000=7Gg@3Aemd00`3Aemd00`000000d]7H0=;Af0030=;Af0030000003>cmX0c/oJ
00P0c/oJ0P0000040?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`0000003`3oool0
01d0oooo00<000000?ooo`3oool00`3oool00`000000Kb9K06lRF`0506lRF`030000003_UE80kiEB
00H0kiEB00<000000>V1<03YPC000P3YPC001@000000ef400000003oool0000003@0oooo0`000000
0`2IhOd0000000000002000000P0VN7m0`00000;09kSo@80000000<0X^Kl0000000000002`2[j?X2
000000H0/^Sh0P0000020<3]lP8000002P36jnl2000000P0b>S]0P0000090=GTh@030000003Bh>80
d^3R00T0d^3R00<000000=GIf`000000203EfM/00`000000dMOM0=7Gg@050=7Gg@050000003BdMP0
d]7H0=;Af0000000303>cmX2000000<0oooo00@000000?ooo`3oool000002@3oool2000000l0oooo
000M0?ooo`030000003oool0oooo00<0oooo00<0000006lRF`1_8U/01P1_8U/00`000000kiEB0>nE
DP050>nEDP030000003YPC00jH4`00<0jH4`00D000000=MQ00000000oooo0000000`0?ooo`<00000
00@0VN7m0000000000000000102IhOd3000000<0VN7m0P00000?09kSo@<000002P2[j?X2000000X0
/^Sh0P00000;0<K[k`0300000038j>d0b>S]00L0b>S]0P0000000`39i>/000000=GTh@060=GTh@03
0000003Bh>80d^3R00T0d^3R00D000000<oMh`000000eMWK000000060=GIf`030000003Aemd0dMOM
00L0dMOM00<000000=;Af00000002`3>cmX2000000030<[>g0000000oooo00<0oooo0P00000;0?oo
o`030000003oool0oooo00d0oooo000M0?ooo`8000000`3oool00`000000Kb9K06lRF`0706lRF`03
0000003_UE80kiEB00D0kiEB00<000000>V1<03YPC000`3YPC001P000000ef400=MQ00000000oooo
000002`0oooo0`000000102IhOd0000000000000000:09WQo@<000003`2Nhod2000000<0Y>Cl0P00
00060:_XnP8000002P2bj?P200000080]nOf0P0000070<K[k`8000002@38j>d00`000000bNC[0<WT
j`020<WTj`8000000`3Ei>42000000X0d^3R0P0000030<oMh`030000003EfM/0000000@0eMWK00<0
00000=7Gg@3Aemd02@3Aemd00`000000c/oJ0<k?fP090<k?fP040000003:c]`0b/kL0<[>g0800000
803oool001d0oooo00<000000?ooo`3oool00P3oool00`000000Kb9K06lRF`0706lRF`030000003_
UE80kiEB00D0kiEB00<000000>V1<03YPC00103YPC001P000000ef400=MQ00000000oooo000002P0
oooo0`000000102IhOd0000000000000000:09WQo@<000000P2KhOd2000000/0W^?m0`0000070:CT
o08000000P2[j?X2000000X0/^Sh0P0000060;OWmP0300000036jnl0a^__00<0a^__00<000000<SX
k@38j>d01`38j>d2000000L0bNC[00<000000=GTh@0000002`3Bh>800`000000cmgS0<oMh`040<oM
h`8000000P3EfM/2000000X0dMOM0P0000000`3=e=l000000<k?fP080<k?fP030000003:c]`0b/kL
00<0b/kL00<000000?ooo`3oool07P3oool000X0oooo0P0000040?ooo`030000003oool0oooo0080
oooo0`0000040?ooo`030000003oool0oooo00<0oooo00<0000006lRF`1_8U/01`1_8U/00`000000
kiEB0>nEDP060>nEDP030000003YPC00jH4`00<0jH4`00L000000=MQ003GH@00ef400000003oool0
000002@0oooo0`0000000`2IhOd0000000000002000000T0VN7m0`00000709_Qo@8000001P2Nhod3
000000`0Y>Cl0P00000:0;;Xn08000002@2gioH2000000030<K[k`000000000000T0b>S]00<00000
0<WTj`39i>/02039i>/00`000000d^3R0=;PhP090=;PhP030000003?gN<0cmgS00H0cmgS0`00000;
0=7Gg@050000003=e=l0cMCO0<gDg`0000001`3>cmX2000000L0b/kL00<000000?ooo`3oool07@3o
ool000T0oooo00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`3oool2000000<0oooo
00<0000006lRF`1_8U/0201_8U/00`000000kiEB0>nEDP060>nEDP030000003YPC00jH4`00@0jH4`
00L000000=MQ003GH@00ef400000003oool000000200oooo0`000000102IhOd00000000000000004
09WQo@<000000`2IhOd3000000`0Vn7m0P00000209kSo@8000003@2Ti?`200000080Z>?k0P000006
0;;Xn0800000302gioH2000000T0b>S]0P0000090<WTj`80000000<0b>7[0000003Bh>80203Bh>80
0`000000cmgS0<oMh`080<oMh`8000002P3Aemd00`000000cMCO0<gDg`030<gDg`030000003>cmX0
c/oJ00<0c/oJ00<000000<[>g03:c]`01`3:c]`2000001h0oooo00090?ooo`040000003oool0oooo
000000/0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000001_8U/0Kb9K00P0Kb9K00<0
00000>nEDP3_UE801P3_UE800`000000jH4`0>V1<0040>V1<0030000003GH@00ef400080ef4000<0
00000?ooo`000000703oool300000080VN7m0P00000:09WQo@<00000402KhOd3000000`0Y>Cl0`00
00060:SSn`8000000P2bj?P2000000`0]nOf0P0000020;[Um08000001P38j>d00`000000bNC[0<WT
j`080<WTj`0300000038hN/0b>7[0080b>7[00<000000=;PhP3Bh>801@3Bh>800`000000cmgS0<oM
h`070<oMh`80000000<0c=[T0000000000001`3Aemd2000000L0cMCO00D000000<k?fP3>cmX0c/oJ
0000000;0<[>g0030000003oool0oooo01`0oooo00090?ooo`040000003oool0oooo000000P0oooo
0`0000040?ooo`030000003oool0oooo0080oooo00<0000006lRF`1_8U/02@1_8U/00`000000kiEB
0>nEDP050>nEDP030000003YPC00jH4`00D0jH4`00@000000=MQ003GH@00ef401000000H0?ooo`<0
00000P2IhOd3000000X0VN7m0P00000209OQoP800000302KhOd3000000<0W^7m0P0000080:CTo080
00002`2Xho/2000000`0]nOf0P0000060;[Um08000000P38j>d2000000X0bNC[00<000000<SQj`38
hN/01038hN/2000000<0d^3R0P0000090<oMh`030000003<f^@0c=[T0080c=[T00<000000=7Gg@3A
emd0103Aemd00`000000cMCO0<gDg`070<gDg`040000003>cmX00000000000X0b/kL0P0000000`37
c=h000000?ooo`0L0?ooo`002@3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo
00@0oooo0P0000020?ooo`030000001_8U/0Kb9K00X0Kb9K00<000000>nEDP3_UE801P3_UE800`00
0000jH4`0>V1<0040>V1<0030000003GH@00ef400080ef4000@000000;<b000000000000503oool3
00000080U^?m0`00000:09WQo@<000001P2GhOh2000000L0Vn7m0`00000809kQo@<000000`2Ti?`2
000000/0Z>?k0P0000020:cSn@800000202gioH2000000X0^^Gd0P00000:0<WTj`8000002@38hN/0
0`000000d^3R0000000:0<oMh`030000003<f^@0c=[T00@0c=[T00<000000=7Gg@3Aemd00P3Aemd0
0`000000cMCO0<gDg`090<gDg`030000003:c]`0b/kL00T0b/kL00@000000<O<gP37c=h0alcN0P00
000L0?ooo`002@3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`3oool0oooo0000000<06lRF`030000003_UE80kiEB00H0kiEB00<000000>V1<03YPC00
1@3YPC000`000000ef400=MQ00020=MQ00040000002c<P000000000000l0oooo1000000209KSo@<0
00000P2Fhod2000000L0VN7m0P00000;09OQoP8000000P2KhOd3000000h0W^7m0`00000:0:SSn`<0
00001P2/hoT00`000000]nOf0;OWmP030;OWmP8000002`2jiO@2000000030;cSlP000000000000L0
bNC[00<000000<SQj`38hN/02P38hN/00`000000cmgS0<oMh`070<oMh`800000203<f^@010000000
dMOM00000000000:0<gDg`80000000<0bM;P0000003:c]`0203:c]`00`000000alcN0<O<gP030<O<
gP030000003oool0oooo01X0oooo00040?ooo`030000003oool0oooo00<0oooo0P0000090?ooo`@0
00000`3oool010000000oooo0?ooo`00000=06lRF`030000003_UE80kiEB00H0kiEB00<000000>V1
<03YPC001@3YPC000`000000ef400=MQ00030=MQ00030000002c<P000000008000002P3oool30000
00<0U^?m0`00000709KSo@8000000`2IhOd2000000h0Un7n0`00000>09kQo@<000000P2PhO`20000
00L0Z>?k0P00000:0:cSn@80000000<0]nOf0000000000002`2jiO@2000000D0_>?b00<000000<WT
j`39i>/00`39i>/00`000000b>7[0<SQj`090<SQj`80000000<0a]kZ0000003?gN<01P3?gN<00`00
0000c=[T0<cJi0090<cJi0030000003=e=l0cMCO00T0cMCO00D000000<WBh039d^00bM;P00000007
0<[>g08000001P37c=h2000001/0oooo00030?ooo`030000003oool0000001D0oooo0P0000020?oo
o`030000001_8U/0Kb9K00/0Kb9K00<000000>nEDP3_UE801P3_UE800`000000jH4`0>V1<0060>V1
<0030000003GH@00ef4000<0ef4000D000000;<b00000000oooo000000060?ooo`<000000`2Fhod3
000000/0U^?m1000000=09OQoP<000000`2Ggoh2000000T0W^7m0`0000070:3Qo08000000`2Xho/2
000000d0[>?i0`00000:0;[Um0800000202lho82000000030<WTj`000000000000X0b>7[0P000004
0<KNjP800000103?gN<00`000000c=[T0<cJi0080<cJi0@000002@3=e=l00`000000bM;P0<WBh003
0<WBh0030000003:c]`0b/kL00<0b/kL00<000000<O<gP37c=h01`37c=h2000001X0oooo00030?oo
o`030000003oool0000001D0oooo00D000000?ooo`3oool0oooo0000000=06lRF`030000003_UE80
kiEB00L0kiEB00<000000>V1<03YPC001@3YPC000`000000ef400=MQ00040=MQ00050000002c<P00
00000?ooo`0000000`3oool2000000<0T>Gk0`00000:09KSo@@00000102AhOh2000000P0Un7n0`00
000809OOoP<000000`2NhOd3000000`0X>7l0`00000=0:cSn@8000000`2_h_P2000000H0^^Gd0P00
000;0;cSlP8000002P38hN/2000000P0a]kZ00@000000<oMh`00000000002P3<f^@01@000000bMOT
0<WGi039en@0000000L0cMCO0P0000070<WBh0050000003:c]`0b/kL0<[>g00000002P37c=h20000
01X0oooo00030?ooo`030000003oool0000001D0oooo00@000000?ooo`3oool000003P1_8U/00`00
0000kiEB0>nEDP060>nEDP`00000103GH@001@000000/c800;<b00000000oooo00<000000P2@iO/3
000000<0T>Gk0`00000309KSo@@000002P2AhOh2000000<0Un7n0`00000>09OOoP<000003@2PhO`2
00000080X]ol0P00000:0:cSn@8000001`2_h_P200000080^^Gd0P00000;0;cSlP8000000P2mh?40
0`000000b>7[0<SQj`060<SQj`0300000036g^X0a]kZ00T0a]kZ00<000000<cJi03<f^@0203<f^@2
000000D0bMOT00<000000<gDg`3=e=l00`3=e=l00`000000bM;P0<WBh0070<WBh0040000003:c]`0
0000000000`0alcN0P0000080?ooo`800000103oool00`000000oooo0?ooo`020?ooo`<000000`3o
ool00080oooo00D000000?ooo`3oool0oooo0000000D0?ooo`80000000<0oooo0000001_8U/03P1_
8U/00`000000kiEB0>nEDP030>nEDP8000000P260P02000000L0YA/01@000000103GH@0000000;<b
002c<P0200000080T>Gk0P000009093Un`<00000402AhOh3000000h0Umon0`00000209KNoP800000
2P2PhO`2000000H0X]ol0P0000060:cSn@8000002`2_h_P2000000/0_>?b0P0000050;gPl@800000
1038hN/2000000X0a]kZ0P0000000`35fnX000000<cJi0070<cJi00300000039en@0bMOT00D0bMOT
0P0000030<gDg`0300000039d^00bM;P00T0bM;P00<000000<O<gP37c=h02P37c=h2000000030<C;
g`000000000000H0oooo00@000000?ooo`3oool000002`3oool100000040oooo0@3oool00080oooo
0P0000000`3oool000000000000D0?ooo`040000003oool0oooo000000l0Kb9K00@000000>nEDP3_
UE80kiEB0P00000608H200030000002U6`00YA/000D0YA/00P0000020:4A00@0000000@0T>Gk0000
000000000000202@iO/3000000<0Pmok0P00000:097QoP@000000`2<g_h2000000T0Umon0`000007
09KNoP8000001P2PhO`2000000X0X]ol0P0000020:cSn@8000002`2_h_P200000080/N3g00<00000
0;cSlP2lho801P2lho82000000T0_N3a00@000000<SQj`00000000002P36g^X2000000@0aM_Z00<0
00000<cJi03<f^@00`3<f^@2000000T0bMOT00@000000<gDg`00000000002P39d^02000000030<K@
hP000000alcN00T0alcN00<000000<C;g`34bml00P34bml00`000000oooo0?ooo`040?ooo`040000
003oool0oooo000000/0oooo0@0000010?ooo`40oooo000K0?ooo`<00000401_8U/010000000kiEB
00000000000908H200030000002U6`00YA/000H0YA/01`000008093Un`<000002023go/3000000<0
TN7n1000000908cNoP<000000`2Ggoh3000000`0U]kn0P0000020:3Qo08000003@2Rgo`3000000/0
[n;h0P0000050;7Pm`800000102lho82000000`0_N3a00<000000<KNjP36g^X02036g^X2000000H0
aM_Z00<000000<cJi03<f^@00P3<f^@00`000000bMOT0<WGi00:0<WGi00300000039d^00bM;P00T0
bM;P00<000000<K@hP36d>800P36d>800`000000alcN0<O<gP050<O<gP8000001@34bml2000000D0
oooo00@000000?ooo`3oool00000203oool3000000<0oooo000J0?ooo`80000000<0oooo0000001_
8U/03`1_8U/2000000`0QP800P0000040:DK00X00000102@iO/3000000d0Pmok1000000?08cNoP@0
00003`2Fg_h4000000`0X]ol0`0000020:CNn`800000202_h_P2000000T0/N3g00@000000;cSlP00
00000000302mh?42000000030;gMl0000000a]kZ00L0a]kZ00<000000<GKjP35fnX01`35fnX01000
0000c=[T00000000000;0<WGi080000000<0a]CU00000039d^001`39d^02000000D0a]3R00<00000
0<O<gP37c=h01037c=h00`000000a<_O0<C;g`060<C;g`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`000P3oool2000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<00000103oool010000000oooo0?ooo`00
000?06lRF`030000000U00009@000080000030260P07000000L0P>Ga1000000<08?On`@00000101h
fO`2000000T0S=kn1000000408WKo`8000002@2Fg_h4000000<0Umcn0P0000080:;Oo0<000001`2T
g_/00`000000[n;h0:oRn0030:oRn08000002`2ah?L2000000`0_N3a0P0000040;gMl08000001036
g^X2000000/0aM_Z00<000000<WGi039en@02P39en@010000000a]CU0<KDi@36e>D2000000H0bM;P
00<000000<K@hP36d>801P36d>800`000000alcN0<O<gP020<O<gP0300000034bml0a<_O00P0a<_O
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00<0
oooo00001@3oool000000?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool010000000
oooo0?ooo`3oool3000000l0Kb9K00<0000002D0000U00000`0U0003000000L0QP801P000004083U
l@H00000101Se^h4000000@0Pmok1000000:07SIo08000000`2<g_h4000000X0RM_o0P00000309KN
oP@000002@2Gg?h2000000<0X]ol0`00000;0:CNn`80000000<0[n;h0000000000002`2ah?L20000
0080/]kf0P0000080;gPl@800000202mgO0010000000a]kZ00000000000;0<GKjP80000000<0`mSZ
00000039en@02039en@2000000D0a]CU0P0000040<WBh00300000036d>80a]3R00P0a]3R00@00000
0<O<gP00000000002`34bml2000000@0oooo0P0000090?ooo`@000000P3oool000050?ooo`000000
oooo0?ooo`0000002P3oool00`000000oooo0?ooo`040?ooo`070000003oool0oooo0?ooo`000000
oooo0000000>06lRF`030000000U00009@0000L09@000P00000208H200h000002P1Se^h7000000l0
N=Wl1000000@08WKo`<000003`2Gg?h3000000l0Y=kk0P00000;0;7Pm`8000001P2bg_H00`000000
_N3a0;gPl@030;gPl@8000002`2mgO000`000000aM_Z0<GKjP0:0<GKjP0300000033f>X0`mSZ0080
`mSZ00<000000<WGi039en@01039en@2000000P0a]CU0P0000000`39d^0000000000000<0<K@hP03
00000034bml0a<_O00X0a<_O0P00000F0?ooo`0000D0oooo0000003oool0oooo0000000:0?ooo`04
0000003oool0oooo0?ooo`<00000103oool00`000000oooo0000000=06lRF`030000000U00009@00
00T09@00200000080?ooo`/000001`1;a^/4000000D0N=Wl1P000004077Co08000002P29fol40000
00<0QmSo0P00000909OLoP@000000P2Hfoh2000000/0Y=kk0`0000020:GMn`8000001`2ah?L20000
00T0/]kf0P0000000`2mh?4000000000000;0;gMl080000000<0_=__00000035fnX02035fnX20000
00H0`mSZ00<000000<WGi039en@00P39en@00`000000a]CU0<KDi@090<KDi@8000003036d>820000
00030<?>h`000000a<_O00P0a<_O0P0000000`3oool000000?ooo`0E0?ooo`0000D0oooo0000003o
ool0oooo0000000;0?ooo`040000003oool0oooo000000H0oooo0P00000=06lRF`030000000U0000
9@0000P09@001@00000F0?oooa800000301ado`3000000<0RM_o1000000908OHo`8000000`2Gg?h4
000000P0V=_n0P0000070:CNn`8000001`2UgO/2000000<0/N3g0P00000<0;;NmP8000002`2mgO02
000000@0_=__00<000000<GKjP35fnX01035fnX2000000T0`mSZ00@000000<WGi000000000002`36
e>D2000000030<?Bi@000000a]3R00P0a]3R0P0000040<?>h`0300000034bml0a<_O00@0a<_O0P00
00040?ooo`030000003oool0oooo01<0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`800000301_8U/00`0000009@00
02D0000602D000H00000703oool6000000L0?[_/10000008077Co0L000003`27f?l3000000h0V=_n
0P0000020:CNn`<000002`2UgO/3000000`0/]kf0P0000020;;Lm@030000002mgO00_Mg`00H0_Mg`
0P0000070;cKk`0300000035fnX0aM_Z0080aM_Z00<000000<?HjP33f>X02P33f>X00`000000a]CU
0<KDi@0:0<KDi@0600000033d^D0`m;U00000033d^D000001P36d>82000000H0`lkS00<000000<C;
g`34bml00P34bml2000000H0oooo00<000000?ooo`3oool04`3oool00080oooo0P0000090?ooo`@0
00000P3oool400000080oooo0P00000<06lRF`030000000U00009@0000@09@001P00000P0?oooaP0
00001`1]cod2000000T0QmSo1000000208OFo`8000003@2Hfoh4000000/0YMgk0`0000020:OKnP80
00002@2bg_H2000000D0/]ce0P0000040;gMl08000002P2lfnl010000000aM_Z00000000000;0<?H
jP80000000<0`MKZ00000036e>D02036e>D2000000@0`m;U0P0000040<K@hP8000002@33c^<01000
0000a<_O0000000000080?ooo`030000003oool0oooo01<0oooo000I0?ooo`8000002`1_8U/00`00
00009@0002D0000202D000H00000903oool00`000000067E00000007000000T0>kG_0P00000;06g?
o@8000000`27f?l4000000P0QmKo00<0000009SKoP2Hfoh01P2Hfoh4000000<0VMWm0P0000080:GM
n`8000001`2WfoX00`000000/]kf0;;NmP040;;NmP8000002@2bg?D010000000_Mg`00000000000<
0;cKk`8000002`33f>X2000000@0`MKZ00<000000<KDi@36e>D01036e>D2000000H0`m;U00@00000
0<?Bi@000000a]3R0P00000<0<?>h`030000003oool0oooo00P0oooo00<000000?ooo`3oool04`3o
ool001T0oooo0P00000:06lRF`030000000U00009@0000H00000:03oool200000080067E1`000009
03^ek`8000001`1]cod7000000d0QmKo0P00000209SKoP@000002@2IfOd2000000<0YMgk0`00000:
0:OKnP8000000P2bg_H2000000/0/]ce0P00000<0;cKk`8000000P2kf>l00`000000`mSZ0<?HjP06
0<?HjP8000001`31e^X00`000000a]CU0<KDi@020<KDi@0300000033d^D0`m;U00L0`m;U00<00000
0<?Bi@0000003033c^<2000000/0oooo00<000000?ooo`3oool04`3oool001T0oooo00<0000006lR
F`1_8U/0201_8U/7000002d0oooo00@00000001Qe@00HMD0067E5`00000606g;oP8000003027e_l4
000000l0VMWm0`00000>0:OKnP<000002`2bg?D200000080/]Wd0P0000080;cKk`8000001@2kf>l2
000000@0`mSZ0P00000:0<7FjP0400000036e>D00000000000X0`m;U0P0000000`31d>H000000<?>
h`090<?>h`030000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool001T0oooo00<00000
06lRF`1_8U/01P1_8U/600000340oooo00<00000001Qe@00HMD00P00HMD8000000T0?k?d0P00000:
06g;oP8000001027e_l6000000@0R=?o0P00000909WIo@@000000P2Jeod2000000X0Ym_j0`000002
0:OIn@030000002bg?D0/]ce00L0/]ce0P0000060;;Im0030000002lfnl0_=__00<0_=__0P000009
0;_Hk`0400000033f>X00000000000`0`MKZ0P00000:0<?Bi@8000000P31d>H2000000P0`lkS0P00
000>0?ooo`030000003oool0oooo01<0oooo000I0?ooo`030000001_8U/0Kb9K0080Kb9K10000000
0`3oool000000000000e0?ooo`8000000`00HMD00`0000000GKN00000006000000T0?k?d0P000006
06g;oPP000003028dol2000000<0VMWm1000000809[Go@030000002WfoX0Ym_j00D0Ym_j0P000006
0:OIn@8000001@2bg?D2000000T0/]Wd0P0000000`2lfnl000000000000;0;_Hk`8000003031e^X2
00000080_]?Z00<000000<?Bi@33d^D01@33d^D2000000@0`M3V00<000000<7@iP0000001@33c^<2
00000140oooo00<000000?ooo`3oool04P3oool001P0oooo00<0000006lRF`0000000`0000020?oo
o`<00000>03oool400000004001Qe@0000000000005fgP<000000P0?SN@A000000L0KlWo0P00000<
08SCo`@000003@2Jeod200000080Ym_j0`00000:0:OIn@030000002bg?D0/]ce00800000302bfO@2
000000/0^mS_0P0000020;[FkP0300000031e^X0`MKZ00L0`MKZ0P0000050;kCjP0300000033d^D0
`m;U0080`m;U0P0000070<7@iP0300000031d>H0000000<0`lkS00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0B0?ooo`00603oool300000080oooo0`00000l0?ooo`030000000MO>H07GcV
00@000000P01M]h4000000803hgT0P00000804Rdn08000002`1_bOl2000000@0R=?o1P00000308[A
o`8000003@2Jeod3000000d0YmWi0`00000<0;;Im08000000P2beo<00`000000^mS_0;_Hk`060;_H
k`8000001@2je^h2000000D0`MKZ0P0000080;kCjP0400000033d^D00000000000X0`M3V0P000000
0`33c^<000000000000D0?ooo`030000003oool0oooo0180oooo000@0?ooo`@00000103oool00`00
0000oooo0000000200000400oooo0P00000301eliP<000000P01M]h8000000P0B;Ch0P00000706o9
o`P000002`2:dOl00`000000V]Om09[Go@0609[Go@@000000P2KeO`00`000000YmWi0:OIn@080:OI
n@<000000P2XeoP2000000T0/]Wd0P0000050;;Gl`800000102kf>l2000000T0^]K^00<000000<7F
jP31e^X00P00000;0;kCjP0300000031d>H0`M3V00/0`M3V0P00000F0?ooo`030000003oool0oooo
0180oooo000B0?ooo`030000003oool0oooo00<0oooo0P0000150?ooo`030000000MO>H07GcV0080
7GcV100000000`01M]h000000000000302VIka8000001P1cb?l2000000`0R]7o0P00000209[Go@@0
00001`2KeO`2000000H0YmWi0P0000070:SGn0030000002bfO@0/]Wd00@0/]Wd0P0000090;;Gl`04
0000002kf>l00000000000/0^]K^0`00000;0;kCjP80000000<0_=7Z00000031d>H02@31d>H30000
01L0oooo00<000000?ooo`3oool04P3oool00180oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`140?ooo`8000000`0MO>H00`00000098_/02B;k005000000@0:IW_0P00000805>fn`80
00002`1cb?l00`000000R]7o08[Ao`0908[Ao`@000003@2KeO`00`000000YmWi0:OIn@03000000X0
Z=Oh0P0000020;;Im08000002`2beo<2000000/0^]K^0P0000020;SDkP030000002ndnX0_]?Z00L0
_]?Z0P0000040;cAjP0300000031d>H0`M3V00D0`M3V0P0000030?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool04P3oool00180oooo00<000000?ooo`3oool01@3oool2000004D0oooo
100000000`0MO>H000000000000402B;k0@000000`0YVNl00`000000DkKk05>fn`0705>fn`800000
2P1cb?l2000000<0R]7o1P00000308c@oP8000002`2KeO`4000000h0Z=Oh0`00000;0;;Gl`800000
0P2beO800`000000^]K^0;[FkP060;[FkP8000001@2he>h00`000000_]?Z0;kCjP050;kCjP030000
002ldNX0_=7Z00D0_=7Z00<000000<7@iP31d>H00P31d>H2000000H0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0B0?ooo`004P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo04<0oooo00<0000003^>k`0kS^l01000000502B;k0P000002@1C]_/2000000D0LlSo2000
000;08c@oP800000102KeO`5000000<0WM?k0P0000090:SGn0@000000P2YeOL00`000000/]Oc0;;G
l`070;;Gl`8000001@2beO800`000000^]K^0;[FkP030;[FkP800000202he>h00`000000_]?Z0;kC
jP020;kCjP8000002@2ldNX010000000`M3V0000000000080?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool04@3oool00100oooo0`00000:0?ooo`030000003oool0oooo04<0oooo00<0
000003^>k`0kS^l00P0kS^l4000000@098_/00@0000003nSmP0oXoH0?j?f4P00000607W7o`800000
302<d?h5000000X0WM?k0P0000030:SGn0@000001`2YeOL2000000D0/]Oc0P0000080;;ElP030000
002je^h0^]K^008000002`2he>h010000000_]?Z00000000000;0;cAjP8000002`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo000B0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0@`3oool00`000000>hk_03^>k`0303^>k`030000000oVO<0000000H00000
1@0oXoH2000000P0G[Sl0P00000:07W7o`800000102<d?h6000000<0Slkm00<0000009gCn`2Mdo/0
2`2Mdo/3000000d0ZMGg00<000000;;Gl`2beo<00P00000:0;;ElP<000003@2he>h2000000/0_=7Z
0P00000>0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool001l0oooo0P00
00140?ooo`030000000kS^l0>hk_00<0>hk_00<0000003nIl`0oVO<00`0oVO<700000080?j?f0P00
000805jho08000001P1iaol8000000X0Slkm0P00000709gCn`@000000P2NdOX00`000000ZMGg0:WE
m`0;0:WEm`<000002P2beO8200000080/M?a00<000000;SDkP2he>h02@2he>h200000080]m;]00<0
00000;cAjP2ldNX01P2ldNX200000140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0A0?ooo`008@3oool00`000000oooo0?ooo`120?ooo`<000000`0kS^l2000000H0?iWc00@00000
05:Zn@1BZ_T0DZ[i5000000607k6oP800000302?c_d00`000000WM?k09gCn`04000000L0W]7j0P00
00070:WEm`@000000P2YdoH00`000000/]Gb0;;ElP060;;ElP8000001@2ado400`000000^=C^0;SD
kP060;SDkP8000001@2gd^d00`000000_=7Z0;cAjP030;cAjP8000004`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo000R0?ooo`030000003oool0oooo0480oooo00<00000
056JlP0000000`0000000`0kS^l0000003nIl`0503nIl`030000001BZ_T0DZ[i00H0DZ[i0P000008
06Vjo@8000002P1na_h00`000000Slkm08o>o@0808o>o@@000003@2NdOX00`000000ZMGg0:WEm`04
000000L0ZM?f0P0000040;;ElP800000202ado400`000000^=C^0;SDkP030;SDkP800000202gd^d0
0`000000_=7Z0;cAjP02000001H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`120?ooo`030000001AV_80DI[b0080DI[b1@00000403nI
l`800000201BZ_T00`000000JK[m06Vjo@0706Vjo@030000001na_h0O/Kn00P0O/Kn0P00000308o>
o@D000000`2BcO`2000000`0W]7j0`00000=0:WCmP040000002beO800000000000/0/M?a00<00000
0;SDkP2he>h00P00000:0;OBk@<000006@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0140oooo000T0?ooo`030000003oool0oooo0480oooo00<00000056JlP1AV_80101AV_800`00
0000E:;f000000040000000303nIl`000000DZ[i00L0DZ[i0P00000806Vjo@8000001@1na_h80000
00X0T/gl00<0000009kAnP2NdOX01@2NdOX400000080Wm3i00<000000:WCmP2YdoH02`2YdoH20000
00d0/M?a0`00000:0;OBk@8000007@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0100oooo000U0?ooo`800000@`3oool00`000000DI[b056JlP04056JlP030000001DX_H0E:;f00<0
E:;f6`00000608?5o@030000002BcO`0T/gl00X0T/gl0P00000209kAnP<000001`2Od?T2000000L0
ZM?f100000020:WAm@030000002ado40/M?a00P0/M?a0P0000020;7Al@030000002gd^d0]m;]00H0
]m;]0P00000O0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool002L0oooo
00<000000?ooo`3oool0@@3oool00`000000DI[b056JlP04056JlP8000001P1DX_H2000000P0HJoj
00<0000007:ko01b^o`01`1b^o`00`000000PlGm08?5o@0808?5o@8000002P2BcO`4000000`0Wm3i
00<000000:WCmP2YdoH0100000070:WAm@8000001@2ado43000000D0/M7a0P0000040;OBk@800000
8P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0100oooo000X0?ooo`030000003o
ool0oooo0440oooo1@000003056JlP030000001DX_H0E:;f00D0E:;f00<00000066_nP1Q[oX01P1Q
[oX2000000P0L[_l0P00000:08?5o@040000002BcO`0T/gl09;=o0H000000`2Dbo/00`000000Wm3i
09o@n@0:09o@n@<000003@2YdOD00`000000/M?a0;7Cl@02000000X0/M7a00@000000;OBk@000000
00009@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo000Y0?ooo`030000
003oool0oooo0440oooo00@0000006:Rm01RX_@0HZ;d2@00000305BRmP800000201Q[oX00`000000
L[_l07:ko00707:ko00300000023aOd0PlGm00<0PlGm2000000:09C;n`8000001P2Od?T400000080
XLkg00<000000:WAm@2YdOD02`2YdOD3000000`0/M7a0P00000W0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0403oool002X0oooo0P0000120?ooo`030000001RX_@0HZ;d00D0HZ;d
00@0000006>Ym`1SZOL0HjWg7@00000608S5o0800000302Dbo/00`000000Wm3i09o@n@03000000L0
XLkg0P0000070:WAm@@000000P2Yco@00`000000/M7a0;7Al@080;7Al@800000:P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo000/0?ooo`030000003oool0oooo0400oooo
0P00000606:Rm0030000001SZOL0HjWg00H0HjWg00<0000006fcnP1]/oX01P1]/oX00`000000N[cl
07Zlo00707Zlo08000002P28aO`00`000000U<_k09C;n`0809C;n`@00000302Qc_L00`000000ZM7e
0:WAm@04000000L0ZLod0P0000050;7Al@<00000;@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0100oooo000]0?ooo`030000003oool0oooo0440oooo00<0000006:Rm01RX_@0101R
X_@2000000L0HjWg00<0000006fcnP1]/oX01P1]/oX00`000000N[cl07Zlo00807Zlo00300000028
aO`0R<Gl00P0R<Gl0P00000309C;n`D000000`2Gb_T00`000000XLkg0:7>m`0:0:7>m`<000003@2Y
co@00`000000/M7a0;7Al@0200000340oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0?0?ooo`00;P3oool00`000000oooo0?ooo`110?ooo`D000000`1RX_@00`000000HjWg06>Ym`05
06>Ym`030000001]/oX0KK?j00H0KK?j0P00000907Zlo08000001@28aO`8000000T0Ul[i0P000006
0:7>m`@000000P2RcOH00`000000ZLod0:W?m00;0:W?m0<00000<`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00l0oooo000_0?ooo`800000@P3oool010000000KZSd06jXm01^Z?@9
000000<0HjWg00<0000006fcnP1]/oX01`1]/oX00`000000N[cl07Zlo00307Zlo0X000001P2<a?X0
0`000000Ul[i09O:n@0:09O:n@030000002Qc_L0XLkg00<000001`2RcOH2000000L0ZLod1000000g
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00340oooo00<000000?oo
o`3oool0@03oool00`000000KZSd06jXm00506jXm0040000001_[_L0Kjkg06n^ma<000001P21_OX0
0`000000S<Cj08c4nP0808c4nP8000002@2Gb_T4000000`0X/gf00<000000:W?m02Yco@01000000l
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool00380oooo00<000000?oo
o`3oool0@03oool00`000000KZSd06jXm00506jXm0030000001_[_L0Kjkg00D0Kjkg0P00000807Je
n@0300000021_OX0PKgj00P0PKgj0P00000:08c4nP040000002Gb_T0Ul[i09O:n@D000000`2IbOP0
0`000000X/gf0:;=mP0:0:;=mP<00000@03oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00l0oooo000c0?ooo`030000003oool0oooo0400oooo00<0000006jXm01^Z?@01@1^Z?@20000
00L0Kjkg00<0000007Jen@1f]OT01P1f]OT2000000X0PKgj00<0000008c4nP2<a?X00`2<a?X80000
00T0VLWh0P0000060:;=mP@00000A03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00l0oooo000d0?ooo`800000@@3oool5000000@0KZSd00<0000006n^m`1_[_L01@1_[_L2000000P0
M[Gi00<00000086mnP21_OX00`21_OX:000000H0T<Ci00<0000009W9n02IbOP02P2IbOP00`000000
X/gf0:;=mP03000004T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`00
=P3oool00`000000oooo0?ooo`0o0?ooo`040000001h[?@0N:cd07R/m1`000001P26__T00`000000
T<Ci0934n@080934n@8000002@2IbOP4000004d0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0>0?ooo`00=`3oool00`000000oooo0?ooo`0o0?ooo`030000001h[?@0N:cd00H0N:cd
00<0000007VamP1i/OH01P1i/OH00`000000O[Oh07jgn00607jgn08000002@26__T2000000X0T<Ci
00@0000009W9n02IbOP0VLWh1@00001A0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03P3oool003P0oooo00<000000?ooo`3oool0?`3oool2000000L0N:cd0P00000707VamP800000
201n]oP00`000000Q[ki08Jnn@0808Jnn@030000002@a?T0T<Ci00<0T<Ci2000001G0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool003T0oooo0P0000110?ooo`030000001h
[?@0N:cd00H0N:cd00<0000007VamP1i/OH01P1i/OH00`000000O[Oh07jgn00607jgn08000001@26
__T900000600oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`00>`3oool0
0`000000oooo0?ooo`0o0?ooob400000JP3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00h0oooo000l0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo000m0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0
oooo000n0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00d0oooo000o0?ooo`800000?03oool00`000000oooo0?oo
o`2:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00440oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03@3oool00480oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`2<0?oo
o`050000003oool0oooo0?ooo`0000003`3oool004<0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`2=0?ooo`040000003oool0oooo000000l0oooo00140?ooo`800000=`3oool00`00
0000oooo0?ooo`2=0?ooo`040000003oool0oooo000000l0oooo00160?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0000000?0?ooo`00A`3oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`0000003P3oool004P0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`2@0?ooo`8000003P3oool004T0oooo0P00
000b0?ooo`030000003oool0oooo0900oooo0P00000>0?ooo`00B`3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0940oooo0P00000>0?ooo`00C03oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo08d0oooo1000000@0?ooo`00C@3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo08T0oooo1000000D0?ooo`00CP3oool2000002`0oooo00<000000?ooo`3oool0
Q@3oool4000001P0oooo001@0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0P@3o
ool4000001`0oooo001A0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0O@3oool4
00000200oooo001B0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0N@3oool40000
02@0oooo001C0?ooo`8000009`3oool00`000000oooo0?ooo`1f0?ooo`<00000:03oool005D0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1b0?ooo`@00000:`3oool005H0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`1^0?ooo`@00000;`3oool005L0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`1Z0?ooo`@00000<`3oool005P0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1V0?ooo`@00000=`3oool005T0oooo0P00000Q0?ooo`03
0000003oool0oooo0680oooo1000000k0?ooo`00F`3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo05l0oooo0`00000o0?ooo`00G03oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo05/0oooo100000120?ooo`00G@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo05L0oooo100000160?ooo`00GP3oool2000001`0oooo00<000000?ooo`3oool0D`3oool40000
04X0oooo001P0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0C`3oool4000004h0
oooo001Q0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0B`3oool400000580oooo
001R0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0A`3oool4000005H0oooo001S
0?ooo`8000005`3oool00`000000oooo0?ooo`140?ooo`<00000FP3oool006D0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`100?ooo`@00000G@3oool006H0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0l0?ooo`@00000H@3oool006L0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0h0?ooo`@00000I@3oool006P0oooo0P00000B0?ooo`030000003o
ool0oooo03@0oooo1000001Y0?ooo`00JP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0300oooo1000001]0?ooo`00J`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
02h0oooo0`00001a0?ooo`00K03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02X0
oooo1000001d0?ooo`00K@3oool2000000`0oooo00<000000?ooo`3oool09P3oool4000007P0oooo
001_0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08P3oool4000007`0oooo001`
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool400000800oooo001a0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool4000008@0oooo001b0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool05P3oool4000008P0oooo001c0?ooo`800000
1P3oool00`000000oooo0?ooo`0C0?ooo`<00000S03oool007D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0?0?ooo`@00000S`3oool007H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`@00000T`3oool007L0oooo00D000000?ooo`3oool0oooo00000009
0?ooo`@00000U`3oool007P0oooo0P0000000`3oool000000?ooo`040?ooo`@00000V`3oool007X0
oooo0P0000000`3oool0000000000002000009l0oooo001k0?ooo`800000X`3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.0938079, -0.00805884, \
0.00382591, 0.00382591}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.72135e-17 1.04977 -0.0679587 1.04977 [
[.14594 .19959 -17.8862 -9 ]
[.14594 .19959 .11381 0 ]
[.27012 .15074 -17.1355 -9 ]
[.27012 .15074 .86454 0 ]
[.40047 .09947 -16.3847 -9 ]
[.40047 .09947 1.61526 0 ]
[.53747 .04562 -15.634 -9 ]
[.53747 .04562 2.36598 0 ]
[.29165 .07573 -9.31117 -9.8125 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 18 3.14607 ]
[.91861 .21225 0 -6.57576 ]
[.91861 .21225 10.0625 3.23674 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01568 .31795 -24 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00696 .37264 -18 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00208 .42927 -24 -2.88161 ]
[-0.00208 .42927 0 6.11839 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -10 -3.08918 ]
[-0.05457 .39542 0 6.72332 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.15516 .20893 m
.15977 .2136 L
s
[(0.2)] .14594 .19959 .98735 1 Mshowa
.27892 .16047 m
.28332 .16534 L
s
[(0.4)] .27012 .15074 .90394 1 Mshowa
.4088 .10962 m
.41296 .11469 L
s
[(0.6)] .40047 .09947 .82053 1 Mshowa
.54525 .05618 m
.54915 .06146 L
s
[(0.8)] .53747 .04562 .73711 1 Mshowa
.125 Mabswid
.06611 .2438 m
.06896 .24652 L
s
.09545 .23231 m
.09827 .23506 L
s
.12513 .22069 m
.12792 .22346 L
s
.18555 .19703 m
.18829 .19986 L
s
.2163 .18499 m
.21901 .18785 L
s
.24742 .1728 m
.2501 .17569 L
s
.3108 .14799 m
.3134 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37573 .12256 m
.37826 .12558 L
s
.44227 .09651 m
.44473 .09958 L
s
.47617 .08323 m
.47859 .08634 L
s
.51049 .06979 m
.51287 .07293 L
s
.58046 .0424 m
.58275 .0456 L
s
.61611 .02844 m
.61836 .03167 L
s
.65223 .0143 m
.65443 .01756 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.1)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.2)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.3)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.4)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(0.5)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70252 .02109 m
.69885 .02251 L
s
.71605 .04178 m
.71237 .04318 L
s
.72932 .06208 m
.72564 .06347 L
s
.74235 .08201 m
.73866 .08339 L
s
.7677 .12078 m
.764 .12213 L
s
.78003 .13965 m
.77633 .14098 L
s
.79214 .15817 m
.78843 .1595 L
s
.80404 .17637 m
.80033 .17768 L
s
.82721 .21182 m
.82349 .21311 L
s
.8385 .22909 m
.83478 .23037 L
s
.8496 .24606 m
.84587 .24733 L
s
.86051 .26275 m
.85677 .264 L
s
.88178 .29529 m
.87804 .29651 L
s
.89215 .31115 m
.88841 .31237 L
s
.90235 .32676 m
.89861 .32797 L
s
.91239 .34211 m
.90864 .34331 L
s
.93198 .37208 m
.92823 .37326 L
s
.94155 .38671 m
.93779 .38788 L
s
.95096 .40111 m
.9472 .40226 L
s
.96022 .41528 m
.95646 .41643 L
s
gsave
.91861 .21225 -61 -10.5758 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02795 .31328 m
.03408 .31095 L
s
[(0.25)] .01568 .31795 1 -0.38067 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0.5)] .00696 .37264 1 -0.37036 Mshowa
.01027 .42483 m
.01644 .42261 L
s
[(0.75)] -0.00208 .42927 1 -0.35964 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03468 .27078 m
.03835 .26935 L
s
.03301 .2813 m
.03669 .27988 L
s
.03134 .29189 m
.03501 .29047 L
s
.02965 .30255 m
.03332 .30114 L
s
.02623 .32409 m
.02991 .3227 L
s
.02451 .33497 m
.02819 .33359 L
s
.02277 .34593 m
.02646 .34455 L
s
.02102 .35697 m
.02471 .35559 L
s
.01749 .37927 m
.02118 .37791 L
s
.0157 .39054 m
.0194 .38919 L
s
.0139 .40189 m
.0176 .40054 L
s
.01209 .41332 m
.01579 .41198 L
s
.00843 .43642 m
.01214 .4351 L
s
.00658 .4481 m
.01029 .44678 L
s
.00472 .45986 m
.00843 .45855 L
s
.00284 .4717 m
.00656 .4704 L
s
gsave
-0.05457 .39542 -71 -7.08918 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(V) show
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.47 .675 .954 r
.38312 .58325 .40512 .60373 .4416 .60449 .41979 .58536 Metetra
.474 .694 .964 r
.41979 .58536 .4416 .60449 .47885 .60447 .45729 .58655 Metetra
.494 .718 .971 r
.45729 .58655 .47885 .60447 .51687 .60297 .49562 .586 Metetra
.526 .744 .975 r
.49562 .586 .51687 .60297 .55563 .59952 .53474 .58318 Metetra
.563 .767 .974 r
.53474 .58318 .55563 .59952 .59508 .5938 .57459 .57779 Metetra
.599 .786 .97 r
.57459 .57779 .59508 .5938 .63516 .58567 .61511 .56971 Metetra
.633 .801 .963 r
.61511 .56971 .63516 .58567 .67579 .57505 .65622 .5589 Metetra
.664 .811 .954 r
.65622 .5589 .67579 .57505 .71691 .56189 .69784 .54532 Metetra
.692 .818 .942 r
.69784 .54532 .71691 .56189 .75844 .54617 .73987 .52895 Metetra
.717 .821 .929 r
.73987 .52895 .75844 .54617 .80031 .52793 .78224 .50975 Metetra
.738 .82 .915 r
.78224 .50975 .80031 .52793 .84243 .50725 .82484 .4878 Metetra
.754 .815 .9 r
.82484 .4878 .84243 .50725 .88476 .48439 .86762 .46334 Metetra
.764 .806 .887 r
.86762 .46334 .88476 .48439 .92729 .45984 .91054 .43687 Metetra
.767 .794 .875 r
.91054 .43687 .92729 .45984 .97003 .43426 .95363 .40922 Metetra
.432 .658 .955 r
.36056 .56225 .38312 .58325 .41979 .58536 .39739 .56597 Metetra
.437 .68 .967 r
.39739 .56597 .41979 .58536 .45729 .58655 .43512 .56857 Metetra
.464 .71 .975 r
.43512 .56857 .45729 .58655 .49562 .586 .47374 .5691 Metetra
.504 .741 .98 r
.47374 .5691 .49562 .586 .53474 .58318 .51322 .56698 Metetra
.548 .769 .98 r
.51322 .56698 .53474 .58318 .57459 .57779 .55349 .56194 Metetra
.59 .791 .976 r
.55349 .56194 .57459 .57779 .61511 .56971 .59446 .55391 Metetra
.629 .807 .968 r
.59446 .55391 .61511 .56971 .65622 .5589 .63606 .54291 Metetra
.664 .818 .958 r
.63606 .54291 .65622 .5589 .69784 .54532 .67819 .5289 Metetra
.695 .825 .945 r
.67819 .5289 .69784 .54532 .73987 .52895 .72075 .51184 Metetra
.722 .829 .931 r
.72075 .51184 .73987 .52895 .78224 .50975 .76365 .49165 Metetra
.746 .828 .915 r
.76365 .49165 .78224 .50975 .82484 .4878 .80676 .46834 Metetra
.764 .823 .898 r
.80676 .46834 .82484 .4878 .86762 .46334 .85 .44211 Metetra
.776 .813 .883 r
.85 .44211 .86762 .46334 .91054 .43687 .89332 .41349 Metetra
.779 .8 .869 r
.89332 .41349 .91054 .43687 .95363 .40922 .93675 .38347 Metetra
.383 .635 .954 r
.33741 .54069 .36056 .56225 .39739 .56597 .37436 .54635 Metetra
.39 .662 .967 r
.37436 .54635 .39739 .56597 .43512 .56857 .41228 .55063 Metetra
.426 .7 .978 r
.41228 .55063 .43512 .56857 .47374 .5691 .45119 .55238 Metetra
.478 .738 .985 r
.45119 .55238 .47374 .5691 .51322 .56698 .49103 .55101 Metetra
.532 .771 .985 r
.49103 .55101 .51322 .56698 .55349 .56194 .53172 .54631 Metetra
.581 .796 .981 r
.53172 .54631 .55349 .56194 .59446 .55391 .57317 .53833 Metetra
.625 .813 .973 r
.57317 .53833 .59446 .55391 .63606 .54291 .61527 .52711 Metetra
.663 .825 .962 r
.61527 .52711 .63606 .54291 .67819 .5289 .65794 .51267 Metetra
.697 .833 .948 r
.65794 .51267 .67819 .5289 .72075 .51184 .70106 .49492 Metetra
.727 .837 .933 r
.70106 .49492 .72075 .51184 .76365 .49165 .74451 .47371 Metetra
.754 .837 .915 r
.74451 .47371 .76365 .49165 .80676 .46834 .78816 .44896 Metetra
.775 .832 .896 r
.78816 .44896 .80676 .46834 .85 .44211 .83189 .42078 Metetra
.789 .821 .878 r
.83189 .42078 .85 .44211 .89332 .41349 .87563 .38973 Metetra
.792 .806 .863 r
.87563 .38973 .89332 .41349 .93675 .38347 .91939 .35697 Metetra
.319 .603 .949 r
.31365 .51858 .33741 .54069 .37436 .54635 .35066 .52658 Metetra
.329 .636 .963 r
.35066 .52658 .37436 .54635 .41228 .55063 .38875 .53283 Metetra
.379 .685 .979 r
.38875 .53283 .41228 .55063 .45119 .55238 .42793 .53595 Metetra
.447 .734 .988 r
.42793 .53595 .45119 .55238 .49103 .55101 .46813 .53536 Metetra
.513 .773 .99 r
.46813 .53536 .49103 .55101 .53172 .54631 .50925 .53099 Metetra
.571 .801 .986 r
.50925 .53099 .53172 .54631 .57317 .53833 .55118 .52301 Metetra
.62 .82 .977 r
.55118 .52301 .57317 .53833 .61527 .52711 .59382 .51156 Metetra
.661 .833 .966 r
.59382 .51156 .61527 .52711 .65794 .51267 .63704 .49667 Metetra
.698 .842 .952 r
.63704 .49667 .65794 .51267 .70106 .49492 .68075 .47824 Metetra
.732 .847 .935 r
.68075 .47824 .70106 .49492 .74451 .47371 .72479 .45603 Metetra
.762 .847 .915 r
.72479 .45603 .74451 .47371 .78816 .44896 .76902 .42978 Metetra
.787 .842 .893 r
.76902 .42978 .78816 .44896 .83189 .42078 .81327 .39947 Metetra
.803 .83 .872 r
.81327 .39947 .83189 .42078 .87563 .38973 .85743 .36565 Metetra
.807 .812 .855 r
.85743 .36565 .87563 .38973 .91939 .35697 .90152 .3297 Metetra
.233 .557 .934 r
.28926 .49586 .31365 .51858 .35066 .52658 .32626 .50674 Metetra
.249 .599 .951 r
.32626 .50674 .35066 .52658 .38875 .53283 .36446 .51532 Metetra
.321 .665 .974 r
.36446 .51532 .38875 .53283 .42793 .53595 .4039 .51996 Metetra
.411 .728 .99 r
.4039 .51996 .42793 .53595 .46813 .53536 .44446 .52014 Metetra
.493 .775 .995 r
.44446 .52014 .46813 .53536 .50925 .53099 .48602 .51604 Metetra
.561 .807 .991 r
.48602 .51604 .50925 .53099 .55118 .52301 .52845 .508 Metetra
.614 .827 .982 r
.52845 .508 .55118 .52301 .59382 .51156 .57163 .49629 Metetra
.659 .841 .97 r
.57163 .49629 .59382 .51156 .63704 .49667 .61545 .48097 Metetra
.699 .851 .955 r
.61545 .48097 .63704 .49667 .68075 .47824 .65977 .4619 Metetra
.736 .857 .937 r
.65977 .4619 .68075 .47824 .72479 .45603 .70445 .4387 Metetra
.77 .858 .915 r
.70445 .4387 .72479 .45603 .76902 .42978 .7493 .41094 Metetra
.799 .853 .891 r
.7493 .41094 .76902 .42978 .81327 .39947 .79411 .37834 Metetra
.818 .84 .866 r
.79411 .37834 .81327 .39947 .85743 .36565 .83871 .34134 Metetra
.823 .819 .845 r
.83871 .34134 .85743 .36565 .90152 .3297 .88312 .30162 Metetra
.115 .487 .901 r
.2642 .47254 .28926 .49586 .32626 .50674 .30108 .487 Metetra
.144 .544 .923 r
.30108 .487 .32626 .50674 .36446 .51532 .33935 .49835 Metetra
.249 .637 .961 r
.33935 .49835 .36446 .51532 .4039 .51996 .37902 .50461 Metetra
.371 .721 .988 r
.37902 .50461 .4039 .51996 .44446 .52014 .41995 .5055 Metetra
.473 .778 .997 r
.41995 .5055 .44446 .52014 .48602 .51604 .46197 .50154 Metetra
.55 .813 .995 r
.46197 .50154 .48602 .51604 .52845 .508 .50493 .49335 Metetra
.609 .835 .986 r
.50493 .49335 .52845 .508 .57163 .49629 .54868 .48133 Metetra
.656 .849 .974 r
.54868 .48133 .57163 .49629 .61545 .48097 .59311 .4656 Metetra
.699 .86 .959 r
.59311 .4656 .61545 .48097 .65977 .4619 .63809 .44594 Metetra
.739 .867 .94 r
.63809 .44594 .65977 .4619 .70445 .4387 .68345 .42187 Metetra
.777 .869 .916 r
.68345 .42187 .70445 .4387 .7493 .41094 .72896 .39264 Metetra
.811 .865 .887 r
.72896 .39264 .7493 .41094 .79411 .37834 .77438 .3576 Metetra
.835 .851 .857 r
.77438 .3576 .79411 .37834 .83871 .34134 .81946 .31696 Metetra
.842 .827 .833 r
.81946 .31696 .83871 .34134 .88312 .30162 .86416 .27269 Metetra
0 .382 .834 r
.23845 .44858 .2642 .47254 .30108 .487 .27508 .46761 Metetra
.005 .463 .868 r
.27508 .46761 .30108 .487 .33935 .49835 .31334 .48222 Metetra
.161 .6 .935 r
.31334 .48222 .33935 .49835 .37902 .50461 .35323 .49013 Metetra
.327 .713 .982 r
.35323 .49013 .37902 .50461 .41995 .5055 .39454 .49155 Metetra
.453 .782 .998 r
.39454 .49155 .41995 .5055 .46197 .50154 .43704 .48755 Metetra
.541 .82 .997 r
.43704 .48755 .46197 .50154 .50493 .49335 .48054 .47908 Metetra
.603 .842 .989 r
.48054 .47908 .50493 .49335 .54868 .48133 .52489 .4667 Metetra
.653 .857 .978 r
.52489 .4667 .54868 .48133 .59311 .4656 .56997 .45058 Metetra
.696 .868 .963 r
.56997 .45058 .59311 .4656 .63809 .44594 .61563 .43046 Metetra
.739 .877 .944 r
.61563 .43046 .63809 .44594 .68345 .42187 .66172 .40566 Metetra
.783 .881 .918 r
.66172 .40566 .68345 .42187 .72896 .39264 .70797 .37511 Metetra
.824 .878 .884 r
.70797 .37511 .72896 .39264 .77438 .3576 .75407 .33759 Metetra
.854 .864 .848 r
.75407 .33759 .77438 .3576 .81946 .31696 .79965 .29274 Metetra
.863 .836 .818 r
.79965 .29274 .81946 .31696 .86416 .27269 .84462 .24288 Metetra
0 .228 .71 r
.21199 .42395 .23845 .44858 .27508 .46761 .24815 .44897 Metetra
0 .349 .769 r
.24815 .44897 .27508 .46761 .31334 .48222 .2863 .46741 Metetra
.061 .551 .891 r
.2863 .46741 .31334 .48222 .35323 .49013 .32642 .47683 Metetra
.284 .706 .97 r
.32642 .47683 .35323 .49013 .39454 .49155 .36814 .47846 Metetra
.437 .788 .997 r
.36814 .47846 .39454 .49155 .43704 .48755 .41114 .47414 Metetra
.533 .828 .999 r
.41114 .47414 .43704 .48755 .48054 .47908 .45522 .46521 Metetra
.598 .849 .992 r
.45522 .46521 .48054 .47908 .52489 .4667 .50019 .45241 Metetra
.648 .864 .981 r
.50019 .45241 .52489 .4667 .56997 .45058 .54595 .43593 Metetra
.692 .876 .967 r
.54595 .43593 .56997 .45058 .61563 .43046 .59234 .41548 Metetra
.737 .887 .948 r
.59234 .41548 .61563 .43046 .66172 .40566 .63921 .39022 Metetra
.786 .894 .921 r
.63921 .39022 .66172 .40566 .70797 .37511 .68628 .35866 Metetra
.835 .893 .882 r
.68628 .35866 .70797 .37511 .75407 .33759 .73313 .31875 Metetra
.874 .878 .836 r
.73313 .31875 .75407 .33759 .79965 .29274 .77928 .26911 Metetra
.887 .846 .798 r
.77928 .26911 .79965 .29274 .84462 .24288 .82448 .21213 Metetra
.487 0 0 r
.18478 .39863 .21199 .42395 .24815 .44897 .22014 .43178 Metetra
0 .203 .616 r
.22014 .43178 .24815 .44897 .2863 .46741 .2581 .45455 Metetra
0 .497 .825 r
.2581 .45455 .2863 .46741 .32642 .47683 .29846 .46505 Metetra
.249 .702 .954 r
.29846 .46505 .32642 .47683 .36814 .47846 .34065 .46636 Metetra
.427 .796 .994 r
.34065 .46636 .36814 .47846 .41114 .47414 .38421 .46133 Metetra
.529 .836 .999 r
.38421 .46133 .41114 .47414 .45522 .46521 .42889 .45173 Metetra
.594 .856 .993 r
.42889 .45173 .45522 .46521 .50019 .45241 .47452 .43842 Metetra
.642 .87 .984 r
.47452 .43842 .50019 .45241 .54595 .43593 .52098 .42163 Metetra
.685 .883 .972 r
.52098 .42163 .54595 .43593 .59234 .41548 .56815 .40105 Metetra
.73 .896 .954 r
.56815 .40105 .59234 .41548 .63921 .39022 .61584 .37569 Metetra
.784 .907 .926 r
.61584 .37569 .63921 .39022 .68628 .35866 .6638 .34363 Metetra
.843 .91 .882 r
.6638 .34363 .68628 .35866 .73313 .31875 .71154 .30177 Metetra
.894 .894 .822 r
.71154 .30177 .73313 .31875 .77928 .26911 .75833 .24677 Metetra
.914 .857 .771 r
.75833 .24677 .77928 .26911 .82448 .21213 .80369 .18042 Metetra
.7 .196 0 r
.15679 .37258 .18478 .39863 .22014 .43178 .19082 .41731 Metetra
.524 0 0 r
.19082 .41731 .22014 .43178 .2581 .45455 .22852 .44457 Metetra
0 .449 .745 r
.22852 .44457 .2581 .45455 .29846 .46505 .26923 .45517 Metetra
.231 .709 .936 r
.26923 .45517 .29846 .46505 .34065 .46636 .31196 .45534 Metetra
.427 .809 .991 r
.31196 .45534 .34065 .46636 .38421 .46133 .35615 .44912 Metetra
.53 .846 .998 r
.35615 .44912 .38421 .46133 .42889 .45173 .40148 .43858 Metetra
.591 .863 .994 r
.40148 .43858 .42889 .45173 .47452 .43842 .4478 .42467 Metetra
.634 .875 .986 r
.4478 .42467 .47452 .43842 .52098 .42163 .49499 .40763 Metetra
.674 .888 .976 r
.49499 .40763 .52098 .42163 .56815 .40105 .54295 .38714 Metetra
.718 .903 .961 r
.54295 .38714 .56815 .40105 .61584 .37569 .59154 .36214 Metetra
.774 .919 .935 r
.59154 .36214 .61584 .37569 .6638 .34363 .64047 .3304 Metetra
.844 .929 .885 r
.64047 .3304 .6638 .34363 .71154 .30177 .68923 .28758 Metetra
.913 .914 .806 r
.68923 .28758 .71154 .30177 .75833 .24677 .73682 .22701 Metetra
.943 .867 .733 r
.73682 .22701 .75833 .24677 .80369 .18042 .78224 .1477 Metetra
.841 .38 0 r
.12798 .3458 .15679 .37258 .19082 .41731 .15977 .40796 Metetra
.632 .068 0 r
.15977 .40796 .19082 .41731 .22852 .44457 .19728 .43864 Metetra
.164 0 0 r
.19728 .43864 .22852 .44457 .26923 .45517 .23855 .44748 Metetra
.243 .732 .923 r
.23855 .44748 .26923 .45517 .31196 .45534 .28197 .44541 Metetra
.442 .827 .987 r
.28197 .44541 .31196 .45534 .35615 .44912 .32686 .43742 Metetra
.536 .857 .997 r
.32686 .43742 .35615 .44912 .40148 .43858 .3729 .42566 Metetra
.589 .869 .994 r
.3729 .42566 .40148 .43858 .4478 .42467 .41994 .41105 Metetra
.626 .879 .988 r
.41994 .41105 .4478 .42467 .49499 .40763 .4679 .39383 Metetra
.66 .89 .981 r
.4679 .39383 .49499 .40763 .54295 .38714 .51668 .37367 Metetra
.698 .907 .969 r
.51668 .37367 .54295 .38714 .59154 .36214 .56618 .34959 Metetra
.752 .929 .947 r
.56618 .34959 .59154 .36214 .64047 .3304 .61618 .31925 Metetra
.832 .949 .896 r
.61618 .31925 .64047 .3304 .68923 .28758 .66615 .27737 Metetra
.925 .937 .791 r
.66615 .27737 .68923 .28758 .73682 .22701 .71479 .21233 Metetra
.973 .875 .678 r
.71479 .21233 .73682 .22701 .78224 .1477 .76009 .11392 Metetra
.911 .507 .188 r
.09832 .31825 .12798 .3458 .15977 .40796 .12616 .40846 Metetra
.648 .109 0 r
.12616 .40846 .15977 .40796 .19728 .43864 .16403 .43797 Metetra
.12 0 0 r
.16403 .43797 .19728 .43864 .23855 .44748 .20626 .44208 Metetra
.295 .776 .92 r
.20626 .44208 .23855 .44748 .28197 .44541 .25057 .43646 Metetra
.471 .85 .985 r
.25057 .43646 .28197 .44541 .32686 .43742 .29625 .42609 Metetra
.549 .868 .995 r
.29625 .42609 .32686 .43742 .3729 .42566 .34306 .41284 Metetra
.59 .874 .993 r
.34306 .41284 .3729 .42566 .41994 .41105 .39086 .39744 Metetra
.618 .881 .99 r
.39086 .39744 .41994 .41105 .4679 .39383 .4396 .38007 Metetra
.642 .891 .985 r
.4396 .38007 .4679 .39383 .51668 .37367 .48923 .3605 Metetra
.67 .907 .977 r
.48923 .3605 .51668 .37367 .56618 .34959 .53968 .33791 Metetra
.713 .933 .961 r
.53968 .33791 .56618 .34959 .61618 .31925 .59079 .3103 Metetra
.791 .966 .917 r
.59079 .3103 .61618 .31925 .66615 .27737 .64215 .27239 Metetra
.916 .968 .789 r
.64215 .27239 .66615 .27737 .71479 .21233 .69233 .20764 Metetra
.993 .872 .595 r
.69233 .20764 .71479 .21233 .76009 .11392 .7372 .07905 Metetra
.937 .583 .321 r
.06775 .29 .09832 .31825 .12616 .40846 .08846 .42697 Metetra
.524 .01 0 r
.08846 .42697 .12616 .40846 .16403 .43797 .12844 .44306 Metetra
.12844 .44306 .16403 .43797 .20626 .44208 .17221 .43869 Metetra
.387 .836 .93 r
.17221 .43869 .20626 .44208 .25057 .43646 .21763 .4282 Metetra
.514 .875 .984 r
.21763 .4282 .25057 .43646 .29625 .42609 .26423 .41491 Metetra
.567 .879 .993 r
.26423 .41491 .29625 .42609 .34306 .41284 .31187 .39991 Metetra
.593 .879 .993 r
.31187 .39991 .34306 .41284 .39086 .39744 .36047 .38363 Metetra
.609 .881 .991 r
.36047 .38363 .39086 .39744 .4396 .38007 .41002 .36617 Metetra
.621 .888 .989 r
.41002 .36617 .4396 .38007 .48923 .3605 .4605 .34737 Metetra
.633 .901 .985 r
.4605 .34737 .48923 .3605 .53968 .33791 .5119 .32678 Metetra
.65 .924 .975 r
.5119 .32678 .53968 .33791 .59079 .3103 .56415 .30322 Metetra
.692 .961 .943 r
.56415 .30322 .59079 .3103 .64215 .27239 .61703 .27315 Metetra
.821 1 .82 r
.61703 .27315 .64215 .27239 .69233 .20764 .66952 .22147 Metetra
.991 .848 .484 r
.66952 .22147 .69233 .20764 .7372 .07905 .71355 .04313 Metetra
.434 .135 .356 r
.00095 .48363 .06775 .29 .08846 .42697 .04527 .46819 Metetra
.147 0 0 r
.04527 .46819 .08846 .42697 .12844 .44306 .09038 .45247 Metetra
.311 .798 .759 r
.09038 .45247 .12844 .44306 .17221 .43869 .13631 .43646 Metetra
.503 .897 .945 r
.13631 .43646 .17221 .43869 .21763 .4282 .18308 .42016 Metetra
.565 .897 .983 r
.18308 .42016 .21763 .4282 .26423 .41491 .23072 .40356 Metetra
.589 .888 .99 r
.23072 .40356 .26423 .41491 .31187 .39991 .27924 .38665 Metetra
.599 .882 .992 r
.27924 .38665 .31187 .39991 .36047 .38363 .32868 .36942 Metetra
.601 .88 .992 r
.32868 .36942 .36047 .38363 .41002 .36617 .37905 .35186 Metetra
.599 .882 .992 r
.37905 .35186 .41002 .36617 .4605 .34737 .43039 .33397 Metetra
.589 .888 .99 r
.43039 .33397 .4605 .34737 .5119 .32678 .48273 .31573 Metetra
.565 .897 .983 r
.48273 .31573 .5119 .32678 .56415 .30322 .53609 .29714 Metetra
.503 .897 .945 r
.53609 .29714 .56415 .30322 .61703 .27315 .5905 .27817 Metetra
.311 .798 .759 r
.5905 .27817 .61703 .27315 .66952 .22147 .646 .25883 Metetra
.147 0 0 r
.646 .25883 .66952 .22147 .71355 .04313 .70262 .2391 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.15516 .20893 m
.15977 .2136 L
s
[(0.2)] .14594 .19959 .98735 1 Mshowa
.27892 .16047 m
.28332 .16534 L
s
[(0.4)] .27012 .15074 .90394 1 Mshowa
.4088 .10962 m
.41296 .11469 L
s
[(0.6)] .40047 .09947 .82053 1 Mshowa
.54525 .05618 m
.54915 .06146 L
s
[(0.8)] .53747 .04562 .73711 1 Mshowa
.125 Mabswid
.06611 .2438 m
.06896 .24652 L
s
.09545 .23231 m
.09827 .23506 L
s
.12513 .22069 m
.12792 .22346 L
s
.18555 .19703 m
.18829 .19986 L
s
.2163 .18499 m
.21901 .18785 L
s
.24742 .1728 m
.2501 .17569 L
s
.3108 .14799 m
.3134 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37573 .12256 m
.37826 .12558 L
s
.44227 .09651 m
.44473 .09958 L
s
.47617 .08323 m
.47859 .08634 L
s
.51049 .06979 m
.51287 .07293 L
s
.58046 .0424 m
.58275 .0456 L
s
.61611 .02844 m
.61836 .03167 L
s
.65223 .0143 m
.65443 .01756 L
s
gsave
.29165 .07573 -70.3112 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{604, 489.812},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009L0001jB000`400?l00000o`00003oo`3ooooo
0?oooeh0oooo003o0?ooool0ooooGP3oool00?l0ooooo`3ooomN0?ooo`00o`3ooooo0?oooeh0oooo
003o0?ooool0ooooGP3oool00?l0ooooo`3ooomN0?ooo`00o`3ooooo0?oooeh0oooo003o0?ooool0
ooooGP3oool00?l0ooooo`3ooomN0?ooo`00o`3ooooo0?oooeh0oooo003o0?ooool0ooooGP3oool0
0?l0ooooo`3ooomN0?ooo`00o`3ooooo0?oooeh0oooo003o0?ooool0ooooGP3oool00?l0ooooo`3o
oomN0?ooo`00o`3ooooo0?oooeh0oooo003o0?ooool0ooooGP3oool00?l0oooo/03oool200000:/0
oooo003o0?ooojl0oooo00@000000?ooo`3oool00000ZP3oool00?l0oooo[`3oool010000000oooo
0?ooo`00002Z0?ooo`00o`3ooon_0?ooo`040000003oool0oooo00000:X0oooo003o0?ooojl0oooo
00@000000?ooo`3oool00000ZP3oool00?l0oooo[`3oool010000000oooo0?ooo`00002Z0?ooo`00
o`3ooon`0?ooo`800000Z`3oool00?l0ooooY@3oool300000;D0oooo003o0?oooj<0oooo0`000000
0`3oool000000000002d0?ooo`00o`3ooonQ0?ooo`<000000`3oool200000;@0oooo003o0?oooil0
oooo0P0000060?ooo`030000003oool000000;<0oooo003o0?oooi`0oooo0`0000080?ooo`040000
003oool0oooo00000;80oooo003o0?oooiT0oooo0`00000;0?ooo`040000003oool0oooo00000;80
oooo003o0?oooiL0oooo0P00000>0?ooo`050000003oool0oooo0?ooo`000000/@3oool00?l0oooo
T`3oool400000100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2^0?ooo`00o`3o
oonB0?ooo`8000004`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0:h0oooo003o
0?ooohl0oooo0`0000020?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`2]0?ooo`00o`3ooon=0?ooo`8000006@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0:`0oooo003o0?ooohX0oooo0`00000K0?ooo`030000003oool0oooo00<0
oooo0P00002]0?ooo`00o`3ooon70?ooo`<000007P3oool010000000oooo0?ooo`3oool200000003
0?ooo`000000oooo0:`0oooo003o0?ooohD0oooo0P00000Q0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0ZP3oool00?l0ooooPP3oool3000002<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`2Z0?ooo`00o`3ooomo0?ooo`<000009P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0:T0oooo003o0?ooogd0oooo0`00000X0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0Z@3oool00?l0ooooN`3oool2000000<0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0:P0oooo003o0?ooodD0oooo
0P0000040?ooo`030000003oool0oooo00<0oooo0P00000U0?ooo`<00000;@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0:L0oooo003o0?oood@0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000Q0?ooo`<00000<03oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0:L0oooo003o0?oood@0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`00000O0?ooo`800000<`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0:H0oooo003o0?oood@0oooo00@000000?ooo`3oool000002@3oool2000001d0oooo0`00000e0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0Y@3oool00?l0ooooA03oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000001X0oooo0P00000h0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0Y@3oool00?l0ooooA03oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000001L0oooo0`00000j0?ooo`030000003oool0oooo00X0oooo0P00
002V0?ooo`00o`3ooom50?ooo`8000002P3oool2000001H0oooo0`00000l0?ooo`030000003oool0
oooo00T0oooo1000002U0?ooo`00o`3ooomV0?ooo`<000000`3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00T0oooo1000002U0?ooo`00o`3ooomS0?ooo`<00000@`3oool00`000000
oooo0?ooo`080?ooo`80000000<0oMUk000000000000Y03oool00?l0ooooH@3oool2000004H0oooo
00<000000?ooo`3oool0203oool200000080oMUk0P00002S0?ooo`00o`3ooomN0?ooo`<00000B03o
ool00`000000oooo0?ooo`080?ooo`8000000P3mfG/200000:<0oooo003o0?oooe`0oooo0P00001;
0?ooo`030000003oool0oooo00L0oooo00<0000002D0000000000`3mfG/200000:80oooo003o0?oo
oeT0oooo0`00001=0?ooo`030000003oool0oooo00L0oooo00<0000002D000000000103mfG/20000
0:40oooo003o0?oooeL0oooo0P00001@0?ooo`030000003oool0oooo00L0oooo00<0000002D00000
0000103mfG/200000:40oooo003o0?oooe@0oooo0`0000000`3oool000000?ooo`1?0?ooo`030000
003oool0oooo00L0oooo00<0000002D0000000001@3mfG/200000:00oooo003o0?oooe40oooo0`00
00040?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01P3oool00`0000009@000000
00060?gIN`030000003oool0000009l0oooo003o0?ooodl0oooo0P0000080?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool01P3oool00`0000009@00000000070?gIN`800000W`3oool0
0<80oooo0P0000000`3oool00000000000240?ooo`<00000FP3oool00`000000oooo0?ooo`060?oo
o`030000000U0000000000P0oMUk0P00002N0?ooo`00``3oool00`000000oooo000000230?ooo`80
0000G@3oool00`000000oooo0?ooo`060?ooo`030000000U0000000000P0oMUk00<000000?ooo`00
0000W@3oool00<@0oooo00<000000?ooo`3oool0O`3oool3000005l0oooo00<000000?ooo`3oool0
1@3oool0100000009@0002D0000000090?gIN`800000W@3oool00<<0oooo00<000000?ooo`000000
O@3oool300000680oooo00<000000?ooo`3oool01@3oool0100000009@0002D00000000:0?gIN`80
0000W03oool00<80oooo0P0000000`3oool000000000001j0?ooo`<00000I03oool00`000000oooo
0?ooo`050?ooo`040000000U00009@00000000X0oMUk00<000000?ooo`000000V`3oool00?l0oooo
@03oool2000000<0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`050?ooo`040000
000U00009@00000000/0oMUk0P00002K0?ooo`00o`3ooolm0?ooo`<00000J@3oool00`000000oooo
0?ooo`040?ooo`050000000U00009@0002D000000000303mfG/2000009X0oooo003o0?ooocX0oooo
0`00001/0?ooo`030000003oool0oooo00@0oooo00D0000002D0000U00009@000000000<0?gIN`03
0000003oool0000009T0oooo003o0?ooocP0oooo0P00001`0?ooo`030000003oool0oooo00<0oooo
00D0000002D0000U00009@000000000=0?gIN`800000V@3oool00?l0oooo=@3oool300000780oooo
00<000000?ooo`3oool00`3oool01@0000009@0002D0000U0000000000d0oMUk0`00002H0?ooo`00
o`3ooolc0?ooo`800000M@3oool00`000000oooo0?ooo`020?ooo`030000000U00009@0000809@00
00<000000?gIN`3mfG/02P3mfG/00`000000o]nH00000002000009L0oooo003o0?oooc00oooo0`00
001g0?ooo`030000003oool0oooo0080oooo00<0000002D0000U00000P0U00000`000000oMUk0?gI
N`0:0?gIN`030000003ngiP0o]nH00800000U`3oool00?l0oooo;P3oool200000080oooo00<00000
0?ooo`3oool0M@3oool00`000000oooo0?ooo`020?ooo`030000000U00009@0000809@0000<00000
0?gIN`3mfG/02P3mfG/01P000000o]nH0?kOV0000000oooo000009H0oooo003h0?ooo`800000103o
ool00`000000oooo0?ooo`030?ooo`800000903oool3000007`0oooo00<000000?ooo`3oool00P3o
ool00`0000009@0002D0000202D000030000003mfG/0oMUk00T0oMUk00<000000?kOV03ngiP00P3n
giP2000009H0oooo003g0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
803oool3000007l0oooo00D000000?ooo`3oool0oooo0000000502D000030000003mfG/0oMUk00T0
oMUk00<000000?kOV03ngiP00`3ngiP2000009D0oooo003g0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000007P3oool200000880oooo00D000000?ooo`3oool0oooo00000005
02D000030000003mfG/0oMUk00T0oMUk00<000000?kOV03ngiP00`3ngiP00`000000oooo0000000<
0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`@00000N@3oool00?L0oooo00@000000?oo
o`3oool00000203oool3000001`0oooo0`0000240?ooo`050000003oool0oooo0?ooo`000000100U
00000`000000oMUk0?gIN`090?gIN`030000003ngiP0o]nH00D0o]nH0P00000;0?ooo`040000003o
ool0oooo000000X0oooo00<000000?ooo`3oool0N03oool00?L0oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`0J0?ooo`800000Q`3oool01@000000oooo0?ooo`3oool0000000@0
9@0000<000000?gIN`3mfG/02@3mfG/00`000000o]nH0?kOV0050?kOV0030000003oool0000000X0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`1h0?ooo`00m`3oool010000000
oooo0?ooo`0000080?ooo`030000003oool0oooo01L0oooo0`0000290?ooo`040000003oool0oooo
000000D09@0000<000000?gIN`3mfG/02@3mfG/00`000000o]nH0?kOV0060?kOV0030000003oool0
000000T0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`1h0?ooo`00n03oool2
000000X0oooo0`00000D0?ooo`<00000R`3oool010000000oooo0?ooo`00000502D000030000003m
fG/0oMUk00P0oMUk00<000000?kOV03ngiP0203ngiP2000000T0oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`1h0?ooo`00o`3ooolI0?ooo`<000000`3oool00`000000oooo0?oo
o`280?ooo`040000003oool0oooo000000D09@0000<000000?gIN`3mfG/0203mfG/00`000000o]nH
0?kOV0080?kOV0030000003oool0000000P0oooo00@000000?ooo`3oool00000203oool3000007X0
oooo003o0?oooaH0oooo0`00002A0?ooo`040000003oool0oooo000000D09@0000<000000?gIN`3m
fG/01`3mfG/00`000000o]nH0?kOV00:0?kOV0<00000203oool2000000/0oooo00<000000?ooo`3o
ool0N03oool00?l0oooo503oool2000009@0oooo00<000000?ooo`0000001P0U00000`000000oMUk
0?gIN`070?gIN`030000003ngiP0o]nH00X0o]nH00<000000?ooo`000000T03oool00?l0oooo4@3o
ool3000009H0oooo00<000000?ooo`0000001P0U00000`000000oMUk0?gIN`070?gIN`030000003n
giP0o]nH00/0o]nH00<000000?ooo`000000S`3oool00?l0oooo3`3oool2000009T0oooo00<00000
0?ooo`0000001P0U00000`000000oMUk0?gIN`060?gIN`030000003ngiP0o]nH00d0o]nH00<00000
0?ooo`000000SP3oool00?l0oooo303oool3000009`0oooo0P00000602D000030000003mfG/0oMUk
00H0oMUk00<000000?kOV03ngiP03@3ngiP00`000000oooo0000002>0?ooo`00o`3oool:0?ooo`80
000000<0oooo0000003oool0W03oool00`0000009@0002D0000502D000030000003mfG/0oMUk00H0
oMUk00<000000?kOV03ngiP03P3ngiP00`000000oooo0000002=0?ooo`00o`3oool70?ooo`<00000
0`3oool00`000000oooo0?ooo`2K0?ooo`030000000U00009@0000D09@0000<000000?gIN`3mfG/0
1@3mfG/00`000000o]nH0?kOV00?0?kOV0040000003oool0oooo000008`0oooo003o0?ooo`@0oooo
0`0000070?ooo`030000003oool0oooo09X0oooo00<0000002D0000U00001@0U00000`000000oMUk
0?gIN`050?gIN`030000003ngiP0o]nH0100o]nH00<000000?ooo`000000S03oool00?l0oooo0P3o
ool200000:L0oooo00<0000002D0000U00001@0U00000`000000oMUk0?gIN`050?gIN`030000003n
giP0o]nH0100o]nH0P0000000`3oool000000?ooo`2:0?ooo`00oP3oool300000:P0oooo0P000007
02D000030000003mfG/0oMUk00@0oMUk00<000000?kOV03ngiP0403ngiP00`000000nMn]00000002
0?ooo`030000003oool0oooo08P0oooo003l0?ooo`800000Z`3oool2000000L09@0000<000000?gI
N`3mfG/0103mfG/00`000000o]nH0?kOV00@0?kOV0060000003igjd0nMn]0000003oool00000RP3o
ool00?T0oooo0`00002]0?ooo`8000001`0U00000`000000oMUk0?gIN`040?gIN`030000003ngiP0
o]nH00l0o]nH00<000000?WO[@3igjd00P3igjd3000008T0oooo003g0?ooo`800000/03oool20000
00L09@0000<000000?gIN`3mfG/00`3mfG/00`000000o]nH0?kOV00@0?kOV0030000003igjd0nMn]
00<0nMn]00<000000?ooo`000000R03oool00?@0oooo0`0000020?ooo`800000[@3oool00`000000
9@000000000602D000030000003mfG/0oMUk00@0oMUk00<000000?kOV03ngiP03`3ngiP00`000000
nMn]0?WO[@040?WO[@030000003oool0000008P0oooo003a0?ooo`<00000]03oool00`0000009@00
0000000602D000030000003mfG/0oMUk00@0oMUk00<000000?kOV03ngiP03`3ngiP00`000000nMn]
0?WO[@050?WO[@030000003oool0000008L0oooo003_0?ooo`800000]`3oool00`0000009@000000
000602D000030000003mfG/0oMUk00<0oMUk00<000000?kOV03ngiP03`3ngiP00`000000nMn]0?WO
[@070?WO[@030000003oool0000008H0oooo003/0?ooo`<00000^@3oool00`0000009@0000000006
02D000030000003mfG/0oMUk00<0oMUk00<000000?kOV03ngiP03`3ngiP00`000000nMn]0?WO[@07
0?WO[@030000003oool0000008H0oooo003Z0?ooo`800000^`3oool0100000009@0002D000000006
02D000030000003mfG/0oMUk00<0oMUk00<000000?kOV03ngiP03P3ngiP00`000000nMn]0?WO[@09
0?WO[@030000003oool0000008D0oooo003W0?ooo`<00000_@3oool0100000009@0002D000000006
02D000030000003mfG/0oMUk0080oMUk00<000000?kOV03ngiP03`3ngiP00`000000nMn]0?WO[@0:
0?WO[@030000003oool0000008@0oooo003U0?ooo`800000`03oool0100000009@0002D000000006
02D000030000003mfG/0oMUk0080oMUk00<000000?kOV03ngiP03P3ngiP00`000000nMn]0?WO[@0<
0?WO[@800000Q03oool00:h0oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0903oool300000080oooo0P00002n0?ooo`040000000U00009@00000000H09@0000<00000
0?gIN`3mfG/00P3mfG/00`000000o]nH0?kOV00>0?kOV0030000003igjd0nMn]00`0nMn]00<00000
0?ooo`000000P`3oool00:d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0R
0?ooo`800000a03oool00`0000009@0002D0000202D000030000000U00009@0000<09@0000D00000
0?gIN`3mfG/0oMUk0000000A0?kOV0030000003igjd0nMn]00d0nMn]0`0000220?ooo`00[@3oool0
10000000oooo0?ooo`0000070?ooo`D00000803oool300000<H0oooo00<0000002D0000U00000P0U
00000`0000009@0002D0000302D000050000003mfG/0oMUk0?gIN`000000403ngiP00`000000nMn]
0?WO[@0?0?WO[@800000PP3oool00:d0oooo00@000000?ooo`3oool000001`3oool010000000oooo
0?ooo`00000N0?ooo`<00000b@3oool00`0000009@0002D0000202D000030000000U00009@0000<0
9@0000D000000?gIN`3mfG/0oMUk0000000@0?kOV0030000003igjd0nMn]0100nMn]0P0000210?oo
o`00[@3oool010000000oooo0?ooo`0000080?ooo`030000003oool0000001`0oooo0P00003<0?oo
o`030000000U00009@0000809@0000<0000002D0000U00000`0U000010000000oMUk0?gIN`00000@
0?kOV0030000003igjd0nMn]0140nMn]0P0000210?ooo`00[@3oool010000000oooo0?ooo`000009
0?ooo`8000006@3oool300000<d0oooo00<0000002D0000U00000`0U00000`0000009@0002D00003
02D000040000003mfG/0oMUk00000100o]nH00<000000?WO[@3igjd04P3igjd200000800oooo002^
0?ooo`8000002`3oool00`000000oooo0?ooo`0E0?ooo`800000d03oool00`0000009@0002D00003
02D000030000000U00009@0000<09@0000<000000?gIN`000000403ngiP00`000000nMn]0?WO[@0B
0?WO[@040000003agK/00000000007l0oooo003@0?ooo`<000000P3oool200000<h0oooo00<00000
02D0000U00000`0U00000`0000009@0002D0000302D000030000003mfG/000000100o]nH00<00000
0?WO[@3igjd04P3igjd010000000lMfk00000000001o0?ooo`00cP3oool200000=D0oooo00<00000
02D0000U00000`0U00000`0000009@0002D0000302D000030000003mfG/0000000l0o]nH00<00000
0?WO[@3igjd04P3igjd010000000lMfk0?7M^`3agK/2000007h0oooo003;0?ooo`<00000eP3oool0
0`0000009@0002D0000402D000030000000U00009@0000<09@000P00000@0?kOV0030000003igjd0
nMn]0180nMn]00<000000?7M^`3agK/00P3agK/2000007d0oooo00380?ooo`<00000f@3oool00`00
00009@0002D0000402D000030000000U00009@0000<09@000P00000?0?kOV0030000003igjd0nMn]
0180nMn]00<000000?7M^`3agK/00`3agK/2000007d0oooo00360?ooo`800000g03oool00`000000
9@0002D0000402D000030000000U00009@0000809@0000<000000?gIN`0000003`3ngiP00`000000
nMn]0?WO[@0B0?WO[@030000003agK/0lMfk00@0lMfk0P00001l0?ooo`00``3oool300000=h0oooo
00<0000002D0000U0000100U00000`0000009@0002D0000202D0008000003`3ngiP00`000000nMn]
0?WO[@0B0?WO[@030000003agK/0lMfk00D0lMfk00<000000?ooo`000000N`3oool00<40oooo0`00
003O0?ooo`030000000U00009@0000D09@0000<0000002D0000U00000P0U0002000000l0o]nH00<0
00000?WO[@3igjd04@3igjd00`000000lMfk0?7M^`070?7M^`800000N`3oool00;h0oooo0`000003
0?ooo`030000003oool0oooo0=`0oooo00<0000002D0000U00001@0U00000`0000009@0002D00002
02D0008000003`3ngiP00`000000nMn]0?WO[@0A0?WO[@030000003agK/0lMfk00P0lMfk0P00001j
0?ooo`00_03oool2000000L0oooo00<000000?ooo`3oool0f`3oool00`0000009@0002D0000502D0
00030000000U00009@0000809@0000<000000?kOV03ngiP03@3ngiP00`000000nMn]0?WO[@0A0?WO
[@030000003agK/0lMfk00T0lMfk00<000000?ooo`000000N@3oool00;T0oooo0`00003W0?ooo`03
0000000U00009@0000D09@0000<0000002D0000U00000P0U00000`000000o]nH0?kOV00=0?kOV003
0000003igjd0nMn]0140nMn]00<000000?7M^`3agK/02P3agK/2000007T0oooo002f0?ooo`<00000
j@3oool00`0000009@0002D0000602D000030000000U00009@0000809@0000<000000?kOV03ngiP0
303ngiP00`000000nMn]0?WO[@0A0?WO[@030000003agK/0lMfk00`0lMfk0P00001h0?ooo`00]03o
ool200000>`0oooo00<0000002D0000U00001`0U00001@0000009@0002D0000U0000000000h0o]nH
00<000000?WO[@3igjd04@3igjd00`000000lMfk0?7M^`0<0?7M^`030000003oool0000007L0oooo
002a0?ooo`<00000kP3oool00`0000009@0002D0000702D000050000000U00009@0002D000000000
3@3ngiP00`000000nMn]0?WO[@0A0?WO[@030000003agK/0lMfk00h0lMfk0P00001g0?ooo`00[`3o
ool2000000030?ooo`000000oooo0>h0oooo00<0000002D0000U00001`0U00001@0000009@0002D0
000U0000000000d0o]nH00<000000?WO[@3igjd0403igjd00`000000lMfk0?7M^`0?0?7M^`030000
003oool0000007H0oooo002/0?ooo`<00000103oool00`000000oooo0?ooo`3[0?ooo`030000000U
00009@0000P09@0000D0000002D0000U00009@000000000<0?kOV0030000003igjd0nMn]0140nMn]
00<000000?7M^`3agK/0403agK/3000007D0oooo002Z0?ooo`800000m@3oool00`0000009@0002D0
000802D000050000000U00009@0002D000000000303ngiP00`000000nMn]0?WO[@0@0?WO[@030000
003agK/0lMfk0180lMfk0P00001e0?ooo`00Y`3oool300000?L0oooo00<0000002D0000U0000200U
00001@0000009@0002D0000U0000000000/0o]nH00<000000?WO[@3igjd04@3igjd00`000000lMfk
0?7M^`0B0?7M^`030000003oool0000007@0oooo002T0?ooo`<00000nP3oool00`0000009@0002D0
000802D000050000000U00009@0002D0000000002`3ngiP00`000000nMn]0?WO[@0@0?WO[@030000
003agK/0lMfk01@0lMfk00<000000?ooo`000000L`3oool00:80oooo0P00003l0?ooo`030000000U
00009@0000T09@0000D0000002D0000U00009@000000000:0?kOV0030000003igjd0nMn]0140nMn]
00<000000?7M^`3agK/04`3agK/010000000jM_500000000000<0?ooo`800000103oool00`000000
oooo0?ooo`020?ooo`@00000F03oool009l0oooo0`00003n0?ooo`030000000U00009@0000T09@00
00D0000002D0000U00009@000000000:0?kOV0030000003igjd0nMn]0100nMn]00<000000?7M^`3a
gK/0503agK/01@000000jM_50000003oool0000000X0oooo00@000000?ooo`3oool00000203oool0
0`000000oooo0?ooo`1I0?ooo`00J@3oool2000000@0oooo00<000000?ooo`3oool00P3oool40000
02D0oooo0P0000000`3oool000000?ooo`3n0?ooo`030000000U00009@0000T09@0000D0000002D0
000U00009@00000000090?kOV0030000003igjd0nMn]0140nMn]00<000000?7M^`3agK/04`3agK/0
1`000000jM_50>WKa@3YflD000000?ooo`0000002@3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo05P0oooo001X0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3o
ool08`3oool3000000@0oooo00<000000?ooo`3oool0o03oool00`0000009@0002D0000902D00005
0000000U00009@0002D0000000002@3ngiP00`000000nMn]0?WO[@0@0?WO[@030000003agK/0lMfk
01<0lMfk00<000000>WKa@3YflD00`3YflD2000000T0oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`1G0?ooo`00J03oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo0200oooo0P00003o0?ooo`H0oooo00<0000002D0000U00002P0U0000100000009@0002D00000
000:0?kOV0030000003igjd0nMn]00l0nMn]00<000000?7M^`3agK/04`3agK/00`000000jM_50>WK
a@040>WKa@030000003oool0000000P0oooo00@000000?ooo`3oool000002`3oool00`000000oooo
0?ooo`1F0?ooo`00J03oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo01`0oooo
0`00003o0?ooo`P0oooo00<0000002D0000U00002P0U0000100000009@0002D0000000090?kOV003
0000003igjd0nMn]0100nMn]00<000000?7M^`3agK/04`3agK/00`000000jM_50>WKa@050>WKa@80
0000203oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000005P0oooo001X0?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool06@3oool200000?l0oooo2`3oool0
0`0000009@0002D0000:02D000040000000U00009@00000000T0o]nH00<000000?WO[@3igjd03`3i
gjd00`000000lMfk0?7M^`0C0?7M^`030000003YflD0jM_500L0jM_50P0000080?ooo`8000002P3o
ool2000005T0oooo001X0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
603oool300000?l0oooo3@3oool00`0000009@0002D0000:02D000040000000U00009@00000000P0
o]nH00<000000?WO[@3igjd0403igjd00`000000lMfk0?7M^`0B0?7M^`030000003YflD0jM_500P0
jM_500<000000?ooo`000000KP3oool006T0oooo0P00000:0?ooo`8000005P3oool300000?l0oooo
3`3oool00`0000009@0002D0000;02D000040000000U00009@00000000P0o]nH00<000000?WO[@3i
gjd03`3igjd00`000000lMfk0?7M^`0C0?7M^`030000003YflD0jM_500T0jM_50P00001^0?ooo`00
R`3oool2000000<0oooo00<000000?ooo`3oool0o`3oool<0?ooo`030000000U00009@0000/09@00
00@0000002D0000U000000001`3ngiP00`000000nMn]0?WO[@0@0?WO[@030000003agK/0lMfk0180
lMfk00<000000>WKa@3YflD02P3YflD00`000000oooo0000001]0?ooo`00R03oool300000?l0oooo
503oool00`0000009@0002D0000<02D000030000000U0000000000L0o]nH00<000000?WO[@3igjd0
3`3igjd00`000000lMfk0?7M^`0B0?7M^`030000003YflD0jM_500`0jM_500<000000?ooo`000000
K03oool008H0oooo0P00003o0?oooaL0oooo00<0000002D0000U0000300U00000`0000009@000000
00060?kOV0030000003igjd0nMn]00l0nMn]00<000000?7M^`3agK/04P3agK/00`000000jM_50>WK
a@0>0>WKa@800000=`3oool2000003<0oooo00230?ooo`<00000o`3ooolH0?ooo`030000000U0000
9@0000d09@0000<0000002D0000000001P3ngiP00`000000nMn]0?WO[@0?0?WO[@030000003agK/0
lMfk0180lMfk00<000000>WKa@3YflD03P3YflD00`000000oooo0000000h0?ooo`030000003oool0
oooo0300oooo00210?ooo`800000o`3ooolK0?ooo`030000000U00009@0000d09@0000<0000002D0
000000001@3ngiP00`000000nMn]0?WO[@0?0?WO[@030000003agK/0lMfk0180lMfk00<000000>WK
a@3YflD0403YflD00`000000oooo0000000g0?ooo`800000<@3oool007h0oooo0`00003o0?oooad0
oooo00<0000002D0000U00003@0U00000`0000009@00000000050?kOV0030000003igjd0nMn]00l0
nMn]00<000000?7M^`3agK/04@3agK/00`000000jM_50>WKa@0B0>WKa@800000=P3oool010000000
oooo0?ooo`00000`0?ooo`00N`3oool3000000030?ooo`000000oooo0?l0oooo7@3oool00`000000
9@0002D0000=02D000040000000U00000000000000<0o]nH00<000000?WO[@3igjd03`3igjd00`00
0000lMfk0?7M^`0A0?7M^`030000003YflD0jM_501<0jM_500<000000?ooo`000000=@3oool01000
0000oooo0?ooo`00000`0?ooo`00N@3oool2000000@0oooo00<000000?ooo`3oool0o`3ooolK0?oo
o`030000000U00009@0000h09@0000@0000002D000000000j_O91000000A0?WO[@030000003agK/0
lMfk0140lMfk00<000000>WKa@3YflD0503YflD3000003@0oooo00@000000?ooo`3oool00000<03o
ool007H0oooo0`0000070?ooo`030000003oool0oooo0?l0oooo6P3oool00`0000009@0002D0000>
02D000030000000U0000000000<0j_O900@000000>c_bP00000000003P3igjd00`000000lMfk0?7M
^`0A0?7M^`030000003YflD0jM_501@0jM_500@000000>?Hc00000000000<`3oool2000000030?oo
o`00000000000300oooo001d0?ooo`800000o`3ooolW0?ooo`030000000U00009@0000h09@0000<0
000002D0000000000`3ZmlT010000000k>o:0>c_bP3/klX2000000/0nMn]00<000000?7M^`3agK/0
4@3agK/00`000000jM_50>WKa@0D0>WKa@060000003Sf<`0hmS<0000003oool00000I`3oool00740
oooo0`00003o0?ooobT0oooo00<0000002D0000U00003P0U00000`0000009@00000000020>[gb@03
0000003/klX0k>o:00@0k>o:00<000000?WO[@3igjd0203igjd00`000000lMfk0?7M^`0A0?7M^`03
0000003YflD0jM_501@0jM_500L000000>?Hc03Sf<`0hmS<0000003oool0000006H0oooo001_0?oo
o`800000o`3oool[0?ooo`030000000U00009@0000l09@0000D0000002D000000000j_O900000008
0>c_bP8000001`3igjd00`000000lMfk0?7M^`0A0?7M^`030000003YflD0jM_501@0jM_500<00000
0>?Hc03Sf<`00`3Sf<`2000006H0oooo001/0?ooo`<00000o`3oool]0?ooo`030000000U00009@00
00l09@0000@0000002D00000000000002`3/klX00`000000nMn]0?WO[@040?WO[@030000003agK/0
lMfk0100lMfk00<000000>WKa@3YflD0503YflD00`000000hmS<0>?Hc0040>?Hc0030000003oool0
000006D0oooo001Y0?ooo`<000000P3oool00`000000oooo0?ooo`3o0?ooobX0oooo00<0000002D0
000U0000400U0002000000030>[gb@000000k>o:00/0k>o:0P0000030?WO[@030000003agK/0lMfk
0100lMfk00<000000>WKa@3YflD0503YflD00`000000hmS<0>?Hc0060>?Hc0030000003oool00000
06@0oooo001W0?ooo`8000001P3oool00`000000oooo0?ooo`3o0?ooobP0oooo0P00000B02D000<0
00003`3/klX2000000030?WO[@000000lMfk0140lMfk00<000000>WKa@3YflD0503YflD00`000000
hmS<0>?Hc0070>?Hc0800000I03oool006@0oooo0`00003o0?oooc80oooo0P00000C02D000800000
4P3/klX00`000000lMfk0?7M^`0@0?7M^`030000003YflD0jM_501@0jM_500<000000>?Hc03Sf<`0
203Sf<`00`000000oooo0000001S0?ooo`00HP3oool200000?l0oooo=03oool00`000000Clc20000
000C02D0008000004@3/klX00`000000jNW>0000000@0?7M^`030000003YflD0jM_501@0jM_500<0
00000>?Hc03Sf<`02P3Sf<`00`000000oooo0000001R0?ooo`00G`3oool300000?l0oooo=@3oool0
0`000000Clc20000000D02D000800000403/klX01@000000jNW>0>WYcP3YjLh0000000l0lMfk00<0
00000>WKa@3YflD04`3YflD00`000000hmS<0>?Hc00;0>?Hc0<00000HP3oool005d0oooo0P00003o
0?ooocL0oooo00<0000004o<`P0000005P0U00000`000000k>o:0>c_bP0>0>c_bP030000003YjLh0
jNW>0080jNW>00<000000?7M^`3agK/02`3agK/00`000000jM_50>WKa@0C0>WKa@030000003Sf<`0
hmS<00d0hmS<00<000000?ooo`000000H@3oool005X0oooo1000003o0?ooocL0oooo00@0000004o<
`P1?c<8000005P0U00000`000000k>o:0>c_bP0=0>c_bP030000003YjLh0jNW>00@0jNW>00<00000
0?7M^`3agK/02@3agK/00`000000jM_50>WKa@0D0>WKa@030000003Sf<`0hmS<00h0hmS<00<00000
0?ooo`000000H03oool005L0oooo0`0000040?ooo`030000003oool0oooo0?l0oooo<`3oool01000
0000Clc204o<`P00000G02D000030000003/klX0k>o:00`0k>o:00<000000>WYcP3YjLh01P3YjLh0
0`000000lMfk0?7M^`070?7M^`030000003YflD0jM_501@0jM_500<000000>?Hc03Sf<`03`3Sf<`0
0`000000oooo0000001P0?ooo`00E@3oool200000?l0oooo?03oool010000000Clc204o<`P00000H
02D000030000003/klX0k>o:00/0k>o:00<000000>WYcP3YjLh0203YjLh00`000000lMfk0?7M^`06
0?7M^`030000003YflD0jM_501<0jM_500<000000>?Hc03Sf<`04@3Sf<`00`000000oooo0000001O
0?ooo`00DP3oool300000?l0oooo?@3oool01@000000Clc204o<`P1?c<80000001L09@000P00000<
0>c_bP030000003YjLh0jNW>00X0jNW>00<000000?7M^`3agK/0103agK/00`000000jM_50>WKa@0C
0>WKa@030000003Sf<`0hmS<01<0hmS<00<000000?ooo`000000GP3oool00500oooo0P00003o0?oo
ocl0oooo00D0000004o<`P1?c<80Clc20000000E02D000<0000000<0k>o:0000003/klX02`3/klX0
0`000000jNW>0>WYcP0;0>WYcP030000003agK/0lMfk0080lMfk00<000000>WKa@3YflD0503YflD0
0`000000hmS<0>?Hc00C0>?Hc0030000003oool0000005h0oooo001=0?ooo`<00000o`3ooom00?oo
o`030000001?c<80Clc20080Clc200<0000002D0000U0000400U0003000000@0k>o:00<000000>c_
bP3/klX02@3/klX00`000000jNW>0>WYcP0=0>WYcP040000003agK/0lMfk000001H0jM_500<00000
0>?Hc03Sf<`05@3Sf<`00`000000oooo0000001M0?ooo`00B`3oool200000?l0oooo@P3oool00`00
0000Clc204o<`P0204o<`P030000000U00009@0000h09@00100000060>c_bP030000003/klX0k>o:
00P0k>o:00<000000>WYcP3YjLh03`3YjLh00`000000lMfk0000000E0>WKa@030000003Sf<`0hmS<
01D0hmS<00@000000=cFd@0000000000G@3oool004P0oooo0`0000020?ooo`800000o`3ooolo0?oo
o`030000001?c<80Clc20080Clc200<0000002D0000U0000300U000300000080j_O900<000000>c_
bP3/klX0103/klX2000000T0k>o:00<000000>WYcP3YjLh04@3YjLh00`000000jM_50>WKa@0C0>WK
a@030000003Sf<`0hmS<01D0hmS<00<000000=cFd@3Le]400`00001L0?ooo`00A@3oool300000?l0
ooooA@3oool00`000000Clc204o<`P0304o<`P030000000U00009@0000T09@000`0000040>[gb@03
0000003/klX0k>o:0080k>o:0`0000020>c_bP030000003/klX0k>o:00D0k>o:00<000000>WYcP3Y
jLh04@3YjLh00`000000i>CB0000000C0>WKa@030000003Sf<`0hmS<01D0hmS<00<000000=cFd@3L
e]400P3Le]400`000000oooo0000001K0?ooo`00@`3oool200000?l0ooooA`3oool00`000000Clc2
04o<`P0304o<`P030000000U00009@0000P09@000P0000060>[gb@030000003/klX0k>o:00<00000
1@3/klX00`000000k>o:0>c_bP050>c_bP030000003YjLh0jNW>0100jNW>00D000000>CTdP3Ti=80
i>CB0000000B0>WKa@030000003Sf<`0hmS<01@0hmS<00<000000=cFd@3Le]40103Le]42000005/0
oooo00100?ooo`<00000o`3ooom80?ooo`030000001?c<80Clc200<0Clc200<0000002D0000U0000
1P0U0003000000P0j_O90`0000090>c_bP030000003/klX0k>o:00<0k>o:00<000000>WYcP3YjLh0
4@3YjLh00`000000i>CB0>CTdP020>CTdP030000003YflD0jM_500h0jM_500<000000>?Hc03Sf<`0
5@3Sf<`00`000000g=KA0=cFd@040=cFd@030000003oool0000005X0oooo000n0?ooo`800000o`3o
oom:0?ooo`030000001?c<80Clc200@0Clc200<0000002D0000U00000`0U0003000000P0j_O90`00
000=0>c_bP050000003/klX0k>o:0>c_bP0000004`3YjLh00`000000i>CB0>CTdP040>CTdP030000
003YflD0jM_500`0jM_500<000000>?Hc03Sf<`05@3Sf<`00`000000g=KA0=cFd@060=cFd@030000
003oool0000005T0oooo000l0?ooo`800000o`3ooom;0?ooo`030000001?c<80Clc200@0Clc200@0
000002D0000U00009@000`0000090>[gb@80000000<0j_O90000003/klX03P3/klX00`000000k>o:
0000000C0>WYcP030000003Ti=80i>CB00H0i>CB00<000000>WKa@3YflD02P3YflD00`000000hmS<
0>?Hc00E0>?Hc0030000003Le]40g=KA00P0g=KA0P00001I0?ooo`00?03oool200000?l0ooooBP3o
ool00`000000Clc204o<`P0504o<`PD00000203ZmlT300000080j_O900<000000>c_bP3/klX03P3/
klX00`000000k>o:0000000B0>WYcP030000003Ti=80i>CB00P0i>CB00<000000>WKa@3YflD0203Y
flD00`000000hmS<0>?Hc00E0>?Hc0030000003Le]40g=KA00T0g=KA00<000000?ooo`000000F03o
ool003`0oooo00@000000?ooo`0000000000o`3ooom70?ooo`030000001?c<80Clc200@0Clc20`00
00020=;od@030000003ZmlT0j_O900@0j_O90`0000050>[gb@030000003/klX0k>o:00l0k>o:00<0
00000>WYcP3YjLh0403YjLh00`000000i>CB0>CTdP090>CTdP030000003YflD0jM_500P0jM_500<0
00000>?Hc03Sf<`0503Sf<`00`000000g=KA0=cFd@0;0=cFd@030000003oool0000005L0oooo000l
0?ooo`80000000<0oooo0000003oool0o`3ooom50?ooo`030000001?c<80Clc20080Clc20`000004
0=;od@030000003ZmlT0j_O90080j_O90`0000070>[gb@030000003/klX0k>o:00l0k>o:00<00000
0>WYcP0000004@3YjLh00`000000i>CB0>CTdP0:0>CTdP030000003YflD0jM_500H0jM_500<00000
0>?Hc03Sf<`0503Sf<`00`000000g=KA0=cFd@0<0=cFd@030000003oool0000005L0oooo000k0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooom20?ooo`030000001?c<80Clc2
00<000001`3Bom400`000000j_O900000002000000T0j_O900<000000>c_bP3/klX03`3/klX01@00
0000jNW>0>WYcP3YjLh0000000l0jNW>00<000000>CTdP3Ti=80303Ti=800`000000jM_50>WKa@04
0>WKa@030000003Sf<`0hmS<01@0hmS<00<000000=cFd@3Le]403P3Le]43000005H0oooo000k0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooom00?ooo`040000001?c<800000
000000T0d_oA0`00000;0>[gb@030000003/klX0k>o:00l0k>o:00<000000>WYcP3YjLh00P3YjLh0
0`000000jNW>0>WYcP0<0>WYcP030000003Ti=80i>CB00h0i>CB00<000000>WKa@3YflD00P3YflD0
0`000000hmS<0>?Hc00D0>?Hc0030000003Le]40g=KA0100g=KA00<000000?ooo`000000E@3oool0
0340oooo0P0000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3oooln0?oo
o`<00000203Bom43000000h0j_O900<000000>c_bP3/klX03`3/klX00`000000jNW>0>WYcP030>WY
cP030000003YjLh0jNW>00X0jNW>00<000000>CTdP3Ti=80403Ti=801@000000jM_50>WKa@3YflD0
000001D0hmS<00<000000=cFd@3Le]404@3Le]400`000000oooo0000001E0?ooo`00<03oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo00D0oooo0P00003o0?oooc/0oooo0`000008
0=;od@<0000000<0d_oA0000003ZmlT03@3ZmlT00`000000k>o:0>c_bP0?0>c_bP030000003YjLh0
jNW>00D0jNW>00<000000>WYcP3YjLh0203YjLh00`000000i>CB0>CTdP0B0>CTdP030000003YflD0
000001H0hmS<00<000000=cFd@3Le]404P3Le]400`000000oooo0000001D0?ooo`00<03oool01000
0000oooo0?ooo`0000070?ooo`<000001`3oool00`000000oooo0?ooo`3o0?ooocD0oooo0`000000
0`1?c<8000000=;od@050=;od@<00000103Bom400`000000j_O90>[gb@0;0>[gb@030000003/klX0
k>o:00l0k>o:00<000000>WYcP3YjLh01P3YjLh00`000000jNW>0>WYcP080>WYcP030000003Ti=80
i>CB01<0i>CB00<000000>?Hc03Sf<`0503Sf<`00`000000g=KA0=cFd@0D0=cFd@030000003oool0
000000/0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P00000j0?ooo`00<03oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooola
0?ooo`<000000`1?c<800`000000d_oA0=;od@030=;od@8000001P3Bom400`000000j_O90>[gb@0;
0>[gb@030000003/klX0k>o:00l0k>o:00<000000>WYcP3YjLh0203YjLh00`000000jNW>0>WYcP06
0>WYcP030000003Ti=80i>CB01<0i>CB00<000000=oPeP000000503Sf<`00`000000g=KA0=cFd@0E
0=cFd@030000003oool0000000X0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`00000i0?ooo`00<03oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0o`3oool^0?ooo`8000000`1?c<8D000000/0j_O900<000000>c_bP3/klX0
3P3/klX00`000000jNW>0>WYcP0:0>WYcP030000003YjLh0jNW>00@0jNW>00<000000>CTdP3Ti=80
4`3Ti=801@000000gn3F0=oPeP3Oh=H000000180hmS<00<000000=cFd@3Le]405`3Le]400`000000
oooo000000090?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0=`3oool00300
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0?l0oooo:P3oool:000000040;7fl@0000000000000000P0/OKa0P0000040<[gjPH00000103ZmlT0
0`000000k>o:0>c_bP0?0>c_bP030000003YjLh0jNW>00/0jNW>00<000000>WYcP3YjLh00P3YjLh0
0`000000i>CB0>CTdP0C0>CTdP030000003Oh=H0gn3F00<0gn3F00<000000>?Hc03Sf<`03P3Sf<`0
0`000000g=KA0=cFd@0G0=cFd@050000003GdmD000000?ooo`000000203oool010000000oooo0?oo
o`0000090?ooo`800000>P3oool00340oooo0P0000070?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0o`3ooolV0?ooo`H000000`20iO45000000X0/OKa00<000000<[gjP3:mnX02P3:
mnX500000100k>o:00<000000>WYcP3YjLh0303YjLh01@000000jNW>0>WYcP3YjLh0000001D0i>CB
00<000000=oPeP3Oh=H0103Oh=H00`000000hmS<0>?Hc00=0>?Hc0030000003Le]40g=KA01L0g=KA
00H000000=OCe@3GdmD000000?ooo`0000080?ooo`040000003oool0oooo000000/0oooo00<00000
0?ooo`3oool0=`3oool003X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oo
ob80oooo10000007083Ul@<00000302am_400`000000b_OZ0<[gjP0=0<[gjP030000003Dl^D0e?;U
008000003@3/klX00`000000jNW>0>WYcP0>0>WYcP030000003YjLh0000001D0i>CB00<000000=oP
eP3Oh=H01P3Oh=H00`000000hmS<0>?Hc00;0>?Hc0030000003Le]40g=KA01L0g=KA00<000000=OC
e@3GdmD00P3GdmD00`000000oooo000000070?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool00000>@3oool003X0oooo0`00000>0?ooo`030000003oool0oooo0?l0oooo7P3oool3
000000P0P>Ga0`00000=0;7fl@8000003`3:mnX00`000000e?;U0=Cbi@030=Cbi@8000002P3/klX0
0`000000jNW>0>WYcP0@0>WYcP800000503Ti=800`000000gn3F0=oPeP080=oPeP030000003Sf<`0
hmS<00T0hmS<00<000000=cFd@3Le]405`3Le]400`000000em?E0=OCe@040=OCe@030000003oool0
000000L0oooo0P00000:0?ooo`800000>P3oool003X0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`3o0?oooaX0oooo0`000008083Ul@@000003P2am_400`000000b_OZ0<[gjP0>0<[g
jP030000003Dl^D0e?;U00H0e?;U0P0000070>c_bP030000003YjLh0jNW>0140jNW>0P00000C0>CT
dP030000003Oh=H0gn3F00X0gn3F00<000000>?Hc03Sf<`01`3Sf<`00`000000g=KA0=cFd@0G0=cF
d@030000003GdmD0em?E00D0em?E00<000000?ooo`000000C`3oool003X0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`3o0?oooaH0oooo0`000008083Ul@D000003`2am_400`000000
b_OZ0<[gjP0=0<[gjP8000002`3Dl^D2000000D0k>o:00<000000>WYcP3YjLh0403YjLh00`000000
i>CB0000000B0>CTdP030000003Oh=H0gn3F00`0gn3F00<000000>?Hc03Sf<`01@3Sf<`00`000000
g=KA0=cFd@0G0=cFd@030000003GdmD0em?E00L0em?E00<000000?ooo`000000CP3oool003T0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3o0?oooa80oooo0`000008083Ul@<00000
0P20iO400`000000/OKa0;7fl@0=0;7fl@8000003`3:mnX00`000000e?;U0=Cbi@0=0=Cbi@800000
0P3/klX00`000000jNW>0>WYcP0@0>WYcP050000003Ti=80i>CB0>CTdP000000403Ti=800`000000
gn3F0=oPeP0>0=oPeP030000003Sf<`0hmS<00@0hmS<00<000000=cFd@3Le]405P3Le]400`000000
em?E0=OCe@090=OCe@030000003oool0000004d0oooo000i0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0o`3oool>0?ooo`<000002@20iO42000000<0P>Ga0P00000?0;7fl@030000
003:mnX0b_OZ00h0b_OZ00<000000=Cbi@3Dl^D0403Dl^D200000180jNW>00<000000>CTdP3Ti=80
0`3Ti=800`000000i>CB0>CTdP0<0>CTdP030000003Oh=H0gn3F00l0gn3F00<000000>?Hc03Sf<`0
0`3Sf<`00`000000g=KA0=cFd@0F0=cFd@030000003GdmD0em?E00X0em?E00<000000?ooo`000000
C@3oool003T0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`00003o0?ooo``0oooo
0`000009083Ul@<000000`20iO4200000100/OKa00<000000<[gjP3:mnX03P3:mnX00`000000e?;U
0=Cbi@0A0=Cbi@040000003HkN80000000000100jNW>00<000000>CTdP3Ti=80103Ti=800`000000
i>CB0>CTdP0:0>CTdP030000003Oh=H0gn3F0140gn3F00D000000>?Hc03Sf<`0hmS<0000000H0=cF
d@030000003GdmD0em?E00`0em?E00<000000?ooo`000000C03oool003T0oooo0`00000A0?ooo`80
00000P3oool200000?l0oooo1`3oool3000000T0P>Ga0`000005083Ul@030000002am_40/OKa00h0
/OKa0P00000@0<[gjP030000003Dl^D0e?;U0140e?;U00<000000=S]hP3HkN800P3HkN82000000d0
jNW>00<000000>CTdP3Ti=801@3Ti=800`000000i>CB0>CTdP090>CTdP030000003Oh=H0gn3F01<0
gn3F00<000000>?Hc0000000603Le]400`000000em?E0=OCe@0>0=OCe@030000003oool0000004/0
oooo000i0?ooo`030000003oool0oooo0100oooo0P0000000`3_UE8000000?ooo`020?ooo`030000
003oool0oooo0?l0oooo0@3oool3000000T0P>Ga0`000006083Ul@800000402am_400`000000b_OZ
0<[gjP0?0<[gjP030000003Dl^D0e?;U0140e?;U00<000000=S]hP3HkN801@3HkN800`000000jNW>
0>WYcP090>WYcP030000003Ti=80i>CB00L0i>CB00<000000>CTdP3Ti=801`3Ti=800`000000gn3F
0=oPeP0E0=oPeP030000003Le]40g=KA01H0g=KA00<000000=OCe@3GdmD0403GdmD2000004/0oooo
000i0?ooo`030000003oool0oooo0100oooo0P0000020>nEDP050000003oool0oooo0?ooo`000000
oP3oool3000000T0P>Ga0`000007083Ul@8000004@2am_400`000000b_OZ0<[gjP0?0<[gjP030000
003Dl^D0e?;U0100e?;U0P0000090=S]hP800000203YjLh00`000000i>CB0>CTdP090>CTdP030000
003Ti=80i>CB00H0i>CB00<000000=oPeP3Oh=H0503Oh=H00`000000f]gI0000000E0=cFd@800000
4`3GdmD3000004X0oooo000h0?ooo`030000003oool0oooo0140oooo00<0000006lRF`0000000P3_
UE801@000000oooo0?ooo`3oool000000?X0oooo0`000009083Ul@<000002020iO4200000140/OKa
0P00000A0<[gjP030000003Dl^D0e?;U0100e?;U00<000000=S]hP3HkN802`3HkN800`000000jNW>
0>WYcP040>WYcP030000003Ti=80i>CB00X0i>CB00<000000>CTdP3Ti=801@3Ti=800`000000gn3F
0=oPeP0D0=oPeP050000003JgMT0f]gI0=[Mf@0000004`3Le]400`000000em?E0=OCe@0D0=OCe@80
0000BP3oool003P0oooo00<000000?ooo`3oool0403oool010000000Kb9K06lRF`0000030>nEDP05
0000003oool0oooo0?ooo`000000m`3oool2000000<0T>Gk10000002083Ul@<000002P20iO400`00
0000/OKa0;7fl@0@0;7fl@030000003:mnX0b_OZ00l0b_OZ0P00000B0=Cbi@030000003HkN80f>gR
00d0f>gR0P0000040>WYcP030000003Ti=80i>CB00/0i>CB00<000000>CTdP3Ti=800`3Ti=800`00
0000gn3F0=oPeP0D0=oPeP030000003JgMT0f]gI00<0f]gI00<000000=cFd@3Le]403`3Le]400`00
0000em?E0=OCe@0F0=OCe@800000B@3oool003P0oooo00<000000?ooo`3oool0403oool010000000
Kb9K06lRF`0000040>nEDP050000003oool0oooo0?ooo`000000l`3oool3000000P0T>Gk1@000009
083Ul@8000004P2am_400`000000b_OZ0<[gjP0?0<[gjP030000003Dl^D0e?;U0140e?;U00<00000
0=S]hP3HkN80403HkN82000000030>WYcP000000i>CB00h0i>CB00D000000>CTdP3Ti=80i>CB0000
000F0=oPeP030000003JgMT0f]gI00@0f]gI00<000000=cFd@3Le]403P3Le]400`000000em?E0=OC
e@0G0=OCe@030000003oool0000004P0oooo000h0?ooo`<00000403oool010000000Kb9K06lRF`00
00050>nEDP050000003oool0oooo0?ooo`000000k`3oool3000000P0T>Gk0`000005093Un`@00000
0`20iO4200000180/OKa0P00000A0<[gjP030000003Dl^D0e?;U0140e?;U00<000000=S]hP3HkN80
4`3HkN800`000000i>CB0>CTdP0?0>CTdP030000003Ti=80000001H0gn3F00<000000=[Mf@3JgMT0
1P3JgMT00`000000g=KA0=cFd@0<0=cFd@030000003GdmD0em?E01T0em?E0P0000180?ooo`00>03o
ool00`000000oooo0?ooo`0?0?ooo`050000001_8U/0Kb9K06lRF`0000001P3_UE8200000080oooo
00<000000?ooo`3oool0jP3oool2000000T0T>Gk0P00000<093Un`@000004P2am_400`000000b_OZ
0<[gjP0@0<[gjP030000003Dl^D0e?;U0140e?;U00<000000=S]hP3HkN804`3HkN800`000000enSQ
0000000@0>CTdP8000005P3Oh=H00`000000f]gI0=[Mf@080=[Mf@030000003Le]40g=KA00X0g=KA
00<000000=OCe@3GdmD06@3GdmD010000000d]7H0000000000170?ooo`00>03oool00`000000oooo
0?ooo`0?0?ooo`050000001_8U/0Kb9K06lRF`000000203_UE8010000000oooo0?ooo`00003X0?oo
o`<00000202@iO/3000000d0T>Gk0P0000030:K/n@@000003@2am_400`000000b_OZ0<[gjP0@0<[g
jP030000003Dl^D0e?;U0140e?;U00<000000=S]hP3HkN804`3HkN8010000000enSQ0=OXh@3Gj>42
000000h0i>CB0P00000E0=oPeP030000003JgMT0f]gI00X0f]gI00<000000=cFd@3Le]40203Le]40
0`000000em?E0=OCe@0I0=OCe@060000003BdMP0d]7H0000003oool00000AP3oool003P0oooo00<0
00000?ooo`3oool03`3oool00`000000Kb9K06lRF`0206lRF`030000003_UE80kiEB00H0kiEB00@0
00000?ooo`3oool00000i03oool3000000P0T>Gk0`00000>093Un`8000002@2Vk?T4000000L0/OKa
0P00000B0<[gjP030000003Dl^D0e?;U0140e?;U00<000000=S]hP3HkN804P3HkN82000000H0enSQ
00<000000>CTdP3Ti=802P3Ti=8010000000gn3F0=oPeP00000C0=oPeP030000003JgMT0f]gI00`0
f]gI00<000000=cFd@3Le]401P3Le]400`000000em?E0=OCe@0I0=OCe@030000003BdMP0d]7H0080
d]7H0P0000160?ooo`00=`3oool00`000000oooo0?ooo`0?0?ooo`030000001_8U/0Kb9K00<0Kb9K
00<000000>nEDP3_UE801`3_UE8010000000oooo0?ooo`00003Q0?ooo`800000202@iO/3000000l0
T>Gk0P00000?0:K/n@@000000P2am_400`000000b_OZ0<[gjP0A0<[gjP030000003Dl^D0e?;U0100
e?;U0P00000D0=S]hP030000003Gj>40enSQ00L0enSQ00<000000>CTdP3Ti=80203Ti=800`000000
gn3F0=oPeP020=oPeP030000003Oh=H0gn3F00l0gn3F00<000000=[Mf@3JgMT03P3JgMT00`000000
g=KA0=cFd@040=cFd@030000003GdmD0em?E01P0em?E0P0000060=;Af0800000A@3oool003L0oooo
00<000000?ooo`0000000P00000=0?ooo`030000001_8U/0Kb9K00<0Kb9K00<000000>nEDP3_UE80
203_UE8010000000oooo0?ooo`00003M0?ooo`<000001`2@iO/3000000l0T>Gk0`00000E0:K/n@<0
00004P3:mnX00`000000e?;U0=Cbi@0@0=Cbi@030000003HkN80f>gR01<0f>gR00<000000=OXh@3G
j>402@3Gj>400`000000i>CB0>CTdP060>CTdP030000003Oh=H0gn3F00<0gn3F00<000000=oPeP3O
h=H03P3Oh=H00`000000f]gI0=[Mf@0?0=[Mf@030000003Le]40g=KA00<0g=KA00<000000=OCe@3G
dmD0603GdmD00`000000d]7H0=;Af0060=;Af0<00000A03oool003L0oooo0P00000@0?ooo`030000
001_8U/0Kb9K00<0Kb9K00<000000>nEDP3_UE802@3_UE8010000000oooo0?ooo`00003I0?ooo`<0
00001`2@iO/300000100T>Gk0P00000G0:K/n@8000000P2fk_H3000000d0b_OZ0P00000B0=Cbi@03
0000003HkN80f>gR01<0f>gR00<000000=OXh@3Gj>402`3Gj>400`000000i>CB0>CTdP040>CTdP03
0000003Oh=H0gn3F00D0gn3F00<000000=oPeP3Oh=H0303Oh=H00`000000f]gI0=[Mf@0A0=[Mf@05
0000003Le]40g=KA0=cFd@0000006P3GdmD00`000000d]7H0=;Af0080=;Af0800000A03oool003L0
oooo00<000000?ooo`3oool03P3oool00`000000Kb9K06lRF`0406lRF`030000003_UE80kiEB00X0
kiEB00@000000?ooo`3oool00000eP3oool2000000L0T>Gk0`00000A093Un`8000005`2Vk?T20000
00L0]^kf0P00000:0<[gjP030000003Dl^D0e?;U0140e?;U00<000000=S]hP3HkN804`3HkN800`00
0000enSQ0=OXh@0=0=OXh@8000000`3Ti=800`000000gn3F0=oPeP070=oPeP030000003Oh=H0gn3F
00X0gn3F00<000000=[Mf@3JgMT04`3JgMT00`000000g=KA0000000J0=OCe@030000003BdMP0d]7H
00X0d]7H0P0000130?ooo`00=`3oool00`000000oooo0?ooo`0>0?ooo`030000001_8U/0Kb9K00@0
Kb9K00<000000>nEDP3_UE802`3_UE800`000000oooo0?ooo`0200000=40oooo0`000006093Un`<0
00004P2@iO/2000001L0Y^ci0P00000;0;K^mP<000001P3:mnX00`000000e?;U0=Cbi@0A0=Cbi@03
0000003HkN80f>gR01<0f>gR00<000000=OXh@3Gj>40403Gj>400`000000i>CB0000000:0=oPeP03
0000003Oh=H0gn3F00T0gn3F00<000000=[Mf@3JgMT05@3JgMT00`000000em?E0=OCe@0H0=OCe@03
0000003BdMP0d]7H00/0d]7H00<000000?ooo`000000@P3oool001X0oooo0P0000040?ooo`030000
003oool0oooo0080oooo100000020?ooo`<000002@3oool00`000000oooo0?ooo`0>0?ooo`030000
001_8U/0Kb9K00D0Kb9K00<000000>nEDP3_UE802`3_UE801@000000oooo0?ooo`3oool000000<d0
oooo0`00000309KSo@80000000@0T>Gk00000000000000004`2@iO/2000001L0Y^ci0P00000@0;K^
mP<000000P3:mnX00`000000e?;U0=Cbi@0A0=Cbi@030000003HkN80f>gR0180f>gR0P00000D0=OX
h@030000003Oh=H0gn3F00X0gn3F00<000000=oPeP3Oh=H01`3Oh=H00`000000f]gI0=[Mf@0E0=[M
f@030000003EfM/0000001P0em?E00<000000=;Af03BdMP03@3BdMP200000480oooo000I0?ooo`04
0000003oool0oooo000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00h0oooo00<0000006lRF`1_8U/01P1_8U/00`000000kiEB0>nEDP0;0>nE
DP8000000`3oool00`000000oooo0?ooo`370?ooo`<000001`2Fhod400000140T>Gk0`00000G0:K/
n@8000005@2fk_H300000180e?;U00<000000=S]hP3HkN804P3HkN800`000000enSQ0=OXh@0C0=OX
h@030000003Ei>40000000`0gn3F00<000000=oPeP3Oh=H01@3Oh=H00`000000f]gI0=[Mf@0E0=[M
f@050000003EfM/0eMWK0=GIf`0000005P3GdmD00`000000d]7H0=;Af00?0=;Af0800000@@3oool0
01T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000Kb9K06lRF`0606lRF`030000003_UE80
kiEB00`0kiEB0P0000030?ooo`030000003oool0oooo0<<0oooo0`00000709KSo@<00000102Fhod3
000000`0T>Gk0P00000H0:K/n@8000005P2fk_H200000080`>gb0P00000?0=Cbi@030000003HkN80
f>gR0180f>gR00<000000=OXh@3Gj>404`3Gj>401@000000eNCQ0=GTh@3Ei>40000000`0gn3F00<0
00000=oPeP3Oh=H00`3Oh=H00`000000f]gI0=[Mf@0E0=[Mf@030000003EfM/0eMWK0080eMWK00<0
00000=OCe@3GdmD04P3GdmD200000180d]7H00<000000?ooo`000000@03oool001T0oooo00@00000
0?ooo`3oool000002P3oool010000000oooo0?ooo`3oool3000000P0oooo0`00000=0?ooo`030000
001_8U/0Kb9K00L0Kb9K00<000000>nEDP3_UE80303_UE800`000000jH4`000000030?ooo`030000
003oool0oooo0;l0oooo0`00000709KSo@<000002P2Fhod2000000P0T>Gk0P00000H0:K/n@800000
5P2fk_H2000000H0`>gb0P00000;0=Cbi@800000503HkN800`000000enSQ0=OXh@0C0=OXh@030000
003Ei>40eNCQ00<0eNCQ00<000000=oPeP3Oh=H02@3Oh=H00`000000gn3F0=oPeP020=oPeP030000
003JgMT0f]gI01D0f]gI00<000000=GIf`3EfM/0103EfM/00`000000em?E0=OCe@0@0=OCe@030000
003BdMP0d]7H01<0d]7H0P0000100?ooo`006@3oool010000000oooo0?ooo`00000;0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool03@3oool00`000000Kb9K06lRF`0706lRF`03
0000003_UE80kiEB00`0kiEB00<000000>V1<03YPC000P0000020?ooo`030000003oool0oooo0;`0
oooo0P00000709KSo@<000003`2Fhod3000000<0T>Gk0P00000H0:K/n@8000005P2fk_H2000000X0
`>gb0P0000080=Cbi@030000003HkN80f>gR01<0f>gR00<000000=OXh@3Gj>404P3Gj>42000000L0
eNCQ00<000000=oPeP3Oh=H02@3Oh=H010000000gn3F0=oPeP00000G0=[Mf@030000003EfM/0eMWK
00H0eMWK00<000000=OCe@3GdmD03P3GdmD00`000000d]7H0=;Af00E0=;Af0800000?`3oool001T0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000Kb9K06lRF`0706lRF`030000003_UE80
kiEB00d0kiEB00D000000>V1<03YPC00jH4`000000020?ooo`030000003oool0oooo0;P0oooo0`00
000609KSo@<000005@2Fhod3000001P0Y^ci0P00000G0;K^mP0300000030kO80`>gb00`0`>gb0P00
00050=Cbi@030000003HkN80f>gR0180f>gR0P00000D0=OXh@030000003Ei>40eNCQ00P0eNCQ00<0
00000=oPeP3Oh=H02@3Oh=H2000001H0f]gI0P00000:0=GIf`030000003GdmD0em?E00`0em?E00<0
00000=;Af03BdMP05P3BdMP3000003h0oooo000J0?ooo`8000002P3oool2000000<0oooo10000007
0?ooo`030000003oool0oooo00`0oooo00<0000006lRF`1_8U/0201_8U/00`000000kiEB0>nEDP0=
0>nEDP030000003YPC00jH4`0080jH4`00@000000?ooo`3oool00000]P3oool3000000H0U^?m0`00
000F09KSo@8000000`2Ri_`2000001@0Y^ci0P00000G0;K^mP8000004@30kO8200000080e?;U00<0
00000=S]hP3HkN804P3HkN800`000000enSQ0=OXh@0C0=OXh@030000003Ei>40eNCQ00X0eNCQ0P00
00090=oPeP8000005@3JgMT00`000000eMWK0=GIf`0:0=GIf`030000003GdmD0em?E00/0em?E00<0
00000=;Af03BdMP0603BdMP2000003h0oooo000f0?ooo`030000003oool0oooo00`0oooo00<00000
06lRF`1_8U/02@1_8U/00`000000kiEB0>nEDP0<0>nEDP030000003YPC00jH4`00<0jH4`00@00000
0?ooo`3oool00000/P3oool3000000H0U^?m0`00000F09KSo@<000001`2Ri_`3000000l0Y^ci0P00
000G0;K^mP8000005@30kO82000001@0f>gR00<000000=OXh@3Gj>404`3Gj>400`000000eNCQ0=GT
h@0=0=GTh@030000003Oh=H0gn3F00D0gn3F00<000000=[Mf@000000503JgMT00`000000eMWK0=GI
f`0<0=GIf`030000003GdmD0em?E00T0em?E00<000000=;Af03BdMP0603BdMP010000000c/oJ0000
0000000m0?ooo`00=@3oool00`000000oooo0?ooo`0=0?ooo`030000001_8U/0Kb9K00T0Kb9K00<0
00000>nEDP3_UE803@3_UE800`000000jH4`0>V1<0030>V1<0040000003oool0oooo00000:h0oooo
0`00000609KSo@<000005P2Fhod3000000d0X^Kl0P00000;0:K/n@8000005`2fk_H2000001H0`>gb
0P0000000`36jnl000000000000A0=S]hP030000003Gj>40enSQ01<0enSQ00<000000=GTh@3Ei>40
3`3Ei>400`000000gn3F0=oPeP030=oPeP050000003JgMT0f]gI0=[Mf@0000004P3JgMT00`000000
eMWK0=GIf`0>0=GIf`030000003GdmD0em?E00L0em?E00<000000=;Af03BdMP05`3BdMP200000080
c/oJ00<000000?ooo`000000?03oool003D0oooo0`00000<0?ooo`030000001_8U/0Kb9K00X0Kb9K
00<000000>nEDP3_UE803@3_UE800`000000jH4`0>V1<0040>V1<0040000003oool0oooo00000:X0
oooo0`00000609KSo@<000005`2Fhod200000180X^Kl0`0000060:K/n@800000602fk_H00`000000
`>gb0<3]lP0E0<3]lP0300000036jnl0a^__00<0a^__0P00000>0=S]hP030000003Gj>40enSQ01<0
enSQ00<000000=GTh@3Ei>404@3Ei>401@000000gn3F0=oPeP3Oh=H0000000D0f]gI00<000000=[M
f@3JgMT03P3JgMT00`000000eMWK0=GIf`0@0=GIf`030000003GdmD0em?E00@0em?E0P00000I0=;A
f0030000003>cmX0c/oJ00<0c/oJ0P00000l0?ooo`00=@3oool00`000000oooo0?ooo`0<0?ooo`03
0000001_8U/0Kb9K00X0Kb9K00<000000>nEDP3_UE803@3_UE800`000000jH4`0>V1<0050>V1<004
0000003oool0oooo00000:H0oooo0`00000309WQo@8000000P2Fhod2000001L0U^?m0`00000G0:;V
o08000000P2Vk?T2000001P0]^kf0P00000F0<3]lP8000002036jnl2000000/0f>gR00<000000=OX
h@3Gj>404`3Gj>400`000000eNCQ0=GTh@0C0=GTh@030000003Oh=H0000000L0f]gI00<000000=[M
f@3JgMT0303JgMT00`000000eMWK0=GIf`0B0=GIf`030000003GdmD0em?E0080em?E00<000000=;A
f03BdMP0603BdMP00`000000c/oJ0<k?fP040<k?fP030000003oool0000003/0oooo000e0?ooo`03
0000003oool0oooo00`0oooo00<0000006lRF`1_8U/02P1_8U/00`000000kiEB0>nEDP0>0>nEDP03
0000003YPC00jH4`00D0jH4`0P0000000`3oool000000?ooo`2Q0?ooo`<000001`2IhOd3000001H0
U^?m0`00000L0:;Vo0<000005`2fk_H2000001H0`>gb0P00000<0<K[k`8000001`3HkN82000001@0
enSQ0P00000G0=GTh@030000003JgMT0f]gI00H0f]gI00<000000=[Mf@3JgMT02`3JgMT00`000000
eMWK0=GIf`0C0=GIf`050000003GdmD0em?E0=OCe@0000006P3BdMP00`000000c/oJ0<k?fP060<k?
fP030000003oool0000003X0oooo000e0?ooo`030000003oool0oooo00/0oooo00<0000006lRF`1_
8U/02`1_8U/00`000000kiEB0>nEDP0>0>nEDP030000003YPC00jH4`00L0jH4`00<000000?ooo`00
0000WP3oool3000000L0VN7m0`00000309WQo@8000004P2Fhod2000001d0X^Kl0P0000030:_XnP80
00004`2fk_H2000001L0`>gb00<000000<K[k`36jnl03P36jnl2000000@0f>gR00<000000=OXh@3G
j>404`3Gj>400`000000eNCQ0=GTh@0F0=GTh@030000003Bh>80000000P0f]gI00<000000=[Mf@3J
gMT02@3JgMT00`000000eMWK0=GIf`0E0=GIf`030000003GdmD0000001T0d]7H0P00000:0<k?fP80
0000>P3oool003D0oooo00<000000?ooo`3oool02`3oool00`000000Kb9K06lRF`0<06lRF`030000
003_UE80kiEB00d0kiEB00<000000>V1<03YPC00203YPC0010000000oooo00000000002I0?ooo`<0
00001`2IhOd3000000P0VN7m0`00000<09KSo@<000007@2Ri_`2000000L0ZnSj0`00000?0;K^mP03
00000030kO80`>gb01D0`>gb0P00000C0<K[k`80000000<0f>gR0000003Gj>40503Gj>400`000000
eNCQ0=GTh@0F0=GTh@050000003Bh>80d^3R0=;PhP000000203JgMT00`000000f]gI0=[Mf@070=[M
f@030000003EfM/0eMWK01L0eMWK00<000000=;Af03BdMP05`3BdMP00`000000c/oJ0<k?fP0:0<k?
fP<00000>@3oool003@0oooo00<000000?ooo`3oool0303oool00`000000Kb9K06lRF`0<06lRF`03
0000003_UE80kiEB00d0kiEB00<000000>V1<03YPC002@3YPC0010000000oooo0?ooo`00002F0?oo
o`8000001`2IhOd3000000h0VN7m0P00000709KSo@<000007P2Ri_`2000000`0ZnSj0P00000;0;K^
mP8000005`30kO800`000000a^__0<K[k`0E0<K[k`030000003Gj>40enSQ01<0enSQ00<000000=GT
h@3Ei>405@3Ei>42000000D0d^3R00<000000=[Mf@3JgMT01@3JgMT00`000000f]gI0=[Mf@060=[M
f@030000003EfM/0eMWK01L0eMWK00<000000=7Gg@0000005`3BdMP00`000000c/oJ0<k?fP0<0<k?
fP030000003oool0000003P0oooo000d0?ooo`<000002`3oool00`000000Kb9K06lRF`0=06lRF`03
0000003_UE80kiEB00h0kiEB00<000000>V1<03YPC002@3YPC0010000000oooo0?ooo`00002B0?oo
o`<000001P2IhOd3000001<0VN7m0P00000309KSo@8000007`2Ri_`200000100ZnSj0`0000060;K^
mP8000005`30kO82000001H0a^__0P0000000`38j>d000000=OXh@0B0=OXh@030000003Ei>40eNCQ
01D0eNCQ00<000000=;PhP3Bh>801P3Bh>800`000000f]gI0=[Mf@050=[Mf@030000003JgMT0f]gI
00@0f]gI00<000000=GIf`3EfM/05P3EfM/2000000<0dMOM00<000000=;Af03BdMP04`3BdMP00`00
0000c/oJ0<k?fP0>0<k?fP800000>03oool003@0oooo00<000000?ooo`3oool02`3oool00`000000
Kb9K06lRF`0=06lRF`030000003_UE80kiEB00h0kiEB00<000000>V1<03YPC002@3YPC0200000080
oooo00<000000?ooo`3oool0S03oool3000000H0VN7m0`00000H09WQo@<000007`2Ri_`2000001D0
ZnSj0P0000020;K^mP8000005`30kO82000001L0a^__00<000000<SXk@38j>d00P38j>d200000100
enSQ00<000000=GTh@3Ei>405@3Ei>400`000000d^3R0=;PhP080=;PhP030000003JgMT0f]gI00D0
f]gI00@000000=[Mf@3JgMT0f]gI0P00000H0=GIf`030000003Aemd0dMOM00<0dMOM00<000000=;A
f03BdMP04@3BdMP200000140c/oJ00<000000?ooo`0000002`3oool2000000@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0L0?ooo`00=03oool00`000000oooo0?ooo`0;0?ooo`03
0000001_8U/0Kb9K00d0Kb9K00<000000>nEDP3_UE803P3_UE800`000000jH4`0>V1<00:0>V1<080
00000P3oool00`000000oooo0?ooo`280?ooo`<000001P2IhOd3000001T0VN7m0P00000209kSo@80
00006`2Ri_`3000001T0ZnSj0P00000H0<3]lP0300000036jnl0a^__01D0a^__0P0000070<SXk@03
0000003Gj>40enSQ00`0enSQ00<000000=GTh@3Ei>405@3Ei>400`000000d^3R0=;PhP0:0=;PhP03
0000003JgMT0f]gI00D0f]gI00<000000=[Mf@0000006@3EfM/00`000000dMOM0=7Gg@050=7Gg@03
0000003BdMP0d]7H00l0d]7H00<000000<k?fP3>cmX04P3>cmX00`000000oooo000000090?ooo`04
0000003oool0oooo000000X0oooo00<000000?ooo`3oool0703oool003@0oooo00<000000?ooo`3o
ool02P3oool00`000000Kb9K06lRF`0>06lRF`030000003_UE80kiEB00l0kiEB00<000000>V1<03Y
PC002@3YPC000`000000ef40000000020?ooo`030000003oool0oooo08@0oooo0`00000609WQo@<0
00006@2IhOd3000000H0W^?m0P00000G0:;Vo08000006P2[j?X200000080/^Sh0P00000D0<3]lP80
00005`36jnl00`000000b>S]0<SXk@080<SXk@030000003Gj>40enSQ00X0enSQ00<000000=GTh@3E
i>405@3Ei>400`000000d^3R0=;PhP0<0=;PhP030000003JgMT0f]gI00@0f]gI0P00000I0=GIf`03
0000003Aemd0dMOM00L0dMOM00<000000=;Af03BdMP03@3BdMP00`000000c/oJ0<k?fP0C0<k?fP03
0000003oool0000000T0oooo00@000000?ooo`3oool000001`3oool5000001d0oooo000d0?ooo`03
0000003oool0oooo00X0oooo00<0000006lRF`1_8U/03`1_8U/00`000000kiEB0>nEDP0>0>nEDP03
0000003YPC00jH4`00X0jH4`00<000000=MQ000000000P3oool00`000000oooo0?ooo`200?ooo`<0
00001`2IhOd2000001X0VN7m0P00000;09kSo@8000004`2Ri_`2000001X0ZnSj0P0000060;;Xn080
00004@30kO800`000000a^__0<K[k`0E0<K[k`8000003038j>d2000000P0enSQ0P00000F0=GTh@80
0000403Bh>800`000000f]gI0=[Mf@030=[Mf@8000005`3EfM/2000000/0dMOM00<000000=;Af03B
dMP02`3BdMP00`000000c/oJ0<k?fP0E0<k?fP030000003oool0000000P0oooo00@000000?ooo`3o
ool000001`3oool010000000oooo0?ooo`00000N0?ooo`00=03oool00`000000oooo0?ooo`0:0?oo
o`030000001_8U/0Kb9K00l0Kb9K00<000000>nEDP3_UE803P3_UE800`000000jH4`0>V1<00:0>V1
<0040000003GH@00ef4000000080oooo00<000000?ooo`3oool0O03oool3000000<0VN7m0P000002
09WQo@<000006@2IhOd3000000l0W^?m0P00000?0:;Vo08000006P2[j?X2000000X0/^Sh0P00000=
0<3]lP8000005`36jnl00`000000b>S]0<SXk@0>0<SXk@030000003Gj>40enSQ00@0enSQ00<00000
0=GTh@3Ei>405@3Ei>400`000000d^3R0=;PhP0A0=;PhP050000003JgMT0f]gI0=[Mf@0000000P3E
fM/00`000000eMWK0=GIf`0C0=GIf`030000003Aemd0dMOM00/0dMOM00<000000=;Af03BdMP02@3B
dMP2000001T0c/oJ0P0000080?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`000000
7P3oool003<0oooo0`00000:0?ooo`030000001_8U/0Kb9K0100Kb9K00<000000>nEDP3_UE803`3_
UE800`000000jH4`0>V1<00:0>V1<0040000003GH@00ef4000000080oooo00<000000?ooo`3oool0
N03oool3000000L0VN7m0`00000I09WQo@<00000502Nhod2000000/0X^Kl0P00000J0:_XnP800000
3P2bj?P2000000T0`>gb0P00000G0<K[k`8000004P38j>d00`000000enSQ0=OXh@020=OXh@030000
003Ei>40eNCQ01D0eNCQ00<000000=;PhP3Bh>804`3Bh>800`000000f]gI000000040=GIf`030000
003EfM/0eMWK0140eMWK00<000000=7Gg@3Aemd03@3Aemd00`000000d]7H0=;Af0070=;Af0030000
003>cmX0c/oJ01T0c/oJ00<000000?ooo`0000001`3oool010000000oooo0?ooo`0000090?ooo`80
00007P3oool003<0oooo00<000000?ooo`3oool02P3oool00`000000Kb9K06lRF`0@06lRF`030000
003_UE80kiEB00l0kiEB00<000000>V1<03YPC002P3YPC001@000000ef400=MQ003GH@0000000080
oooo00<000000?ooo`3oool0M03oool3000000L0VN7m0`00000309WQo@8000005@2IhOd2000001T0
W^?m0P0000070:;Vo08000006P2[j?X200000180/^Sh0P0000060<3]lP0300000036jnl0a^__01H0
a^__00<000000<SXk@38j>d04`38j>d2000000030=OXh@000000eNCQ01H0eNCQ00<000000=;PhP3B
h>805@3Bh>800`000000eMWK0=GIf`030=GIf`030000003EfM/0eMWK0100eMWK00<000000=7Gg@3A
emd03`3Aemd00`000000d]7H0=;Af0050=;Af0030000003>cmX0c/oJ01/0c/oJ0`0000070?ooo`80
00002`3oool00`000000oooo0?ooo`0L0?ooo`00<`3oool00`000000oooo0?ooo`0:0?ooo`030000
001_8U/0Kb9K0100Kb9K00<000000>nEDP3_UE803`3_UE800`000000jH4`0>V1<00;0>V1<0040000
003GH@00ef400=MQ0080000000<0oooo0000003oool0L03oool4000000L0VN7m0`00000809WQo@80
0000402IhOd3000001d0W^?m0P0000030:;Vo08000006P2[j?X2000001H0/^Sh0P0000020<3]lP80
00005`36jnl2000001P0b>S]00<000000=GTh@3Ei>405@3Ei>400`000000d^3R0=;PhP0E0=;PhP03
0000003?gN<0000000D0eMWK00<000000=GIf`3EfM/03@3EfM/2000001<0dMOM00<000000=;Af03B
dMP00`3BdMP00`000000c/oJ0<k?fP0J0<k?fP80000000<0b/kL000000000000<`3oool003<0oooo
00<000000?ooo`3oool02@3oool00`000000Kb9K06lRF`0A06lRF`030000003_UE80kiEB0100kiEB
00<000000>V1<03YPC002P3YPC000`000000ef400=MQ00030=MQ00030000003oool0000006d0oooo
0`00000809WQo@<000003@2IhOd2000000`0VN7m0P00000R09kSo@<000006P2[j?X2000001X0/^Sh
0P00000H0<K[k`0300000038j>d0b>S]01H0b>S]0P0000000`39i>/000000000000C0=GTh@800000
5P3Bh>82000000<0cmgS00<000000=GIf`3EfM/00`3EfM/00`000000eMWK0=GIf`0;0=GIf`030000
003Aemd0dMOM01<0dMOM00@000000=;Af03BdMP0d]7H0P00000L0<k?fP070000003:c]`0b/kL0<[>
g0000000oooo0000000b0?ooo`00<`3oool00`000000oooo0?ooo`090?ooo`030000001_8U/0Kb9K
0140Kb9K00<000000>nEDP3_UE80403_UE800`000000jH4`0>V1<00;0>V1<0030000003GH@00ef40
00<0ef4000<000000?ooo`000000J@3oool3000000P0VN7m0`00000B09WQo@8000001`2IhOd30000
0240W^?m0`0000030:CTo08000005P2[j?X2000001/0/^Sh0P0000000`2gioH000000000000D0<K[
k`8000006038j>d00`000000bNC[0<WTj`030<WTj`030000003Ei>40eNCQ00l0eNCQ00<000000=;P
hP3Bh>805@3Bh>800`000000cmgS0<oMh`040<oMh`030000003EfM/0eMWK0080eMWK00<000000=GI
f`3EfM/02P3EfM/00`000000dMOM0=7Gg@0E0=7Gg@030000003BdMP0000001d0c/oJ00<000000<[>
g03:c]`00`3:c]`00`000000oooo0000000a0?ooo`00<`3oool010000000oooo0000000000080?oo
o`030000001_8U/0Kb9K0180Kb9K00<000000>nEDP3_UE803`3_UE800`000000jH4`0>V1<00;0>V1
<0030000003GH@00ef4000@0ef4000@000000?ooo`0000000000I03oool3000000P0VN7m0`00000G
09WQo@8000000`2IhOd200000280W^?m0P0000080:CTo08000004P2[j?X2000001/0/^Sh0P000005
0;OWmP8000004@36jnl00`000000b>S]0<SXk@0F0<SXk@8000001`39i>/2000000h0eNCQ00<00000
0=;PhP3Bh>805@3Bh>800`000000cmgS0<oMh`060<oMh`030000003EfM/0eMWK0080eMWK00<00000
0=GIf`3EfM/0203EfM/00`000000dMOM0=7Gg@0G0=7Gg@030000003>cmX0c/oJ01X0c/oJ0P000007
0<[>g0800000<@3oool00380oooo0`0000090?ooo`030000001_8U/0Kb9K01<0Kb9K00<000000>nE
DP3_UE80403_UE800`000000jH4`0>V1<00;0>V1<0030000003GH@00ef4000@0ef4000@000000?oo
o`3oool00000H03oool3000000P0VN7m0`00000L09WQo@<000008@2Nhod3000000`0Y>Cl0P00000>
0:_XnP8000006`2bj?P2000000T0]nOf00<000000<K[k`36jnl03036jnl2000001P0b>S]00<00000
0<WTj`39i>/02@39i>/00`000000eNCQ0=GTh@0:0=GTh@030000003Bh>80d^3R01@0d^3R0P00000:
0<oMh`030000003EfM/0eMWK0080eMWK00<000000=GIf`3EfM/01@3EfM/2000001T0dMOM00<00000
0<gDg`0000006P3>cmX00`000000b/kL0<[>g0070<[>g0030000003oool000000300oooo000b0?oo
o`030000003oool0oooo00T0oooo00<0000006lRF`1_8U/04`1_8U/00`000000kiEB0>nEDP0@0>nE
DP030000003YPC00jH4`00/0jH4`00<000000=MQ003GH@001@3GH@0010000000oooo0?ooo`00001L
0?ooo`<000002@2IhOd2000001`0VN7m0`00000309_Qo@800000702Nhod300000140Y>Cl0P00000:
0:_XnP8000006`2bj?P2000000`0]nOf0P00000;0<K[k`0300000038j>d0b>S]01H0b>S]0P00000=
0<WTj`030000003Ei>40eNCQ00P0eNCQ00<000000=;PhP3Bh>80503Bh>800`000000cmgS0<oMh`0;
0<oMh`030000003EfM/0eMWK0080eMWK00<000000=GIf`3EfM/00`3EfM/00`000000dMOM0=7Gg@0G
0=7Gg@8000000`3=e=l00`000000c/oJ0<k?fP0F0<k?fP030000003:c]`0b/kL00T0b/kL00<00000
0?ooo`000000;`3oool00380oooo00<000000?ooo`3oool02@3oool00`000000Kb9K06lRF`0C06lR
F`030000003_UE80kiEB0100kiEB00<000000>V1<03YPC00303YPC000`000000ef400=MQ00050=MQ
00040000003oool0oooo000005P0oooo0`00000309WQo@800000102IhOd3000001/0VN7m0`000008
09_Qo@<000005`2Nhod2000001H0Y>Cl0P0000060:_XnP8000006`2bj?P200000100]nOf00<00000
0<K[k`36jnl01P36jnl2000001P0b>S]00<000000<WTj`39i>/03P39i>/2000000H0eNCQ0P00000F
0=;PhP030000003?gN<0cmgS00d0cmgS00D000000=GIf`3EfM/0eMWK000000040=GIf`030000003A
emd0dMOM01L0dMOM00<000000<gDg`3=e=l00`3=e=l00`000000c/oJ0<k?fP0D0<k?fP800000303:
c]`00`000000oooo0000000_0?ooo`00703oool2000000@0oooo00<000000?ooo`3oool00P3oool3
000000P0oooo00<000000?ooo`3oool0203oool00`000000Kb9K06lRF`0D06lRF`030000003_UE80
kiEB0140kiEB00<000000>V1<03YPC002`3YPC000`000000ef400=MQ00060=MQ00040000003oool0
oooo000005D0oooo0P00000809WQo@@000006`2IhOd3000000h0Vn7m0P00000B09kSo@<000006P2T
i?`200000080ZnSj0P00000K0;;Xn08000004`2gioH2000000D0a^__00<000000<SXk@38j>d05P38
j>d2000001<0bNC[00<000000=GTh@3Ei>400P3Ei>400`000000d^3R0=;PhP0D0=;PhP8000004@3?
gN<01@000000eMWK0=GIf`3EfM/000000080eMWK00<000000=7Gg@3Aemd05`3Aemd00`000000cMCO
0<gDg`050<gDg`030000003>cmX0c/oJ0180c/oJ00<000000<[>g03:c]`03@3:c]`3000002h0oooo
000K0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`080?ooo`030000001_8U/0Kb9K01@0Kb9K00<000000>nEDP3_UE804@3_UE800`000000jH4`
0>V1<00<0>V1<0030000003GH@00ef4000H0ef4000@000000?ooo`3oool00000D@3oool3000000P0
VN7m0`0000000`2IhOd000000000000H09WQo@<000004`2KhOd2000000d0W^?m0`00000O0:CTo0<0
00006P2bj?P2000001L0]nOf0P0000000`36jnl000000000000G0<SXk@8000005P39i>/200000003
0=GTh@000000d^3R01D0d^3R00<000000<oMh`3?gN<04P3?gN<010000000eMWK0=GIf`3EfM/20000
01T0dMOM00<000000<gDg`3=e=l01`3=e=l00`000000c/oJ0<k?fP0@0<k?fP030000003:c]`0b/kL
00l0b/kL00<000000?ooo`000000;@3oool001/0oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<0000006lRF`1_8U/05@1_8U/00`00
0000kiEB0>nEDP0@0>nEDP030000003YPC00jH4`00`0jH4`00<000000=MQ003GH@001`3GH@001000
0000oooo0?ooo`00001=0?ooo`<00000202IhOd3000000H0VN7m0`00000B09WQo@<00000602KhOd3
000000P0W^?m0P00000P0:CTo08000000`2Xho/2000001H0/^Sh0P00000K0;OWmP0300000038j>d0
b>S]01H0b>S]00<000000<WTj`39i>/06039i>/00`000000d^3R0=;PhP0D0=;PhP030000003?gN<0
cmgS01@0cmgS00D000000=GIf`000000dMOM0000000G0=7Gg@8000002`3=e=l00`000000c/oJ0<k?
fP0=0<k?fP8000004P3:c]`00`000000oooo0000000]0?ooo`006`3oool010000000oooo0?ooo`00
00080?ooo`<00000203oool3000000L0oooo00<0000006lRF`1_8U/05P1_8U/00`000000kiEB0>nE
DP0A0>nEDP030000003YPC00jH4`00`0jH4`00<000000=MQ003GH@001P3GH@0200000080oooo00<0
00000?ooo`3oool0B03oool2000000P0VN7m0`00000<09WQo@8000003@2IhOd3000001h0Vn7m0P00
000309kSo@<000007`2Ti?`3000000L0Z>?k0P00000B0;;Xn08000006`2gioH2000000030;[Um000
0000000001@0b>S]0P00000I0<WTj`80000000<0b>7[0000003Bh>804P3Bh>82000001P0cmgS00@0
00000=7Gg@3Aemd000005P3Aemd00`000000cMCO0<gDg`0;0<gDg`030000003>cmX0c/oJ00`0c/oJ
00<000000<[>g03:c]`04`3:c]`00`000000oooo0000000/0?ooo`006`3oool010000000oooo0?oo
o`0000080?ooo`030000003oool0oooo00L0oooo0P0000090?ooo`030000001_8U/0Kb9K01H0Kb9K
00<000000>nEDP3_UE804@3_UE800`000000jH4`0>V1<00<0>V1<0030000003GH@00ef4000L0ef40
0P0000020?ooo`030000003oool0oooo04@0oooo0`00000709WQo@<000004@2IhOd2000000P0VN7m
0`00000S09_Qo@<00000802Ti?`2000000`0Z>?k0P00000>0;;Xn08000006`2gioH2000000D0^^Gd
0P00000A0<SXk@0300000039i>/0bNC[01P0bNC[00<000000<SQj`38hN/00P38hN/200000100d^3R
00<000000<oMh`3?gN<05`3?gN<00`000000c=[T000000020=7Gg@030000003Aemd0dMOM0180dMOM
00<000000<gDg`3=e=l03@3=e=l00`000000c/oJ0<k?fP0:0<k?fP030000003:c]`0b/kL01D0b/kL
00<000000?ooo`000000:`3oool001/0oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo00<0000006lRF`1_8U/05P1_8U/00`000000kiEB
0>nEDP0A0>nEDP030000003YPC00jH4`00d0jH4`00<000000=MQ003GH@001`3GH@0200000080oooo
00<000000?ooo`3oool0@03oool3000000L0VN7m0`00000F09WQo@8000000`2IhOd3000002<0Vn7m
0`00000209kQo@800000702Ti?`300000100Z>?k0P00000:0;;Xn08000006`2gioH2000000T0^^Gd
00<000000<SXk@38j>d03038j>d2000001T0bNC[0P0000070<SQj`030000003Bh>80d^3R00`0d^3R
00<000000<oMh`3?gN<05P3?gN<2000000<0c=[T00@000000=7Gg@3Aemd000004@3Aemd200000140
cMCO00<000000<k?fP3>cmX01`3>cmX2000001P0b/kL00<000000?ooo`000000:`3oool001`0oooo
0P0000090?ooo`@000001P3oool00`000000oooo0?ooo`070?ooo`030000001_8U/0Kb9K01L0Kb9K
00<000000>nEDP3_UE804P3_UE800`000000jH4`0>V1<00<0>V1<0030000003GH@00ef4000P0ef40
0P0000020?ooo`030000003oool0oooo03d0oooo0P00000709WQo@<000006`2IhOd3000002@0Vn7m
0P00000709kQo@800000602Ti?`2000001D0Z>?k0P0000060;;Xn08000006`2gioH2000000`0^^Gd
0P00000;0<SXk@0300000039i>/0bNC[01P0bNC[00<000000<SQj`38hN/02038hN/00`000000d^3R
0=;PhP090=;PhP800000603?gN<00`000000c=[T0<cJi0040<cJi0030000003Aemd000000100dMOM
00<000000<gDg`3=e=l04P3=e=l00`000000c/oJ0<k?fP050<k?fP030000003:c]`0b/kL01T0b/kL
00<000000?ooo`000000:P3oool00340oooo00<000000?ooo`3oool01`3oool00`000000Kb9K06lR
F`0G06lRF`030000003_UE80kiEB0180kiEB00<000000>V1<03YPC003@3YPC000`000000ef400=MQ
00070=MQ00030000002c<P0000000080oooo00<000000?ooo`3oool0>@3oool3000000L0VN7m0P00
000K09WQo@<000000`2GhOh2000001l0Vn7m0`00000;09kQo@800000502Ti?`2000001T0Z>?k0P00
00020;;Xn08000006`2gioH200000100^^Gd00<000000<SXk@38j>d01P38j>d2000001T0bNC[0P00
000<0<SQj`030000003Bh>80d^3R00L0d^3R00<000000<oMh`3?gN<05`3?gN<00`000000c=[T0<cJ
i0060<cJi0030000003Aemd0000000h0dMOM00<000000<gDg`3=e=l0503=e=l00`000000c/oJ0<k?
fP030<k?fP030000003:c]`0b/kL01P0b/kL0P0000001037c=h000000?ooo`00000Y0?ooo`00<@3o
ool00`000000oooo0?ooo`070?ooo`030000001_8U/0Kb9K01P0Kb9K00<000000>nEDP3_UE804@3_
UE800`000000jH4`0>V1<00=0>V1<0030000003GH@00ef4000P0ef4000<000000;<b000000000P3o
ool00`000000oooo0?ooo`0e0?ooo`<000001`2IhOd3000001X0VN7m0`00000809OQoP8000006P2K
hOd300000100W^7m0P00000?0:CTo0<000007@2Xho/2000001/0]nOf0P00000C0;[Um08000001@38
j>d00`000000bNC[0<WTj`0H0<WTj`0300000038hN/0b>7[00d0b>7[00<000000=;PhP3Bh>801@3B
h>800`000000cmgS0<oMh`0F0<oMh`8000002P3<f^@00`000000dMOM0000000<0=7Gg@030000003=
e=l0cMCO01D0cMCO00@000000<k?fP3>cmX0c/oJ0P00000J0<[>g00400000037c=h0alcN0<O<gP<0
0000:@3oool00340oooo0`0000060?ooo`030000001_8U/0Kb9K01T0Kb9K00<000000>nEDP3_UE80
4@3_UE800`000000jH4`0>V1<00>0>V1<0030000003GH@00ef4000P0ef4000<000000;<b00000000
0P3oool00`000000oooo0?ooo`0a0?ooo`<000000`2Fhod200000080VN7m0`00000J09WQo@<00000
3@2GhOh2000001H0Vn7m0P00000E09kQo@8000002`2Ti?`2000001h0Z>?k0P0000020:cSn@800000
602gioH00`000000^^Gd0;[Um00E0;[Um080000000<0b>S]0000000000006@39i>/200000140b>7[
0P0000030=;PhP800000603?gN<00`000000c=[T0<cJi00:0<cJi0040000003Aemd0dMOM000000T0
dMOM0P00000I0<gDg`030000003>cmX0000001/0b/kL00<000000<O<gP37c=h00`37c=h00`000000
oooo0000000X0?ooo`00<03oool2000000P0oooo00<0000006lRF`1_8U/06@1_8U/00`000000kiEB
0>nEDP0B0>nEDP030000003YPC00jH4`00d0jH4`00<000000=MQ003GH@002@3GH@000`000000/c80
000000020?ooo`800000;P3oool3000000L0U^?m1000000I09WQo@<000004P2GhOh200000140Vn7m
0`00000I09kQo@8000001P2Ti?`3000001h0Z>?k0P0000060:cSn@800000502gioH2000001X0^^Gd
00<000000<WTj`39i>/05`39i>/2000001D0b>7[00<000000=;PhP0000006@3?gN<00`000000c=[T
0<cJi00<0<cJi0030000003Aemd0000000P0dMOM00<000000<gDg`3=e=l06P3=e=l00`000000b/kL
0<[>g00H0<[>g08000001`37c=h00`000000oooo0000000W0?ooo`00<03oool00`000000oooo0?oo
o`060?ooo`030000001_8U/0Kb9K01X0Kb9K00<000000>nEDP3_UE804P3_UE800`000000jH4`0>V1
<00>0>V1<0030000003GH@00ef4000P0ef4000@000000;<b002c<P0000000`3oool00`000000oooo
0?ooo`0X0?ooo`<000001`2Fhod3000000@0U^?m0P00000D09WQo@<000005`2GhOh2000000`0Vn7m
0`00000N09kQo@8000000P2Ti?`2000001l0Z>?k0P00000:0:cSn@800000402gioH2000001X0^^Gd
0P0000000`2lho8000000000000F0<WTj`0300000038hN/0b>7[01H0b>7[00<000000<oMh`3?gN<0
5P3?gN<200000100c=[T00<000000=7Gg@0000001P3Aemd00`000000cMCO0<gDg`0I0<gDg`800000
00<0bM;P0000003:c]`05`3:c]`00`000000alcN0<O<gP070<O<gP030000003oool0000002L0oooo
000`0?ooo`030000003oool0oooo00H0oooo00<0000006lRF`1_8U/06P1_8U/00`000000kiEB0>nE
DP0B0>nEDP030000003YPC00jH4`00h0jH4`00<000000=MQ003GH@002@3GH@0010000000/c800;<b
000000030?ooo`030000003oool0oooo02@0oooo0`00000709KSo@<000002@2Fhod3000000h0VN7m
0`00000L09OQoP800000202KhOd200000280W^7m0`00000N0:SSn`<000003P2/hoT00`000000]nOf
0;OWmP0;0;OWmP8000006P2jiO@2000000D0_>?b00<000000<WTj`39i>/04@39i>/2000001L0b>7[
0P0000000`36g^X000000<oMh`0E0<oMh`030000003<f^@0c=[T0140c=[T00<000000=7Gg@000000
103Aemd00`000000cMCO0<gDg`0I0<gDg`0500000039d^00bM;P0<WBh00000005P3:c]`2000000/0
alcN00<000000?ooo`0000009P3oool000@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`060?ooo`030000001_8U/0Kb9K01X0Kb9K00<000000>nEDP3_UE804`3_UE800`000000jH4`
0>V1<00>0>V1<0030000003GH@00ef4000T0ef4000@000000;<b002c<P0000000`3oool00`000000
oooo0?ooo`0P0?ooo`<000001`2Fhod3000000l0U^?m0`00000809WQo@<000008@2GhOh2000000<0
Vn7m0`00000R09kQo@8000000P2PhO`2000001/0Z>?k0P00000B0:cSn@8000002@2gioH2000001X0
^^Gd0P0000080;cSlP8000004039i>/00`000000b>7[0<SQj`0F0<SQj`0300000036g^X0a]kZ0080
a]kZ00<000000<oMh`3?gN<04P3?gN<00`000000c=[T0<cJi00C0<cJi0040000003Aemd000000=7G
g@8000006P3=e=l2000000D0bM;P00<000000<[>g03:c]`04P3:c]`00`000000alcN0<O<gP0<0<O<
gP030000003oool0000002D0oooo00030?ooo`030000003oool0000002X0oooo00<000000?ooo`3o
ool01@3oool00`000000Kb9K06lRF`0K06lRF`030000003_UE80kiEB01<0kiEB00<000000>V1<03Y
PC003P3YPC000`000000ef400=MQ000:0=MQ00040000002c<P00/c80000000<0oooo00<000000?oo
o`3oool0703oool3000000L0U^?m0`00000E09KSo@8000000`2IhOd3000002H0Un7n0`00000R09kQ
o@<000001P2PhO`2000001L0Z>?k0P00000F0:cSn@8000001@2gioH2000001X0^^Gd0P00000<0;cS
lP0300000039i>/0bNC[00/0bNC[0P00000G0<SQj`8000001P36g^X00`000000cmgS0<oMh`0?0<oM
h`8000005`3<f^@3000001/0cMCO00<000000<WBh039d^001P39d^000`000000b/kL0<[>g00?0<[>
g08000003`37c=h00`000000oooo0000000U0?ooo`000`3oool00`000000oooo0000000Z0?ooo`03
0000003oool0oooo00D0oooo00<0000006lRF`1_8U/0701_8U/00`000000kiEB0>nEDP0B0>nEDP03
0000003YPC00jH4`00l0jH4`00<000000=MQ003GH@002@3GH@001@000000/c800;<b002c<P000000
00<0oooo00<000000?ooo`3oool0603oool3000000L0U^?m0`00000J09KSo@<000009P2GhOh30000
0080Umon0P00000N09kQo@<000002`2PhO`2000001<0Z>?k0P00000J0:cSn@80000000<0]nOf0000
000000006P2jiO@2000000l0_>?b00<000000<WTj`39i>/02@39i>/00`000000b>7[0<SQj`0F0<SQ
j`0300000036g^X0a]kZ00L0a]kZ00<000000<oMh`3?gN<03@3?gN<00`000000c=[T0<cJi00H0<cJ
i08000006@3=e=l2000000T0bM;P00<000000<[>g03:c]`03P3:c]`00`000000alcN0<O<gP0@0<O<
gP030000003oool0000002@0oooo00030?ooo`030000003oool0000002X0oooo0`0000050?ooo`03
0000001_8U/0Kb9K01`0Kb9K00<000000>nEDP3_UE804`3_UE800`000000jH4`0>V1<00>0>V1<003
0000003GH@00ef4000X0ef4000D000000;<b002c<P00/c80000000030?ooo`030000003oool0oooo
01@0oooo0`00000809KSo@8000006P2Fhod3000000<0TN7n0P00000Q09OQoP<000001`2Ggoh20000
01X0W^7m0P00000@0:3Qo08000003P2Xho/3000001d0[>?i0P00000J0;[Um08000004P2lho820000
00L0bNC[0P00000G0<SQj`8000002`36g^X00`000000cmgS0<oMh`0;0<oMh`030000003<f^@0c=[T
01L0c=[T0P0000000`39en@000000000000G0<gDg`0300000039d^00bM;P00X0bM;P00<000000<[>
g03:c]`0303:c]`00`000000alcN0<O<gP0B0<O<gP<000008`3oool00080oooo00D000000?ooo`3o
ool0oooo0000000X0?ooo`8000001P3oool00`000000Kb9K06lRF`0M06lRF`030000003_UE80kiEB
01<0kiEB00<000000>V1<03YPC003`3YPC000`000000ef400=MQ000:0=MQ00050000002c<P00/c80
0;<b000000000`3oool00`000000oooo0?ooo`0@0?ooo`<00000202Fhod3000001T0U^?m0`000008
097QoP800000702GhOh3000000`0Umon0P00000E09kQo@<00000502PhO`2000000X0Z>?k0P00000N
0:cSn@8000000P2_h_P2000001L0^^Gd00<000000;cSlP2lho80502lho800`000000bNC[0<WTj`03
0<WTj`0300000038hN/0b>7[01H0b>7[00<000000<KNjP36g^X03036g^X00`000000cmgS0<oMh`08
0<oMh`8000006@3<f^@00`000000bMOT0<WGi0020<WGi0800000503=e=l2000000h0bM;P00<00000
0<[>g03:c]`02@3:c]`2000001D0alcN00<000000?ooo`0000008`3oool00080oooo0P0000000`3o
ool000000000000X0?ooo`030000003oool0oooo00D0oooo00<0000006lRF`1_8U/07@1_8U/00`00
0000kiEB0>nEDP0C0>nEDP030000003YPC00jH4`00l0jH4`00<000000=MQ003GH@002`3GH@001@00
0000/c800;<b002c<P00000000<0oooo00<000000?ooo`3oool0303oool3000000<0T>Gk0P000003
09KSo@<000006@2Fhod3000000d0TN7n0P00000G09OQoP<000004@2Ggoh200000140W^7m0P00000I
0:3Qo08000001P2Xho/2000001h0[>?i0P0000060:oRn08000004`2jiO@2000001P0_>?b0P000000
0`39i>/000000000000G0<SQj`8000004036g^X00`000000cmgS0<oMh`060<oMh`030000003<f^@0
c=[T01L0c=[T0P0000050<WGi08000004`3=e=l00`000000bM;P0<WBh00?0<WBh0030000003:c]`0
b/kL00L0b/kL00<000000<O<gP37c=h05P37c=h00`000000oooo0000000R0?ooo`00;`3oool00`00
0000oooo0?ooo`050?ooo`030000001_8U/0Kb9K01d0Kb9K00<000000>nEDP3_UE80503_UE800`00
0000jH4`0>V1<00?0>V1<0030000003GH@00ef4000X0ef4000<000000;<b002c<P000P2c<P001@00
0000oooo0?ooo`3oool0000000/0oooo0P000008093Un`<000006@2Fhod300000180TN7n0P00000B
09OQoP<000005P2Ggoh2000000`0W^7m0`00000M0:3Qo08000000P2Xho/2000001d0[>?i0`00000:
0:oRn0030000002jiO@0^^Gd00h0^^Gd0P00000K0;cSlP8000006038hN/00`000000a]kZ0<KNjP0A
0<KNjP030000003?gN<0cmgS00@0cmgS00<000000<cJi03<f^@05`3<f^@00`000000bMOT0<WGi006
0<WGi08000004@3=e=l00`000000bM;P0<WBh00@0<WBh0030000003:c]`0b/kL00D0b/kL0P00000J
0<O<gP8000008P3oool002l0oooo00<000000?ooo`3oool0103oool00`000000Kb9K06lRF`0N06lR
F`030000003_UE80kiEB01<0kiEB5@00000<0=MQ00030000002c<P00/c800080/c800P0000020?oo
o`030000003oool0oooo00D0oooo0`000007093Un`<000000`2@iO/2000001@0U^?m0`00000G097Q
oP8000003@2GhOh3000001/0Umon0P00000709kQo@<000008@2PhO`3000001d0[>?i0P00000>0:oR
n0800000302jiO@2000001/0_>?b0P0000020;gPl@0300000038hN/0b>7[01@0b>7[00<000000<KN
jP36g^X04`36g^X010000000cmgS0<oMh`3?gN<2000001P0c=[T0P00000:0<WGi08000003P3=e=l2
000001@0bM;P00<000000<[>g03:c]`00`3:c]`00`000000alcN0<O<gP0J0<O<gP030000003oool0
00000240oooo000_0?ooo`030000003oool0oooo00@0oooo00<0000006lRF`1_8U/07`1_8U/00`00
0000kiEB0>nEDP0@0>nEDP8000000P260P000`000000YA/00:DK000?0:DK00D000002@3GH@000`00
0000/c800;<b00030;<b00040000003oool0oooo000000<0oooo0`000007093Un`<00000202@iO/3
000000h0U^?m0`00000L097QoP800000202GhOh300000200Umon0P00000309kQo@8000008@2PhO`3
000000<0X]ol0P00000H0:cSn@<000004P2_h_P00`000000^^Gd0;[Um0070;[Um08000006`2lho82
000000D0_N3a0P00000B0<SQj`8000005`36g^X00`000000cmgS0000000I0<cJi00300000039en@0
bMOT00/0bMOT00<000000<gDg`3=e=l02`3=e=l00`000000bM;P0<WBh00E0<WBh0050000003:c]`0
b/kL0<[>g00000007P37c=h00`000000oooo0000000P0?ooo`00;`3oool3000000@0oooo00<00000
06lRF`1_8U/07`1_8U/00`000000kiEB0>nEDP0>0>nEDP8000001@260P0200000100YA/00P000002
0:4A00<000001`3GH@000`000000/c800;<b00030;<b00030000003oool0oooo00<000001`2@iO/3
000000h0T>Gk0`00000809KSo@<000008@2AhOh2000000<0Un7n0`00000U09OOoP<00000802PhO`3
000000P0X]ol0P00000D0:cSn@8000005P2_h_P2000000D0^^Gd0P00000K0;cSlP8000002@2mh?40
0`000000b>7[0<SQj`0>0<SQj`0300000036g^X0a]kZ01P0a]kZ00<000000<cJi03<f^@05P3<f^@2
000000l0bMOT00<000000<gDg`3=e=l0203=e=l2000001P0bM;P00@000000<[>g000000000007@37
c=h2000000030<C;g`00000000000200oooo000^0?ooo`8000001@3oool00`000000Kb9K06lRF`0P
06lRF`030000003_UE80kiEB00`0kiEB0P00000908H200030000002U6`00YA/000l0YA/000<00000
0:4A002Q4@000P2Q4@04000000<0ef4000<000000;<b002c<P00102c<P03000000H0T>Gk0`00000D
093Un`8000000`2Fhod3000002H0TN7n0`00000U09OOoP<000000`2Fg_h2000001/0X>7l0`00000=
0:;Oo0800000402/hoT2000001X0[n;h0P0000000`2jiO@000000000000K0;cSlP800000302mh?40
0`000000b>7[0<SQj`0;0<SQj`8000006@36g^X2000000030<GKjP000000c=[T01D0c=[T00<00000
0<WGi039en@04039en@00`000000cMCO0<gDg`060<gDg`0300000039d^00bM;P01T0bM;P00<00000
0<O<gP37c=h06`37c=h2000000<0a<_O00<000000?ooo`0000007`3oool002h0oooo00<000000?oo
o`3oool0103oool00`000000Kb9K06lRF`0P06lRF`030000003_UE80kiEB00X0kiEB0P00000<08H2
00030000002U6`00YA/000l0YA/000<000000:4A002Q4@001@2Q4@0500000080/c800`000006093U
n`<000006@2@iO/3000002D0TN7n1000000308cNoP8000007`2Ggoh4000000P0U]kn0P00000F0:3Q
o0<000004P2Rgo`2000000/0[>?i0`00000M0:oRn08000006`2lho82000000l0_N3a0P00000:0<SQ
j`0300000036g^X0a]kZ01L0a]kZ0P0000040<GKjP030000003<f^@0c=[T0180c=[T00<000000<WG
i039en@04@39en@2000000D0cMCO0P00000J0<WBh080000000<0a]3R00000037c=h06P37c=h00`00
0000a<_O0<C;g`040<C;g`<000007P3oool002h0oooo00<000000?ooo`3oool0103oool00`000000
Kb9K06lRF`0P06lRF`030000003_UE80kiEB00P0kiEB0P00000?08H200030000002U6`00YA/000l0
YA/000<000000:4A002Q4@00202Q4@03000000L0T>Gk0P00000H093Un`@000000`23go/3000001h0
TN7n1000000908cNoP<000006@2Ggoh3000000h0U]kn0P00000B0:3Qo08000005`2Rgo`2000000L0
[>?i0P00000N0:oRn08000000P2ah?L2000001L0_>?b0P00000C0;gPl@0300000038hN/0b>7[00D0
b>7[0P00000I0<KNjP0300000035fnX0aM_Z00D0aM_Z00<000000<cJi03<f^@03`3<f^@2000001D0
bMOT00<000000<gDg`3=e=l00P3=e=l00`000000bM;P0<WBh00I0<WBh00300000036d>80a]3R0080
a]3R00<000000<O<gP37c=h05P37c=h2000000P0a<_O0P00000N0?ooo`00;P3oool00`000000oooo
0?ooo`030?ooo`030000001_8U/0Kb9K0240Kb9K00<000000>nEDP3_UE801P3_UE8200000180QP80
0P00000@0:DK008000001P2Q4@03000000H0T>Gk0`00000G093Un`<000002P23go/3000001L0TN7n
1000000@08cNoP800000502Ggoh3000001<0U]kn0P00000=0:3Qo0<000006`2Rgo`2000000<0[>?i
0P00000N0:oRn08000001P2ah?L2000001<0_>?b0P00000F0;gPl@0300000038hN/0b>7[00<0b>7[
00<000000<KNjP36g^X05`36g^X2000000T0aM_Z00<000000<cJi03<f^@03@3<f^@00`000000bMOT
0<WGi00F0<WGi0040000003=e=l00000000001X0bM;P0P0000050<K@hP0300000037c=h0alcN01D0
alcN00<000000<C;g`34bml02034bml00`000000oooo0000000;0?ooo`800000103oool00`000000
oooo0?ooo`020?ooo`<00000103oool002h0oooo00<000000?ooo`3oool00`3oool00`000000Kb9K
06lRF`0R06lRF`030000003_UE80kiEB00<0kiEB0P00000F08H200030000002U6`00YA/000l0YA/0
00<000000:4A002Q4@0010000005093Un`<000005P2@iO/400000100Pmok0`00000A097QoP<00000
5P2<g_h2000000l0Umon0`00000H09KNoP800000202PhO`300000200X]ol0`00000N0:oRn0800000
2P2ah?L00`000000_>?b0;cSlP0>0;cSlP8000006@2mh?42000000030<SQj`000000000001T0a]kZ
00<000000<GKjP35fnX02P35fnX2000000/0c=[T0P00000J0<WGi00300000039d^00bM;P01T0bM;P
00<000000<K@hP36d>801P36d>800`000000alcN0<O<gP0B0<O<gP8000003034bml00`000000oooo
000000090?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00@3oool002h0oooo
100000020?ooo`030000001_8U/0Kb9K0280Kb9K00@000000>nEDP3_UE80kiEB0P00000I08H20003
0000002U6`00YA/000h0YA/00`000004083Ul@D000005@2@iO/4000001L0Pmok0`00000:097QoP@0
00006`2<g_h3000000P0Umon1000000M09KNoP8000000`2PhO`300000240X]ol0P0000020:CNn`80
00006P2_h_P3000000d0/N3g0P00000<0;cSlP8000007@2mh?400`000000a]kZ0<KNjP0G0<KNjP80
00003`35fnX00`000000c=[T0<cJi0070<cJi00300000039en@0bMOT01P0bMOT0P0000000`36e>D0
00000<WBh00G0<WBh08000002P36d>800`000000alcN0<O<gP0?0<O<gP8000003`34bml2000000T0
oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`010?ooo`00;@3oool2000000@0
oooo00<0000006lRF`1_8U/08`1_8U/010000000kiEB00000000000L08H200030000002U6`00YA/0
00X0YA/00`000006083Ul@<000000`20iO45000000d0T>Gk0`00000N08?On`<000000`2AhOh40000
0280S=kn0P00000309OOoP<000008`2Fg_h300000240X]ol0`0000060:CNn`8000005P2_h_P20000
0180/N3g00<000000;cSlP2lho801`2lho82000001d0_N3a0P0000000`2mgO0000000<KNjP0E0<KN
jP8000004P35fnX00`000000c=[T0<cJi0040<cJi08000006P39en@010000000a]CU0<KDi@36e>D2
000001H0bM;P00<000000<K@hP36d>802`36d>800`000000alcN0<O<gP0=0<O<gP0300000034bml0
a<_O0100a<_O0P0000080?ooo`040000003oool0oooo000000P0oooo0`0000040?ooo`00;@3oool0
0`000000oooo0?ooo`030?ooo`030000001_8U/0Kb9K02<0Kb9K0P00000O08H200030000002U6`00
YA/000H0YA/00`000006083Ul@<000002`20iO45000000@0T>Gk1000000S08?On`@000009`2<g_h4
000002<0U]kn0`00000209OLoP8000007@2Rgo`3000000/0Y=kk0P00000B0:oRn08000005@2ah?L2
000000D0_>?b0P00000M0;gPl@800000102mgO02000001<0a]kZ00<000000<GKjP35fnX04`35fnX0
0`000000c=[T0<cJi0020<cJi00300000039en@0bMOT01P0bMOT0P0000050<KDi@0300000039d^00
bM;P0180bM;P0P00000>0<K@hP0300000037c=h0alcN00/0alcN0P00000C0<C;g`030000003oool0
000000L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`040?ooo`00;@3oool0
0`000000oooo0?ooo`030?ooo`030000001_8U/0Kb9K0280Kb9K00<0000002D0000U00000P00000N
08H2008000000`2U6`03000000H0P>Ga0`00000C083Ul@@000008`23go/4000000@0N=Wl0`00000P
08cNoP@000001029fol2000001h0U]kn0`00000709OLoP8000006@2Rgo`200000100Y=kk00<00000
0:oRn02_h_P0302_h_P3000001T0/N3g0P0000000`2lho8000000000000M0;gPl@800000202mgO00
0`000000a]kZ0<KNjP0>0<KNjP8000005`35fnX010000000c=[T00000000000J0<WGi00300000036
e>D0a]CU00H0a]CU00<000000<WBh039d^004039d^000`000000a]3R0<K@hP0?0<K@hP0300000037
c=h0alcN00T0alcN00<000000<C;g`34bml05034bml2000000L0oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`040?ooo`004@3oool2000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`<00000203oool00`000000oooo0?ooo`020?ooo`030000001_
8U/0Kb9K0280Kb9K00<0000002D0000U00000`0U0003000001d0QP800`000006083Ul@<000004P20
iO44000000@0HmK^1000000K08?On`@000002`1hfO`3000001T0S=kn1000000:08WKo`8000006@2F
g_h3000000`0Umcn0P00000D0:;Oo0<000004`2Tg_/2000000X0[n;h0P00000M0;7Pm`8000007@2m
h?42000000/0_Mg`00<000000<KNjP36g^X03036g^X00`000000aM_Z0<GKjP0H0<GKjP0300000039
en@0bMOT01P0bMOT0P0000090<KDi@8000003`39d^02000001<0a]3R00<000000<O<gP37c=h01P37
c=h2000001P0a<_O0P0000070?ooo`8000002@3oool4000000<0oooo000@0?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00<0000006lRF`1_8U/08@1_8U/00`0000009@0002D0000702D0008000006@26
0P03000000D0P>Ga0`00000A083Ul@@00000301Se^h3000001@0Pmok1000000B07SIo08000004P2<
g_h500000100RM_o0P00000C09KNoP@000004@2Gg?h200000100X]ol0P00000H0:CNn`8000001P2_
h_P2000001d0/N3g0P0000020;;NmP8000006@2mh?42000000h0_Mg`0P00000:0<KNjP8000006@35
fnX2000000030<?HjP000000bMOT01L0bMOT00<000000<KDi@36e>D02P36e>D2000000d0bM;P00<0
00000<K@hP36d>805036d>800`000000alcN0<O<gP030<O<gP8000006P34bml2000001T0oooo000@
0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00<0000006lRF`1_8U/0801_8U/00`0000009@0002D0
000:02D00080000050260P03000000H0P>Ga0P00000?083Ul@D000004`1Se^h4000000`0Pmok1000
000H07SIo0<000002`2<g_h4000001L0RM_o0`00000=09KNoP<000005`2Gg?h2000000/0X]ol0`00
000L0:CNn`8000000P2_h_P2000001d0/N3g0P0000060;;NmP030000002mh?40_N3a01@0_N3a0P00
000B0;gMl00300000036g^X0a]kZ00D0a]kZ0P00000I0<GKjP8000001033f>X00`000000bMOT0<WG
i00C0<WGi08000003P36e>D2000000X0bM;P0P00000G0<K@hP0300000037c=h0alcN0080alcN00<0
00000<C;g`34bml06`34bml00`000000oooo0?ooo`0G0?ooo`00403oool010000000oooo0?ooo`00
000:0?ooo`040000003oool0oooo0?ooo`<00000203oool3000000030?ooo`000000Kb9K0240Kb9K
00<0000002D0000U00003@0U0003000000h0QP800`000006083Ul@<000003@20iO44000001`0HmK^
1000000408?On`@000007`1hfO`3000000@0S=kn1000000N08WKo`800000202Fg_h3000001`0Umcn
0P0000060:;Oo0<00000802Tg_/3000001d0/N3g0P0000090;;NmP8000004P2mh?42000001D0_Mg`
00<000000<KNjP36g^X00`36g^X00`000000aM_Z0<GKjP0H0<GKjP0300000033f>X0`mSZ00D0`mSZ
00<000000<WGi039en@04@39en@00`000000a]CU0<KDi@0?0<KDi@8000002039d^000`000000a]3R
0<K@hP0H0<K@hP0400000037c=h00000000001`0a<_O0`00000I0?ooo`00403oool010000000oooo
0?ooo`00000;0?ooo`040000003oool0oooo000000T0oooo0P0000030?ooo`030000001_8U/0Kb9K
01l0Kb9K00<0000002D0000U00004@0U0002000000T0QP803000000<083Ul@@000008@1Se^h70000
02D0N=Wl1@00000T08WKo`8000000`2Fg_h300000240Umcn0P0000020:;Oo08000008@2Tg_/20000
0080YMgk0P00000J0;7Pm`8000003@2bg_H00`000000_N3a0;gPl@0=0;gPl@800000602mgO020000
00030<KNjP000000000001T0aM_Z0P0000090<?HjP0300000039en@0bMOT00h0bMOT0P00000B0<KD
i@8000001P39d^02000001`0a]3R00<000000<C;g`34bml06P34bml2000000<0oooo00<000000?oo
o`3oool05P3oool00100oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000Kb9K06lRF`0N
06lRF`030000000U00009@0001@09@000`00000308H200<000001P1?c<8300000080Clc23`00000K
06?FkPP000001P1;a^/4000001d0N=Wl1@000004077Co08000009029fol4000002D0Umcn0`00000P
0:CNn`<000001P2UgO/00`000000/N3g0;7Pm`0E0;7Pm`800000402bg_H00`000000_N3a0;gPl@0:
0;gPl@800000702mgO000`000000aM_Z0<GKjP0H0<GKjP0300000033f>X0`mSZ00X0`mSZ00<00000
0<WGi039en@03039en@00`000000a]CU0<KDi@0C0<KDi@8000001039d^000`000000a]3R0<K@hP0J
0<K@hP80000000<0`lkS00000034bml06@34bml00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01H0oooo000A0?ooo`8000002@3oool400000080oooo100000060?ooo`050000003oool0oooo
0?ooo`000000801_8U/00`0000009@0002D0000H02D000<000001P1?c<8<000000P0oooo3@000009
06?FkPP000004P1;a^/3000001D0N=Wl1@00000;077Co08000007P29fol4000000@0QmSo0P00000O
09OLoP@000000P2Hfoh2000001`0Y=kk0`00000:0:GMn`8000004`2ah?L2000001<0/]kf0P000008
0;gPl@800000702mgO02000000030;cKk`000000aM_Z01H0aM_Z0P00000>0<?HjP0300000039en@0
bMOT00T0bMOT0P00000G0<KDi@80000000<0bM;P0000000000006`36d>82000000<0`lkS00<00000
0<C;g`34bml05P34bml2000000H0oooo00<000000?ooo`3oool05P3oool002`0oooo00D000000?oo
o`3oool0oooo0000000O06lRF`030000000U00009@0001L09@000`0000000`1?c<80000000000005
00000200oooo2P00000M04_6j`<000003@1hfO`500000180LM?l0P00000H08WKo`@000002P27f?l2
000001X0Umcn0`00000809SKoP800000602Tg_/2000000l0YMgk00<000000;7Pm`2ah?L03P2ah?L2
000001L0/]kf00<000000;gPl@2mh?400`2mh?42000001`0_Mg`0P0000040;cKk`0300000035fnX0
aM_Z0180aM_Z0P00000A0<?HjP0300000039en@0bMOT00L0bMOT00<000000<KDi@36e>D06036e>D2
000001`0a]3R00<000000<?>h`33c^<01033c^<00`000000a<_O0<C;g`0D0<C;g`030000003oool0
oooo00H0oooo00<000000?ooo`3oool05P3oool002`0oooo00D000000?ooo`3oool0oooo0000000N
06lRF`030000000U00009@0001D09@001`000000103oool0000000000000000[0?ooo`H00000701;
a^/4000000@0N=Wl1@00000I077Co0<000004029fol500000100QmSo0P00000D09OLoP@000003@2H
foh2000001<0Y=kk0`00000B0:GMn`030000002ah?L0/N3g00/0/N3g0P00000J0;;NmP80000000<0
_N3a000000000000702mgO02000000L0_=__00<000000<GKjP35fnX04035fnX00`000000`mSZ0<?H
jP0B0<?HjP0300000039en@0bMOT00@0bMOT0P00000J0<KDi@80000000<0`m;U00000036d>806036
d>82000000P0`lkS00<000000<C;g`34bml04@34bml2000000T0oooo00<000000?ooo`3oool05P3o
ool002`0oooo0P0000000`3oool0000006lRF`0L06lRF`8000005@0U000600000080oooo0`00000d
0?ooo`H000003`1;a^/?00000240LM?l0P00000:08WKo`@000005`27f?l2000000h0Umcn1000000C
09SKoP030000002Tg_/0Y=kk00h0Y=kk0P00000F0:GMn`8000002@2ah?L2000001d0/]kf0P00000L
0;gMl08000002P2lfnl00`000000aM_Z0<GKjP0=0<GKjP8000005P33f>X00`000000bMOT0<WGi002
0<WGi00300000036e>D0a]CU01P0a]CU0P0000020<?Bi@0300000033d^D0000001L0a]3R00<00000
0<?>h`33c^<02033c^<00`000000a<_O0<C;g`0?0<C;g`8000002`3oool00`000000oooo0?ooo`0F
0?ooo`00:`3oool200000080oooo00<0000006lRF`1_8U/06P1_8U/00`0000009@0002D0000B02D0
00H000000P3oool3000003d0oooo3`00000>03jkk0@00000801ado`2000000@0RM_o1000000M08OH
o`8000002@2Gg?h3000001P0V=_n0P00000;0:CNn`<000006P2UgO/00`000000/N3g0;7Pm`040;7P
m`8000007@2bg_H200000080/]ce00<000000;gMl02mgO005`2mgO02000000d0_=__0P00000<0<GK
jP0300000033f>X0`mSZ01L0`mSZ00@000000<WGi000000000006@36e>D2000000D0`m;U0P00000E
0<K@hP8000003033c^<00`000000a<_O0<C;g`0=0<C;g`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool05P3oool002/0oooo00D000000?ooo`3oool0oooo0000000K06lRF`030000000U0000
9@0001409@00100000040?ooo`800000A03oool6000001L0?[_/0`00000L077Co0L000008`27f?l2
000000<0Umcn1000000M09SKoP8000001P2Tg_/3000001h0YMgk0P0000020;7Pm`8000007@2bg_H2
000000D0/]ce0P00000E0;gMl08000004@2lfnl00`000000aM_Z0<GKjP070<GKjP8000006`33f>X0
0`000000a]CU0<KDi@0H0<KDi@0300000033d^D0`m;U00D0`m;U00<000000<?Bi@0000004P36d>82
000000l0`lkS00<000000<C;g`34bml02P34bml2000000l0oooo00<000000?ooo`3oool05@3oool0
02/0oooo00@000000?ooo`3oool000006`1_8U/00`0000009@0002D0000?02D000@00000103oool3
000004L0oooo2@00000F03jkk0<000004@1ado`8000000H0KLom0P00000S08OHo`@000008`2Hfoh2
00000080Y=kk0P00000R0:GMn`<000007@2bg_H2000000T0/]ce00<000000;gMl02mgO00402mgO02
000001@0_=__00<000000<GKjP35fnX01035fnX2000001/0`mSZ0P0000000`31e^X000000<KDi@0F
0<KDi@8000002@33d^D00`000000`m;U0000000@0<K@hP0300000033c^<0`lkS0100`lkS00<00000
0<C;g`34bml02034bml00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01D0oooo000[0?oo
o`040000003oool0oooo000001X0Kb9K00<0000002D0000U00003@0U0003000000D0oooo0`00001;
0?ooo`0300000000HMD0000000@0000000<007:n0000000000000P00000E03jkk0@000001@1ado`8
00000100KLom0`00000K08OHo`D000000`27e_l2000002<0V=_n0`00000Q0:GMn`<000000P2WfoX2
000001T0/]kf0`00000<0;;Lm@030000002mgO00_Mg`00d0_Mg`0P00000G0;cKk`0300000035fnX0
aM_Z0080aM_Z00<000000<?HjP33f>X06@33f>X2000000@0`MKZ00<000000<KDi@36e>D04P36e>D2
000000`0`m;U00<000000<?Bi@0000003@36d>82000001<0`lkS00<000000<C;g`34bml01P34bml2
00000180oooo00<000000?ooo`3oool05@3oool002/0oooo00<000000?ooo`0000006P1_8U/00`00
00009@0002D0000;02D000<000001@3oool3000004l0oooo00<00000001Qe@00HMD01P000002001b
_Qh000006`1]cod3000001<0QmSo1@00000:08OFo`8000007@2Hfoh400000080VMWm0P00000M0:GM
n`<000001`2WfoX2000001D0/]kf0P00000@0;;Lm@8000002`2mgO02000001X0_=__00@000000<GK
jP00000000006P33f>X2000000L0`MKZ00<000000<KDi@36e>D04036e>D00`000000`m;U0<?Bi@0=
0<?Bi@0300000033d^D0000000/0a]3R00<000000<?>h`33c^<05033c^<00`000000a<_O0<C;g`03
0<C;g`800000503oool00`000000oooo0?ooo`0E0?ooo`00:`3oool00`000000oooo0000000I06lR
F`030000000U00009@0000T09@000`0000050?ooo`<00000D`3oool020000000067E001Qe@00HMD0
0000000j]@00000005W410000002001b_P8000005P0k]Nl2000001h0KLom0P00000<08OHo`D00000
4@27e_l2000001P0V=_n0`00000809WIo@800000602UgO/3000000`0Ym_j00<000000;;NmP2bg_H0
402bg_H2000001@0/]ce00<000000;gMl02mgO001P2mgO02000001`0_=__0P00000J0<?HjP800000
2P31e^X00`000000a]CU0<KDi@0=0<KDi@8000004033d^D010000000`m;U0<?Bi@0000080<K@hP80
00006033c^<01@000000a<_O0<C;g`34bml0000001H0oooo00<000000?ooo`3oool05@3oool002/0
oooo0`00000H06lRF`030000000U00009@0000L09@000`0000050?ooo`<00000E`3oool010000000
067E001Qe@00HMD400000003001Ia0000000000000L000005@0k]Nl3000001d0KLom0`00000408OH
o`D000006027e_l00`000000V=_n09SKoP0A09SKoP@000003@2IfOd200000180YMgk1000000@0:OK
nP8000003@2bg_H3000001L0/]ce00<000000;gMl02mgO000`2mgO02000001`0_=__0P0000020;_H
k`0300000033f>X0`mSZ01D0`mSZ0P00000=0<7FjP0300000036e>D0a]CU00X0a]CU0P00000C0<?B
i@0300000033d^D0000000H0a]3R0P00000J0<?>h`0400000034bml00000000001L0oooo00<00000
0?ooo`3oool05@3oool002X0oooo00<000000?ooo`000000601_8U/00`0000009@0002D0000402D0
00@000001@3oool3000005/0oooo00<00000001Qe@00HMD00P00HMD30000008005W40P000002001o
d`H000005@0k]Nl3000001X0KLom1`00000N08OFo`8000003@2Hfoh4000001<0VMWm0P00000=0:GM
n`<000005P2WfoX00`000000/]kf0;;NmP080;;NmP8000006`2bg?D2000000030;gMl00000000000
01`0_=__0P0000050;_Hk`8000004`33f>X200000100`MKZ00<000000<KDi@36e>D01`36e>D20000
01H0`m;U00<000000<?Bi@0000001036d>800`000000`lkS0<?>h`0K0<?>h`030000003oool0oooo
01L0oooo00<000000?ooo`3oool05@3oool002X0oooo00<000000?ooo`0000005`1_8U/00`000000
9@0002D0000202D000<000001P3oool3000005l0oooo00<00000001Qe@00HMD00`00HMD300000080
05W40`000002001od`D000005P0k]Nl200000100KLom2000000506g;oP8000008027e_l2000000P0
V=_n0`00000I09WIo@800000202UgO/3000001X0Ym_j0P0000060;;NmP8000007P2bg?D2000001`0
_=__0P0000090;_Hk`0300000033f>X0`mSZ00l0`mSZ00<000000<7FjP31e^X04@31e^X00`000000
a]CU0<KDi@050<KDi@0300000033d^D0`m;U01L0`m;U00@000000<?Bi@000000a]3R0P00000L0<?>
h`8000006P3oool00`000000oooo0?ooo`0E0?ooo`00:P3oool00`000000oooo0000000F06lRF`03
0000000U00009@0000<000001P3oool3000006<0oooo00<00000001Qe@00HMD01000HMD2000000@0
05W40P000004001od`@000005@0k]Nl3000000D0KLom2000000?06g;oP8000008027e_l200000080
V=_n1000000N09WIo@8000000`2UgO/3000001l0Ym_j0P0000020;;NmP8000007P2bg?D200000080
/]Wd00<000000;cKk`2lfnl05`2lfnl2000000`0^mS_00<000000<?HjP33f>X03033f>X2000001D0
`MKZ00<000000<KDi@36e>D00P36e>D2000001X0`m;U00@000000<?Bi@33d^D000007033c^<20000
01d0oooo00<000000?ooo`3oool0503oool002X0oooo0P00000F06lRF`@000001`3oool2000006L0
oooo00<00000001Qe@00HMD01@00HMD2000000@005W40P000006001odad000006@1]boh2000001h0
QmKo1000000T09WIo@<000008`2WfoX3000001d0/]ce0`0000050;;Im08000005@2lfnl2000000l0
^mS_00<000000<?HjP33f>X02@33f>X2000001P0`MKZ00@000000<KDi@00000000007@33d^D20000
00030<7@iP000000`lkS01P0`lkS0P00000O0?ooo`030000003oool0oooo01@0oooo000Z0?ooo`80
0000501_8U/3000000L0oooo0`00001Z0?ooo`0300000000HMD0067E00H0067E0P000004001Ia0@0
00001@00Om<2000001H0?k?d0P00000K06g;oP8000005`27e_l5000000<0R=?o0P00000O09WIo@@0
00000P2Jeod2000001l0Ym_j0`0000020:OIn@8000006P2bg?D2000000X0/]Wd00<000000;cKk`2l
fnl0402lfnl200000180^mS_00<000000<?HjP33f>X01P33f>X2000001/0`MKZ00<000000<?Bi@33
d^D06`33d^D2000000050<7@iP000000`M3V0<7@iP0000005`33c^<00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo01@0oooo000Z0?ooo`8000004@1_8U/3000000L0oooo0`00001^0?ooo`03
00000000HMD0067E00H0067E10000003001Ia0H000000`00Om<3000001D0?k?d0P00000K06g;oP80
00004027e_l5000000X0R=?o0P00000J09WIo@<00000202Jeod00`000000Ym_j0:OKnP0J0:OKnP80
00001`2WfOT00`000000/]ce0;;Lm@0D0;;Lm@<000003@2bfO@00`000000_=__0;cKk`0=0;cKk`80
00005@2kf>l2000000@0`mSZ0P00000K0<7FjP80000000<0_]?Z00000033d^D06@33d^D2000000@0
`M3V00@000000<7@iP31d>H000005033c^<200000280oooo00<000000?ooo`3oool0503oool002T0
oooo0P00000@06lRF`8000001`3oool300000780oooo00<00000001Qe@00HMD01`00HMD010000000
0GKN000000000003001Ia08000000P0?SN@40000008007oC0`00000D03ncm08000006`1]boh20000
00X0QmKo1000000A08SCo`800000502IfOd4000000`0V]Om0P00000G0:OKnP<000002P2WfOT20000
0180/]ce0P00000A0;;Im0030000002lfnl0_=__00X0_=__0P00000I0;_Hk`0400000033f>X00000
000001/0`MKZ0P0000040;kCjP0300000033d^D0`m;U01D0`m;U0P0000060<7@iP0500000031d>H0
`M3V0<7@iP0000004@33c^<2000002@0oooo00<000000?ooo`3oool0503oool002T0oooo0P00000=
06lRF`<000001P3oool3000007H0oooo0P000008001Qe@0300000001M]h00GKN00<000000P00FL@2
000000@03hgT1`00000D03ncm08000006`1]boh2000000<0QmKo1@00000G08SCo`8000003P2IfOd4
00000180V]Om00<000000:OKnP2WfoX04@2WfoX3000000l0YmWi00<000000;;Lm@2bg?D0302bg?D3
000001@0/]Wd00<000000;cKk`2lfnl01`2lfnl2000001/0^mS_0P00000K0<7FjP8000001`2ndnX0
0`000000`m;U0<?Bi@0B0<?Bi@8000002@31d>H01@000000`M3V0<7@iP31d>H0000000h0`lkS0P00
000V0?ooo`030000003oool0oooo01@0oooo000Y0?ooo`8000002P1_8U/3000000H0oooo0`00001j
0?ooo`<000001`00HMD2000000<00GKN0`0000000`00FL@000000000000700n=i0D000004`0o/o@2
000001D0KL_n2@00000N08SCo`8000002@2IfOd3000001L0V]Om00<000000:OKnP2WfoX03@2WfoX3
000001<0YmWi0P00000:0;;Lm@800000602bfO@2000000D0_=__0P00000K0;_Hk`8000000P2je^h0
0`000000`MKZ0<7FjP0F0<7FjP8000002P2ndnX00`000000`m;U0<?Bi@0?0<?Bi@8000003031d>H0
10000000`M3V0<7@iP00000<0<?>h`800000:03oool00`000000oooo0?ooo`0D0?ooo`00:@3oool0
0`000000Kb9K06lRF`0606lRF`<000001P3oool3000007h0oooo00<0000001eliP0000000P000006
001Qe@0300000001M]h00GKN00<00GKN1@00000900n=i0h00000200o/o@2000000L0KL_n30000007
06o9o`8000008028dol2000000<0VMWm1000000K09[Go@8000002P2WfoX3000001P0YmWi00<00000
0;;Lm@2bg?D0102bg?D3000001`0/]Wd00<000000;cKk`2lfnl00P00000K0;_Hk`8000001@2je^h0
0`000000`MKZ0<7FjP0C0<7FjP8000003@2ndnX00`000000`m;U0<?Bi@0=0<?Bi@0300000031d>H0
`M3V00`0`M3V00D000000<7@iP31d>H0`M3V0000000:0<?>h`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool04`3oool002T0oooo00<0000006lRF`1_8U/00`1_8U/3000000H0oooo0`000022
0?ooo`040000000MO>H07GcV01eliP<000001000HMD00`0000000GKN005fgP05005fgP@000002`0?
SN@2000000P0B;Ch4@00000E06o9o`8000007`28dol400000240V]Om00<000000:OKnP2WfoX01@2W
foX2000001`0YmWi0P0000020;;Lm@8000007`2bfO@3000001/0^mS_0P0000080;[FkP0300000031
e^X0`MKZ0100`MKZ0P00000?0;kCjP0300000033d^D0`m;U00/0`m;U0P00000@0<7@iP0500000031
d>H0`M3V0<7@iP0000001`33c^<2000002`0oooo00<000000?ooo`3oool04`3oool002T0oooo00@0
000006lRF`1_8U/0Kb9K0P0000060?ooo`<00000QP3oool00`0000007GcV01eliP0301eliP800000
0`00HMD2000000L00GKN1000000;00n=i08000004`18]?P2000001T0KlWo0P00000H08SCo`D00000
0`2:dOl200000240V]Om0P0000020:OKnP<000007`2WfOT3000001l0/]Wd0P0000020;;Gl`030000
002kf>l0^mS_01L0^mS_0P00000;0;[FkP0300000031e^X0`MKZ00h0`MKZ00<000000;kCjP2ndnX0
402ndnX00`000000`m;U0<?Bi@080<?Bi@8000004`31d>H01@000000`M3V0<7@iP31d>H0000000@0
`lkS0P00000^0?ooo`030000003oool0oooo01<0oooo000X0?ooo`D000001P3oool2000008X0oooo
00<0000001eliP0MO>H0100MO>H300000080067E00<00000005fgP01M]h01`01M]h4000000X03hgT
0P00000C04Rdn08000006@1_bOl200000140R=?o1@00000:08[Ao`8000007`2Jeod4000001l0YmWi
0`0000020:SGn0030000002bfO@0/]Wd01X0/]Wd0`0000050;;Gl`8000005@2kf>l2000000h0^]K^
00<000000<7FjP31e^X02`31e^X2000001@0_]?Z00<000000<?Bi@33d^D01@33d^D2000001H0`M3V
00H000000<7@iP31d>H0`M3V00000033c^<200000300oooo00<000000?ooo`3oool04`3oool002P0
oooo0P0000060?ooo`<00000S@3oool00`0000007GcV01eliP0601eliP@000002P01M]h8000000H0
3hgT0P00000C04Rdn08000006@1_bOl2000000/0R=?o1000000A08[Ao`8000006@2Jeod4000000<0
VmGl0P00000L0:OIn@8000001P2XeoP2000001P0/]Wd0P00000:0;;Gl`030000002kf>l0^mS_0100
^mS_0P00000A0;[FkP0300000031e^X0`MKZ00P0`MKZ0P00000G0;kCjP0300000033d^D0`m;U0080
`m;U0P00000H0<7@iP0300000031d>H0`M3V0080`M3V00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0C0?ooo`00:03oool00`000000oooo0?ooo`020?ooo`<00000T@3oool2000000T07GcV
0`00000:005fgP030000000YVNl0:IW_00<0:IW_1@00000300n=i08000004`18]?P2000001T0KlWo
0P00000408SCo`D000005`2:dOl00`000000V]Om09[Go@0B09[Go@@000002@2KeO`2000001L0YmWi
0`00000:0:SGn0030000002bfO@0/]Wd01<0/]Wd0P00000=0;;Gl`030000002kf>l0^mS_00d0^mS_
0P00000D0;[FkP0300000031e^X0`MKZ00D0`MKZ0P00000J0;kCjP0400000033d^D00000000001/0
`M3V00@000000<7@iP0000000000<`3oool00`000000oooo0?ooo`0C0?ooo`00703oool4000000P0
oooo00<000000?ooo`0000000P00002F0?ooo`030000000MO>H07GcV00P07GcV0`000009005fgP80
0000200YVNl7000001<0B;Ch0P00000E06o9o`P000007@2:dOl2000000h0V]Om1000000?09_Eo003
0000002WfOT0YmWi0140YmWi0`00000>0:SGn0030000002bfO@0/]Wd00l0/]Wd0`00000@0;;Gl`80
00002`2kf>l2000001L0^]K^00<000000<7FjP31e^X00P31e^X2000001d0_]?Z00<000000<7@iP31
d>H06`31d>H2000003D0oooo00<000000?ooo`3oool04`3oool001h0oooo00<000000?ooo`3oool0
1`3oool2000009X0oooo00<0000001eliP0MO>H02@0MO>H5000000L00GKN00<0000002VIk`0YVNl0
2`0YVNl>000000P0B;Ch0P00000706o9o``000001P1cb?l2000001l0R]7o0P00000809[Go@@00000
502KeO`2000000l0YmWi0P00000B0:SGn08000003@2bfO@2000001D0/]Oc00<000000;_Hk`2kf>l0
1P2kf>l2000001X0^]K^00@000000<7FjP00000000007@2ndnX2000000030;cAjP000000`M3V01T0
`M3V0P0000020?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool04P3oool001h0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2I0?ooo`030000000MO>H07GcV00T07GcV
0P00000202B;k0<000001@01M]h2000000h0:IW_0P00000905>fna400000501cb?l2000001l0R]7o
0P00000209[Go@@000006P2KeO`00`000000YmWi0:OIn@090:OIn@<000005P2XeoP00`000000/]Wd
0;;Im0070;;Im0<00000602beo<00`000000^mS_0;_Hk`030;_Hk`8000007@2je^h00`000000_]?Z
0;kCjP0K0;kCjP800000102ldNX00`000000`M3V0<7@iP0E0<7@iP800000103oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo0180oooo000N0?ooo`030000003oool0oooo00T0oooo0P00
002J0?ooo`030000000MO>H07GcV00X07GcV00<0000002B;k00TRn`00P0TRn`4000000<00GKN0P00
000>02VIk`8000004`1C]_/2000001T0LlSo0P00000M08[Ao`@000007`2KeO`2000000H0YmWi0`00
000J0:SGn0030000002bfO@0/]Wd00@0/]Wd0P00000L0;;Gl`80000000<0^mS_0000000000007@2j
e^h2000000030;SDkP000000_]?Z01T0_]?Z0P0000070;cAjP0300000031d>H0`M3V0180`M3V0P00
00070?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool04P3oool001h0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`2H0?ooo`030000000MO>H07GcV00X07GcV00<00000
02B;k00TRn`01@0TRn`3000000800GKN00<0000002VIk`0YVNl03@0YVNl2000001<0DkKk0P00000I
07?8o`030000002:dOl0R]7o01D0R]7o1@00000308c@oP800000802KeO`200000080YmWi0P00000N
0:SGn08000000P2bfO@2000001l0/]Oc0P00000M0;[FkP800000102he>h00`000000_]?Z0;kCjP0E
0;kCjP8000002P2ldNX00`000000`M3V0<7@iP0?0<7@iP8000002P3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo0180oooo000L0?ooo`<000003P3oool00`000000oooo0?ooo`2H0?oo
o`8000002`0MO>H00`00000098_/02B;k00702B;k0D000003`0YVNl00`000000DkKk05>fn`0B05>f
n`800000601cb?l200000100R]7o1@00000:08c@oP8000007P2KeO`400000240Z=Oh0`00000O0;;G
l`8000000P2beO800`000000^]K^0;[FkP0H0;[FkP8000001`2he>h00`000000_]?Z0;kCjP0B0;kC
jP8000003@2ldNX00`000000`M3V0<7@iP0=0<7@iP030000003oool0oooo00X0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0B0?ooo`007P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo09P0oooo1@00000801eliP8000002`0TRn`5000000`0:IW_0P00000D05>fn`03
0000001cb?l0LlSo01L0LlSo0P00000:08[Ao`@000004@2<d?h00`000000VmGl09_Eo00G09_Eo0@0
00000`2Mdo/2000001d0Z=Oh0`0000020:WEm`030000002beo<0/]Oc01X0/]Oc0`0000050;;ElP03
0000002je^h0^]K^01D0^]K^0P00000:0;SDkP030000002ndnX0_]?Z00l0_]?Z0P00000?0;cAjP03
00000031d>H0`M3V00/0`M3V0P00000>0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool04P3oool002l0oooo00<000000?ooo`3oool0V03oool010000000>hk_03^>k`0kS^l3000000L0
7GcV00<0000002B;k00TRn`02P0TRn`20000000303nSmP000000000000D000001`0YVNl2000001<0
DkKk0P00000I07?8o`8000000`2:dOl5000001H0S=3n0P00000C09_Eo0@000002@2Mdo/00`000000
Z=Oh0:SGn00G0:SGn0<000001P2YeOL2000001P0/]Oc0P0000090;;ElP030000002je^h0^]K^0180
^]K^0P00000=0;SDkP8000003@2ndnX200000180_=7Z00<000000<7@iP31d>H02031d>H200000140
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0B0?ooo`00<03oool2000009T0oooo
0P00000403^>k`@00000100MO>H00`00000098_/02B;k00;02B;k0030000000oXoH0?j?f00D0?j?f
200000000`0YVNl000000000000C05>fn`800000501cb?l8000001d0S=3n00<0000009_Eo02KeO`0
302KeO`4000000h0WM?k0P00000D0:SGn0<000002`2YeOL00`000000/]Oc0;;Gl`0C0;;Gl`800000
302beO800`000000^]K^0;[FkP0?0;[FkP8000004@2he>h00`000000_]?Z0;kCjP080;kCjP800000
5@2ldNX00`000000`M3V0<7@iP050<7@iP800000503oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0180oooo000b0?ooo`030000003oool0oooo09P0oooo00<0000003^>k`0kS^l01@0k
S^l3000000807GcV0P00000<02B;k08000003@0oXoH?000000T0DkKk0P00000607?8o``000001P1i
aol2000001h0S=3n0P00000809_Eo0@00000502Mdo/00`000000Z=Oh0:SGn00>0:SGn0<000003`2Y
eOL00`000000/]Oc0;;Gl`0?0;;Gl`<000003`2beO82000000d0^]K^0P00000D0;SDkP030000002n
dnX0_]?Z00D0_]?Z0P00000H0;cAjP0300000031d>H0`M3V0080`M3V0P00000F0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool04@3oool003<0oooo00<000000?ooo`3oool0V03oool0
0`000000>hk_03^>k`0703^>k`D000003@0TRn`00`000000?j?f03nSmP0>03nSmP8000002@1N^?`A
000001@0NLOo0P00000N08c@oP8000000P2KeO`4000001T0WM?k0P00000;0:SGn0<000004`2YeOL2
000000d0/]Oc0P00000D0;;ElP030000002je^h0^]K^00P0^]K^0P00000G0;SDkP030000002ndnX0
_]?Z0080_]?Z0P00000K0;cAjP0400000031d>H00000000001T0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0A0?ooo`00=03oool00`000000oooo0?ooo`2H0?ooo`030000000kS^l0
>hk_00X0>hk_1000000;02B;k0800000400oXoH00`000000G[Sl05jho00B05jho08000006@1iaol0
0`000000S=3n08c@oP0K08c@oP@000007`2Mdo/00`000000Z=Oh0:SGn0050:SGn0<00000602YeOL0
0`000000/]Oc0;;Gl`070;;Gl`<000005`2beO800`000000^]K^0;[FkP050;[FkP8000006P2he>h0
10000000_]?Z00000000000M0;cAjP800000703oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo0140oooo000e0?ooo`800000V@3oool00`000000>hk_03^>k`0;03^>k`030000000oVO<0
000000@00000200TRn`2000000l0?j?f0P00000D05jho0800000601iaol2000001H0S=3n1@000003
08o>o@8000007`2Mdo/200000080Z=Oh0`00000L0:WEm`030000002beo<0/]Oc00@0/]Oc0P00000K
0;;ElP030000002je^h0^]K^0080^]K^0P00000L0;SDkP8000007@2ldNX2000001l0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0A0?ooo`00=`3oool00`000000oooo0?ooo`2G0?oo
o`030000000kS^l0>hk_00/0>hk_00<0000003nIl`0oVO<00`0oVO<6000000@098_/00<0000003nS
mP0oXoH03P0oXoH00`000000G[Sl05jho00C05jho0030000001iaol0NLOo01L0NLOo00<0000008c@
oP2<d?h03P2<d?h5000000X0Slkm00<0000009gCn`2Mdo/07@2Mdo/300000200ZMGg0P0000020;;G
l`8000007P2beO8010000000^]K^00000000000L0;SDkP8000000P2gd^d00`000000_=7Z0;cAjP0H
0;cAjP8000008@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0140oooo000h0?oo
o`030000003oool0oooo09L0oooo0P00000<03^>k`8000002@0oVO<7000000l0?j?f0P00000D05jh
o0800000601iaol2000000X0S=3n1000000@08o>o@8000006P2Mdo/300000080W]7j00<000000:WE
m`2YeOL07`2YeOL300000200/]Gb0P00000L0;SDkP8000001@2gd^d00`000000_=7Z0;cAjP0E0;cA
jP800000903oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0140oooo000i0?ooo`03
0000003oool0oooo09P0oooo00<0000003^>k`0kS^l02`0kS^l00`000000?iWc03nIl`0;03nIl`H0
00003@0oXoH2000001@0G[Sl00<0000007W7o`1iaol05`1iaol2000000<0S=3n1@00000F08o>o@03
0000002Mdo/0WM?k01<0WM?k1000000609kAnP800000702YeOL300000080ZM?f00<000000;;ElP2b
eO806`2beO8300000080/M?a00<000000;SDkP2he>h05`2he>h2000000P0]m;]00<000000;cAjP2l
dNX04P2ldNX2000002L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`00
>P3oool2000009T0oooo00<0000003^>k`0kS^l02`0kS^l00`000000?iWc03nIl`0=03nIl`030000
001BZ_T0DZ[i00L00000200oXoH00`000000G[Sl05jho00B05jho0800000501iaol8000001`0Slkm
00<0000009gCn`2Mdo/03`2Mdo/3000000`0W]7j00<000000:WEm`2YeOL05P2YeOL3000000H0ZM?f
0P00000I0;;ElP8000001P2ado400`000000^=C^0;SDkP0D0;SDkP8000002`2gd^d00`000000_=7Z
0;cAjP0?0;cAjP800000:P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0100oooo
000l0?ooo`030000003oool0oooo09L0oooo0P00000<03^>k`030000000oVO<0?iWc00d0?iWc0P00
000705:Zn@P0000000<0?j?f000000000000501N^?`2000000H0NLOo3000000607k6oP8000007@2?
c_d2000000`0WM?k0`00000@09kAnP030000002YeOL0ZMGg0180ZMGg0`00000;0:WCmP030000002b
eO80/]Gb01<0/]Gb0`0000090;7Cl@030000002he>h0^=C^0100^=C^0`00000>0;OBk@030000002l
dNX0_=7Z00`0_=7Z0P00000/0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0403o
ool003d0oooo00<000000?ooo`3oool0U`3oool5000000T0>hk_00<0000003nIl`0oVO<03P0oVO<0
0`000000DZ[i05:Zn@0<05:ZnAl00000501na_h2000001d0Slkm00<0000009gCn`2Mdo/01@2Mdo/4
000001@0W]7j0P00000?0:WEm`<000003`2YdoH00`000000/]Gb0;;ElP0?0;;ElP<000003@2ado40
0`000000^=C^0;SDkP0=0;SDkP8000004P2gd^d00`000000_=7Z0;cAjP090;cAjP800000;`3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0100oooo000n0?ooo`030000003oool0oooo
09L0oooo00@00000056JlP1AV_80DI[b1000000603^>k`8000003`0oVO<00`000000DZ[i05:Zn@0?
05:Zn@800000501Y^_d2000001T0O/Kn00<0000008o>o@2?c_d06`2?c_d200000080WM?k0`00000J
09kAnP030000002YeOL0ZMGg00T0ZMGg0`00000C0:WCmP030000002beO80/]Gb00`0/]Gb0P00000A
0;7Cl@8000002`2he>h2000001D0]m;]00<000000;cAjP2ldNX01P2ldNX200000380oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`00?`3oool00`000000oooo0?ooo`2G0?oo
o`030000001AV_80DI[b00@0DI[b1000000403^>k`030000000oVO<0?iWc00d0?iWc0P00000A05:Z
n@030000001Y^_d0JK[m01<0JK[m00<0000007k6oP1na_h05`1na_h2000001X0Slkm1@00000N09kA
nP030000002YeOL0ZMGg00D0ZMGg0`00000G0:WCmP030000002beO80/]Gb00P0/]Gb0`00000E0;7C
l@030000002he>h0^=C^00H0^=C^0P00000H0;OBk@030000002ldNX0_=7Z00<0_=7Z0P00000d0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool0403oool00400oooo0P00002H0?ooo`03
0000001AV_80DI[b00L0DI[b100000000`0kS^l0000003nIl`0?03nIl`030000001BZ_T0DZ[i00l0
DZ[i0P00000D06Vjo@8000006@1na_h00`000000Slkm08o>o@0A08o>o@H00000102BcO`2000001h0
W]7j0P0000020:WEm`<000006`2YdoH2000000D0/]Gb0`00000I0;7Cl@030000002he>h0^=C^00<0
^=C^0P00000K0;OBk@030000002ldNX0_=7Z00800000=`3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo0100oooo00120?ooo`030000003oool0oooo09H0oooo00<00000056JlP1AV_80
2P1AV_86000000d0?iWc00<0000005:Zn@1BZ_T0401BZ_T00`000000JK[m06Vjo@0C06Vjo@030000
001na_h0O/Kn01L0O/Kn0P00000;08o>o@H00000302BcO`00`000000W]7j09kAnP0L09kAnP<00000
802YdoH00`000000/]Gb0;;ElP02000001d0/M?a00<000000;SDkP2he>h00P00000M0;OBk@<00000
>P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0100oooo00130?ooo`030000003o
ool0oooo09H0oooo00<00000056JlP1AV_80301AV_800`000000E:;f05BRmP07000000L0?iWc0P00
000A05:Zn@030000001Y^_d0JK[m01<0JK[m00<0000007k6oP1na_h0601na_h2000000<0Slkm1P00
000C09;=o0800000602NdOX400000080Wm3i00<000000:WCmP2YdoH07P2YdoH3000001l0/M?a0`00
000M0;OBk@800000?P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00l0oooo0014
0?ooo`030000003oool0oooo09H0oooo00<00000056JlP1AV_80301AV_800`000000E:;f05BRmP06
05BRmPL000000P0oVO<00`000000DZ[i05:Zn@0?05:Zn@800000501Y^_d2000001L0O/Kn1P00000K
09;=o0030000002NdOX0W]7j0140W]7j1000000709o@n@8000006`2YdoH300000080ZM7e00<00000
0;7Cl@2ado406`2ado4200000080/M7a00<000000;OBk@2gd^d06@2gd^d200000400oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`0?0?ooo`00A@3oool2000009L0oooo00<00000056J
lP1AV_80301AV_82000000d0E:;f2@00000=05:Zn@030000001Y^_d0JK[m01<0JK[m00<0000007k6
oP1na_h0301na_h8000000@0PlGm0P00000L09;=o08000003@2NdOX4000000d0Wm3i00<000000:WC
mP2YdoH05@2YdoH3000000H0ZM7e0P00000H0;7Cl@<000001@2adO400`000000]m;]0;OBk@0F0;OB
k@800000@`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00l0oooo00170?ooo`03
0000003oool0oooo09D0oooo00<00000056JlP1AV_803@1AV_800`000000E:;f05BRmP0>05BRmP03
0000001Q[oX0HJoj0080HJoj2`00000305:Zn@800000501Y^_d2000000@0O/Kn2000000>08?5o@03
0000002BcO`0T/gl01/0T/gl00<0000009kAnP2NdOX01P2NdOX400000180Wm3i00<000000:WCmP2Y
doH04@2YdoH3000000/0ZM7e00<000000;7Cl@2ado404`2ado42000000T0/M7a00<000000;OBk@2g
d^d04`2gd^d2000004H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0?0?ooo`00
B03oool00`000000oooo0?ooo`2E0?ooo`030000001AV_80DI[b00d0DI[b00<0000005BRmP1DX_H0
3P1DX_H2000000d0HJoj7`00000G08?5o@800000702BcO`200000080W]7j1000000G09o@n@800000
3`2YdoH2000000l0ZM7e00<000000;7Cl@2ado403`2ado43000000`0/M7a00<000000;OBk@2gd^d0
402gd^d2000004T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0?0?ooo`00B@3o
ool00`000000oooo0?ooo`2E0?ooo`030000001AV_80DI[b00d0DI[b00<0000005BRmP1DX_H03`1D
X_H00`000000HJoj066_nP0@066_nP800000501b^o`2000001X0PlGm00<0000009;=o02BcO`06@2B
cO`4000001d0Wm3i00<000000:WCmP2YdoH02@2YdoH300000180ZM7e00<000000;7Cl@2ado402`2a
do4300000100/M7a0P00000>0;OBk@800000B`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00l0oooo001:0?ooo`800000UP3oool00`000000DI[b056JlP0=056JlP030000001DX_H0
E:;f00l0E:;f00<00000066_nP1Q[oX04@1Q[oX00`000000L[_l07:ko00C07:ko08000006@23aOd0
0`000000T/gl09;=o00D09;=o0@000000`2Dbo/00`000000Wm3i09o@n@0L09o@n@030000002YdoH0
ZM?f00D0ZM?f0`00000F0:WAm@030000002ado40/M?a00P0/M?a0P00000E0;7Al@030000002gd^d0
]m;]00T0]m;]0P00001>0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03`3oool0
04`0oooo00<000000?ooo`3oool0U03oool4000000`0DI[b0P00000@05BRmP8000004P1Q[oX20000
01D0L[_l00<0000008?5o@23aOd05`23aOd2000000l0T/gl1@00000809C;n`8000007@2Od?T20000
0080ZM?f0`00000J0:WAm@8000001@2ado43000001P0/M7a00<000000;OBk@2gd^d01P2gd^d20000
0540oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0?0?ooo`00C@3oool00`000000
oooo0?ooo`2D0?ooo`030000001RX_@0HZ;d00H00000201AV_800`000000E:;f05BRmP0?05BRmP03
0000001Q[oX0HJoj0140HJoj00<0000007:ko01b^o`04`1b^o`2000001T0PlGm00<0000009;=o02B
cO`01`2BcO`5000000l0U<_k00<0000009o@n@2Od?T06`2Od?T3000001l0ZM7e00<000000;7Cl@2a
do400P00000L0;7Al@030000002gd^d0]m;]00<0]m;]0P00001C0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool03P3oool004h0oooo00<000000?ooo`3oool0U03oool00`000000HZ;d
06:Rm00506:Rm0L000000P1AV_800`000000E:;f05BRmP0?05BRmP030000001Q[oX0HJoj0140HJoj
00<0000007:ko01b^o`0501b^o`00`000000PlGm08?5o@0G08?5o@8000000`2BcO`4000001D0U<_k
00<0000009o@n@2Od?T05P2Od?T400000080XLkg00<000000:WAm@2YdOD07@2YdOD3000001l0/M7a
00<000000;OBk@2gd^d00P00001F0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
3P3oool004l0oooo00<000000?ooo`3oool0U03oool2000000`0HZ;d2@00000<05BRmP8000004P1Q
[oX2000001D0L[_l0P00000D08?5o@P000006P2Dbo/200000180Wm3i100000070:7>m`8000006P2Y
dOD300000080ZLod00<000000;7Al@2adO407@2adO43000005T0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0>0?ooo`00D03oool2000009H0oooo00<0000006:Rm01RX_@03@1RX_@0
0`000000HjWg06>Ym`0206>Ym`X00000101DX_H00`000000HJoj066_nP0A066_nP030000001b^o`0
L[_l01@0L[_l0P00000608?5o@`000001P28aO`2000001`0U<_k00<0000009o@n@2Od?T02`2Od?T4
000000d0XLkg00<000000:WAm@2YdOD0502YdOD3000000H0ZLod00<000000;7Al@2adO406@2adO43
000005d0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0>0?ooo`00DP3oool00`00
0000oooo0?ooo`2D0?ooo`030000001RX_@0HZ;d00d0HZ;d00<0000006>Ym`1SZOL02`1SZOL@0000
00T0HJoj0P00000;07:ko14000005028aO`00`000000U<_k09C;n`0J09C;n`030000002Od?T0Wm3i
00H0Wm3i1000000B0:7>m`030000002YdOD0ZM7e0100ZM7e0`00000:0:W?m0030000002adO40/M7a
01D0/M7a0`00001P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool03P3oool005<0
oooo00<000000?ooo`3oool0U03oool00`000000HZ;d06:Rm00=06:Rm08000004@1SZOL00`000000
KK?j06fcnP0706fcnQH00000301j_?`00`000000R<Gl08S5o00G08S5o08000006`2Dbo/200000080
Wm3i1000000G0:7>m`030000002YdOD0ZM7e00d0ZM7e0P00000>0:W?m0030000002adO40/M7a0140
/M7a0`00001T0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03P3oool005@0oooo
00<000000?ooo`3oool0U03oool00`000000HZ;d06:Rm00>06:Rm0030000001SZOL0HjWg00l0HjWg
0P00000C06fcnP8000005@1j_?`2000001T0R<Gl00<0000009C;n`2Dbo/0602Dbo/4000001`0XLkg
00<000000:WAm@2YdOD02@2YdOD300000140ZLod0P00000>0;7Al@<00000J03oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo00h0oooo001E0?ooo`800000U@3oool2000000l0HZ;d00<0
000006>Ym`1SZOL0401SZOL00`000000KK?j06fcnP0B06fcnP030000001j_?`0N[cl01@0N[cl00<0
000008S5o028aO`05`28aO`200000180U<_k1P00000309O:n@030000002Qc_L0XLkg01/0XLkg0P00
00060:WAm@<000005P2Yco@00`000000/M7a0;7Al@080;7Al@<00000K03oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00d0oooo001G0?ooo`030000003oool0oooo09@0oooo00<00000
06:Rm01RX_@03@1RX_@00`000000HjWg06>Ym`0@06>Ym`030000001]/oX0KK?j0180KK?j0P00000E
07Zlo00300000028aO`0R<Gl01P0R<Gl00<0000009C;n`2Dbo/02@2Dbo/6000000X0Ul[i0P00000M
0:7>m`030000002YdOD0ZM7e00<000006P2Yco@00`000000/M7a0;7Al@040;7Al@<00000K`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00d0oooo001H0?ooo`030000003oool0oooo
09@0oooo00<0000006:Rm01RX_@03@1RX_@00`000000HjWg06>Ym`0@06>Ym`800000501]/oX00`00
0000N[cl07Zlo00C07Zlo08000006@28aO`2000000<0U<_k1P00000B09O:n@030000002Qc_L0XLkg
01X0XLkg0`00000N0:W?m0030000002adO40/M7a00<00000L`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00d0oooo001I0?ooo`030000003oool0oooo09@0oooo1000000<06:Rm080
00004P1SZOL00`000000KK?j06fcnP0B06fcnP030000001j_?`0N[cl01@0N[cl00<0000008S5o028
aO`05@28aO`6000001T0Ul[i00<000000:7>m`2Qc_L05@2Qc_L400000080X/gf00<000000:W?m02Y
co@0702Yco@3000007L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`00
FP3oool2000009D0oooo00<0000006jXm01^Z?@01P00000806:Rm0030000001SZOL0HjWg0100HjWg
00<0000006fcnP1]/oX04P1]/oX2000001D0N[cl00<0000008S5o028aO`03028aO`8000000@0S<Cj
00<0000009O:n@2Gb_T06@2Gb_T00`000000XLkg0:7>m`0@0:7>m`@000001`2RcOH2000001T0ZLod
0`00001j0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool03@3oool005`0oooo00<0
00000?ooo`3oool0T`3oool00`000000KZSd06jXm00506jXm0L000000P1RX_@00`000000HjWg06>Y
m`0@06>Ym`800000501]/oX00`000000N[cl07Zlo00C07Zlo08000001028aO`8000000d0S<Cj0P00
000J09O:n@030000002Qc_L0XLkg00/0XLkg1000000=0:;=mP030000002Yco@0ZLod01@0ZLod0P00
001n0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool005d0oooo00<00000
0?ooo`3oool0T`3oool00`000000KZSd06jXm00;06jXm0h000002@1SZOL00`000000KK?j06fcnP0B
06fcnP8000002`1j_?`>000001L0S<Cj00<0000009O:n@2Gb_T0602Gb_T2000000L0XLkg1000000B
0:;=mP030000002Yco@0ZLod0100ZLod0`0000210?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool03@3oool005h0oooo00<000000?ooo`3oool0T`3oool00`000000KZSd06jXm00>06jX
m0030000001_[_L0Kjkg00L0Kjkg:`00000;086mnP030000002<a?X0S<Cj01P0S<Cj00<0000009O:
n@2Gb_T06@2Gb_T00`000000XLkg0:7>m`04000001L0X/gf00<000000:W?m02Yco@0302Yco@30000
08D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0<0?ooo`00G`3oool00`000000
oooo0?ooo`2C0?ooo`030000001^Z?@0KZSd00h0KZSd0P00000B06n^m`030000001f]OT0M[Gi01<0
M[Gi00<00000086mnP21_OX04`21_OX2000001T0S<Cj0P00000H09O:n@@00000702RcOH00`000000
ZLod0:W?m0080:W?m0<00000R03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00`0
oooo001P0?ooo`800000U03oool00`000000KZSd06jXm00?06jXm0030000001_[_L0Kjkg0100Kjkg
00<0000007Jen@1f]OT04`1f]OT00`000000PKgj086mnP0D086mnP030000002<a?X0S<Cj01P0S<Cj
00<0000009O:n@2Gb_T03`2Gb_T6000000<0VLWh0P00000L0:;=mP8000001P2Yco@2000008`0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0<0?ooo`00HP3oool00`000000oooo0?oo
o`2B0?ooo`030000001^Z?@0KZSd00l0KZSd00<0000006n^m`1_[_L0401_[_L2000001@0M[Gi0P00
000E086mnP030000002<a?X0S<Cj01P0S<Cj00<0000009O:n@2Gb_T02@2Gb_T5000000/0VLWh00<0
00000:;=mP2RcOH06`2RcOH00`000000ZLod0:W?m003000008l0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0<0?ooo`00H`3oool00`000000oooo0?ooo`2B0?ooo`030000001^Z?@0
KZSd00l0KZSd0P00000B06n^m`030000001f]OT0M[Gi01<0M[Gi00<00000086mnP21_OX04`21_OX2
000001T0S<Cj0P00000309O:n@H000004@2IbOP00`000000X/gf0:;=mP0I0:;=mP@00000T`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00`0oooo001T0?ooo`030000003oool0oooo
0980oooo00<0000006jXm01^Z?@0401^Z?@00`000000Kjkg06n^m`0@06n^m`030000001f]OT0M[Gi
01<0M[Gi00<00000086mnP21_OX05021_OX00`000000S<Cj08c4nP0E08c4nPH00000602IbOP20000
01D0X/gf1000002G0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool006D0
oooo0P00002C0?ooo`030000001^Z?@0KZSd0100KZSd00<0000006n^m`1_[_L0401_[_L00`000000
M[Gi07Jen@0C07Jen@0300000021_OX0PKgj01@0PKgj00<0000008c4nP2<a?X0302<a?X8000000@0
T<Ci00<0000009W9n02IbOP06@2IbOP00`000000X/gf0:;=mP0=0:;=mPD00000W03oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo001W0?ooo`030000003oool0oooo0940oooo
00<0000006jXm01^Z?@0401^Z?@200000140Kjkg00<0000007Jen@1f]OT04`1f]OT00`000000PKgj
086mnP0D086mnP800000102<a?X8000000d0T<Ci0P00000J09W9n0030000002RcOH0X/gf00L0X/gf
1@00002R0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02`3oool006P0oooo00<0
00000?ooo`3oool0T@3oool;000000T0KZSd00<0000006n^m`1_[_L03`1_[_L2000001@0M[Gi0P00
000A086mnPT000005`2@a?T00`000000VLWh09W9n00H09W9n08000000`2RcOH400000:P0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0;0?ooo`00J@3oool00`000000oooo0?ooo`2A
0?ooo`030000001h[?@0N:cd00L0N:cd5000000906n^m`030000001f]OT0M[Gi01<0M[Gi00<00000
086mnP21_OX01021_OX:000000H0Q[ki00<000000934n@2@a?T0602@a?T00`000000VLWh09W9n00G
09W9n0D00000[03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo001Z0?oo
o`030000003oool0oooo0940oooo00<0000007R/m01h[?@04@1h[?@00`000000NK7f07VamP0607Va
mRH000004@26__T2000001T0T<Ci00<0000009W9n02IbOP04P2IbOP400000;80oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0;0?ooo`00J`3oool200000980oooo0P00000B07R/m003
0000001i/OH0NK7f0100NK7f00<0000007jgn01n]oP04`1n]oP00`000000Q[ki08Jnn@0E08Jnn@03
0000002@a?T0T<Ci01L0T<Ci00<0000009W9n02IbOP0302IbOP500000;L0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0;0?ooo`00K@3oool00`000000oooo0?ooo`2A0?ooo`030000
001h[?@0N:cd0100N:cd00<0000007VamP1i/OH0401i/OH00`000000O[Oh07jgn00C07jgn0800000
5P26__T00`000000T<Ci0934n@0G0934n@800000202IbOP400000;`0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0;0?ooo`00KP3oool00`000000oooo0?ooo`2A0?ooo`030000001h
[?@0N:cd0100N:cd00<0000007VamP1i/OH0401i/OH2000001D0O[Oh00<0000008Jnn@26__T05026
__T2000001T0T<Ci00@0000009W9n02IbOP0VLWh100000310?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool02`3oool006l0oooo00<000000?ooo`3oool0T@3oool00`000000N:cd07R/
m00@07R/m0030000001i/OH0NK7f0140NK7f00<0000007jgn01n]oP04`1n]oP00`000000Q[ki08Jn
n@0E08Jnn@030000002@a?T0T<Ci01@0T<Ci1P0000360?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool02`3oool00700oooo0P00002B0?ooo`030000001h[?@0N:cd0100N:cd0P00000B
07VamP030000001n]oP0O[Oh01<0O[Oh0P00000F08Jnn@030000002@a?T0T<Ci00/0T<Ci2000003=
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02P3oool00780oooo00<000000?oo
o`3oool0T03oool200000180N:cd00<0000007VamP1i/OH0401i/OH00`000000O[Oh07jgn00D07jg
n00300000026__T0Q[ki01@0Q[ki0P0000040934n@L00000e@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00X0oooo001c0?ooo`030000003oool0oooo0940oooo00<0000007R/m01h
[?@0401h[?@00`000000NK7f07VamP0@07VamP030000001n]oP0O[Oh01@0O[Oh00<0000008Jnn@26
__T04026__T900000=d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`00
M03oool00`000000oooo0?ooo`2A0?ooo`030000001h[?@0N:cd0100N:cd00<0000007VamP1i/OH0
401i/OH2000001D0O[Oh0P00000608Jnn@X00000i`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00X0oooo001e0?ooo`800000TP3oool:000000T0N:cd00<0000007VamP1i/OH04@1i
/OH00`000000O[Oh07jgn00907jgn1400000lP3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00X0oooo001g0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01`3ooolY
00000?l0oooo103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo001h0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0o`3ooole0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02P3oool007T0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`3o0?ooocH0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`00
NP3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0?l0oooo=P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00T0oooo001k0?ooo`800000S03oool00`000000oooo0?oo
o`3o0?ooocL0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`00O@3oool0
0`000000oooo0?ooo`290?ooo`030000003oool0oooo0?l0oooo>03oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00T0oooo001n0?ooo`030000003oool0oooo08P0oooo00<000000?oo
o`3oool0o`3oooli0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool007l0
oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`3o0?ooocT0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`00P03oool2000008L0oooo00<000000?ooo`3oool0
o`3ooolj0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00880oooo00<0
00000?ooo`3oool0P`3oool00`000000oooo0?ooo`3o0?oooc`0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`00P`3oool00`000000oooo0?ooo`220?ooo`030000003oool0
oooo0?l0oooo?@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00240?oo
o`030000003oool0oooo0840oooo00<000000?ooo`3oool0o`3ooolm0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0203oool008D0oooo0P0000210?ooo`030000003oool0oooo0?l0
oooo?P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00270?ooo`030000
003oool0oooo07h0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0203oool008P0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?oo
o`3o0?oood00oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`00R@3oool0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0?l0oooo@03oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00P0oooo002:0?ooo`030000003oool0oooo07/0oooo00<000000?oo
o`3oool0o`3ooom10?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool008/0
oooo0P00001k0?ooo`030000003oool0oooo0?l0oooo@P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo002=0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
o`3ooom20?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool008h0oooo00<0
00000?ooo`3oool0M`3oool00`000000oooo0?ooo`3o0?oood<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`070?ooo`00S`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo0?l0ooooA03oool01@000000oooo0?ooo`3oool0000000T0oooo002@0?ooo`800000MP3oool0
0`000000oooo0?ooo`3o0?ooodD0oooo00@000000?ooo`3oool000002@3oool00980oooo00<00000
0?ooo`3oool0L`3oool00`000000oooo0?ooo`3o0?ooodD0oooo00@000000?ooo`3oool000002@3o
ool009<0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`3o0?ooodH0oooo00<00000
0?ooo`0000002@3oool009@0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`3o0?oo
odL0oooo00<000000?ooo`000000203oool009D0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`3o0?ooodP0oooo0P0000080?ooo`00UP3oool200000700oooo00<000000?ooo`3oool0
o`3ooom80?ooo`800000203oool009P0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?oo
o`3o0?ooodP0oooo0P0000080?ooo`00V@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0
oooo0?l0ooooA03oool4000000X0oooo002J0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0o`3ooom00?ooo`@000003P3oool009/0oooo0P00001[0?ooo`030000003oool0oooo0?l0
oooo?03oool400000180oooo002M0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0
o`3ooolh0?ooo`@000005P3oool009h0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?oo
o`3o0?ooocD0oooo0`00000J0?ooo`00W`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0
oooo0?l0oooo<P3oool4000001d0oooo002P0?ooo`800000I@3oool00`000000oooo0?ooo`3o0?oo
obh0oooo1000000Q0?ooo`00XP3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0?l0
oooo:P3oool4000002D0oooo002S0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
o`3ooolV0?ooo`@00000:@3oool00:@0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?oo
o`3o0?ooob<0oooo0`00000]0?ooo`00Y@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0
oooo0?l0oooo7`3oool400000300oooo002V0?ooo`800000G`3oool00`000000oooo0?ooo`3o0?oo
oa/0oooo1000000d0?ooo`00Z03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0?l0
oooo5`3oool4000003P0oooo002Y0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
o`3ooolC0?ooo`@00000?03oool00:X0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?oo
o`3o0?ooo`l0oooo100000100?ooo`00Z`3oool2000005X0oooo00<000000?ooo`3oool0o`3oool<
0?ooo`<00000A03oool00:d0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3o0?oo
o`P0oooo100000170?ooo`00[P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0?l0
oooo103oool4000004/0oooo002_0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0
o`3oool4000004l0oooo002`0?ooo`800000E@3oool00`000000oooo0?ooo`3k0?ooo`@00000D`3o
ool00;80oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3h0?ooo`<00000E`3oool0
0;<0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`3d0?ooo`@00000FP3oool00;@0
oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`3`0?ooo`@00000GP3oool00;D0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`3/0?ooo`@00000HP3oool00;H0oooo0P00
001?0?ooo`030000003oool0oooo0>P0oooo1000001V0?ooo`00^03oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo0>D0oooo0`00001Z0?ooo`00^@3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo0>40oooo1000001]0?ooo`00^P3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo0=d0oooo1000001a0?ooo`00^`3oool2000004X0oooo00<000000?ooo`3oool0
f@3oool4000007D0oooo002m0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0eP3o
ool4000007T0oooo002n0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0d`3oool3
000007d0oooo002o0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0c`3oool40000
0800oooo00300?ooo`800000A03oool00`000000oooo0?ooo`3;0?ooo`@00000Q03oool00<80oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`370?ooo`@00000R03oool00<<0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`@00000S03oool00<@0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`300?ooo`<00000T03oool00<D0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`2l0?ooo`@00000T`3oool00<H0oooo0P00000n0?ooo`03
0000003oool0oooo0;P0oooo1000002G0?ooo`00b03oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0;@0oooo1000002K0?ooo`00b@3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo0;00oooo1000002O0?ooo`00bP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo0:d0oooo0`00002S0?ooo`00b`3oool2000003T0oooo00<000000?ooo`3oool0Z@3oool40000
0:H0oooo003=0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0Y@3oool400000:X0
oooo003>0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0X@3oool400000:h0oooo
003?0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0W@3oool400000;80oooo003@
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0V@3oool400000;H0oooo003A0?oo
o`800000<`3oool00`000000oooo0?ooo`2F0?ooo`<00000^P3oool00=<0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`2B0?ooo`@00000_@3oool00=@0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`2>0?ooo`@00000`@3oool00=D0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`2:0?ooo`@00000a@3oool00=H0oooo0P00000^0?ooo`030000003oool0
oooo08H0oooo100000390?ooo`00f03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
08<0oooo0`00003=0?ooo`00f@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0800
oooo1000003@0?ooo`00fP3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo07`0oooo
1000003D0?ooo`00f`3oool2000002P0oooo00<000000?ooo`3oool0N03oool400000=P0oooo003M
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0M03oool400000=`0oooo003N0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0L@3oool300000>00oooo003O0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool400000><0oooo003P0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0J@3oool400000>L0oooo003Q0?ooo`8000008P3o
ool00`000000oooo0?ooo`1U0?ooo`@00000j`3oool00><0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`1Q0?ooo`@00000k`3oool00>@0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`1N0?ooo`<00000l`3oool00>D0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1J0?ooo`@00000mP3oool00>H0oooo0P00000M0?ooo`030000003oool0oooo05H0oooo
1000003j0?ooo`00j03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0580oooo1000
003n0?ooo`00j@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04h0oooo1000003o
0?ooo`<0oooo003Z0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0B`3oool30000
0?l0oooo1`3oool00>/0oooo0P00000H0?ooo`030000003oool0oooo04L0oooo1000003o0?ooo`X0
oooo003]0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0@`3oool400000?l0oooo
3P3oool00>h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0o0?ooo`@00000o`3o
oolB0?ooo`00k`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03/0oooo1000003o
0?oooaH0oooo003`0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0>03oool30000
0?l0oooo6P3oool00?40oooo0P00000B0?ooo`030000003oool0oooo03@0oooo1000003o0?oooad0
oooo003c0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0<03oool400000?l0oooo
8@3oool00?@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0/0?ooo`@00000o`3o
oolU0?ooo`00m@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02P0oooo1000003o
0?ooobT0oooo003f0?ooo`800000303oool00`000000oooo0?ooo`0U0?ooo`@00000o`3oool]0?oo
o`00n03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0280oooo0`00003o0?oooc40
oooo003i0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool400000?l0oooo
=03oool00?X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000o`3o
oolh0?ooo`00n`3oool2000000L0oooo00<000000?ooo`3oool05P3oool400000?l0oooo?03oool0
0?d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`@00000o`3ooom00?oo
o`00oP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo0`00003o0?oood@0
oooo003o0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool400000?l0oooo
A`3oool00?l0oooo0@3oool01@000000oooo0?ooo`3oool0000000T0oooo1000003o0?oood/0oooo
003o0?ooo`80oooo0P0000000`3oool000000?ooo`040?ooo`@00000o`3ooom?0?ooo`00o`3oool4
0?ooo`80000000<0oooo0000000000000P00003o0?oooe<0oooo003o0?ooo`D0oooo0P00003o0?oo
oeL0oooo003o0?ooool0ooooGP3oool00?l0ooooo`3ooomN0?ooo`00o`3ooooo0?oooeh0oooo003o
0?ooool0ooooGP3oool00?l0ooooo`3ooomN0?ooo`00o`3ooooo0?oooeh0oooo003o0?ooool0oooo
GP3oool00?l0ooooo`3ooomN0?ooo`00o`3ooooo0?oooeh0oooo003o0?ooool0ooooGP3oool00?l0
ooooo`3ooomN0?ooo`00o`3ooooo0?oooeh0oooo003o0?ooool0ooooGP3oool00?l0ooooo`3ooomN
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 603}, {488.812, 0}} -> {-0.0691591, 0.0237481, \
0.00171713, 0.00171713}}],

Cell[CellGroupData[{

Cell["\<\
Problem 3: Sphere with an axially symmetric charge distribution  \
\
\>", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Required packages", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell["\<\
 Needs[\"Calculus`VectorAnalysis`\"]
 Needs[\"Graphics`ParametricPlot3D`\"] \
\>", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell["Solution", "Subsubsection",
  Evaluatable->False,
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Clear[\"Global`*\"];", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    FormBox[
      RowBox[{\(Clear::"wrsym"\), \(\(:\)\(\ \)\), "\<\"Symbol \
\\!\\(TraditionalForm\\`Monopole\\) is Protected.\"\>"}], 
      TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{\(Clear::"wrsym"\), \(\(:\)\(\ \)\), "\<\"Symbol \
\\!\\(TraditionalForm\\`TrigToP\\) is Protected.\"\>"}], 
      TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{\(Clear::"wrsym"\), \(\(:\)\(\ \)\), "\<\"Symbol \
\\!\\(TraditionalForm\\`TrigToY\\) is Protected.\"\>"}], 
      TraditionalForm]], "Message"],

Cell[BoxData[
    FormBox[
      RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(TraditionalForm\\`\\(Clear :: \\\"wrsym\\\"\\)\\) will be suppressed \
during this calculation.\"\>"}], TraditionalForm]], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part a", "Subsubsection",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(potInA[s_]\), ":=", 
      RowBox[{"Sum", "[", 
        RowBox[{
          RowBox[{
            FormBox[\(\((r\/a)\)\^i\ \(A(i)\)\),
              "TraditionalForm"], " ", \(LegendreP[i, Cos[\[Theta]]]\)}], 
          ",", \({i, 0, s}\)}], "]"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(potOutA[s_]\), ":=", 
      RowBox[{"Sum", "[", 
        RowBox[{
          RowBox[{\(A[i]\), " ", 
            FormBox[\(\((a\/r)\)\^\(i + 1\)\),
              "TraditionalForm"], \(LegendreP[i, Cos[\[Theta]]]\)}], 
          ",", \({i, 0, s}\)}], "]"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(chargeDensity[s_]\), ":=", 
      RowBox[{
        RowBox[{
          FormBox[\(1\/\(4\ \[Pi]\)\),
            "TraditionalForm"], \((D[potInA[s], r] - D[potOutA[s], r])\)}], 
        "//.", \({r \[Rule] a}\)}]}]], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(chargeDensity[2] // Apart\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(TraditionalForm\`\(15\ \(A(2)\)\ \(\(cos\^2\)(\[Theta])\)\)\/\(8\ a\ \
\[Pi]\) + \(3\ \(A(1)\)\ \(cos(\[Theta])\)\)\/\(4\ a\ \[Pi]\) + \(2\ \(A(0)\) \
- 5\ \(A(2)\)\)\/\(8\ a\ \[Pi]\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(aEquation[s_, Qdensity_] := 
      LogicalExpand[
        chargeDensity[s] \[Equal] 
          Qdensity + O[Cos[\[Theta]]]\^\(s + 1\)]\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(aRule[s_, Qdensity_] := 
      Solve[aEquation[s, Qdensity], Array[A, s + 1, 0]] // Flatten\)], "Input",\

  Hyphenation->False],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"aRule", "[", 
      RowBox[{"4", ",", 
        FormBox[\(\(Q\ \(\(cos\^2\)(\[Theta])\)\)\/a\^2\),
          "TraditionalForm"]}], "]"}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(TraditionalForm\`{A(0) \[Rule] \(4\ \[Pi]\ Q\)\/\(3\ a\), 
      A(1) \[Rule] 0, A(2) \[Rule] \(8\ \[Pi]\ Q\)\/\(15\ a\), 
      A(3) \[Rule] 0, A(4) \[Rule] 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(potInA[4]\), "/.", 
      RowBox[{"aRule", "[", 
        RowBox[{"4", ",", 
          FormBox[\(\(Q\ \(\(cos\^2\)(\[Theta])\)\)\/a\^2\),
            "TraditionalForm"]}], "]"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(TraditionalForm\`\(8\ \[Pi]\ Q\ \((\(3\ \(\(cos\^2\)(\[Theta])\)\)\/2 - \
1\/2)\)\ r\^2\)\/\(15\ a\^3\) + \(4\ \[Pi]\ Q\)\/\(3\ a\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(potOutA[4]\), "/.", 
      RowBox[{"aRule", "[", 
        RowBox[{"4", ",", 
          FormBox[\(\(Q\ \(\(cos\^2\)(\[Theta])\)\)\/a\^2\),
            "TraditionalForm"]}], "]"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(TraditionalForm\`\(8\ \[Pi]\ Q\ \((\(3\ \(\(cos\^2\)(\[Theta])\)\)\/2 - \
1\/2)\)\ a\^2\)\/\(15\ r\^3\) + \(4\ \[Pi]\ Q\)\/\(3\ r\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part b", "Subsubsection",
  Hyphenation->False],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"surfaceQ", "=", 
      RowBox[{
        FormBox[\(\(Q\ \((\(\(cos\^2\)(\[Theta])\)\/2 + 
                    cos(\[Theta]))\)\)\/a\^2\),
          "TraditionalForm"], "//", "Expand"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(TraditionalForm\`\(Q\ \(\(cos\^2\)(\[Theta])\)\)\/\(2\ a\^2\) + \(Q\ \
\(cos(\[Theta])\)\)\/a\^2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["potOutQ= potOutA[8] //. aRule[8,surfaceQ]", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm\`\(4\ \[Pi]\ Q\ \((\(3\ \(\(cos\^2\)(\[Theta])\)\)\/2 - \
1\/2)\)\ a\^2\)\/\(15\ r\^3\) + \(4\ \[Pi]\ Q\ \(cos(\[Theta])\)\ a\)\/\(3\ r\
\^2\) + \(2\ \[Pi]\ Q\)\/\(3\ r\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["potInQ= potInA[8]//.aRule[8,surfaceQ]", "Input",
  InitializationCell->False,
  Hyphenation->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TraditionalForm\`\(4\ \[Pi]\ Q\ \((\(3\ \(\(cos\^2\)(\[Theta])\)\)\/2 - \
1\/2)\)\ r\^2\)\/\(15\ a\^3\) + \(4\ \[Pi]\ Q\ \(cos(\[Theta])\)\ r\)\/\(3\ a\
\^2\) + \(2\ \[Pi]\ Q\)\/\(3\ a\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(values = {Q \[Rule] 1, a \[Rule] 1};\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(p1 = 
        CylindricalPlot3D[
          potInQ //. values, {r, 0, 1}, {\[Theta], 0, 2\ \[Pi]}, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(p2 = 
        CylindricalPlot3D[
          potOutQ //. values, {r, 1, 3}, {\[Theta], 0, 2  \[Pi]}, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[p1, 
        p2, \[IndentingNewLine]AxesLabel \[Rule] {a, b, 
            c}, \[IndentingNewLine]ViewPoint \[Rule] {\(-1.5\), \(-2\), 
            2}, \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 1}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  Hyphenation->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.07206 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0887636 1.1505 -3.05745e-17 1.1505 [
[.10718 .94059 -6.77329 0 ]
[.10718 .94059 5.22671 9 ]
[.29053 1.00145 -3.19569 0 ]
[.29053 1.00145 2.80431 9 ]
[.45748 1.05683 -3.02845 0 ]
[.45748 1.05683 2.97155 9 ]
[.28768 1.0738 -5.32312 0 ]
[.28768 1.0738 4.67688 9.8125 ]
[.90539 .88469 -5.12946 0 ]
[.90539 .88469 6.87054 9 ]
[.75186 .97108 -2.73227 0 ]
[.75186 .97108 3.26773 9 ]
[.61674 1.04709 -2.87186 0 ]
[.61674 1.04709 3.12814 9 ]
[.75825 1.04271 -4.55379 0 ]
[.75825 1.04271 5.44621 9.8125 ]
[.93099 .36573 0 -7.94995 ]
[.93099 .36573 6 1.05005 ]
[.9506 .4722 0 -7.7263 ]
[.9506 .4722 6 1.2737 ]
[.97204 .58865 0 -7.48579 ]
[.97204 .58865 6 1.51421 ]
[.99556 .71654 0 -7.22642 ]
[.99556 .71654 6 1.77358 ]
[1.0196 .48489 0 -8.3025 ]
[1.0196 .48489 10 1.51 ]
[ 0 0 0 0 ]
[ 1 1.07206 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .89001 m
.54651 1.07206 L
s
.10901 .92632 m
.10993 .91919 L
s
[(-2)] .10718 .94059 .12888 -1 Mshowa
.29147 .9871 m
.29194 .97993 L
s
[(0)] .29053 1.00145 .06523 -1 Mshowa
.45761 1.04244 m
.45768 1.03525 L
s
[(2)] .45748 1.05683 .00948 -1 Mshowa
.125 Mabswid
.15629 .94207 m
.15677 .93778 L
s
.20243 .95744 m
.20284 .95315 L
s
.24748 .97245 m
.24782 .96815 L
s
.33445 1.00142 m
.33466 .99711 L
s
.37644 1.01541 m
.3766 1.01109 L
s
.41748 1.02908 m
.41758 1.02476 L
s
.06057 .91018 m
.06119 .90592 L
s
.0109 .89364 m
.0116 .88938 L
s
.49685 1.05552 m
.49684 1.0512 L
s
.53523 1.0683 m
.53516 1.06399 L
s
gsave
.28768 1.0738 -66.3231 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
.25 Mabswid
1 .81584 m
.54651 1.07206 L
s
.90333 .87046 m
.90229 .86335 L
s
[(-2)] .90539 .88469 -0.14509 -1 Mshowa
.75058 .95676 m
.74994 .9496 L
s
[(0)] .75186 .97108 -0.08924 -1 Mshowa
.61613 1.03272 m
.61582 1.02554 L
s
[(2)] .61674 1.04709 -0.04271 -1 Mshowa
.125 Mabswid
.86322 .89312 m
.86267 .88884 L
s
.82444 .91503 m
.82394 .91074 L
s
.78691 .93623 m
.78647 .93194 L
s
.71539 .97664 m
.71506 .97234 L
s
.68128 .99591 m
.681 .99161 L
s
.64821 1.0146 m
.64798 1.01029 L
s
.94482 .84702 m
.94413 .84276 L
s
.98777 .82275 m
.98701 .8185 L
s
.585 1.05031 m
.58486 1.046 L
s
.55477 1.06739 m
.55467 1.06308 L
s
gsave
.75825 1.04271 -65.5538 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
.25 Mabswid
.90663 .30341 m
1 .81584 L
s
.91958 .37448 m
.91388 .37885 L
s
[(0)] .93099 .36573 -1 .76666 Mshowa
.93891 .48058 m
.93307 .48477 L
s
[(2)] .9506 .4722 -1 .71696 Mshowa
.96005 .5966 m
.95406 .60058 L
s
[(4)] .97204 .58865 -1 .66351 Mshowa
.98326 .72399 m
.97711 .72772 L
s
[(6)] .99556 .71654 -1 .60587 Mshowa
.125 Mabswid
.92426 .40014 m
.92081 .40274 L
s
.92904 .42637 m
.92557 .42894 L
s
.93392 .45318 m
.93044 .45572 L
s
.94402 .5086 m
.94049 .51109 L
s
.94924 .53727 m
.94569 .53972 L
s
.95459 .56659 m
.95101 .56901 L
s
.96565 .62732 m
.96203 .62967 L
s
.97138 .65877 m
.96774 .66109 L
s
.97725 .69099 m
.97359 .69326 L
s
.915 .34935 m
.9116 .352 L
s
.91052 .32475 m
.90714 .32743 L
s
.98943 .75782 m
.98571 .76001 L
s
.99575 .79249 m
.99201 .79464 L
s
gsave
1.0196 .48489 -61 -12.3025 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
.25 Mabswid
.41699 0 m
.39846 .53401 L
s
.39846 .53401 m
0 .89001 L
s
0 .89001 m
.08461 .38696 L
s
.08461 .38696 m
.41699 0 L
s
.90663 .30341 m
.53727 .59904 L
s
.53727 .59904 m
.54651 1.07206 L
s
.54651 1.07206 m
1 .81584 L
s
1 .81584 m
.90663 .30341 L
s
.41699 0 m
.39846 .53401 L
s
.39846 .53401 m
1 .81584 L
s
1 .81584 m
.90663 .30341 L
s
.90663 .30341 m
.41699 0 L
s
.08461 .38696 m
.53727 .59904 L
s
.53727 .59904 m
.54651 1.07206 L
s
.54651 1.07206 m
0 .89001 L
s
0 .89001 m
.08461 .38696 L
s
0 0 m
1 0 L
1 1.07206 L
0 1.07206 L
closepath
clip
newpath
.5 Mabswid
.46877 .63829 m .46826 .64165 L .38253 .62184 L p .499 .738 .98 r
F P
0 g
s
.46826 .64165 m .46877 .63829 L .55353 .64029 L p .479 .795 .999 r
F P
0 g
s
.55353 .64029 m .55571 .64296 L .46826 .64165 L p .479 .795 .999 r
F P
0 g
s
.38253 .62184 m .38573 .61822 L .46877 .63829 L p .499 .738 .98 r
F P
0 g
s
.46928 .63511 m .46877 .63829 L .38573 .61822 L p .472 .732 .983 r
F P
0 g
s
.46877 .63829 m .46928 .63511 L .55134 .63786 L p .439 .789 .997 r
F P
0 g
s
.55134 .63786 m .55353 .64029 L .46877 .63829 L p .439 .789 .997 r
F P
0 g
s
.38573 .61822 m .38253 .62184 L .30532 .58501 L p .551 .703 .94 r
F P
0 g
s
.55571 .64296 m .55353 .64029 L .63321 .62346 L p .54 .863 .996 r
F P
0 g
s
.63321 .62346 m .63796 .6251 L .55571 .64296 L p .54 .863 .996 r
F P
0 g
s
.30532 .58501 m .31109 .58165 L .38573 .61822 L p .551 .703 .94 r
F P
0 g
s
.38896 .61471 m .38573 .61822 L .31109 .58165 L p .538 .697 .942 r
F P
0 g
s
.38573 .61822 m .38896 .61471 L .46928 .63511 L p .472 .732 .983 r
F P
0 g
s
.4698 .63214 m .46928 .63511 L .38896 .61471 L p .438 .724 .986 r
F P
0 g
s
.46928 .63511 m .4698 .63214 L .54913 .63573 L p .385 .777 .988 r
F P
0 g
s
.54913 .63573 m .55134 .63786 L .46928 .63511 L p .385 .777 .988 r
F P
0 g
s
.55353 .64029 m .55134 .63786 L .62843 .62211 L p .505 .864 .988 r
F P
0 g
s
.62843 .62211 m .63321 .62346 L .55353 .64029 L p .505 .864 .988 r
F P
0 g
s
.31109 .58165 m .31688 .57833 L .38896 .61471 L p .538 .697 .942 r
F P
0 g
s
.3922 .61133 m .38896 .61471 L .31688 .57833 L p .522 .691 .944 r
F P
0 g
s
.38896 .61471 m .3922 .61133 L .4698 .63214 L p .438 .724 .986 r
F P
0 g
s
.47032 .62942 m .4698 .63214 L .3922 .61133 L p .395 .711 .986 r
F P
0 g
s
.4698 .63214 m .47032 .62942 L .54691 .63394 L p .315 .754 .966 r
F P
0 g
s
.54691 .63394 m .54913 .63573 L .4698 .63214 L p .315 .754 .966 r
F P
0 g
s
.55134 .63786 m .54913 .63573 L .62363 .62113 L p .456 .857 .97 r
F P
0 g
s
.62363 .62113 m .62843 .62211 L .55134 .63786 L p .456 .857 .97 r
F P
0 g
s
.31688 .57833 m .3227 .57507 L .3922 .61133 L p .522 .691 .944 r
F P
0 g
s
.39547 .60809 m .3922 .61133 L .3227 .57507 L p .504 .682 .946 r
F P
0 g
s
.3922 .61133 m .39547 .60809 L .47032 .62942 L p .395 .711 .986 r
F P
0 g
s
.47085 .62698 m .47032 .62942 L .39547 .60809 L p .34 .691 .981 r
F P
0 g
s
.47032 .62942 m .47085 .62698 L .54468 .63255 L p .221 .712 .923 r
F P
0 g
s
.54468 .63255 m .54691 .63394 L .47032 .62942 L p .221 .712 .923 r
F P
0 g
s
.54913 .63573 m .54691 .63394 L .61881 .62056 L p .388 .835 .932 r
F P
0 g
s
.61881 .62056 m .62363 .62113 L .54913 .63573 L p .388 .835 .932 r
F P
0 g
s
.31109 .58165 m .30532 .58501 L .24342 .53352 L p .602 .692 .906 r
F P
0 g
s
.3227 .57507 m .32856 .57186 L .39547 .60809 L p .504 .682 .946 r
F P
0 g
s
.39875 .60502 m .39547 .60809 L .32856 .57186 L p .482 .671 .947 r
F P
0 g
s
.39547 .60809 m .39875 .60502 L .47085 .62698 L p .34 .691 .981 r
F P
0 g
s
.63796 .6251 m .63321 .62346 L .70076 .58815 L p .66 .907 .98 r
F P
0 g
s
.70076 .58815 m .70783 .58849 L .63796 .6251 L p .66 .907 .98 r
F P
0 g
s
.24342 .53352 m .25142 .531 L .31109 .58165 L p .602 .692 .906 r
F P
0 g
s
.31688 .57833 m .31109 .58165 L .25142 .531 L p .597 .687 .905 r
F P
0 g
s
.47137 .62489 m .47085 .62698 L .39875 .60502 L p .268 .661 .968 r
F P
0 g
s
.47085 .62698 m .47137 .62489 L .54244 .63164 L p .1 .642 .846 r
F P
0 g
s
.4719 .62321 m .47244 .62202 L .512 .62786 L p .199 0 0 r
F P
0 g
s
.54244 .63164 m .54468 .63255 L .49056 .62847 L p .1 .642 .846 r
F P
0 g
s
.54244 .63164 m .49056 .62847 L .49273 .62841 L .1 .642 .846 r
F
.47137 .62489 m .4719 .62321 L .54018 .63131 L p 0 .538 .728 r
F P
0 g
s
.54018 .63131 m .53791 .63168 L .54122 .63128 L p .103 0 0 r
F P
0 g
s
.54691 .63394 m .54468 .63255 L .61397 .62048 L p .296 .791 .866 r
F P
0 g
s
.61397 .62048 m .61881 .62056 L .60357 .62339 L p .296 .791 .866 r
F P
0 g
s
.60357 .62339 m .54691 .63394 L p .59248 .62479 L .296 .791 .866 r
F P
0 g
s
.61397 .62048 m .60357 .62339 L .59248 .62479 L .296 .791 .866 r
F
.54468 .63255 m .54244 .63164 L .60911 .62099 L p .178 .713 .76 r
F P
0 g
s
.61143 .62092 m .58131 .62617 L p .60911 .62099 L .178 .713 .76 r
F P
0 g
s
.60911 .62099 m .58131 .62617 L .57727 .6267 L .178 .713 .76 r
F
.60643 .62142 m .56016 .62881 L p .60423 .62221 L 0 0 0 r
F P
0 g
s
.56016 .62881 m .54244 .63164 L p .56308 .62849 L 0 0 0 r
F P
0 g
s
.60423 .62221 m .56016 .62881 L .56308 .62849 L 0 0 0 r
F
.58131 .62617 m .54468 .63255 L p .57727 .6267 L .178 .713 .76 r
F P
0 g
s
.54244 .63164 m .54018 .63131 L .60423 .62221 L p 0 0 0 r
F P
0 g
s
.59933 .62428 m .60423 .62221 L .6014 .62261 L p .103 0 0 r
F P
0 g
s
.6014 .62261 m .54018 .63131 L p .59933 .62428 L .103 0 0 r
F P
0 g
s
.59933 .62428 m .59441 .62739 L .59699 .62616 L p 0 0 0 r
F P
0 g
s
.60423 .62221 m .59933 .62428 L .60175 .6231 L p 0 0 0 r
F P
0 g
s
.60423 .62221 m .60911 .62099 L .60643 .62142 L p 0 0 0 r
F P
0 g
s
.60911 .62099 m .60423 .62221 L .60651 .62107 L p .416 .855 .755 r
F P
0 g
s
.60651 .62107 m .65789 .59553 L p .60911 .62099 L .416 .855 .755 r
F P
0 g
s
.65069 .59922 m .65789 .59553 L .65337 .59777 L p 0 0 0 r
F P
0 g
s
.65337 .59777 m .60423 .62221 L p .63349 .60773 L 0 0 0 r
F P
0 g
s
.65069 .59922 m .65337 .59777 L .63349 .60773 L 0 0 0 r
F
.61397 .62048 m .60911 .62099 L .66508 .59275 L p .503 .91 .853 r
F P
0 g
s
.65789 .59553 m .66508 .59275 L .60911 .62099 L p .416 .855 .755 r
F P
0 g
s
.59699 .62616 m .64348 .60404 L p .6126 .61819 L 0 0 0 r
F P
0 g
s
.60175 .6231 m .65069 .59922 L p .63349 .60773 L 0 0 0 r
F P
0 g
s
.63349 .60773 m .60423 .62221 L .60182 .62307 L 0 0 0 r
F
.63349 .60773 m .60182 .62307 L .60175 .6231 L F
.6126 .61819 m .59933 .62428 L .59748 .62577 L F
.6126 .61819 m .59748 .62577 L .59699 .62616 L F
.55732 .62934 m .57769 .62689 L p .56234 .62868 L .103 0 0 r
F P
0 g
s
.57769 .62689 m .59933 .62428 L p .57392 .6273 L .103 0 0 r
F P
0 g
s
.57392 .6273 m .56234 .62868 L .57769 .62689 L .103 0 0 r
F
.60911 .62099 m .61397 .62048 L .61143 .62092 L p .178 .713 .76 r
F P
0 g
s
.54122 .63128 m .55732 .62934 L p .55143 .62997 L .103 0 0 r
F P
0 g
s
.56234 .62868 m .55143 .62997 L .55732 .62934 L .103 0 0 r
F
.55143 .62997 m .54018 .63131 L .54104 .63129 L F
.55143 .62997 m .54104 .63129 L .54122 .63128 L F
.54018 .63131 m .54244 .63164 L .53926 .63134 L p 0 .538 .728 r
F P
0 g
s
.53926 .63134 m .49064 .62672 L p .54018 .63131 L 0 .538 .728 r
F P
0 g
s
.49064 .62672 m .47137 .62489 L p .49263 .62687 L 0 .538 .728 r
F P
0 g
s
.54018 .63131 m .49064 .62672 L .49263 .62687 L 0 .538 .728 r
F
.53791 .63168 m .54018 .63131 L .49071 .62544 L p .199 0 0 r
F P
0 g
s
.49071 .62544 m .4719 .62321 L p .49252 .62585 L .199 0 0 r
F P
0 g
s
.53791 .63168 m .49071 .62544 L .49252 .62585 L .199 0 0 r
F
.50883 .62795 m .49252 .62585 L .512 .62786 L F
.49252 .62585 m .4719 .62321 L .49021 .62533 L F
.49252 .62585 m .49021 .62533 L .512 .62786 L F
.512 .62786 m .53791 .63168 L p .50883 .62795 L F P
0 g
s
.53563 .6329 m .53791 .63168 L .49077 .62472 L p .345 0 0 r
F P
0 g
s
.49077 .62472 m .47244 .62202 L p .4924 .62545 L .345 0 0 r
F P
0 g
s
.53563 .6329 m .49077 .62472 L .4924 .62545 L .345 0 0 r
F
.47297 .62142 m .48181 .62304 L p .47479 .62227 L F P
0 g
s
.49006 .62492 m .47244 .62202 L .48181 .62304 L .345 0 0 r
F
.50719 .628 m .47957 .62324 L .51014 .62823 L F
.47957 .62324 m .47244 .62202 L .47927 .62314 L F
.47957 .62324 m .47927 .62314 L .51014 .62823 L F
.47351 .62155 m .50827 .62945 L p .47589 .62208 L .465 0 0 r
F P
0 g
s
.47297 .62142 m .47351 .62155 L p .47589 .62208 L .465 0 0 r
F P
0 g
s
.50555 .62883 m .47297 .62142 L .50827 .62945 L .465 0 0 r
F
.48181 .62304 m .51014 .62823 L p .49006 .62492 L .345 0 0 r
F P
0 g
s
.51014 .62823 m .53563 .6329 L p .50719 .628 L .345 0 0 r
F P
0 g
s
.53334 .63515 m .53563 .6329 L .47297 .62142 L p .465 0 0 r
F P
0 g
s
.4121 .59515 m .41549 .59352 L .47351 .62155 L p 0 .317 .668 r
F P
0 g
s
.47297 .62142 m .41639 .597 L p .47038 .6202 L 0 .317 .668 r
F P
0 g
s
.47351 .62155 m .47297 .62142 L p .47038 .6202 L 0 .317 .668 r
F P
0 g
s
.40873 .59717 m .4121 .59515 L .47297 .62142 L p 0 .448 .799 r
F P
0 g
s
.47297 .62142 m .47244 .62202 L .40873 .59717 L p 0 .448 .799 r
F P
0 g
s
.47351 .62155 m .47085 .62026 L p .47223 .62126 L .428 0 0 r
F P
0 g
s
.47244 .62202 m .47297 .62142 L p .47479 .62227 L .345 0 0 r
F P
0 g
s
.47405 .62257 m .47351 .62155 L p .47223 .62126 L .428 0 0 r
F P
0 g
s
.47038 .6202 m .41639 .597 L .4193 .59824 L 0 .317 .668 r
F
.47085 .62026 m .41956 .59549 L p .46618 .61867 L .428 0 0 r
F P
0 g
s
.46618 .61867 m .41956 .59549 L .42231 .59691 L .428 0 0 r
F
.41549 .59352 m .4189 .59238 L .46633 .61835 L p F P
0 g
s
.47405 .62257 m .47085 .62026 L .46618 .61867 L .428 0 0 r
F
.46633 .61835 m .47405 .62257 L p .46055 .61587 L F P
0 g
s
.41956 .59549 m .41549 .59352 L p .42231 .59691 L .428 0 0 r
F P
0 g
s
.46055 .61587 m .41549 .59352 L .46633 .61835 L .428 0 0 r
F
.40539 .59952 m .40873 .59717 L .47244 .62202 L p .054 .547 .887 r
F P
0 g
s
.47244 .62202 m .4719 .62321 L .40539 .59952 L p .054 .547 .887 r
F P
0 g
s
.47459 .6247 m .47405 .62257 L .42274 .59449 L p .572 0 0 r
F P
0 g
s
.42274 .59449 m .4189 .59238 L p .42533 .59611 L .572 0 0 r
F P
0 g
s
.47459 .6247 m .42274 .59449 L .42533 .59611 L .572 0 0 r
F
.4189 .59238 m .42233 .59182 L .46706 .61996 L p F P
0 g
s
.46141 .61705 m .4189 .59238 L .46706 .61996 L .572 0 0 r
F
.4719 .62321 m .47137 .62489 L .40206 .60215 L p .174 .615 .94 r
F P
0 g
s
.40206 .60215 m .40539 .59952 L .4719 .62321 L p .174 .615 .94 r
F P
0 g
s
.46706 .61996 m .47459 .6247 L p .46141 .61705 L .572 0 0 r
F P
0 g
s
.49056 .62847 m .47085 .62698 L p .49273 .62841 L .1 .642 .846 r
F P
0 g
s
.39875 .60502 m .40206 .60215 L .47137 .62489 L p .268 .661 .968 r
F P
0 g
s
.47513 .62824 m .47459 .6247 L .42945 .5963 L p .68 .135 0 r
F P
0 g
s
.47513 .62824 m .42945 .5963 L .43045 .59722 L .68 .135 0 r
F
.47513 .62824 m .42594 .59409 L .42835 .59598 L F
.42945 .5963 m .42594 .59409 L p .43045 .59722 L F P
0 g
s
.42594 .59409 m .42233 .59182 L p .42835 .59598 L .68 .135 0 r
F P
0 g
s
.42233 .59182 m .42578 .59197 L .46778 .62284 L p .68 .135 0 r
F P
0 g
s
.46227 .61937 m .42233 .59182 L .46778 .62284 L .68 .135 0 r
F
.46778 .62284 m .47513 .62824 L p .46227 .61937 L F P
0 g
s
.47568 .63357 m .47513 .62824 L .43239 .59683 L p .754 .248 .011 r
F P
0 g
s
.43239 .59683 m .42578 .59197 L p .43411 .59892 L .754 .248 .011 r
F P
0 g
s
.47568 .63357 m .43239 .59683 L .43411 .59892 L .754 .248 .011 r
F
.42578 .59197 m .42925 .593 L .43236 .59572 L p F P
0 g
s
.43556 .59852 m .46852 .62731 L p .437 .60125 L .754 .248 .011 r
F P
0 g
s
.42925 .593 m .43274 .59513 L .43574 .59831 L p .8 .336 .13 r
F P
0 g
s
.46314 .62312 m .42578 .59197 L .46852 .62731 L .754 .248 .011 r
F
.43236 .59572 m .43556 .59852 L p .43405 .59881 L F P
0 g
s
.437 .60125 m .43405 .59881 L .43556 .59852 L .754 .248 .011 r
F
.43405 .59881 m .42578 .59197 L .43236 .59572 L F
.46852 .62731 m .47568 .63357 L p .46314 .62312 L F P
0 g
s
.47622 .64124 m .47568 .63357 L .43532 .59831 L p .8 .336 .13 r
F P
0 g
s
.43532 .59831 m .42925 .593 L p .4369 .60086 L .8 .336 .13 r
F P
0 g
s
.47622 .64124 m .43532 .59831 L .4369 .60086 L .8 .336 .13 r
F
.43574 .59831 m .43905 .60183 L p .43713 .60099 L F P
0 g
s
.43905 .60183 m .44239 .60536 L p .44031 .60421 L .8 .336 .13 r
F P
0 g
s
.4434 .60735 m .44031 .60421 L .44239 .60536 L .8 .336 .13 r
F
.44031 .60421 m .43713 .60099 L .43905 .60183 L F
.44239 .60536 m .46278 .62699 L p .4434 .60735 L F P
0 g
s
.43713 .60099 m .42925 .593 L .43574 .59831 L .8 .336 .13 r
F
.46278 .62699 m .47622 .64124 L p .45855 .6231 L F P
0 g
s
.45855 .6231 m .42925 .593 L .46278 .62699 L .8 .336 .13 r
F
.47677 .65202 m .47622 .64124 L .43825 .60097 L p .83 .402 .222 r
F P
0 g
s
.43825 .60097 m .43274 .59513 L p .43967 .60408 L .83 .402 .222 r
F P
0 g
s
.47677 .65202 m .43825 .60097 L .43967 .60408 L .83 .402 .222 r
F
.44073 .60537 m .43776 .60156 L .43932 .6027 L F
.43625 .59866 m .43932 .6027 L p .43776 .60156 L F P
0 g
s
.45965 .6299 m .44087 .60564 L .46376 .63489 L .83 .402 .222 r
F
.44087 .60564 m .43274 .59513 L .44073 .60537 L F
.44087 .60564 m .44073 .60537 L .46376 .63489 L F
.43932 .6027 m .46376 .63489 L p .44073 .60537 L F P
0 g
s
.46376 .63489 m .47677 .65202 L p .45965 .6299 L .83 .402 .222 r
F P
0 g
s
.47731 .66704 m .47677 .65202 L .43625 .59866 L p .848 .452 .292 r
F P
0 g
s
.40161 .54082 m .40797 .53871 L .43978 .60397 L p 0 0 .408 r
F P
0 g
s
.43534 .59516 m .43485 .59386 L .43314 .59061 L .66 .284 0 r
F
.43625 .59866 m .43978 .60397 L p .44176 .60779 L .848 .452 .292 r
F P
0 g
s
.43719 .59897 m .43668 .5977 L .43534 .59516 L .66 .284 0 r
F
.43978 .60397 m .4429 .60921 L p .44176 .60779 L .848 .452 .292 r
F P
0 g
s
.4429 .60921 m .46477 .64596 L p .44428 .61198 L .848 .452 .292 r
F P
0 g
s
.44428 .61198 m .44176 .60779 L .4429 .60921 L .848 .452 .292 r
F
.46477 .64596 m .47731 .66704 L p .46076 .63948 L F P
0 g
s
.46076 .63948 m .44444 .6123 L .46477 .64596 L .848 .452 .292 r
F
.44444 .6123 m .43625 .59866 L .44428 .61198 L F
.44444 .6123 m .44428 .61198 L .46477 .64596 L F
.4429 .60921 m .43978 .60397 L p .44611 .61795 L .861 .49 .346 r
F P
0 g
s
.43978 .60397 m .44333 .61162 L p .44588 .61743 L .861 .49 .346 r
F P
0 g
s
.47784 .68801 m .4429 .60921 L .44611 .61795 L .861 .49 .346 r
F
.46188 .65278 m .44611 .61795 L .45918 .64677 L F
.44611 .61795 m .43978 .60397 L .44588 .61743 L F
.44611 .61795 m .44588 .61743 L .45918 .64677 L F
.41007 .53791 m .41439 .53627 L .44333 .61162 L p .66 .284 0 r
F P
0 g
s
.43984 .60371 m .43994 .6033 L .43891 .60123 L .732 .384 0 r
F
.43978 .60397 m .43318 .59339 L .43188 .59091 L 0 0 .408 r
F
.43978 .60397 m .43625 .59866 L p .43521 .59665 L F P
0 g
s
.44333 .61162 m .43845 .6014 L .43719 .59897 L .66 .284 0 r
F
.43845 .6014 m .43668 .5977 L .43719 .59897 L F
.43668 .5977 m .43485 .59386 L .43534 .59516 L F
.43978 .60397 m .4372 .59868 L p .43845 .6014 L F P
0 g
s
.4372 .59868 m .43485 .59386 L p .43668 .5977 L .66 .284 0 r
F P
0 g
s
.43845 .6014 m .4372 .59868 L .43668 .5977 L .66 .284 0 r
F
.44333 .61162 m .43978 .60397 L p .43845 .6014 L F P
0 g
s
.43485 .59386 m .40797 .53871 L p .43314 .59061 L .66 .284 0 r
F P
0 g
s
.40797 .53871 m .41007 .53791 L p .44333 .61162 L .66 .284 0 r
F P
0 g
s
.46287 .65495 m .45918 .64677 L .46579 .66133 L .861 .49 .346 r
F
.46188 .65278 m .45918 .64677 L .46287 .65495 L F
.44333 .61162 m .46579 .66133 L p .44588 .61743 L F P
0 g
s
.46579 .66133 m .47784 .68801 L p .46188 .65278 L .861 .49 .346 r
F P
0 g
s
.47837 .71766 m .47784 .68801 L .44333 .61162 L p .869 .52 .386 r
F P
0 g
s
.44689 .62238 m .47837 .71766 L p .46504 .67732 L .869 .52 .386 r
F P
0 g
s
.44333 .61162 m .44689 .62238 L p .46504 .67732 L .869 .52 .386 r
F P
0 g
s
.44689 .62238 m .44128 .60698 L .43984 .60371 L .732 .384 0 r
F
.44128 .60698 m .43994 .6033 L .43984 .60371 L F
.43891 .60123 m .4365 .59386 L .43506 .59104 L F
.43994 .6033 m .4365 .59386 L .43891 .60123 L F
.44333 .61162 m .44075 .60492 L p .44128 .60698 L F P
0 g
s
.44075 .60492 m .4365 .59386 L p .43994 .6033 L .732 .384 0 r
F P
0 g
s
.44128 .60698 m .44075 .60492 L .43994 .6033 L .732 .384 0 r
F
.44689 .62238 m .44333 .61162 L p .44128 .60698 L F P
0 g
s
.4365 .59386 m .41439 .53627 L p .43506 .59104 L .732 .384 0 r
F P
0 g
s
.41439 .53627 m .41787 .53453 L p .44689 .62238 L .732 .384 0 r
F P
0 g
s
.47784 .68801 m .47731 .66704 L .4429 .60921 L p .861 .49 .346 r
F P
0 g
s
.41787 .53453 m .42087 .53303 L .44689 .62238 L p .732 .384 0 r
F P
0 g
s
.43188 .59091 m .4312 .59023 L .42939 .58678 L 0 0 .408 r
F
.43318 .59339 m .4312 .59023 L .43188 .59091 L F
.43274 .59513 m .43625 .59866 L p .43776 .60156 L .83 .402 .222 r
F P
0 g
s
.43625 .59866 m .4312 .59023 L p .43521 .59665 L 0 0 .408 r
F P
0 g
s
.4312 .59023 m .40161 .54082 L p .42939 .58678 L 0 0 .408 r
F P
0 g
s
.41639 .597 m .4121 .59515 L p .4193 .59824 L 0 .317 .668 r
F P
0 g
s
.47351 .62155 m .47405 .62257 L .5064 .63173 L p .553 .029 0 r
F P
0 g
s
.5064 .63173 m .53105 .63871 L p .50392 .63062 L .553 .029 0 r
F P
0 g
s
.50392 .63062 m .47351 .62155 L .5064 .63173 L .553 .029 0 r
F
.50827 .62945 m .53334 .63515 L p .50555 .62883 L .465 0 0 r
F P
0 g
s
.32856 .57186 m .33445 .56872 L .39875 .60502 L p .482 .671 .947 r
F P
0 g
s
.40206 .60215 m .39875 .60502 L .33445 .56872 L p .456 .658 .948 r
F P
0 g
s
.63321 .62346 m .62843 .62211 L .69367 .58814 L p .649 .92 .977 r
F P
0 g
s
.69367 .58814 m .70076 .58815 L .63321 .62346 L p .649 .92 .977 r
F P
0 g
s
.25142 .531 m .25946 .52848 L .31688 .57833 L p .597 .687 .905 r
F P
0 g
s
.3227 .57507 m .31688 .57833 L .25946 .52848 L p .592 .682 .904 r
F P
0 g
s
.25946 .52848 m .26752 .52595 L .3227 .57507 L p .592 .682 .904 r
F P
0 g
s
.32856 .57186 m .3227 .57507 L .26752 .52595 L p .586 .676 .903 r
F P
0 g
s
.33445 .56872 m .34038 .56566 L .40206 .60215 L p .456 .658 .948 r
F P
0 g
s
.40539 .59952 m .40206 .60215 L .34038 .56566 L p .423 .641 .947 r
F P
0 g
s
.62843 .62211 m .62363 .62113 L .68655 .58852 L p .632 .931 .969 r
F P
0 g
s
.68655 .58852 m .69367 .58814 L .62843 .62211 L p .632 .931 .969 r
F P
0 g
s
.26752 .52595 m .27562 .52342 L .32856 .57186 L p .586 .676 .903 r
F P
0 g
s
.33445 .56872 m .32856 .57186 L .27562 .52342 L p .579 .669 .901 r
F P
0 g
s
.34038 .56566 m .34633 .56268 L .40539 .59952 L p .423 .641 .947 r
F P
0 g
s
.40873 .59717 m .40539 .59952 L .34633 .56268 L p .384 .619 .944 r
F P
0 g
s
.62363 .62113 m .61881 .62056 L .67941 .58936 L p .606 .938 .95 r
F P
0 g
s
.67941 .58936 m .68655 .58852 L .62363 .62113 L p .606 .938 .95 r
F P
0 g
s
.27562 .52342 m .28375 .52087 L .33445 .56872 L p .579 .669 .901 r
F P
0 g
s
.34038 .56566 m .33445 .56872 L .28375 .52087 L p .571 .661 .898 r
F P
0 g
s
.34633 .56268 m .35232 .55979 L .40873 .59717 L p .384 .619 .944 r
F P
0 g
s
.4121 .59515 m .40873 .59717 L .35232 .55979 L p .335 .59 .938 r
F P
0 g
s
.28375 .52087 m .29191 .5183 L .34038 .56566 L p .571 .661 .898 r
F P
0 g
s
.34633 .56268 m .34038 .56566 L .29191 .5183 L p .563 .652 .895 r
F P
0 g
s
.61881 .62056 m .61397 .62048 L .67226 .59074 L p .565 .933 .915 r
F P
0 g
s
.67226 .59074 m .67941 .58936 L .61881 .62056 L p .565 .933 .915 r
F P
0 g
s
.29191 .5183 m .30011 .51569 L .34633 .56268 L p .563 .652 .895 r
F P
0 g
s
.35232 .55979 m .34633 .56268 L .30011 .51569 L p .553 .641 .891 r
F P
0 g
s
.35232 .55979 m .35835 .55701 L .4121 .59515 L p .335 .59 .938 r
F P
0 g
s
.41549 .59352 m .4121 .59515 L .35835 .55701 L p .274 .552 .927 r
F P
0 g
s
.25142 .531 m .24342 .53352 L .20351 .47082 L p .642 .699 .887 r
F P
0 g
s
.66508 .59275 m .67226 .59074 L .61397 .62048 L p .503 .91 .853 r
F P
0 g
s
.20351 .47082 m .21318 .46975 L .25142 .531 L p .642 .699 .887 r
F P
0 g
s
.25946 .52848 m .25142 .531 L .21318 .46975 L p .641 .696 .885 r
F P
0 g
s
.30011 .51569 m .30835 .51304 L .35232 .55979 L p .553 .641 .891 r
F P
0 g
s
.35835 .55701 m .35232 .55979 L .30835 .51304 L p .543 .628 .886 r
F P
0 g
s
.70783 .58849 m .70076 .58815 L .74908 .53622 L p .748 .888 .943 r
F P
0 g
s
.74908 .53622 m .75803 .53501 L .70783 .58849 L p .748 .888 .943 r
F P
0 g
s
.53791 .63168 m .53563 .6329 L .59441 .62739 L p .231 0 0 r
F P
0 g
s
.59441 .62739 m .59933 .62428 L .53791 .63168 L p .231 0 0 r
F P
0 g
s
.21318 .46975 m .22287 .46865 L .25946 .52848 L p .641 .696 .885 r
F P
0 g
s
.26752 .52595 m .25946 .52848 L .22287 .46865 L p .641 .693 .883 r
F P
0 g
s
.35835 .55701 m .36441 .55434 L .41549 .59352 L p .274 .552 .927 r
F P
0 g
s
.4189 .59238 m .41549 .59352 L .36441 .55434 L p .198 .501 .907 r
F P
0 g
s
.30835 .51304 m .31662 .51031 L .35835 .55701 L p .543 .628 .886 r
F P
0 g
s
.36441 .55434 m .35835 .55701 L .31662 .51031 L p .532 .613 .879 r
F P
0 g
s
.70076 .58815 m .69367 .58814 L .74013 .53776 L p .755 .903 .943 r
F P
0 g
s
.74013 .53776 m .74908 .53622 L .70076 .58815 L p .755 .903 .943 r
F P
0 g
s
.22287 .46865 m .23258 .4675 L .26752 .52595 L p .641 .693 .883 r
F P
0 g
s
.27562 .52342 m .26752 .52595 L .23258 .4675 L p .64 .69 .88 r
F P
0 g
s
.53105 .63871 m .53334 .63515 L .47351 .62155 L p .553 .029 0 r
F P
0 g
s
.23258 .4675 m .24231 .46629 L .27562 .52342 L p .64 .69 .88 r
F P
0 g
s
.28375 .52087 m .27562 .52342 L .24231 .46629 L p .64 .686 .877 r
F P
0 g
s
.53563 .6329 m .53334 .63515 L .58949 .63177 L p .336 0 0 r
F P
0 g
s
.58949 .63177 m .59441 .62739 L .53563 .6329 L p .336 0 0 r
F P
0 g
s
.31662 .51031 m .32494 .50749 L .36441 .55434 L p .532 .613 .879 r
F P
0 g
s
.37051 .55179 m .36441 .55434 L .32494 .50749 L p .519 .596 .871 r
F P
0 g
s
.36441 .55434 m .37051 .55179 L .4189 .59238 L p .198 .501 .907 r
F P
0 g
s
.69367 .58814 m .68655 .58852 L .73117 .53969 L p .762 .919 .941 r
F P
0 g
s
.73117 .53969 m .74013 .53776 L .69367 .58814 L p .762 .919 .941 r
F P
0 g
s
.42233 .59182 m .4189 .59238 L .37051 .55179 L p .105 .435 .875 r
F P
0 g
s
.24231 .46629 m .25206 .46502 L .28375 .52087 L p .64 .686 .877 r
F P
0 g
s
.29191 .5183 m .28375 .52087 L .25206 .46502 L p .64 .682 .874 r
F P
0 g
s
.25206 .46502 m .26182 .46365 L .29191 .5183 L p .64 .682 .874 r
F P
0 g
s
.30011 .51569 m .29191 .5183 L .26182 .46365 L p .641 .678 .869 r
F P
0 g
s
.32494 .50749 m .33329 .50452 L .37051 .55179 L p .519 .596 .871 r
F P
0 g
s
.37665 .54937 m .37051 .55179 L .33329 .50452 L p .506 .576 .86 r
F P
0 g
s
.37051 .55179 m .37665 .54937 L .42233 .59182 L p .105 .435 .875 r
F P
0 g
s
.68655 .58852 m .67941 .58936 L .72219 .54205 L p .769 .937 .938 r
F P
0 g
s
.72219 .54205 m .73117 .53969 L .68655 .58852 L p .769 .937 .938 r
F P
0 g
s
.47405 .62257 m .47459 .6247 L .52874 .64389 L p .614 .133 .089 r
F P
0 g
s
.52874 .64389 m .53105 .63871 L .47405 .62257 L p .614 .133 .089 r
F P
0 g
s
.26182 .46365 m .27161 .46216 L .30011 .51569 L p .641 .678 .869 r
F P
0 g
s
.30835 .51304 m .30011 .51569 L .27161 .46216 L p .642 .673 .864 r
F P
0 g
s
.42578 .59197 m .42233 .59182 L .37665 .54937 L p 0 .348 .825 r
F P
0 g
s
.53334 .63515 m .53105 .63871 L .58455 .63776 L p .414 0 .051 r
F P
0 g
s
.58455 .63776 m .58949 .63177 L .53334 .63515 L p .414 0 .051 r
F P
0 g
s
.27161 .46216 m .28143 .46053 L .30835 .51304 L p .642 .673 .864 r
F P
0 g
s
.31662 .51031 m .30835 .51304 L .28143 .46053 L p .644 .667 .858 r
F P
0 g
s
.33329 .50452 m .34169 .50135 L .37665 .54937 L p .506 .576 .86 r
F P
0 g
s
.38282 .54708 m .37665 .54937 L .34169 .50135 L p .493 .553 .846 r
F P
0 g
s
.37665 .54937 m .38282 .54708 L .42578 .59197 L p 0 .348 .825 r
F P
0 g
s
.63626 .61024 m .64348 .60404 L .64106 .60519 L p 0 0 0 r
F P
0 g
s
.64106 .60519 m .59441 .62739 L p .63626 .61024 L 0 0 0 r
F P
0 g
s
.62905 .61816 m .63626 .61024 L .63371 .61141 L p .076 0 0 r
F P
0 g
s
.63371 .61141 m .58949 .63177 L p .62905 .61816 L .076 0 0 r
F P
0 g
s
.62905 .61816 m .62184 .62827 L .62374 .62585 L p 0 0 0 r
F P
0 g
s
.63626 .61024 m .62905 .61816 L .63083 .61595 L p .635 .899 .581 r
F P
0 g
s
.6484 .60034 m .59933 .62428 L p .64348 .60404 L 0 0 0 r
F P
0 g
s
.59441 .62739 m .58949 .63177 L .63626 .61024 L p 0 0 0 r
F P
0 g
s
.63083 .61595 m .65934 .58066 L p .63626 .61024 L .635 .899 .581 r
F P
0 g
s
.62374 .62585 m .6504 .59186 L p .62905 .61816 L 0 0 0 r
F P
0 g
s
.64348 .60404 m .63626 .61024 L .63795 .60819 L p .704 .96 .703 r
F P
0 g
s
.63795 .60819 m .6683 .57152 L p .64348 .60404 L .704 .96 .703 r
F P
0 g
s
.64348 .60404 m .65069 .59922 L .6484 .60034 L p 0 0 0 r
F P
0 g
s
.67941 .58936 m .67226 .59074 L .71321 .54494 L p .775 .955 .93 r
F P
0 g
s
.71321 .54494 m .72219 .54205 L .67941 .58936 L p .775 .955 .93 r
F P
0 g
s
.28143 .46053 m .29127 .45871 L .31662 .51031 L p .644 .667 .858 r
F P
0 g
s
.32494 .50749 m .31662 .51031 L .29127 .45871 L p .646 .661 .85 r
F P
0 g
s
.47459 .6247 m .47513 .62824 L .52643 .65116 L p .655 .214 .191 r
F P
0 g
s
.52643 .65116 m .52874 .64389 L .47459 .6247 L p .655 .214 .191 r
F P
0 g
s
.34169 .50135 m .35013 .4979 L .38282 .54708 L p .493 .553 .846 r
F P
0 g
s
.38904 .54492 m .38282 .54708 L .35013 .4979 L p .479 .527 .829 r
F P
0 g
s
.38282 .54708 m .38904 .54492 L .42925 .593 L p 0 .24 .752 r
F P
0 g
s
.42925 .593 m .42578 .59197 L .38282 .54708 L p 0 .24 .752 r
F P
0 g
s
.29127 .45871 m .30113 .45665 L .32494 .50749 L p .646 .661 .85 r
F P
0 g
s
.33329 .50452 m .32494 .50749 L .30113 .45665 L p .649 .654 .842 r
F P
0 g
s
.67226 .59074 m .66508 .59275 L .70423 .54845 L p .779 .973 .916 r
F P
0 g
s
.70423 .54845 m .71321 .54494 L .67226 .59074 L p .779 .973 .916 r
F P
0 g
s
.30113 .45665 m .31103 .45427 L .33329 .50452 L p .649 .654 .842 r
F P
0 g
s
.34169 .50135 m .33329 .50452 L .31103 .45427 L p .654 .647 .831 r
F P
0 g
s
.53105 .63871 m .52874 .64389 L .57961 .64577 L p .471 .051 .161 r
F P
0 g
s
.57961 .64577 m .58455 .63776 L .53105 .63871 L p .471 .051 .161 r
F P
0 g
s
.38027 .36967 m .39094 .35485 L .39179 .39873 L p .906 .77 .7 r
F P
0 g
s
.39179 .39873 m .38146 .41355 L .38027 .36967 L p .906 .77 .7 r
F P
0 g
s
.38146 .41355 m .39179 .39873 L .40208 .45772 L p .749 .595 .685 r
F P
0 g
s
.39641 .40468 m .39179 .39873 L .39094 .35485 L p .354 .311 .672 r
F P
0 g
s
.39179 .39873 m .39641 .40468 L .40618 .4617 L p .312 .274 .655 r
F P
0 g
s
.40618 .4617 m .40208 .45772 L .39179 .39873 L p .312 .274 .655 r
F P
0 g
s
.35013 .4979 m .35862 .49404 L .38904 .54492 L p .479 .527 .829 r
F P
0 g
s
.3953 .54285 m .38904 .54492 L .35862 .49404 L p .467 .499 .808 r
F P
0 g
s
.38904 .54492 m .3953 .54285 L .43274 .59513 L p 0 .113 .655 r
F P
0 g
s
.43274 .59513 m .42925 .593 L .38904 .54492 L p 0 .113 .655 r
F P
0 g
s
.31103 .45427 m .32096 .45149 L .34169 .50135 L p .654 .647 .831 r
F P
0 g
s
.35013 .4979 m .34169 .50135 L .32096 .45149 L p .66 .639 .818 r
F P
0 g
s
.32096 .45149 m .33092 .44816 L .35013 .4979 L p .66 .639 .818 r
F P
0 g
s
.35862 .49404 m .35013 .4979 L .33092 .44816 L p .668 .631 .803 r
F P
0 g
s
.66508 .59275 m .65789 .59553 L .69524 .55269 L p .779 .989 .893 r
F P
0 g
s
.69524 .55269 m .70423 .54845 L .66508 .59275 L p .779 .989 .893 r
F P
0 g
s
.39009 .33726 m .3803 .34647 L .38314 .34362 L p .533 .848 .545 r
F P
0 g
s
.39009 .33726 m .39989 .32404 L .39821 .32982 L p .947 .957 .676 r
F P
0 g
s
.39565 .36204 m .39094 .35485 L .39989 .32404 L p .417 .358 .684 r
F P
0 g
s
.39989 .32404 m .40421 .33223 L .39565 .36204 L p .417 .358 .684 r
F P
0 g
s
.40421 .33223 m .39989 .32404 L .4181 .30576 L p .475 .397 .689 r
F P
0 g
s
.39989 .32404 m .39009 .33726 L .41031 .317 L p 0 0 0 r
F P
0 g
s
.38314 .34362 m .40251 .32421 L p .39009 .33726 L .533 .848 .545 r
F P
0 g
s
.39821 .32982 m .39094 .35485 L p .39009 .33726 L .947 .957 .676 r
F P
0 g
s
.39094 .35485 m .38027 .36967 L .39009 .33726 L p .947 .957 .676 r
F P
0 g
s
.39094 .35485 m .39565 .36204 L .39641 .40468 L p .354 .311 .672 r
F P
0 g
s
.40107 .41071 m .39641 .40468 L .39565 .36204 L p .359 .312 .669 r
F P
0 g
s
.39641 .40468 m .40107 .41071 L .41031 .46564 L p .32 .278 .654 r
F P
0 g
s
.41031 .46564 m .40618 .4617 L .39641 .40468 L p .32 .278 .654 r
F P
0 g
s
.33092 .44816 m .34092 .44411 L .35862 .49404 L p .668 .631 .803 r
F P
0 g
s
.36717 .4896 m .35862 .49404 L .34092 .44411 L p .679 .623 .786 r
F P
0 g
s
.35862 .49404 m .36717 .4896 L .3953 .54285 L p .467 .499 .808 r
F P
0 g
s
.47513 .62824 m .47568 .63357 L .52411 .66114 L p .683 .277 .27 r
F P
0 g
s
.52411 .66114 m .52643 .65116 L .47513 .62824 L p .683 .277 .27 r
F P
0 g
s
.40161 .54082 m .3953 .54285 L .36717 .4896 L p .456 .468 .782 r
F P
0 g
s
.3953 .54285 m .40161 .54082 L .43625 .59866 L p 0 0 .536 r
F P
0 g
s
.43625 .59866 m .43274 .59513 L .3953 .54285 L p 0 0 .536 r
F P
0 g
s
.40208 .45772 m .39322 .46922 L .38146 .41355 L p .749 .595 .685 r
F P
0 g
s
.39322 .46922 m .40208 .45772 L .42087 .53303 L p .46 .384 .685 r
F P
0 g
s
.40208 .45772 m .40618 .4617 L .42407 .53379 L p .306 .256 .637 r
F P
0 g
s
.42407 .53379 m .42087 .53303 L .40208 .45772 L p .306 .256 .637 r
F P
0 g
s
.36966 .38042 m .38027 .36967 L .38146 .41355 L p .871 .759 .736 r
F P
0 g
s
.38146 .41355 m .37123 .42447 L .36966 .38042 L p .871 .759 .736 r
F P
0 g
s
.37123 .42447 m .38146 .41355 L .39322 .46922 L p .727 .6 .715 r
F P
0 g
s
.40039 .36942 m .39565 .36204 L .40421 .33223 L p .417 .355 .68 r
F P
0 g
s
.39565 .36204 m .40039 .36942 L .40107 .41071 L p .359 .312 .669 r
F P
0 g
s
.34092 .44411 m .35097 .43908 L .36717 .4896 L p .679 .623 .786 r
F P
0 g
s
.37578 .4843 m .36717 .4896 L .35097 .43908 L p .691 .614 .765 r
F P
0 g
s
.36717 .4896 m .37578 .4843 L .40161 .54082 L p .456 .468 .782 r
F P
0 g
s
.58949 .63177 m .58455 .63776 L .62905 .61816 L p .076 0 0 r
F P
0 g
s
.35097 .43908 m .36107 .43271 L .37578 .4843 L p .691 .614 .765 r
F P
0 g
s
.38446 .47772 m .37578 .4843 L .36107 .43271 L p .707 .606 .741 r
F P
0 g
s
.37578 .4843 m .38446 .47772 L .40797 .53871 L p .45 .437 .753 r
F P
0 g
s
.40797 .53871 m .40161 .54082 L .37578 .4843 L p .45 .437 .753 r
F P
0 g
s
.40575 .41683 m .40107 .41071 L .40039 .36942 L p .364 .312 .666 r
F P
0 g
s
.40107 .41071 m .40575 .41683 L .41447 .46955 L p .328 .281 .652 r
F P
0 g
s
.41447 .46955 m .41031 .46564 L .40107 .41071 L p .328 .281 .652 r
F P
0 g
s
.39322 .46922 m .38446 .47772 L .37123 .42447 L p .727 .6 .715 r
F P
0 g
s
.38446 .47772 m .39322 .46922 L .41439 .53627 L p .45 .408 .72 r
F P
0 g
s
.42087 .53303 m .41439 .53627 L .39322 .46922 L p .46 .384 .685 r
F P
0 g
s
.36107 .43271 m .37123 .42447 L .38446 .47772 L p .707 .606 .741 r
F P
0 g
s
.41439 .53627 m .40797 .53871 L .38446 .47772 L p .45 .408 .72 r
F P
0 g
s
.65789 .59553 m .65069 .59922 L .68625 .55781 L p .77 .996 .854 r
F P
0 g
s
.68625 .55781 m .69524 .55269 L .65789 .59553 L p .77 .996 .854 r
F P
0 g
s
.52874 .64389 m .52643 .65116 L .57467 .65639 L p .513 .127 .246 r
F P
0 g
s
.57467 .65639 m .57961 .64577 L .52874 .64389 L p .513 .127 .246 r
F P
0 g
s
.21318 .46975 m .20351 .47082 L .19165 .40188 L p .668 .715 .884 r
F P
0 g
s
.40421 .33223 m .40853 .34067 L .40039 .36942 L p .417 .355 .68 r
F P
0 g
s
.40514 .37699 m .40039 .36942 L .40853 .34067 L p .417 .352 .676 r
F P
0 g
s
.40039 .36942 m .40514 .37699 L .40575 .41683 L p .364 .312 .666 r
F P
0 g
s
.19165 .40188 m .20212 .40281 L .21318 .46975 L p .668 .715 .884 r
F P
0 g
s
.22287 .46865 m .21318 .46975 L .20212 .40281 L p .669 .714 .882 r
F P
0 g
s
.40618 .4617 m .41031 .46564 L .4273 .53444 L p .314 .261 .637 r
F P
0 g
s
.4273 .53444 m .42407 .53379 L .40618 .4617 L p .314 .261 .637 r
F P
0 g
s
.35909 .38827 m .36966 .38042 L .37123 .42447 L p .839 .749 .765 r
F P
0 g
s
.37123 .42447 m .36107 .43271 L .35909 .38827 L p .839 .749 .765 r
F P
0 g
s
.20212 .40281 m .21258 .40368 L .22287 .46865 L p .669 .714 .882 r
F P
0 g
s
.23258 .4675 m .22287 .46865 L .21258 .40368 L p .672 .714 .88 r
F P
0 g
s
.75803 .53501 m .74908 .53622 L .77155 .47156 L p .769 .829 .899 r
F P
0 g
s
.77155 .47156 m .78165 .46858 L .75803 .53501 L p .769 .829 .899 r
F P
0 g
s
.21258 .40368 m .22304 .40447 L .23258 .4675 L p .672 .714 .88 r
F P
0 g
s
.24231 .46629 m .23258 .4675 L .22304 .40447 L p .674 .714 .878 r
F P
0 g
s
.41046 .42302 m .40575 .41683 L .40514 .37699 L p .368 .313 .664 r
F P
0 g
s
.40575 .41683 m .41046 .42302 L .41866 .47343 L p .336 .284 .651 r
F P
0 g
s
.41866 .47343 m .41447 .46955 L .40575 .41683 L p .336 .284 .651 r
F P
0 g
s
.41031 .317 m .4181 .30576 L .39989 .32404 L p 0 0 0 r
F P
0 g
s
.3803 .34647 m .39009 .33726 L .38027 .36967 L p .937 .949 .765 r
F P
0 g
s
.38027 .36967 m .36966 .38042 L .3803 .34647 L p .937 .949 .765 r
F P
0 g
s
.22304 .40447 m .23349 .40517 L .24231 .46629 L p .674 .714 .878 r
F P
0 g
s
.25206 .46502 m .24231 .46629 L .23349 .40517 L p .677 .713 .876 r
F P
0 g
s
.40853 .34067 m .41287 .34937 L .40514 .37699 L p .417 .352 .676 r
F P
0 g
s
.40992 .38475 m .40514 .37699 L .41287 .34937 L p .418 .349 .673 r
F P
0 g
s
.40514 .37699 m .40992 .38475 L .41046 .42302 L p .368 .313 .664 r
F P
0 g
s
.34856 .39401 m .35909 .38827 L .36107 .43271 L p .81 .74 .787 r
F P
0 g
s
.36107 .43271 m .35097 .43908 L .34856 .39401 L p .81 .74 .787 r
F P
0 g
s
.23349 .40517 m .24394 .40575 L .25206 .46502 L p .677 .713 .876 r
F P
0 g
s
.26182 .46365 m .25206 .46502 L .24394 .40575 L p .681 .713 .873 r
F P
0 g
s
.24394 .40575 m .25439 .4062 L .26182 .46365 L p .681 .713 .873 r
F P
0 g
s
.27161 .46216 m .26182 .46365 L .25439 .4062 L p .686 .713 .869 r
F P
0 g
s
.41031 .46564 m .41447 .46955 L .43054 .53497 L p .322 .265 .637 r
F P
0 g
s
.43054 .53497 m .4273 .53444 L .41031 .46564 L p .322 .265 .637 r
F P
0 g
s
.74908 .53622 m .74013 .53776 L .76146 .47482 L p .778 .836 .896 r
F P
0 g
s
.76146 .47482 m .77155 .47156 L .74908 .53622 L p .778 .836 .896 r
F P
0 g
s
.4181 .30576 m .42152 .31497 L .40421 .33223 L p .475 .397 .689 r
F P
0 g
s
.40853 .34067 m .40421 .33223 L .42152 .31497 L p .471 .391 .685 r
F P
0 g
s
.25439 .4062 m .26483 .40647 L .27161 .46216 L p .686 .713 .869 r
F P
0 g
s
.28143 .46053 m .27161 .46216 L .26483 .40647 L p .692 .714 .866 r
F P
0 g
s
.33805 .39821 m .34856 .39401 L .35097 .43908 L p .784 .733 .805 r
F P
0 g
s
.35097 .43908 m .34092 .44411 L .33805 .39821 L p .784 .733 .805 r
F P
0 g
s
.47568 .63357 m .47622 .64124 L .52179 .67472 L p .702 .325 .331 r
F P
0 g
s
.52179 .67472 m .52411 .66114 L .47568 .63357 L p .702 .325 .331 r
F P
0 g
s
.65069 .59922 m .64348 .60404 L .67727 .56401 L p .747 .99 .793 r
F P
0 g
s
.67727 .56401 m .68625 .55781 L .65069 .59922 L p .747 .99 .793 r
F P
0 g
s
.26483 .40647 m .27528 .40653 L .28143 .46053 L p .692 .714 .866 r
F P
0 g
s
.29127 .45871 m .28143 .46053 L .27528 .40653 L p .699 .714 .861 r
F P
0 g
s
.41519 .4293 m .41046 .42302 L .40992 .38475 L p .373 .313 .661 r
F P
0 g
s
.41046 .42302 m .41519 .4293 L .42287 .47726 L p .343 .287 .65 r
F P
0 g
s
.42287 .47726 m .41866 .47343 L .41046 .42302 L p .343 .287 .65 r
F P
0 g
s
.32756 .40124 m .33805 .39821 L .34092 .44411 L p .763 .727 .82 r
F P
0 g
s
.34092 .44411 m .33092 .44816 L .32756 .40124 L p .763 .727 .82 r
F P
0 g
s
.27528 .40653 m .28572 .40633 L .29127 .45871 L p .699 .714 .861 r
F P
0 g
s
.30113 .45665 m .29127 .45871 L .28572 .40633 L p .707 .716 .856 r
F P
0 g
s
.28572 .40633 m .29617 .40581 L .30113 .45665 L p .707 .716 .856 r
F P
0 g
s
.31103 .45427 m .30113 .45665 L .29617 .40581 L p .717 .717 .849 r
F P
0 g
s
.41287 .34937 m .41722 .35832 L .40992 .38475 L p .418 .349 .673 r
F P
0 g
s
.41471 .3927 m .40992 .38475 L .41722 .35832 L p .418 .346 .669 r
F P
0 g
s
.40992 .38475 m .41471 .3927 L .41519 .4293 L p .373 .313 .661 r
F P
0 g
s
.31709 .40339 m .32756 .40124 L .33092 .44816 L p .745 .723 .832 r
F P
0 g
s
.33092 .44816 m .32096 .45149 L .31709 .40339 L p .745 .723 .832 r
F P
0 g
s
.29617 .40581 m .30663 .40486 L .31103 .45427 L p .717 .717 .849 r
F P
0 g
s
.32096 .45149 m .31103 .45427 L .30663 .40486 L p .73 .72 .841 r
F P
0 g
s
.30663 .40486 m .31709 .40339 L .32096 .45149 L p .73 .72 .841 r
F P
0 g
s
.58455 .63776 m .57961 .64577 L .62184 .62827 L p .17 0 .038 r
F P
0 g
s
.62184 .62827 m .62905 .61816 L .58455 .63776 L p .17 0 .038 r
F P
0 g
s
.42152 .31497 m .42495 .32442 L .40853 .34067 L p .471 .391 .685 r
F P
0 g
s
.41287 .34937 m .40853 .34067 L .42495 .32442 L p .467 .386 .681 r
F P
0 g
s
.74013 .53776 m .73117 .53969 L .75138 .47842 L p .789 .845 .894 r
F P
0 g
s
.75138 .47842 m .76146 .47482 L .74013 .53776 L p .789 .845 .894 r
F P
0 g
s
.41447 .46955 m .41866 .47343 L .4338 .53538 L p .329 .269 .637 r
F P
0 g
s
.4338 .53538 m .43054 .53497 L .41447 .46955 L p .329 .269 .637 r
F P
0 g
s
.37052 .35276 m .3803 .34647 L .36966 .38042 L p .906 .922 .817 r
F P
0 g
s
.36966 .38042 m .35909 .38827 L .37052 .35276 L p .906 .922 .817 r
F P
0 g
s
.52643 .65116 m .52411 .66114 L .56974 .67041 L p .543 .185 .311 r
F P
0 g
s
.56974 .67041 m .57467 .65639 L .52643 .65116 L p .543 .185 .311 r
F P
0 g
s
.41996 .43566 m .41519 .4293 L .41471 .3927 L p .377 .313 .658 r
F P
0 g
s
.41519 .4293 m .41996 .43566 L .42712 .48106 L p .35 .29 .648 r
F P
0 g
s
.42712 .48106 m .42287 .47726 L .41519 .4293 L p .35 .29 .648 r
F P
0 g
s
.42495 .32442 m .42838 .33411 L .41287 .34937 L p .467 .386 .681 r
F P
0 g
s
.41722 .35832 m .41287 .34937 L .42838 .33411 L p .463 .38 .677 r
F P
0 g
s
.41722 .35832 m .42158 .36753 L .41471 .3927 L p .418 .346 .669 r
F P
0 g
s
.41954 .40086 m .41471 .3927 L .42158 .36753 L p .418 .343 .666 r
F P
0 g
s
.41471 .3927 m .41954 .40086 L .41996 .43566 L p .377 .313 .658 r
F P
0 g
s
.73117 .53969 m .72219 .54205 L .74131 .4824 L p .801 .854 .89 r
F P
0 g
s
.74131 .4824 m .75138 .47842 L .73117 .53969 L p .801 .854 .89 r
F P
0 g
s
.6683 .57152 m .67727 .56401 L .64348 .60404 L p .704 .96 .703 r
F P
0 g
s
.41866 .47343 m .42287 .47726 L .43708 .53567 L p .337 .273 .637 r
F P
0 g
s
.43708 .53567 m .4338 .53538 L .41866 .47343 L p .337 .273 .637 r
F P
0 g
s
.42838 .33411 m .43182 .34406 L .41722 .35832 L p .463 .38 .677 r
F P
0 g
s
.42158 .36753 m .41722 .35832 L .43182 .34406 L p .46 .375 .673 r
F P
0 g
s
.39471 .32847 m .40251 .32421 L .39919 .32754 L p .682 .969 .766 r
F P
0 g
s
.39919 .32754 m .3803 .34647 L p .39471 .32847 L .682 .969 .766 r
F P
0 g
s
.39471 .32847 m .3869 .33055 L .39087 .32927 L p .259 .762 .728 r
F P
0 g
s
.40251 .32421 m .39471 .32847 L .39897 .32725 L p 0 0 0 r
F P
0 g
s
.40669 .32062 m .39009 .33726 L p .40251 .32421 L .533 .848 .545 r
F P
0 g
s
.42495 .32442 m .42152 .31497 L .44602 .31239 L p .503 .409 .682 r
F P
0 g
s
.39897 .32725 m .42947 .31852 L p .40251 .32421 L 0 0 0 r
F P
0 g
s
.40251 .32421 m .41031 .317 L .40669 .32062 L p .533 .848 .545 r
F P
0 g
s
.41031 .317 m .40251 .32421 L .4343 .31645 L p .185 0 0 r
F P
0 g
s
.42947 .31852 m .4343 .31645 L .43094 .31727 L p 0 0 0 r
F P
0 g
s
.43094 .31727 m .40251 .32421 L p .41988 .32054 L 0 0 0 r
F P
0 g
s
.41988 .32054 m .42947 .31852 L .42874 .31792 L 0 0 0 r
F
.42464 .31842 m .42947 .31852 L .42421 .32002 L p .259 .762 .728 r
F P
0 g
s
.42421 .32002 m .39471 .32847 L p .42464 .31842 L .259 .762 .728 r
F P
0 g
s
.42152 .31497 m .4181 .30576 L .44391 .30229 L p .509 .416 .686 r
F P
0 g
s
.44391 .30229 m .44602 .31239 L .42152 .31497 L p .509 .416 .686 r
F P
0 g
s
.4343 .31645 m .43911 .31144 L .41031 .317 L p .185 0 0 r
F P
0 g
s
.42464 .31842 m .41978 .31672 L .425 .31707 L p .134 .658 .88 r
F P
0 g
s
.42947 .31852 m .42464 .31842 L .43017 .31908 L p .143 0 0 r
F P
0 g
s
.44602 .31239 m .44814 .32265 L .42495 .32442 L p .503 .409 .682 r
F P
0 g
s
.47477 .31837 m .47529 .32873 L .44602 .31239 L p .517 .413 .675 r
F P
0 g
s
.44814 .32265 m .44602 .31239 L .47529 .32873 L p .511 .407 .672 r
F P
0 g
s
.43911 .31144 m .4343 .31645 L .4724 .32682 L p .539 .032 0 r
F P
0 g
s
.4724 .32682 m .47358 .32458 L .46691 .32204 L p .539 .032 0 r
F P
0 g
s
.46128 .32168 m .4724 .32682 L .46691 .32204 L .539 .032 0 r
F
.51018 .36041 m .50761 .35936 L .49024 .33768 L p .782 .295 .064 r
F P
0 g
s
.49142 .3385 m .51018 .36041 L .49024 .33768 L .782 .295 .064 r
F
.48745 .33342 m .51018 .36041 L .48338 .32912 L F
.49024 .33768 m .48338 .32912 L p .49142 .3385 L F P
0 g
s
.47529 .32873 m .47477 .31837 L .50761 .35936 L p .511 .394 .657 r
F P
0 g
s
.47358 .32458 m .51018 .36041 L p .48745 .33342 L .782 .295 .064 r
F P
0 g
s
.48338 .32912 m .47477 .31837 L p .48745 .33342 L .782 .295 .064 r
F P
0 g
s
.47477 .31837 m .47358 .32458 L p .48745 .33342 L .782 .295 .064 r
F P
0 g
s
.47529 .32873 m .47582 .33916 L .44814 .32265 L p .511 .407 .672 r
F P
0 g
s
.50761 .35936 m .50642 .36869 L .47529 .32873 L p .511 .394 .657 r
F P
0 g
s
.47582 .33916 m .47529 .32873 L .50642 .36869 L p .506 .39 .656 r
F P
0 g
s
.51276 .35839 m .51018 .36041 L .48808 .33878 L p .666 .114 0 r
F P
0 g
s
.48808 .33878 m .47358 .32458 L p .49073 .33939 L .666 .114 0 r
F P
0 g
s
.49073 .33939 m .51276 .35839 L .48808 .33878 L .666 .114 0 r
F
.47358 .32458 m .4724 .32682 L .5062 .35326 L p F P
0 g
s
.47358 .32458 m .5062 .35326 L .50348 .35039 L .666 .114 0 r
F
.47121 .32631 m .4724 .32682 L .46258 .32415 L p .393 0 0 r
F P
0 g
s
.5062 .35326 m .51276 .35839 L p .50348 .35039 L .666 .114 0 r
F P
0 g
s
.51534 .35438 m .51276 .35839 L .4724 .32682 L p .408 0 0 r
F P
0 g
s
.4724 .32682 m .47121 .32631 L .50211 .34596 L p .408 0 0 r
F P
0 g
s
.4724 .32682 m .50211 .34596 L .50075 .34502 L .408 0 0 r
F
.47786 .32798 m .5064 .34297 L p .47121 .32631 L 0 .405 .825 r
F P
0 g
s
.5064 .34297 m .51794 .34903 L p .50464 .34257 L 0 .405 .825 r
F P
0 g
s
.47121 .32631 m .5064 .34297 L .50464 .34257 L 0 .405 .825 r
F
.50211 .34596 m .51534 .35438 L p .50075 .34502 L .408 0 0 r
F P
0 g
s
.47121 .32631 m .47001 .32386 L .47786 .32798 L p 0 .405 .825 r
F P
0 g
s
.46258 .32415 m .44847 .32031 L p .47121 .32631 L .393 0 0 r
F P
0 g
s
.44847 .32031 m .4343 .31645 L p .45037 .32075 L .393 0 0 r
F P
0 g
s
.45037 .32075 m .47121 .32631 L .44847 .32031 L .393 0 0 r
F
.42947 .31852 m .47121 .32631 L p .45037 .32075 L F P
0 g
s
.4343 .31645 m .42947 .31852 L p .45037 .32075 L .393 0 0 r
F P
0 g
s
.47001 .32386 m .47121 .32631 L .44277 .321 L p .143 0 0 r
F P
0 g
s
.44277 .321 m .42947 .31852 L p .44564 .32065 L .143 0 0 r
F P
0 g
s
.44564 .32065 m .47001 .32386 L .44277 .321 L .143 0 0 r
F
.43017 .31908 m .4414 .32043 L p .42947 .31852 L F P
0 g
s
.42947 .31852 m .4414 .32043 L .44639 .32074 L .143 0 0 r
F
.46691 .32204 m .43911 .31144 L p .46128 .32168 L .539 .032 0 r
F P
0 g
s
.42874 .31792 m .42947 .31852 L .43094 .31727 L 0 0 0 r
F
.425 .31707 m .45719 .31922 L p .42464 .31842 L .134 .658 .88 r
F P
0 g
s
.44602 .31239 m .44391 .30229 L .47477 .31837 L p .517 .413 .675 r
F P
0 g
s
.47358 .32458 m .47477 .31837 L .44391 .30229 L p .607 .171 .185 r
F P
0 g
s
.44391 .30229 m .43911 .31144 L .47358 .32458 L p .607 .171 .185 r
F P
0 g
s
.45719 .31922 m .46882 .31999 L p .45492 .3195 L .134 .658 .88 r
F P
0 g
s
.42464 .31842 m .45719 .31922 L .45492 .3195 L .134 .658 .88 r
F
.4414 .32043 m .45726 .32233 L p .44639 .32074 L .143 0 0 r
F P
0 g
s
.45726 .32233 m .47001 .32386 L p .4557 .32197 L .143 0 0 r
F P
0 g
s
.44639 .32074 m .45726 .32233 L .4557 .32197 L .143 0 0 r
F
.39087 .32927 m .39669 .3274 L p .39471 .32847 L .259 .762 .728 r
F P
0 g
s
.39669 .3274 m .42464 .31842 L p .40684 .3244 L .259 .762 .728 r
F P
0 g
s
.39471 .32847 m .39669 .3274 L .40684 .3244 L .259 .762 .728 r
F
.42158 .36753 m .42596 .377 L .41954 .40086 L p .418 .343 .666 r
F P
0 g
s
.42438 .40922 m .41954 .40086 L .42596 .377 L p .418 .341 .663 r
F P
0 g
s
.41954 .40086 m .42438 .40922 L .42475 .44211 L p .381 .314 .656 r
F P
0 g
s
.42475 .44211 m .41996 .43566 L .41954 .40086 L p .381 .314 .656 r
F P
0 g
s
.41996 .43566 m .42475 .44211 L .43139 .48482 L p .357 .292 .647 r
F P
0 g
s
.43139 .48482 m .42712 .48106 L .41996 .43566 L p .357 .292 .647 r
F P
0 g
s
.42087 .53303 m .42407 .53379 L .44884 .6184 L p .321 .252 .621 r
F P
0 g
s
.44884 .6184 m .44689 .62238 L .42087 .53303 L p .321 .252 .621 r
F P
0 g
s
.43911 .31144 m .44391 .30229 L .4181 .30576 L p .313 0 .095 r
F P
0 g
s
.4181 .30576 m .41031 .317 L .43911 .31144 L p .313 0 .095 r
F P
0 g
s
.36075 .35688 m .37052 .35276 L .35909 .38827 L p .87 .89 .847 r
F P
0 g
s
.35909 .38827 m .34856 .39401 L .36075 .35688 L p .87 .89 .847 r
F P
0 g
s
.72219 .54205 m .71321 .54494 L .73125 .48683 L p .814 .864 .885 r
F P
0 g
s
.73125 .48683 m .74131 .4824 L .72219 .54205 L p .814 .864 .885 r
F P
0 g
s
.43182 .34406 m .43526 .35426 L .42158 .36753 L p .46 .375 .673 r
F P
0 g
s
.42596 .377 m .42158 .36753 L .43526 .35426 L p .457 .37 .669 r
F P
0 g
s
.42287 .47726 m .42712 .48106 L .44038 .53584 L p .344 .277 .636 r
F P
0 g
s
.44038 .53584 m .43708 .53567 L .42287 .47726 L p .344 .277 .636 r
F P
0 g
s
.47622 .64124 m .47677 .65202 L .51948 .69318 L p .716 .363 .378 r
F P
0 g
s
.51948 .69318 m .52179 .67472 L .47622 .64124 L p .716 .363 .378 r
F P
0 g
s
.57961 .64577 m .57467 .65639 L .61465 .64119 L p .243 0 .149 r
F P
0 g
s
.61465 .64119 m .62184 .62827 L .57961 .64577 L p .243 0 .149 r
F P
0 g
s
.42596 .377 m .43035 .38675 L .42438 .40922 L p .418 .341 .663 r
F P
0 g
s
.42925 .41778 m .42438 .40922 L .43035 .38675 L p .418 .338 .659 r
F P
0 g
s
.42438 .40922 m .42925 .41778 L .42958 .44865 L p .385 .314 .654 r
F P
0 g
s
.42958 .44865 m .42475 .44211 L .42438 .40922 L p .385 .314 .654 r
F P
0 g
s
.42407 .53379 m .4273 .53444 L .45079 .6143 L p .328 .256 .622 r
F P
0 g
s
.45079 .6143 m .44884 .6184 L .42407 .53379 L p .328 .256 .622 r
F P
0 g
s
.42475 .44211 m .42958 .44865 L .43569 .48854 L p .363 .295 .645 r
F P
0 g
s
.43569 .48854 m .43139 .48482 L .42475 .44211 L p .363 .295 .645 r
F P
0 g
s
.42838 .33411 m .42495 .32442 L .44814 .32265 L p .497 .403 .679 r
F P
0 g
s
.43526 .35426 m .43872 .36473 L .42596 .377 L p .457 .37 .669 r
F P
0 g
s
.43035 .38675 m .42596 .377 L .43872 .36473 L p .454 .365 .666 r
F P
0 g
s
.71321 .54494 m .70423 .54845 L .7212 .49178 L p .829 .875 .878 r
F P
0 g
s
.7212 .49178 m .73125 .48683 L .71321 .54494 L p .829 .875 .878 r
F P
0 g
s
.35097 .35937 m .36075 .35688 L .34856 .39401 L p .835 .86 .863 r
F P
0 g
s
.34856 .39401 m .33805 .39821 L .35097 .35937 L p .835 .86 .863 r
F P
0 g
s
.65934 .58066 m .6683 .57152 L .63626 .61024 L p .635 .899 .581 r
F P
0 g
s
.44814 .32265 m .45025 .3331 L .42838 .33411 L p .497 .403 .679 r
F P
0 g
s
.43182 .34406 m .42838 .33411 L .45025 .3331 L p .492 .397 .675 r
F P
0 g
s
.42712 .48106 m .43139 .48482 L .4437 .53589 L p .351 .281 .636 r
F P
0 g
s
.4437 .53589 m .44038 .53584 L .42712 .48106 L p .351 .281 .636 r
F P
0 g
s
.4273 .53444 m .43054 .53497 L .45275 .61008 L p .334 .26 .622 r
F P
0 g
s
.45275 .61008 m .45079 .6143 L .4273 .53444 L p .334 .26 .622 r
F P
0 g
s
.43035 .38675 m .43476 .39677 L .42925 .41778 L p .418 .338 .659 r
F P
0 g
s
.43414 .42655 m .42925 .41778 L .43476 .39677 L p .418 .336 .656 r
F P
0 g
s
.42925 .41778 m .43414 .42655 L .43444 .45527 L p .389 .314 .651 r
F P
0 g
s
.43444 .45527 m .42958 .44865 L .42925 .41778 L p .389 .314 .651 r
F P
0 g
s
.43872 .36473 m .44218 .37545 L .43035 .38675 L p .454 .365 .666 r
F P
0 g
s
.43476 .39677 m .43035 .38675 L .44218 .37545 L p .45 .36 .662 r
F P
0 g
s
.52411 .66114 m .52179 .67472 L .56483 .689 L p .565 .231 .362 r
F P
0 g
s
.56483 .689 m .56974 .67041 L .52411 .66114 L p .565 .231 .362 r
F P
0 g
s
.42958 .44865 m .43444 .45527 L .44002 .49222 L p .369 .297 .644 r
F P
0 g
s
.44002 .49222 m .43569 .48854 L .42958 .44865 L p .369 .297 .644 r
F P
0 g
s
.45025 .3331 m .45237 .34372 L .43182 .34406 L p .492 .397 .675 r
F P
0 g
s
.43526 .35426 m .43182 .34406 L .45237 .34372 L p .487 .39 .672 r
F P
0 g
s
.3803 .34647 m .37052 .35276 L .39471 .32847 L p .682 .969 .766 r
F P
0 g
s
.34119 .36063 m .35097 .35937 L .33805 .39821 L p .806 .834 .872 r
F P
0 g
s
.33805 .39821 m .32756 .40124 L .34119 .36063 L p .806 .834 .872 r
F P
0 g
s
.70423 .54845 m .69524 .55269 L .71118 .49736 L p .846 .887 .869 r
F P
0 g
s
.71118 .49736 m .7212 .49178 L .70423 .54845 L p .846 .887 .869 r
F P
0 g
s
.43139 .48482 m .43569 .48854 L .44703 .53582 L p .358 .284 .636 r
F P
0 g
s
.44703 .53582 m .4437 .53589 L .43139 .48482 L p .358 .284 .636 r
F P
0 g
s
.43054 .53497 m .4338 .53538 L .45472 .60575 L p .34 .264 .623 r
F P
0 g
s
.45472 .60575 m .45275 .61008 L .43054 .53497 L p .34 .264 .623 r
F P
0 g
s
.45237 .34372 m .45449 .35452 L .43526 .35426 L p .487 .39 .672 r
F P
0 g
s
.43872 .36473 m .43526 .35426 L .45449 .35452 L p .481 .384 .668 r
F P
0 g
s
.44218 .37545 m .44565 .38645 L .43476 .39677 L p .45 .36 .662 r
F P
0 g
s
.43919 .40706 m .43476 .39677 L .44565 .38645 L p .447 .356 .659 r
F P
0 g
s
.43476 .39677 m .43919 .40706 L .43414 .42655 L p .418 .336 .656 r
F P
0 g
s
.43907 .43554 m .43414 .42655 L .43919 .40706 L p .418 .334 .653 r
F P
0 g
s
.43414 .42655 m .43907 .43554 L .43933 .46199 L p .392 .314 .649 r
F P
0 g
s
.43933 .46199 m .43444 .45527 L .43414 .42655 L p .392 .314 .649 r
F P
0 g
s
.3314 .36093 m .34119 .36063 L .32756 .40124 L p .781 .813 .878 r
F P
0 g
s
.32756 .40124 m .31709 .40339 L .3314 .36093 L p .781 .813 .878 r
F P
0 g
s
.43444 .45527 m .43933 .46199 L .44438 .49585 L p .375 .3 .643 r
F P
0 g
s
.44438 .49585 m .44002 .49222 L .43444 .45527 L p .375 .3 .643 r
F P
0 g
s
.45449 .35452 m .45662 .36551 L .43872 .36473 L p .481 .384 .668 r
F P
0 g
s
.44218 .37545 m .43872 .36473 L .45662 .36551 L p .476 .379 .665 r
F P
0 g
s
.4338 .53538 m .43708 .53567 L .45669 .60129 L p .346 .267 .624 r
F P
0 g
s
.45669 .60129 m .45472 .60575 L .4338 .53538 L p .346 .267 .624 r
F P
0 g
s
.69524 .55269 m .68625 .55781 L .70117 .50368 L p .864 .899 .857 r
F P
0 g
s
.70117 .50368 m .71118 .49736 L .69524 .55269 L p .864 .899 .857 r
F P
0 g
s
.32159 .36049 m .3314 .36093 L .31709 .40339 L p .761 .796 .881 r
F P
0 g
s
.31709 .40339 m .30663 .40486 L .32159 .36049 L p .761 .796 .881 r
F P
0 g
s
.43569 .48854 m .44002 .49222 L .45039 .53562 L p .364 .287 .635 r
F P
0 g
s
.45039 .53562 m .44703 .53582 L .43569 .48854 L p .364 .287 .635 r
F P
0 g
s
.44565 .38645 m .44914 .39772 L .43919 .40706 L p .447 .356 .659 r
F P
0 g
s
.44364 .41765 m .43919 .40706 L .44914 .39772 L p .445 .351 .656 r
F P
0 g
s
.43919 .40706 m .44364 .41765 L .43907 .43554 L p .418 .334 .653 r
F P
0 g
s
.6415 .60571 m .6504 .59186 L .64865 .5941 L p 0 0 0 r
F P
0 g
s
.64865 .5941 m .62184 .62827 L p .6415 .60571 L 0 0 0 r
F P
0 g
s
.63265 .62302 m .6415 .60571 L .63965 .60816 L p 0 0 0 r
F P
0 g
s
.63965 .60816 m .61465 .64119 L p .63265 .62302 L 0 0 0 r
F P
0 g
s
.62387 .64495 m .63265 .62302 L .6307 .62572 L p 0 0 .002 r
F P
0 g
s
.6307 .62572 m .60748 .65779 L p .62387 .64495 L 0 0 .002 r
F P
0 g
s
.61518 .67323 m .62387 .64495 L .6218 .64799 L p 0 0 .108 r
F P
0 g
s
.6218 .64799 m .60037 .67935 L p .61518 .67323 L 0 0 .108 r
F P
0 g
s
.60664 .71049 m .61518 .67323 L .61298 .67671 L p 0 0 .191 r
F P
0 g
s
.61298 .67671 m .59334 .70774 L p .60664 .71049 L 0 0 .191 r
F P
0 g
s
.59831 .76101 m .60664 .71049 L .60428 .71462 L p 0 0 .254 r
F P
0 g
s
.60428 .71462 m .58642 .74585 L p .59831 .76101 L 0 0 .254 r
F P
0 g
s
.5903 .83205 m .59831 .76101 L .57968 .79839 L p .004 0 .302 r
F P
0 g
s
.59831 .76101 m .5903 .83205 L .59099 .81784 L p .918 .781 .301 r
F P
0 g
s
.58642 .74585 m .57968 .79839 L .59831 .76101 L p 0 0 .254 r
F P
0 g
s
.59099 .81784 m .59449 .74601 L p .59831 .76101 L .918 .781 .301 r
F P
0 g
s
.60664 .71049 m .59831 .76101 L .59904 .75104 L p .938 .82 .369 r
F P
0 g
s
.60037 .67935 m .59334 .70774 L .61518 .67323 L p 0 0 .108 r
F P
0 g
s
.59334 .70774 m .58642 .74585 L .60664 .71049 L p 0 0 .191 r
F P
0 g
s
.59904 .75104 m .60358 .68877 L p .60664 .71049 L .938 .82 .369 r
F P
0 g
s
.61518 .67323 m .60664 .71049 L .60738 .70303 L p .956 .858 .443 r
F P
0 g
s
.61465 .64119 m .60748 .65779 L .63265 .62302 L p 0 0 0 r
F P
0 g
s
.60748 .65779 m .60037 .67935 L .62387 .64495 L p 0 0 .002 r
F P
0 g
s
.60738 .70303 m .61291 .64679 L p .61518 .67323 L .956 .858 .443 r
F P
0 g
s
.62387 .64495 m .61518 .67323 L .61591 .66736 L p .969 .891 .519 r
F P
0 g
s
.62184 .62827 m .61465 .64119 L .6415 .60571 L p 0 0 0 r
F P
0 g
s
.61591 .66736 m .62241 .61488 L p .62387 .64495 L .969 .891 .519 r
F P
0 g
s
.63265 .62302 m .62387 .64495 L .62458 .64015 L p .973 .917 .592 r
F P
0 g
s
.65766 .58273 m .62905 .61816 L p .6504 .59186 L 0 0 0 r
F P
0 g
s
.62458 .64015 m .63204 .58994 L p .63265 .62302 L .973 .917 .592 r
F P
0 g
s
.6415 .60571 m .63265 .62302 L .63334 .61897 L p .97 .933 .657 r
F P
0 g
s
.63334 .61897 m .64175 .56998 L p .6415 .60571 L .97 .933 .657 r
F P
0 g
s
.6504 .59186 m .6415 .60571 L .64218 .60221 L p .959 .939 .713 r
F P
0 g
s
.64218 .60221 m .65155 .5537 L p .6504 .59186 L .959 .939 .713 r
F P
0 g
s
.6504 .59186 m .65934 .58066 L .65766 .58273 L p 0 0 0 r
F P
0 g
s
.57467 .65639 m .56974 .67041 L .60748 .65779 L p .298 0 .236 r
F P
0 g
s
.60748 .65779 m .61465 .64119 L .57467 .65639 L p .298 0 .236 r
F P
0 g
s
.44402 .44474 m .43907 .43554 L .44364 .41765 L p .419 .331 .651 r
F P
0 g
s
.43907 .43554 m .44402 .44474 L .44425 .46879 L p .396 .315 .647 r
F P
0 g
s
.44425 .46879 m .43933 .46199 L .43907 .43554 L p .396 .315 .647 r
F P
0 g
s
.47677 .65202 m .47731 .66704 L .51718 .71849 L p .726 .392 .414 r
F P
0 g
s
.51718 .71849 m .51948 .69318 L .47677 .65202 L p .726 .392 .414 r
F P
0 g
s
.45662 .36551 m .45875 .37669 L .44218 .37545 L p .476 .379 .665 r
F P
0 g
s
.44565 .38645 m .44218 .37545 L .45875 .37669 L p .471 .373 .662 r
F P
0 g
s
.31176 .35946 m .32159 .36049 L .30663 .40486 L p .745 .782 .883 r
F P
0 g
s
.30663 .40486 m .29617 .40581 L .31176 .35946 L p .745 .782 .883 r
F P
0 g
s
.3869 .33055 m .39471 .32847 L .37052 .35276 L p .749 .99 .885 r
F P
0 g
s
.37052 .35276 m .36075 .35688 L .3869 .33055 L p .749 .99 .885 r
F P
0 g
s
.43933 .46199 m .44425 .46879 L .44876 .49945 L p .381 .302 .641 r
F P
0 g
s
.44876 .49945 m .44438 .49585 L .43933 .46199 L p .381 .302 .641 r
F P
0 g
s
.43708 .53567 m .44038 .53584 L .45867 .59672 L p .352 .271 .624 r
F P
0 g
s
.45867 .59672 m .45669 .60129 L .43708 .53567 L p .352 .271 .624 r
F P
0 g
s
.45025 .3331 m .44814 .32265 L .47582 .33916 L p .506 .401 .669 r
F P
0 g
s
.30191 .35796 m .31176 .35946 L .29617 .40581 L p .731 .771 .885 r
F P
0 g
s
.29617 .40581 m .28572 .40633 L .30191 .35796 L p .731 .771 .885 r
F P
0 g
s
.44002 .49222 m .44438 .49585 L .45376 .5353 L p .371 .291 .635 r
F P
0 g
s
.45376 .5353 m .45039 .53562 L .44002 .49222 L p .371 .291 .635 r
F P
0 g
s
.44914 .39772 m .45263 .40926 L .44364 .41765 L p .445 .351 .656 r
F P
0 g
s
.44811 .42852 m .44364 .41765 L .45263 .40926 L p .442 .347 .653 r
F P
0 g
s
.44364 .41765 m .44811 .42852 L .44402 .44474 L p .419 .331 .651 r
F P
0 g
s
.45875 .37669 m .46089 .38805 L .44565 .38645 L p .471 .373 .662 r
F P
0 g
s
.44914 .39772 m .44565 .38645 L .46089 .38805 L p .467 .367 .659 r
F P
0 g
s
.47582 .33916 m .47634 .34964 L .45025 .3331 L p .506 .401 .669 r
F P
0 g
s
.45237 .34372 m .45025 .3331 L .47634 .34964 L p .5 .395 .667 r
F P
0 g
s
.68625 .55781 m .67727 .56401 L .69118 .51089 L p .883 .911 .842 r
F P
0 g
s
.69118 .51089 m .70117 .50368 L .68625 .55781 L p .883 .911 .842 r
F P
0 g
s
.29205 .35608 m .30191 .35796 L .28572 .40633 L p .72 .762 .886 r
F P
0 g
s
.28572 .40633 m .27528 .40653 L .29205 .35608 L p .72 .762 .886 r
F P
0 g
s
.449 .45416 m .44402 .44474 L .44811 .42852 L p .419 .329 .648 r
F P
0 g
s
.44402 .44474 m .449 .45416 L .4492 .47569 L p .399 .315 .645 r
F P
0 g
s
.4492 .47569 m .44425 .46879 L .44402 .44474 L p .399 .315 .645 r
F P
0 g
s
.44038 .53584 m .4437 .53589 L .46065 .59203 L p .357 .275 .625 r
F P
0 g
s
.46065 .59203 m .45867 .59672 L .44038 .53584 L p .357 .275 .625 r
F P
0 g
s
.47634 .34964 m .47686 .36019 L .45237 .34372 L p .5 .395 .667 r
F P
0 g
s
.45449 .35452 m .45237 .34372 L .47686 .36019 L p .495 .39 .664 r
F P
0 g
s
.44425 .46879 m .4492 .47569 L .45317 .50301 L p .386 .304 .64 r
F P
0 g
s
.45317 .50301 m .44876 .49945 L .44425 .46879 L p .386 .304 .64 r
F P
0 g
s
.28215 .35389 m .29205 .35608 L .27528 .40653 L p .711 .755 .887 r
F P
0 g
s
.27528 .40653 m .26483 .40647 L .28215 .35389 L p .711 .755 .887 r
F P
0 g
s
.46089 .38805 m .46303 .39961 L .44914 .39772 L p .467 .367 .659 r
F P
0 g
s
.45263 .40926 m .44914 .39772 L .46303 .39961 L p .462 .362 .656 r
F P
0 g
s
.45263 .40926 m .45614 .42109 L .44811 .42852 L p .442 .347 .653 r
F P
0 g
s
.45261 .43969 m .44811 .42852 L .45614 .42109 L p .439 .343 .65 r
F P
0 g
s
.44811 .42852 m .45261 .43969 L .449 .45416 L p .419 .329 .648 r
F P
0 g
s
.52179 .67472 m .51948 .69318 L .55995 .71386 L p .581 .267 .402 r
F P
0 g
s
.55995 .71386 m .56483 .689 L .52179 .67472 L p .581 .267 .402 r
F P
0 g
s
.27224 .35146 m .28215 .35389 L .26483 .40647 L p .703 .75 .888 r
F P
0 g
s
.26483 .40647 m .25439 .4062 L .27224 .35146 L p .703 .75 .888 r
F P
0 g
s
.44438 .49585 m .44876 .49945 L .45715 .53485 L p .377 .294 .635 r
F P
0 g
s
.45715 .53485 m .45376 .5353 L .44438 .49585 L p .377 .294 .635 r
F P
0 g
s
.47686 .36019 m .47739 .37081 L .45449 .35452 L p .495 .39 .664 r
F P
0 g
s
.45662 .36551 m .45449 .35452 L .47739 .37081 L p .489 .384 .662 r
F P
0 g
s
.37906 .33098 m .3869 .33055 L .36075 .35688 L p .763 .962 .932 r
F P
0 g
s
.36075 .35688 m .35097 .35937 L .37906 .33098 L p .763 .962 .932 r
F P
0 g
s
.26229 .34881 m .27224 .35146 L .25439 .4062 L p .697 .745 .888 r
F P
0 g
s
.25439 .4062 m .24394 .40575 L .26229 .34881 L p .697 .745 .888 r
F P
0 g
s
.4437 .53589 m .44703 .53582 L .46264 .58722 L p .363 .279 .625 r
F P
0 g
s
.46264 .58722 m .46065 .59203 L .4437 .53589 L p .363 .279 .625 r
F P
0 g
s
.45402 .46381 m .449 .45416 L .45261 .43969 L p .419 .327 .645 r
F P
0 g
s
.449 .45416 m .45402 .46381 L .45418 .48268 L p .402 .315 .642 r
F P
0 g
s
.45418 .48268 m .4492 .47569 L .449 .45416 L p .402 .315 .642 r
F P
0 g
s
.46303 .39961 m .46517 .41137 L .45263 .40926 L p .462 .362 .656 r
F P
0 g
s
.45614 .42109 m .45263 .40926 L .46517 .41137 L p .458 .357 .653 r
F P
0 g
s
.47739 .37081 m .47791 .38149 L .45662 .36551 L p .489 .384 .662 r
F P
0 g
s
.45875 .37669 m .45662 .36551 L .47791 .38149 L p .484 .379 .659 r
F P
0 g
s
.25232 .34599 m .26229 .34881 L .24394 .40575 L p .692 .741 .889 r
F P
0 g
s
.24394 .40575 m .23349 .40517 L .25232 .34599 L p .692 .741 .889 r
F P
0 g
s
.67727 .56401 m .6683 .57152 L .68122 .5192 L p .903 .923 .821 r
F P
0 g
s
.68122 .5192 m .69118 .51089 L .67727 .56401 L p .903 .923 .821 r
F P
0 g
s
.4492 .47569 m .45418 .48268 L .45761 .50652 L p .392 .306 .639 r
F P
0 g
s
.45761 .50652 m .45317 .50301 L .4492 .47569 L p .392 .306 .639 r
F P
0 g
s
.24232 .34303 m .25232 .34599 L .23349 .40517 L p .688 .738 .889 r
F P
0 g
s
.23349 .40517 m .22304 .40447 L .24232 .34303 L p .688 .738 .889 r
F P
0 g
s
.45614 .42109 m .45967 .43321 L .45261 .43969 L p .439 .343 .65 r
F P
0 g
s
.45712 .45116 m .45261 .43969 L .45967 .43321 L p .437 .339 .647 r
F P
0 g
s
.45261 .43969 m .45712 .45116 L .45402 .46381 L p .419 .327 .645 r
F P
0 g
s
.44876 .49945 m .45317 .50301 L .46056 .53427 L p .383 .297 .634 r
F P
0 g
s
.46056 .53427 m .45715 .53485 L .44876 .49945 L p .383 .297 .634 r
F P
0 g
s
.47791 .38149 m .47844 .39223 L .45875 .37669 L p .484 .379 .659 r
F P
0 g
s
.46089 .38805 m .45875 .37669 L .47844 .39223 L p .479 .373 .657 r
F P
0 g
s
.23228 .33994 m .24232 .34303 L .22304 .40447 L p .684 .736 .89 r
F P
0 g
s
.22304 .40447 m .21258 .40368 L .23228 .33994 L p .684 .736 .89 r
F P
0 g
s
.44703 .53582 m .45039 .53562 L .46463 .5823 L p .369 .282 .626 r
F P
0 g
s
.46463 .5823 m .46264 .58722 L .44703 .53582 L p .369 .282 .626 r
F P
0 g
s
.22222 .33675 m .23228 .33994 L .21258 .40368 L p .681 .734 .89 r
F P
0 g
s
.21258 .40368 m .20212 .40281 L .22222 .33675 L p .681 .734 .89 r
F P
0 g
s
.46517 .41137 m .46733 .42333 L .45614 .42109 L p .458 .357 .653 r
F P
0 g
s
.45967 .43321 m .45614 .42109 L .46733 .42333 L p .453 .352 .65 r
F P
0 g
s
.3712 .33015 m .37906 .33098 L .35097 .35937 L p .757 .922 .944 r
F P
0 g
s
.35097 .35937 m .34119 .36063 L .3712 .33015 L p .757 .922 .944 r
F P
0 g
s
.21212 .33348 m .22222 .33675 L .20212 .40281 L p .679 .732 .89 r
F P
0 g
s
.20212 .40281 m .19165 .40188 L .21212 .33348 L p .679 .732 .89 r
F P
0 g
s
.56974 .67041 m .56483 .689 L .60037 .67935 L p .34 .04 .303 r
F P
0 g
s
.60037 .67935 m .60748 .65779 L .56974 .67041 L p .34 .04 .303 r
F P
0 g
s
.47844 .39223 m .47896 .40305 L .46089 .38805 L p .479 .373 .657 r
F P
0 g
s
.46303 .39961 m .46089 .38805 L .47896 .40305 L p .474 .368 .654 r
F P
0 g
s
.45906 .47368 m .45402 .46381 L .45712 .45116 L p .419 .325 .643 r
F P
0 g
s
.45402 .46381 m .45906 .47368 L .4592 .48976 L p .405 .315 .64 r
F P
0 g
s
.4592 .48976 m .45418 .48268 L .45402 .46381 L p .405 .315 .64 r
F P
0 g
s
.45039 .53562 m .45376 .5353 L .46663 .57725 L p .374 .286 .626 r
F P
0 g
s
.46663 .57725 m .46463 .5823 L .45039 .53562 L p .374 .286 .626 r
F P
0 g
s
.45418 .48268 m .4592 .48976 L .46208 .50999 L p .397 .308 .637 r
F P
0 g
s
.46208 .50999 m .45761 .50652 L .45418 .48268 L p .397 .308 .637 r
F P
0 g
s
.45967 .43321 m .4632 .44563 L .45712 .45116 L p .437 .339 .647 r
F P
0 g
s
.46167 .46293 m .45712 .45116 L .4632 .44563 L p .434 .335 .644 r
F P
0 g
s
.45712 .45116 m .46167 .46293 L .45906 .47368 L p .419 .325 .643 r
F P
0 g
s
.45317 .50301 m .45761 .50652 L .46398 .53357 L p .389 .3 .634 r
F P
0 g
s
.46398 .53357 m .46056 .53427 L .45317 .50301 L p .389 .3 .634 r
F P
0 g
s
.47896 .40305 m .47949 .41393 L .46303 .39961 L p .474 .368 .654 r
F P
0 g
s
.46517 .41137 m .46303 .39961 L .47949 .41393 L p .469 .363 .652 r
F P
0 g
s
.46733 .42333 m .46949 .43549 L .45967 .43321 L p .453 .352 .65 r
F P
0 g
s
.4632 .44563 m .45967 .43321 L .46949 .43549 L p .449 .347 .647 r
F P
0 g
s
.47731 .66704 m .47784 .68801 L .5149 .75371 L p .733 .415 .442 r
F P
0 g
s
.5149 .75371 m .51718 .71849 L .47731 .66704 L p .733 .415 .442 r
F P
0 g
s
.6683 .57152 m .65934 .58066 L .67129 .52886 L p .924 .932 .794 r
F P
0 g
s
.67129 .52886 m .68122 .5192 L .6683 .57152 L p .924 .932 .794 r
F P
0 g
s
.78165 .46858 m .77155 .47156 L .7631 .40038 L p .75 .769 .868 r
F P
0 g
s
.7631 .40038 m .77334 .3955 L .78165 .46858 L p .75 .769 .868 r
F P
0 g
s
.47784 .68801 m .47837 .71766 L .51265 .80396 L p .738 .433 .464 r
F P
0 g
s
.44689 .62238 m .44884 .6184 L .47872 .70763 L p .339 .25 .607 r
F P
0 g
s
.47872 .70763 m .47837 .71766 L .44689 .62238 L p .339 .25 .607 r
F P
0 g
s
.77155 .47156 m .76146 .47482 L .75289 .40546 L p .757 .77 .864 r
F P
0 g
s
.75289 .40546 m .7631 .40038 L .77155 .47156 L p .757 .77 .864 r
F P
0 g
s
.45376 .5353 m .45715 .53485 L .46864 .5721 L p .379 .289 .627 r
F P
0 g
s
.46864 .5721 m .46663 .57725 L .45376 .5353 L p .379 .289 .627 r
F P
0 g
s
.47949 .41393 m .48002 .42488 L .46517 .41137 L p .469 .363 .652 r
F P
0 g
s
.46733 .42333 m .46517 .41137 L .48002 .42488 L p .464 .358 .649 r
F P
0 g
s
.46414 .48379 m .45906 .47368 L .46167 .46293 L p .419 .323 .64 r
F P
0 g
s
.45906 .47368 m .46414 .48379 L .46426 .49694 L p .408 .315 .638 r
F P
0 g
s
.46426 .49694 m .4592 .48976 L .45906 .47368 L p .408 .315 .638 r
F P
0 g
s
.44884 .6184 m .45079 .6143 L .47906 .6976 L p .343 .254 .608 r
F P
0 g
s
.47906 .6976 m .47872 .70763 L .44884 .6184 L p .343 .254 .608 r
F P
0 g
s
.36332 .32834 m .3712 .33015 L .34119 .36063 L p .745 .885 .944 r
F P
0 g
s
.34119 .36063 m .3314 .36093 L .36332 .32834 L p .745 .885 .944 r
F P
0 g
s
.50642 .36869 m .50523 .37796 L .47582 .33916 L p .506 .39 .656 r
F P
0 g
s
.47634 .34964 m .47582 .33916 L .50523 .37796 L p .501 .386 .654 r
F P
0 g
s
.46949 .43549 m .47165 .44786 L .4632 .44563 L p .449 .347 .647 r
F P
0 g
s
.46676 .45834 m .4632 .44563 L .47165 .44786 L p .445 .342 .644 r
F P
0 g
s
.4632 .44563 m .46676 .45834 L .46167 .46293 L p .434 .335 .644 r
F P
0 g
s
.45761 .50652 m .46208 .50999 L .46742 .53274 L p .394 .303 .633 r
F P
0 g
s
.46742 .53274 m .46398 .53357 L .45761 .50652 L p .394 .303 .633 r
F P
0 g
s
.76146 .47482 m .75138 .47842 L .74272 .4108 L p .764 .772 .86 r
F P
0 g
s
.74272 .4108 m .75289 .40546 L .76146 .47482 L p .764 .772 .86 r
F P
0 g
s
.46624 .47502 m .46167 .46293 L .46676 .45834 L p .432 .332 .641 r
F P
0 g
s
.46167 .46293 m .46624 .47502 L .46414 .48379 L p .419 .323 .64 r
F P
0 g
s
.4592 .48976 m .46426 .49694 L .46658 .51341 L p .402 .31 .636 r
F P
0 g
s
.46658 .51341 m .46208 .50999 L .4592 .48976 L p .402 .31 .636 r
F P
0 g
s
.50523 .37796 m .50404 .38718 L .47634 .34964 L p .501 .386 .654 r
F P
0 g
s
.47686 .36019 m .47634 .34964 L .50404 .38718 L p .496 .381 .653 r
F P
0 g
s
.45079 .6143 m .45275 .61008 L .4794 .68756 L p .348 .257 .61 r
F P
0 g
s
.51265 .80396 m .5149 .75371 L .47784 .68801 L p .738 .433 .464 r
F P
0 g
s
.4794 .68756 m .47906 .6976 L .45079 .6143 L p .348 .257 .61 r
F P
0 g
s
.48002 .42488 m .48055 .4359 L .46733 .42333 L p .464 .358 .649 r
F P
0 g
s
.46949 .43549 m .46733 .42333 L .48055 .4359 L p .459 .353 .647 r
F P
0 g
s
.45715 .53485 m .46056 .53427 L .47065 .56682 L p .385 .293 .627 r
F P
0 g
s
.47065 .56682 m .46864 .5721 L .45715 .53485 L p .385 .293 .627 r
F P
0 g
s
.50404 .38718 m .50284 .39634 L .47686 .36019 L p .496 .381 .653 r
F P
0 g
s
.47739 .37081 m .47686 .36019 L .50284 .39634 L p .491 .377 .651 r
F P
0 g
s
.75138 .47842 m .74131 .4824 L .73258 .41641 L p .772 .773 .854 r
F P
0 g
s
.73258 .41641 m .74272 .4108 L .75138 .47842 L p .772 .773 .854 r
F P
0 g
s
.45275 .61008 m .45472 .60575 L .47974 .67752 L p .352 .261 .611 r
F P
0 g
s
.47974 .67752 m .4794 .68756 L .45275 .61008 L p .352 .261 .611 r
F P
0 g
s
.50284 .39634 m .50165 .40545 L .47739 .37081 L p .491 .377 .651 r
F P
0 g
s
.47791 .38149 m .47739 .37081 L .50165 .40545 L p .486 .373 .65 r
F P
0 g
s
.3554 .32577 m .36332 .32834 L .3314 .36093 L p .732 .855 .939 r
F P
0 g
s
.3314 .36093 m .32159 .36049 L .3554 .32577 L p .732 .855 .939 r
F P
0 g
s
.47165 .44786 m .47383 .46044 L .46676 .45834 L p .445 .342 .644 r
F P
0 g
s
.47033 .47137 m .46676 .45834 L .47383 .46044 L p .441 .337 .641 r
F P
0 g
s
.46676 .45834 m .47033 .47137 L .46624 .47502 L p .432 .332 .641 r
F P
0 g
s
.48055 .4359 m .48108 .44699 L .46949 .43549 L p .459 .353 .647 r
F P
0 g
s
.47165 .44786 m .46949 .43549 L .48108 .44699 L p .454 .348 .644 r
F P
0 g
s
.46926 .49414 m .46414 .48379 L .46624 .47502 L p .42 .322 .638 r
F P
0 g
s
.46414 .48379 m .46926 .49414 L .46935 .50422 L p .411 .316 .636 r
F P
0 g
s
.46935 .50422 m .46426 .49694 L .46414 .48379 L p .411 .316 .636 r
F P
0 g
s
.74131 .4824 m .73125 .48683 L .72248 .42235 L p .78 .775 .848 r
F P
0 g
s
.72248 .42235 m .73258 .41641 L .74131 .4824 L p .78 .775 .848 r
F P
0 g
s
.46208 .50999 m .46658 .51341 L .47087 .53179 L p .4 .306 .633 r
F P
0 g
s
.47087 .53179 m .46742 .53274 L .46208 .50999 L p .4 .306 .633 r
F P
0 g
s
.50165 .40545 m .50045 .4145 L .47791 .38149 L p .486 .373 .65 r
F P
0 g
s
.47844 .39223 m .47791 .38149 L .50045 .4145 L p .482 .369 .648 r
F P
0 g
s
.45472 .60575 m .45669 .60129 L .48008 .66748 L p .356 .264 .612 r
F P
0 g
s
.48008 .66748 m .47974 .67752 L .45472 .60575 L p .356 .264 .612 r
F P
0 g
s
.65934 .58066 m .6504 .59186 L .66139 .54021 L p .943 .939 .758 r
F P
0 g
s
.66139 .54021 m .67129 .52886 L .65934 .58066 L p .943 .939 .758 r
F P
0 g
s
.47084 .48743 m .46624 .47502 L .47033 .47137 L p .43 .328 .638 r
F P
0 g
s
.46624 .47502 m .47084 .48743 L .46926 .49414 L p .42 .322 .638 r
F P
0 g
s
.46056 .53427 m .46398 .53357 L .47266 .56143 L p .39 .296 .628 r
F P
0 g
s
.47266 .56143 m .47065 .56682 L .46056 .53427 L p .39 .296 .628 r
F P
0 g
s
.46426 .49694 m .46935 .50422 L .4711 .51679 L p .406 .311 .635 r
F P
0 g
s
.4711 .51679 m .46658 .51341 L .46426 .49694 L p .406 .311 .635 r
F P
0 g
s
.51948 .69318 m .51718 .71849 L .55514 .74762 L p .593 .295 .433 r
F P
0 g
s
.55514 .74762 m .55995 .71386 L .51948 .69318 L p .593 .295 .433 r
F P
0 g
s
.50045 .4145 m .49925 .42349 L .47844 .39223 L p .482 .369 .648 r
F P
0 g
s
.47896 .40305 m .47844 .39223 L .49925 .42349 L p .477 .365 .647 r
F P
0 g
s
.45669 .60129 m .45867 .59672 L .48043 .65743 L p .361 .268 .613 r
F P
0 g
s
.48043 .65743 m .48008 .66748 L .45669 .60129 L p .361 .268 .613 r
F P
0 g
s
.73125 .48683 m .7212 .49178 L .71241 .42867 L p .789 .776 .841 r
F P
0 g
s
.71241 .42867 m .72248 .42235 L .73125 .48683 L p .789 .776 .841 r
F P
0 g
s
.48108 .44699 m .48161 .45815 L .47165 .44786 L p .454 .348 .644 r
F P
0 g
s
.47383 .46044 m .47165 .44786 L .48161 .45815 L p .45 .343 .642 r
F P
0 g
s
.41978 .31672 m .42464 .31842 L .3869 .33055 L p .447 .876 .914 r
F P
0 g
s
.3869 .33055 m .37906 .33098 L .41978 .31672 L p .447 .876 .914 r
F P
0 g
s
.49925 .42349 m .49806 .43242 L .47896 .40305 L p .477 .365 .647 r
F P
0 g
s
.47949 .41393 m .47896 .40305 L .49806 .43242 L p .472 .361 .646 r
F P
0 g
s
.47383 .46044 m .47601 .47324 L .47033 .47137 L p .441 .337 .641 r
F P
0 g
s
.47393 .4847 m .47033 .47137 L .47601 .47324 L p .437 .333 .638 r
F P
0 g
s
.47033 .47137 m .47393 .4847 L .47084 .48743 L p .43 .328 .638 r
F P
0 g
s
.46398 .53357 m .46742 .53274 L .47468 .55592 L p .395 .299 .628 r
F P
0 g
s
.47468 .55592 m .47266 .56143 L .46398 .53357 L p .395 .299 .628 r
F P
0 g
s
.45867 .59672 m .46065 .59203 L .48077 .64738 L p .365 .271 .615 r
F P
0 g
s
.48077 .64738 m .48043 .65743 L .45867 .59672 L p .365 .271 .615 r
F P
0 g
s
.34746 .32259 m .3554 .32577 L .32159 .36049 L p .721 .83 .932 r
F P
0 g
s
.32159 .36049 m .31176 .35946 L .34746 .32259 L p .721 .83 .932 r
F P
0 g
s
.46658 .51341 m .4711 .51679 L .47434 .5307 L p .405 .308 .632 r
F P
0 g
s
.47434 .5307 m .47087 .53179 L .46658 .51341 L p .405 .308 .632 r
F P
0 g
s
.49806 .43242 m .49686 .4413 L .47949 .41393 L p .472 .361 .646 r
F P
0 g
s
.48002 .42488 m .47949 .41393 L .49686 .4413 L p .468 .356 .644 r
F P
0 g
s
.47441 .50473 m .46926 .49414 L .47084 .48743 L p .42 .32 .635 r
F P
0 g
s
.46926 .49414 m .47441 .50473 L .47447 .5116 L p .414 .316 .635 r
F P
0 g
s
.47447 .5116 m .46935 .50422 L .46926 .49414 L p .414 .316 .635 r
F P
0 g
s
.7212 .49178 m .71118 .49736 L .70237 .43544 L p .799 .777 .832 r
F P
0 g
s
.70237 .43544 m .71241 .42867 L .7212 .49178 L p .799 .777 .832 r
F P
0 g
s
.48161 .45815 m .48215 .46938 L .47383 .46044 L p .45 .343 .642 r
F P
0 g
s
.47601 .47324 m .47383 .46044 L .48215 .46938 L p .445 .339 .64 r
F P
0 g
s
.46065 .59203 m .46264 .58722 L .48111 .63733 L p .37 .275 .616 r
F P
0 g
s
.48111 .63733 m .48077 .64738 L .46065 .59203 L p .37 .275 .616 r
F P
0 g
s
.47547 .50017 m .47084 .48743 L .47393 .4847 L p .427 .325 .636 r
F P
0 g
s
.47084 .48743 m .47547 .50017 L .47441 .50473 L p .42 .32 .635 r
F P
0 g
s
.46935 .50422 m .47447 .5116 L .47565 .52013 L p .411 .313 .633 r
F P
0 g
s
.47565 .52013 m .4711 .51679 L .46935 .50422 L p .411 .313 .633 r
F P
0 g
s
.49686 .4413 m .49566 .45011 L .48002 .42488 L p .468 .356 .644 r
F P
0 g
s
.48055 .4359 m .48002 .42488 L .49566 .45011 L p .463 .352 .643 r
F P
0 g
s
.56483 .689 m .55995 .71386 L .59334 .70774 L p .371 .092 .354 r
F P
0 g
s
.59334 .70774 m .60037 .67935 L .56483 .689 L p .371 .092 .354 r
F P
0 g
s
.46742 .53274 m .47087 .53179 L .47671 .5503 L p .4 .303 .628 r
F P
0 g
s
.47671 .5503 m .47468 .55592 L .46742 .53274 L p .4 .303 .628 r
F P
0 g
s
.46264 .58722 m .46463 .5823 L .48145 .62728 L p .374 .278 .617 r
F P
0 g
s
.48145 .62728 m .48111 .63733 L .46264 .58722 L p .374 .278 .617 r
F P
0 g
s
.49566 .45011 m .49446 .45887 L .48055 .4359 L p .463 .352 .643 r
F P
0 g
s
.48108 .44699 m .48055 .4359 L .49446 .45887 L p .458 .348 .641 r
F P
0 g
s
.47601 .47324 m .4782 .48626 L .47393 .4847 L p .437 .333 .638 r
F P
0 g
s
.47754 .49836 m .47393 .4847 L .4782 .48626 L p .433 .329 .636 r
F P
0 g
s
.47393 .4847 m .47754 .49836 L .47547 .50017 L p .427 .325 .636 r
F P
0 g
s
.71118 .49736 m .70117 .50368 L .69238 .44274 L p .81 .777 .822 r
F P
0 g
s
.69238 .44274 m .70237 .43544 L .71118 .49736 L p .81 .777 .822 r
F P
0 g
s
.33947 .31891 m .34746 .32259 L .31176 .35946 L p .712 .811 .927 r
F P
0 g
s
.31176 .35946 m .30191 .35796 L .33947 .31891 L p .712 .811 .927 r
F P
0 g
s
.48215 .46938 m .48268 .48069 L .47601 .47324 L p .445 .339 .64 r
F P
0 g
s
.4782 .48626 m .47601 .47324 L .48268 .48069 L p .441 .334 .638 r
F P
0 g
s
.4711 .51679 m .47565 .52013 L .47782 .52948 L p .41 .311 .631 r
F P
0 g
s
.47782 .52948 m .47434 .5307 L .4711 .51679 L p .41 .311 .631 r
F P
0 g
s
.46463 .5823 m .46663 .57725 L .48179 .61722 L p .378 .282 .618 r
F P
0 g
s
.48179 .61722 m .48145 .62728 L .46463 .5823 L p .378 .282 .618 r
F P
0 g
s
.49446 .45887 m .49325 .46756 L .48108 .44699 L p .458 .348 .641 r
F P
0 g
s
.48161 .45815 m .48108 .44699 L .49325 .46756 L p .454 .344 .64 r
F P
0 g
s
.65155 .5537 m .66139 .54021 L .6504 .59186 L p .959 .939 .713 r
F P
0 g
s
.47087 .53179 m .47434 .5307 L .47873 .54456 L p .405 .306 .629 r
F P
0 g
s
.47873 .54456 m .47671 .5503 L .47087 .53179 L p .405 .306 .629 r
F P
0 g
s
.4796 .51557 m .47441 .50473 L .47547 .50017 L p .42 .318 .633 r
F P
0 g
s
.47441 .50473 m .4796 .51557 L .47963 .51908 L p .416 .316 .633 r
F P
0 g
s
.47963 .51908 m .47447 .5116 L .47441 .50473 L p .416 .316 .633 r
F P
0 g
s
.46663 .57725 m .46864 .5721 L .48213 .60717 L p .383 .285 .619 r
F P
0 g
s
.48213 .60717 m .48179 .61722 L .46663 .57725 L p .383 .285 .619 r
F P
0 g
s
.48013 .51324 m .47547 .50017 L .47754 .49836 L p .425 .321 .633 r
F P
0 g
s
.47547 .50017 m .48013 .51324 L .4796 .51557 L p .42 .318 .633 r
F P
0 g
s
.41491 .3138 m .41978 .31672 L .37906 .33098 L p .552 .894 .981 r
F P
0 g
s
.37906 .33098 m .3712 .33015 L .41491 .3138 L p .552 .894 .981 r
F P
0 g
s
.49325 .46756 m .49205 .4762 L .48161 .45815 L p .454 .344 .64 r
F P
0 g
s
.48215 .46938 m .48161 .45815 L .49205 .4762 L p .449 .34 .638 r
F P
0 g
s
.47447 .5116 m .47963 .51908 L .48023 .52342 L p .415 .315 .632 r
F P
0 g
s
.48023 .52342 m .47565 .52013 L .47447 .5116 L p .415 .315 .632 r
F P
0 g
s
.48268 .48069 m .48322 .49207 L .4782 .48626 L p .441 .334 .638 r
F P
0 g
s
.4804 .4995 m .4782 .48626 L .48322 .49207 L p .436 .33 .635 r
F P
0 g
s
.4782 .48626 m .4804 .4995 L .47754 .49836 L p .433 .329 .636 r
F P
0 g
s
.70117 .50368 m .69118 .51089 L .68242 .45068 L p .821 .776 .81 r
F P
0 g
s
.68242 .45068 m .69238 .44274 L .70117 .50368 L p .821 .776 .81 r
F P
0 g
s
.46864 .5721 m .47065 .56682 L .48247 .59711 L p .387 .289 .621 r
F P
0 g
s
.48247 .59711 m .48213 .60717 L .46864 .5721 L p .387 .289 .621 r
F P
0 g
s
.33146 .31484 m .33947 .31891 L .30191 .35796 L p .704 .795 .921 r
F P
0 g
s
.30191 .35796 m .29205 .35608 L .33146 .31484 L p .704 .795 .921 r
F P
0 g
s
.48117 .51234 m .47754 .49836 L .4804 .4995 L p .43 .324 .633 r
F P
0 g
s
.47754 .49836 m .48117 .51234 L .48013 .51324 L p .425 .321 .633 r
F P
0 g
s
.49205 .4762 m .49085 .48477 L .48215 .46938 L p .449 .34 .638 r
F P
0 g
s
.48268 .48069 m .48215 .46938 L .49085 .48477 L p .445 .336 .637 r
F P
0 g
s
.47434 .5307 m .47782 .52948 L .48076 .53871 L p .41 .309 .629 r
F P
0 g
s
.48076 .53871 m .47873 .54456 L .47434 .5307 L p .41 .309 .629 r
F P
0 g
s
.47565 .52013 m .48023 .52342 L .48132 .52814 L p .415 .314 .631 r
F P
0 g
s
.48132 .52814 m .47782 .52948 L .47565 .52013 L p .415 .314 .631 r
F P
0 g
s
.47065 .56682 m .47266 .56143 L .48281 .58705 L p .392 .292 .622 r
F P
0 g
s
.48281 .58705 m .48247 .59711 L .47065 .56682 L p .392 .292 .622 r
F P
0 g
s
.49085 .48477 m .48965 .49327 L .48268 .48069 L p .445 .336 .637 r
F P
0 g
s
.48322 .49207 m .48268 .48069 L .48965 .49327 L p .44 .332 .635 r
F P
0 g
s
.47266 .56143 m .47468 .55592 L .48315 .57699 L p .396 .296 .623 r
F P
0 g
s
.48315 .57699 m .48281 .58705 L .47266 .56143 L p .396 .296 .623 r
F P
0 g
s
.48322 .49207 m .48375 .50352 L .4804 .4995 L p .436 .33 .635 r
F P
0 g
s
.48261 .51296 m .4804 .4995 L .48375 .50352 L p .432 .326 .633 r
F P
0 g
s
.4804 .4995 m .48261 .51296 L .48117 .51234 L p .43 .324 .633 r
F P
0 g
s
.54511 .4206 m .53922 .42846 L .50761 .35936 L p 0 0 .554 r
F P
0 g
s
.50761 .35936 m .51018 .36041 L .54511 .4206 L p 0 0 .554 r
F P
0 g
s
.50642 .36869 m .50761 .35936 L .53922 .42846 L p .501 .373 .638 r
F P
0 g
s
.3234 .31044 m .33146 .31484 L .29205 .35608 L p .698 .783 .917 r
F P
0 g
s
.29205 .35608 m .28215 .35389 L .3234 .31044 L p .698 .783 .917 r
F P
0 g
s
.69118 .51089 m .68122 .5192 L .6725 .45939 L p .833 .775 .796 r
F P
0 g
s
.6725 .45939 m .68242 .45068 L .69118 .51089 L p .833 .775 .796 r
F P
0 g
s
.48483 .52666 m .4796 .51557 L .48013 .51324 L closepath p .42 .317 .631 r
F P
0 g
s
.48483 .52666 m .47963 .51908 L .4796 .51557 L closepath p .419 .316 .631 r
F P
0 g
s
.47782 .52948 m .48132 .52814 L .4828 .53274 L p .415 .312 .629 r
F P
0 g
s
.4828 .53274 m .48076 .53871 L .47782 .52948 L p .415 .312 .629 r
F P
0 g
s
.47468 .55592 m .47671 .5503 L .48348 .56692 L p .4 .299 .624 r
F P
0 g
s
.48348 .56692 m .48315 .57699 L .47468 .55592 L p .4 .299 .624 r
F P
0 g
s
.53922 .42846 m .53634 .43482 L .50642 .36869 L p .501 .373 .638 r
F P
0 g
s
.50523 .37796 m .50642 .36869 L .53634 .43482 L p .498 .371 .638 r
F P
0 g
s
.48483 .52666 m .48013 .51324 L .48117 .51234 L closepath p .423 .318 .631 r
F P
0 g
s
.48965 .49327 m .48844 .50172 L .48322 .49207 L p .44 .332 .635 r
F P
0 g
s
.48375 .50352 m .48322 .49207 L .48844 .50172 L p .436 .329 .634 r
F P
0 g
s
.48483 .52666 m .48023 .52342 L .47963 .51908 L closepath p .419 .316 .631 r
F P
0 g
s
.53634 .43482 m .53346 .44104 L .50523 .37796 L p .498 .371 .638 r
F P
0 g
s
.50404 .38718 m .50523 .37796 L .53346 .44104 L p .494 .368 .637 r
F P
0 g
s
.48483 .52666 m .48117 .51234 L .48261 .51296 L closepath p .426 .32 .631 r
F P
0 g
s
.47671 .5503 m .47873 .54456 L .48382 .55686 L p .405 .303 .625 r
F P
0 g
s
.48382 .55686 m .48348 .56692 L .47671 .5503 L p .405 .303 .625 r
F P
0 g
s
.53346 .44104 m .53057 .44713 L .50404 .38718 L p .494 .368 .637 r
F P
0 g
s
.50284 .39634 m .50404 .38718 L .53057 .44713 L p .49 .365 .637 r
F P
0 g
s
.48483 .52666 m .48132 .52814 L .48023 .52342 L closepath p .42 .316 .63 r
F P
0 g
s
.53057 .44713 m .52769 .4531 L .50284 .39634 L p .49 .365 .637 r
F P
0 g
s
.50165 .40545 m .50284 .39634 L .52769 .4531 L p .486 .362 .637 r
F P
0 g
s
.48844 .50172 m .48724 .5101 L .48375 .50352 L p .436 .329 .634 r
F P
0 g
s
.48429 .51505 m .48375 .50352 L .48724 .5101 L p .432 .325 .632 r
F P
0 g
s
.48375 .50352 m .48429 .51505 L .48261 .51296 L p .432 .326 .633 r
F P
0 g
s
.41001 .30994 m .41491 .3138 L .3712 .33015 L p .603 .876 .992 r
F P
0 g
s
.3712 .33015 m .36332 .32834 L .41001 .30994 L p .603 .876 .992 r
F P
0 g
s
.48483 .52666 m .48261 .51296 L .48429 .51505 L closepath p .428 .321 .631 r
F P
0 g
s
.52769 .4531 m .52481 .45894 L .50165 .40545 L p .486 .362 .637 r
F P
0 g
s
.50045 .4145 m .50165 .40545 L .52481 .45894 L p .481 .359 .636 r
F P
0 g
s
.47873 .54456 m .48076 .53871 L .48416 .54679 L p .409 .306 .626 r
F P
0 g
s
.48416 .54679 m .48382 .55686 L .47873 .54456 L p .409 .306 .626 r
F P
0 g
s
.48483 .52666 m .4828 .53274 L .48132 .52814 L closepath p .42 .315 .629 r
F P
0 g
s
.52481 .45894 m .52193 .46464 L .50045 .4145 L p .481 .359 .636 r
F P
0 g
s
.49925 .42349 m .50045 .4145 L .52193 .46464 L p .477 .356 .636 r
F P
0 g
s
.31531 .30577 m .3234 .31044 L .28215 .35389 L p .693 .773 .913 r
F P
0 g
s
.28215 .35389 m .27224 .35146 L .31531 .30577 L p .693 .773 .913 r
F P
0 g
s
.52193 .46464 m .51905 .47021 L .49925 .42349 L p .477 .356 .636 r
F P
0 g
s
.49806 .43242 m .49925 .42349 L .51905 .47021 L p .473 .353 .636 r
F P
0 g
s
.48076 .53871 m .4828 .53274 L .4845 .53673 L p .414 .31 .627 r
F P
0 g
s
.4845 .53673 m .48416 .54679 L .48076 .53871 L p .414 .31 .627 r
F P
0 g
s
.51905 .47021 m .51618 .47565 L .49806 .43242 L p .473 .353 .636 r
F P
0 g
s
.49686 .4413 m .49806 .43242 L .51618 .47565 L p .469 .35 .635 r
F P
0 g
s
.48724 .5101 m .48604 .51841 L .48429 .51505 L p .432 .325 .632 r
F P
0 g
s
.48483 .52666 m .48429 .51505 L .48604 .51841 L closepath p .427 .321 .631 r
F P
0 g
s
.51618 .47565 m .5133 .48096 L .49686 .4413 L p .469 .35 .635 r
F P
0 g
s
.49566 .45011 m .49686 .4413 L .5133 .48096 L p .465 .347 .635 r
F P
0 g
s
.68122 .5192 m .67129 .52886 L .66262 .46904 L p .846 .772 .78 r
F P
0 g
s
.66262 .46904 m .6725 .45939 L .68122 .5192 L p .846 .772 .78 r
F P
0 g
s
.64175 .56998 m .65155 .5537 L .6415 .60571 L p .97 .933 .657 r
F P
0 g
s
.5133 .48096 m .51043 .48614 L .49566 .45011 L p .465 .347 .635 r
F P
0 g
s
.49446 .45887 m .49566 .45011 L .51043 .48614 L p .461 .344 .634 r
F P
0 g
s
.48483 .52666 m .4845 .53673 L .4828 .53274 L closepath p .418 .313 .628 r
F P
0 g
s
.51043 .48614 m .50757 .49118 L .49446 .45887 L p .461 .344 .634 r
F P
0 g
s
.49325 .46756 m .49446 .45887 L .50757 .49118 L p .456 .341 .634 r
F P
0 g
s
.50757 .49118 m .50471 .49608 L .49325 .46756 L p .456 .341 .634 r
F P
0 g
s
.49205 .4762 m .49325 .46756 L .50471 .49608 L p .452 .338 .633 r
F P
0 g
s
.50471 .49608 m .50185 .50086 L .49205 .4762 L p .452 .338 .633 r
F P
0 g
s
.49085 .48477 m .49205 .4762 L .50185 .50086 L p .448 .335 .633 r
F P
0 g
s
.50185 .50086 m .499 .5055 L .49085 .48477 L p .448 .335 .633 r
F P
0 g
s
.48965 .49327 m .49085 .48477 L .499 .5055 L p .443 .332 .632 r
F P
0 g
s
.499 .5055 m .49615 .51 L .48965 .49327 L p .443 .332 .632 r
F P
0 g
s
.48844 .50172 m .48965 .49327 L .49615 .51 L p .439 .329 .632 r
F P
0 g
s
.49615 .51 m .49331 .51437 L .48844 .50172 L p .439 .329 .632 r
F P
0 g
s
.48724 .5101 m .48844 .50172 L .49331 .51437 L p .435 .326 .631 r
F P
0 g
s
.49331 .51437 m .49048 .5186 L .48724 .5101 L p .435 .326 .631 r
F P
0 g
s
.48604 .51841 m .48724 .5101 L .49048 .5186 L p .43 .323 .631 r
F P
0 g
s
.48483 .52666 m .4899 .53939 L .4891 .54107 L closepath p .423 .316 .628 r
F P
0 g
s
.48483 .52666 m .49016 .53631 L .4899 .53939 L closepath p .425 .317 .628 r
F P
0 g
s
.48483 .52666 m .48983 .53217 L .49016 .53631 L closepath p .425 .317 .628 r
F P
0 g
s
.48483 .52666 m .48897 .52746 L .48983 .53217 L closepath p .425 .317 .628 r
F P
0 g
s
.48483 .52666 m .48765 .5227 L .48897 .52746 L closepath p .424 .318 .629 r
F P
0 g
s
.48483 .52666 m .48604 .51841 L .48765 .5227 L closepath p .426 .319 .63 r
F P
0 g
s
.48483 .52666 m .48624 .53964 L .4845 .53673 L closepath p .417 .312 .628 r
F P
0 g
s
.48483 .52666 m .48783 .54115 L .48624 .53964 L closepath p .417 .313 .628 r
F P
0 g
s
.48483 .52666 m .4891 .54107 L .48783 .54115 L closepath p .42 .314 .628 r
F P
0 g
s
.49048 .5186 m .48765 .5227 L .48604 .51841 L p .43 .323 .631 r
F P
0 g
s
.46882 .31999 m .47001 .32386 L .42464 .31842 L p .134 .658 .88 r
F P
0 g
s
.30718 .30086 m .31531 .30577 L .27224 .35146 L p .688 .765 .91 r
F P
0 g
s
.27224 .35146 m .26229 .34881 L .30718 .30086 L p .688 .765 .91 r
F P
0 g
s
.48416 .54679 m .4845 .53673 L .48624 .53964 L p .413 .308 .626 r
F P
0 g
s
.51718 .71849 m .5149 .75371 L .55042 .79452 L p .602 .317 .457 r
F P
0 g
s
.55042 .79452 m .55514 .74762 L .51718 .71849 L p .602 .317 .457 r
F P
0 g
s
.48382 .55686 m .48416 .54679 L .48765 .55279 L p .408 .304 .624 r
F P
0 g
s
.48624 .53964 m .48765 .55279 L .48416 .54679 L p .413 .308 .626 r
F P
0 g
s
.49312 .52815 m .48897 .52746 L .48765 .5227 L p .429 .32 .629 r
F P
0 g
s
.48765 .5227 m .49048 .5186 L .49312 .52815 L p .429 .32 .629 r
F P
0 g
s
.48348 .56692 m .48382 .55686 L .48906 .5661 L p .404 .301 .623 r
F P
0 g
s
.48765 .55279 m .48906 .5661 L .48382 .55686 L p .408 .304 .624 r
F P
0 g
s
.48765 .55279 m .48624 .53964 L .48783 .54115 L p .413 .309 .626 r
F P
0 g
s
.40508 .30535 m .41001 .30994 L .36332 .32834 L p .629 .851 .984 r
F P
0 g
s
.36332 .32834 m .3554 .32577 L .40508 .30535 L p .629 .851 .984 r
F P
0 g
s
.49487 .53771 m .48983 .53217 L .48897 .52746 L p .429 .319 .627 r
F P
0 g
s
.48897 .52746 m .49312 .52815 L .49487 .53771 L p .429 .319 .627 r
F P
0 g
s
.48315 .57699 m .48348 .56692 L .49048 .57958 L p .4 .297 .621 r
F P
0 g
s
.48906 .5661 m .49048 .57958 L .48348 .56692 L p .404 .301 .623 r
F P
0 g
s
.4973 .52875 m .49312 .52815 L .49048 .5186 L p .434 .323 .629 r
F P
0 g
s
.49048 .5186 m .49331 .51437 L .4973 .52875 L p .434 .323 .629 r
F P
0 g
s
.299 .29577 m .30718 .30086 L .26229 .34881 L p .685 .759 .908 r
F P
0 g
s
.26229 .34881 m .25232 .34599 L .299 .29577 L p .685 .759 .908 r
F P
0 g
s
.67129 .52886 m .66139 .54021 L .65279 .47985 L p .858 .768 .762 r
F P
0 g
s
.65279 .47985 m .66262 .46904 L .67129 .52886 L p .858 .768 .762 r
F P
0 g
s
.48783 .54115 m .49084 .55596 L .48765 .55279 L p .413 .309 .626 r
F P
0 g
s
.49084 .55596 m .48783 .54115 L .4891 .54107 L p .417 .311 .626 r
F P
0 g
s
.48281 .58705 m .48315 .57699 L .49191 .59323 L p .397 .293 .619 r
F P
0 g
s
.49048 .57958 m .49191 .59323 L .48315 .57699 L p .4 .297 .621 r
F P
0 g
s
.55102 .41189 m .54511 .4206 L .51018 .36041 L p 0 .205 .723 r
F P
0 g
s
.51018 .36041 m .51276 .35839 L .55102 .41189 L p 0 .205 .723 r
F P
0 g
s
.49553 .54614 m .49016 .53631 L .48983 .53217 L p .428 .318 .627 r
F P
0 g
s
.48983 .53217 m .49487 .53771 L .49553 .54614 L p .428 .318 .627 r
F P
0 g
s
.4934 .55585 m .4891 .54107 L .4899 .53939 L p .422 .314 .626 r
F P
0 g
s
.4891 .54107 m .4934 .55585 L .49084 .55596 L p .417 .311 .626 r
F P
0 g
s
.48247 .59711 m .48281 .58705 L .49334 .60706 L p .393 .29 .617 r
F P
0 g
s
.49191 .59323 m .49334 .60706 L .48281 .58705 L p .397 .293 .619 r
F P
0 g
s
.50149 .52924 m .4973 .52875 L .49331 .51437 L p .438 .326 .628 r
F P
0 g
s
.49331 .51437 m .49615 .51 L .50149 .52924 L p .438 .326 .628 r
F P
0 g
s
.48906 .5661 m .48765 .55279 L .49084 .55596 L p .41 .305 .623 r
F P
0 g
s
.49502 .55245 m .4899 .53939 L .49016 .53631 L p .426 .317 .626 r
F P
0 g
s
.49016 .53631 m .49553 .54614 L .49502 .55245 L p .426 .317 .626 r
F P
0 g
s
.4899 .53939 m .49502 .55245 L .4934 .55585 L p .422 .314 .626 r
F P
0 g
s
.55995 .71386 m .55514 .74762 L .58642 .74585 L p .395 .132 .394 r
F P
0 g
s
.58642 .74585 m .59334 .70774 L .55995 .71386 L p .395 .132 .394 r
F P
0 g
s
.48213 .60717 m .48247 .59711 L .49478 .62106 L p .389 .286 .615 r
F P
0 g
s
.49334 .60706 m .49478 .62106 L .48247 .59711 L p .393 .29 .617 r
F P
0 g
s
.51794 .34903 m .51534 .35438 L .47121 .32631 L p 0 .405 .825 r
F P
0 g
s
.49994 .54326 m .49487 .53771 L .49312 .52815 L p .433 .321 .626 r
F P
0 g
s
.49312 .52815 m .4973 .52875 L .49994 .54326 L p .433 .321 .626 r
F P
0 g
s
.5057 .52963 m .50149 .52924 L .49615 .51 L p .442 .328 .628 r
F P
0 g
s
.49615 .51 m .499 .5055 L .5057 .52963 L p .442 .328 .628 r
F P
0 g
s
.48179 .61722 m .48213 .60717 L .49623 .63523 L p .385 .282 .614 r
F P
0 g
s
.49478 .62106 m .49623 .63523 L .48213 .60717 L p .389 .286 .615 r
F P
0 g
s
.29079 .2905 m .299 .29577 L .25232 .34599 L p .682 .754 .906 r
F P
0 g
s
.25232 .34599 m .24232 .34303 L .29079 .2905 L p .682 .754 .906 r
F P
0 g
s
.48145 .62728 m .48179 .61722 L .49768 .64959 L p .382 .279 .612 r
F P
0 g
s
.49623 .63523 m .49768 .64959 L .48179 .61722 L p .385 .282 .614 r
F P
0 g
s
.49048 .57958 m .48906 .5661 L .49388 .57107 L p .406 .301 .621 r
F P
0 g
s
.49084 .55596 m .49388 .57107 L .48906 .5661 L p .41 .305 .623 r
F P
0 g
s
.50993 .52991 m .5057 .52963 L .499 .5055 L p .447 .33 .628 r
F P
0 g
s
.499 .5055 m .50185 .50086 L .50993 .52991 L p .447 .33 .628 r
F P
0 g
s
.49388 .57107 m .49084 .55596 L .4934 .55585 L p .414 .307 .623 r
F P
0 g
s
.48111 .63733 m .48145 .62728 L .49914 .66414 L p .378 .276 .61 r
F P
0 g
s
.49768 .64959 m .49914 .66414 L .48145 .62728 L p .382 .279 .612 r
F P
0 g
s
.46761 .31508 m .46882 .31999 L .41978 .31672 L p .332 .746 .978 r
F P
0 g
s
.41978 .31672 m .41491 .3138 L .46761 .31508 L p .332 .746 .978 r
F P
0 g
s
.40013 .30018 m .40508 .30535 L .3554 .32577 L p .642 .828 .972 r
F P
0 g
s
.3554 .32577 m .34746 .32259 L .40013 .30018 L p .642 .828 .972 r
F P
0 g
s
.48077 .64738 m .48111 .63733 L .50061 .67887 L p .375 .272 .609 r
F P
0 g
s
.49914 .66414 m .50061 .67887 L .48111 .63733 L p .378 .276 .61 r
F P
0 g
s
.50094 .55617 m .49553 .54614 L .49487 .53771 L p .431 .319 .625 r
F P
0 g
s
.49487 .53771 m .49994 .54326 L .50094 .55617 L p .431 .319 .625 r
F P
0 g
s
.51418 .53009 m .50993 .52991 L .50185 .50086 L p .451 .333 .627 r
F P
0 g
s
.50185 .50086 m .50471 .49608 L .51418 .53009 L p .451 .333 .627 r
F P
0 g
s
.28252 .28509 m .29079 .2905 L .24232 .34303 L p .68 .749 .904 r
F P
0 g
s
.24232 .34303 m .23228 .33994 L .28252 .28509 L p .68 .749 .904 r
F P
0 g
s
.66139 .54021 m .65155 .5537 L .64301 .49212 L p .871 .762 .74 r
F P
0 g
s
.64301 .49212 m .65279 .47985 L .66139 .54021 L p .871 .762 .74 r
F P
0 g
s
.50504 .54885 m .49994 .54326 L .4973 .52875 L p .437 .323 .626 r
F P
0 g
s
.4973 .52875 m .50149 .52924 L .50504 .54885 L p .437 .323 .626 r
F P
0 g
s
.48043 .65743 m .48077 .64738 L .50209 .6938 L p .371 .269 .607 r
F P
0 g
s
.50061 .67887 m .50209 .6938 L .48077 .64738 L p .375 .272 .609 r
F P
0 g
s
.49773 .57101 m .4934 .55585 L .49502 .55245 L p .421 .312 .624 r
F P
0 g
s
.4934 .55585 m .49773 .57101 L .49388 .57107 L p .414 .307 .623 r
F P
0 g
s
.63204 .58994 m .64175 .56998 L .63265 .62302 L p .973 .917 .592 r
F P
0 g
s
.48008 .66748 m .48043 .65743 L .50357 .70892 L p .368 .266 .606 r
F P
0 g
s
.50209 .6938 m .50357 .70892 L .48043 .65743 L p .371 .269 .607 r
F P
0 g
s
.50017 .56583 m .49502 .55245 L .49553 .54614 L p .427 .316 .624 r
F P
0 g
s
.49553 .54614 m .50094 .55617 L .50017 .56583 L p .427 .316 .624 r
F P
0 g
s
.49191 .59323 m .49048 .57958 L .49693 .5865 L p .403 .297 .619 r
F P
0 g
s
.49388 .57107 m .49693 .5865 L .49048 .57958 L p .406 .301 .621 r
F P
0 g
s
.51844 .53016 m .51418 .53009 L .50471 .49608 L p .455 .335 .627 r
F P
0 g
s
.50471 .49608 m .50757 .49118 L .51844 .53016 L p .455 .335 .627 r
F P
0 g
s
.49502 .55245 m .50017 .56583 L .49773 .57101 L p .421 .312 .624 r
F P
0 g
s
.47974 .67752 m .48008 .66748 L .50506 .72424 L p .364 .262 .604 r
F P
0 g
s
.50357 .70892 m .50506 .72424 L .48008 .66748 L p .368 .266 .606 r
F P
0 g
s
.52273 .53012 m .51844 .53016 L .50757 .49118 L p .459 .337 .627 r
F P
0 g
s
.50757 .49118 m .51043 .48614 L .52273 .53012 L p .459 .337 .627 r
F P
0 g
s
.4794 .68756 m .47974 .67752 L .50656 .73977 L p .361 .259 .602 r
F P
0 g
s
.50506 .72424 m .50656 .73977 L .47974 .67752 L p .364 .262 .604 r
F P
0 g
s
.27422 .27955 m .28252 .28509 L .23228 .33994 L p .677 .746 .902 r
F P
0 g
s
.23228 .33994 m .22222 .33675 L .27422 .27955 L p .677 .746 .902 r
F P
0 g
s
.49693 .5865 m .49388 .57107 L .49773 .57101 L p .412 .304 .621 r
F P
0 g
s
.55694 .40283 m .55102 .41189 L .51276 .35839 L p .194 .359 .801 r
F P
0 g
s
.51276 .35839 m .51534 .35438 L .55694 .40283 L p .194 .359 .801 r
F P
0 g
s
.47906 .6976 m .4794 .68756 L .50807 .75549 L p .358 .256 .601 r
F P
0 g
s
.50656 .73977 m .50807 .75549 L .4794 .68756 L p .361 .259 .602 r
F P
0 g
s
.51018 .55445 m .50504 .54885 L .50149 .52924 L p .441 .325 .625 r
F P
0 g
s
.50149 .52924 m .5057 .52963 L .51018 .55445 L p .441 .325 .625 r
F P
0 g
s
.52702 .52997 m .52273 .53012 L .51043 .48614 L p .463 .339 .626 r
F P
0 g
s
.51043 .48614 m .5133 .48096 L .52702 .52997 L p .463 .339 .626 r
F P
0 g
s
.49334 .60706 m .49191 .59323 L .5 .60226 L p .4 .293 .617 r
F P
0 g
s
.49693 .5865 m .5 .60226 L .49191 .59323 L p .403 .297 .619 r
F P
0 g
s
.47872 .70763 m .47906 .6976 L .50959 .77143 L p .355 .253 .599 r
F P
0 g
s
.50807 .75549 m .50959 .77143 L .47906 .6976 L p .358 .256 .601 r
F P
0 g
s
.50639 .56639 m .50094 .55617 L .49994 .54326 L p .434 .32 .624 r
F P
0 g
s
.49994 .54326 m .50504 .54885 L .50639 .56639 L p .434 .32 .624 r
F P
0 g
s
.39515 .29453 m .40013 .30018 L .34746 .32259 L p .649 .809 .96 r
F P
0 g
s
.34746 .32259 m .33947 .31891 L .39515 .29453 L p .649 .809 .96 r
F P
0 g
s
.47837 .71766 m .47872 .70763 L .51112 .78759 L p .351 .25 .598 r
F P
0 g
s
.50959 .77143 m .51112 .78759 L .47872 .70763 L p .355 .253 .599 r
F P
0 g
s
.53134 .52972 m .52702 .52997 L .5133 .48096 L p .466 .341 .626 r
F P
0 g
s
.5133 .48096 m .51618 .47565 L .53134 .52972 L p .466 .341 .626 r
F P
0 g
s
.52055 .34277 m .51794 .34903 L .47001 .32386 L p .179 .549 .93 r
F P
0 g
s
.47001 .32386 m .46882 .31999 L .52055 .34277 L p .179 .549 .93 r
F P
0 g
s
.51112 .78759 m .51265 .80396 L .47837 .71766 L p .351 .25 .598 r
F P
0 g
s
.26587 .2739 m .27422 .27955 L .22222 .33675 L p .676 .743 .901 r
F P
0 g
s
.22222 .33675 m .21212 .33348 L .26587 .2739 L p .676 .743 .901 r
F P
0 g
s
.50209 .58655 m .49773 .57101 L .50017 .56583 L p .42 .31 .622 r
F P
0 g
s
.49773 .57101 m .50209 .58655 L .49693 .5865 L p .412 .304 .621 r
F P
0 g
s
.53567 .52936 m .53134 .52972 L .51618 .47565 L p .47 .344 .626 r
F P
0 g
s
.51618 .47565 m .51905 .47021 L .53567 .52936 L p .47 .344 .626 r
F P
0 g
s
.46641 .30937 m .46761 .31508 L .41491 .3138 L p .447 .769 .997 r
F P
0 g
s
.41491 .3138 m .41001 .30994 L .46641 .30937 L p .447 .769 .997 r
F P
0 g
s
.51535 .56008 m .51018 .55445 L .5057 .52963 L p .445 .326 .624 r
F P
0 g
s
.5057 .52963 m .50993 .52991 L .51535 .56008 L p .445 .326 .624 r
F P
0 g
s
.50538 .57955 m .50017 .56583 L .50094 .55617 L p .429 .315 .623 r
F P
0 g
s
.50094 .55617 m .50639 .56639 L .50538 .57955 L p .429 .315 .623 r
F P
0 g
s
.49478 .62106 m .49334 .60706 L .5031 .61835 L p .396 .29 .615 r
F P
0 g
s
.5 .60226 m .5031 .61835 L .49334 .60706 L p .4 .293 .617 r
F P
0 g
s
.54002 .52889 m .53567 .52936 L .51905 .47021 L p .474 .346 .625 r
F P
0 g
s
.51905 .47021 m .52193 .46464 L .54002 .52889 L p .474 .346 .625 r
F P
0 g
s
.50017 .56583 m .50538 .57955 L .50209 .58655 L p .42 .31 .622 r
F P
0 g
s
.5 .60226 m .49693 .5865 L .50209 .58655 L p .409 .301 .619 r
F P
0 g
s
.65155 .5537 m .64175 .56998 L .63328 .50624 L p .882 .754 .716 r
F P
0 g
s
.63328 .50624 m .64301 .49212 L .65155 .5537 L p .882 .754 .716 r
F P
0 g
s
.54438 .52831 m .54002 .52889 L .52193 .46464 L p .477 .348 .625 r
F P
0 g
s
.52193 .46464 m .52481 .45894 L .54438 .52831 L p .477 .348 .625 r
F P
0 g
s
.74272 .4108 m .73258 .41641 L .69478 .35198 L p .727 .719 .843 r
F P
0 g
s
.73258 .41641 m .72248 .42235 L .68589 .35928 L p .73 .715 .837 r
F P
0 g
s
.68589 .35928 m .69478 .35198 L .73258 .41641 L p .73 .715 .837 r
F P
0 g
s
.72248 .42235 m .71241 .42867 L .67705 .36681 L p .733 .711 .83 r
F P
0 g
s
.67705 .36681 m .68589 .35928 L .72248 .42235 L p .733 .711 .83 r
F P
0 g
s
.75289 .40546 m .74272 .4108 L .70371 .34485 L p .724 .722 .848 r
F P
0 g
s
.69478 .35198 m .70371 .34485 L .74272 .4108 L p .727 .719 .843 r
F P
0 g
s
.71241 .42867 m .70237 .43544 L .66825 .37458 L p .737 .706 .822 r
F P
0 g
s
.66825 .37458 m .67705 .36681 L .71241 .42867 L p .737 .706 .822 r
F P
0 g
s
.5119 .57681 m .50639 .56639 L .50504 .54885 L p .437 .32 .622 r
F P
0 g
s
.50504 .54885 m .51018 .55445 L .5119 .57681 L p .437 .32 .622 r
F P
0 g
s
.7631 .40038 m .75289 .40546 L .7127 .33788 L p .721 .724 .853 r
F P
0 g
s
.70371 .34485 m .7127 .33788 L .75289 .40546 L p .724 .722 .848 r
F P
0 g
s
.54875 .52761 m .54438 .52831 L .52481 .45894 L p .481 .349 .624 r
F P
0 g
s
.52481 .45894 m .52769 .4531 L .54875 .52761 L p .481 .349 .624 r
F P
0 g
s
.70237 .43544 m .69238 .44274 L .65951 .38264 L p .74 .701 .814 r
F P
0 g
s
.65951 .38264 m .66825 .37458 L .70237 .43544 L p .74 .701 .814 r
F P
0 g
s
.77334 .3955 m .7631 .40038 L .72173 .33104 L p .718 .726 .857 r
F P
0 g
s
.7127 .33788 m .72173 .33104 L .7631 .40038 L p .721 .724 .853 r
F P
0 g
s
.52056 .56574 m .51535 .56008 L .50993 .52991 L p .449 .328 .623 r
F P
0 g
s
.50993 .52991 m .51418 .53009 L .52056 .56574 L p .449 .328 .623 r
F P
0 g
s
.55314 .52681 m .54875 .52761 L .52769 .4531 L p .484 .351 .624 r
F P
0 g
s
.52769 .4531 m .53057 .44713 L .55314 .52681 L p .484 .351 .624 r
F P
0 g
s
.39013 .2885 m .39515 .29453 L .33947 .31891 L p .654 .793 .949 r
F P
0 g
s
.33947 .31891 m .33146 .31484 L .39013 .2885 L p .654 .793 .949 r
F P
0 g
s
.72173 .33104 m .73081 .32433 L .77334 .3955 L p .718 .726 .857 r
F P
0 g
s
.49623 .63523 m .49478 .62106 L .50622 .63478 L p .393 .286 .613 r
F P
0 g
s
.5031 .61835 m .50622 .63478 L .49478 .62106 L p .396 .29 .615 r
F P
0 g
s
.69238 .44274 m .68242 .45068 L .65081 .39106 L p .744 .694 .804 r
F P
0 g
s
.65081 .39106 m .65951 .38264 L .69238 .44274 L p .744 .694 .804 r
F P
0 g
s
.55754 .52589 m .55314 .52681 L .53057 .44713 L p .488 .353 .623 r
F P
0 g
s
.53057 .44713 m .53346 .44104 L .55754 .52589 L p .488 .353 .623 r
F P
0 g
s
.56289 .39365 m .55694 .40283 L .51534 .35438 L p .334 .456 .835 r
F P
0 g
s
.51534 .35438 m .51794 .34903 L .56289 .39365 L p .334 .456 .835 r
F P
0 g
s
.68242 .45068 m .6725 .45939 L .64215 .39988 L p .747 .686 .792 r
F P
0 g
s
.64215 .39988 m .65081 .39106 L .68242 .45068 L p .747 .686 .792 r
F P
0 g
s
.56196 .52487 m .55754 .52589 L .53346 .44104 L p .491 .355 .623 r
F P
0 g
s
.53346 .44104 m .53634 .43482 L .56196 .52487 L p .491 .355 .623 r
F P
0 g
s
.5065 .60248 m .50209 .58655 L .50538 .57955 L p .419 .308 .62 r
F P
0 g
s
.50209 .58655 m .5065 .60248 L .5 .60226 L p .409 .301 .619 r
F P
0 g
s
.56639 .52372 m .56196 .52487 L .53634 .43482 L p .494 .357 .622 r
F P
0 g
s
.53634 .43482 m .53922 .42846 L .56639 .52372 L p .494 .357 .622 r
F P
0 g
s
.5031 .61835 m .5 .60226 L .5065 .60248 L p .407 .298 .617 r
F P
0 g
s
.51062 .59362 m .50538 .57955 L .50639 .56639 L p .43 .315 .621 r
F P
0 g
s
.50639 .56639 m .5119 .57681 L .51062 .59362 L p .43 .315 .621 r
F P
0 g
s
.57461 .5023 m .56639 .52372 L .53922 .42846 L p .453 .361 .661 r
F P
0 g
s
.53922 .42846 m .54511 .4206 L .57461 .5023 L p .453 .361 .661 r
F P
0 g
s
.5258 .57142 m .52056 .56574 L .51418 .53009 L p .452 .329 .622 r
F P
0 g
s
.51418 .53009 m .51844 .53016 L .5258 .57142 L p .452 .329 .622 r
F P
0 g
s
.6725 .45939 m .66262 .46904 L .63354 .4092 L p .749 .676 .779 r
F P
0 g
s
.63354 .4092 m .64215 .39988 L .6725 .45939 L p .749 .676 .779 r
F P
0 g
s
.49768 .64959 m .49623 .63523 L .50936 .65156 L p .39 .283 .611 r
F P
0 g
s
.50622 .63478 m .50936 .65156 L .49623 .63523 L p .393 .286 .613 r
F P
0 g
s
.50538 .57955 m .51062 .59362 L .5065 .60248 L p .419 .308 .62 r
F P
0 g
s
.51744 .58744 m .5119 .57681 L .51018 .55445 L p .44 .321 .621 r
F P
0 g
s
.51018 .55445 m .51535 .56008 L .51744 .58744 L p .44 .321 .621 r
F P
0 g
s
.46519 .30306 m .46641 .30937 L .41001 .30994 L p .513 .77 .989 r
F P
0 g
s
.41001 .30994 m .40508 .30535 L .46519 .30306 L p .513 .77 .989 r
F P
0 g
s
.52317 .33586 m .52055 .34277 L .46882 .31999 L p .336 .618 .954 r
F P
0 g
s
.46882 .31999 m .46761 .31508 L .52317 .33586 L p .336 .618 .954 r
F P
0 g
s
.38509 .28215 m .39013 .2885 L .33146 .31484 L p .657 .781 .94 r
F P
0 g
s
.33146 .31484 m .3234 .31044 L .38509 .28215 L p .657 .781 .94 r
F P
0 g
s
.66262 .46904 m .65279 .47985 L .62498 .41912 L p .751 .664 .765 r
F P
0 g
s
.62498 .41912 m .63354 .4092 L .66262 .46904 L p .751 .664 .765 r
F P
0 g
s
.62241 .61488 m .63204 .58994 L .62387 .64495 L p .969 .891 .519 r
F P
0 g
s
.53107 .57712 m .5258 .57142 L .51844 .53016 L p .456 .331 .621 r
F P
0 g
s
.51844 .53016 m .52273 .53012 L .53107 .57712 L p .456 .331 .621 r
F P
0 g
s
.64175 .56998 m .63204 .58994 L .62362 .52277 L p .893 .744 .69 r
F P
0 g
s
.62362 .52277 m .63328 .50624 L .64175 .56998 L p .893 .744 .69 r
F P
0 g
s
.49914 .66414 m .49768 .64959 L .51253 .6687 L p .387 .28 .609 r
F P
0 g
s
.50936 .65156 m .51253 .6687 L .49768 .64959 L p .39 .283 .611 r
F P
0 g
s
.58289 .48402 m .57461 .5023 L .54511 .4206 L p .51 .422 .692 r
F P
0 g
s
.54511 .4206 m .55102 .41189 L .58289 .48402 L p .51 .422 .692 r
F P
0 g
s
.50622 .63478 m .5031 .61835 L .51094 .61882 L p .405 .295 .615 r
F P
0 g
s
.5065 .60248 m .51094 .61882 L .5031 .61835 L p .407 .298 .617 r
F P
0 g
s
.51094 .61882 m .5065 .60248 L .51062 .59362 L p .419 .306 .618 r
F P
0 g
s
.56887 .38449 m .56289 .39365 L .51794 .34903 L p .424 .518 .85 r
F P
0 g
s
.51794 .34903 m .52055 .34277 L .56887 .38449 L p .424 .518 .85 r
F P
0 g
s
.65279 .47985 m .64301 .49212 L .61647 .42978 L p .753 .651 .748 r
F P
0 g
s
.61647 .42978 m .62498 .41912 L .65279 .47985 L p .753 .651 .748 r
F P
0 g
s
.51592 .60803 m .51062 .59362 L .5119 .57681 L p .431 .314 .619 r
F P
0 g
s
.5119 .57681 m .51744 .58744 L .51592 .60803 L p .431 .314 .619 r
F P
0 g
s
.52304 .59827 m .51744 .58744 L .51535 .56008 L p .443 .322 .62 r
F P
0 g
s
.51535 .56008 m .52056 .56574 L .52304 .59827 L p .443 .322 .62 r
F P
0 g
s
.5149 .75371 m .51265 .80396 L .54587 .86175 L p .609 .334 .475 r
F P
0 g
s
.54587 .86175 m .55042 .79452 L .5149 .75371 L p .609 .334 .475 r
F P
0 g
s
.53639 .58285 m .53107 .57712 L .52273 .53012 L p .459 .332 .62 r
F P
0 g
s
.52273 .53012 m .52702 .52997 L .53639 .58285 L p .459 .332 .62 r
F P
0 g
s
.51062 .59362 m .51592 .60803 L .51094 .61882 L p .419 .306 .618 r
F P
0 g
s
.50061 .67887 m .49914 .66414 L .51573 .6862 L p .384 .277 .607 r
F P
0 g
s
.51253 .6687 m .51573 .6862 L .49914 .66414 L p .387 .28 .609 r
F P
0 g
s
.59121 .4681 m .58289 .48402 L .55102 .41189 L p .553 .471 .717 r
F P
0 g
s
.55102 .41189 m .55694 .40283 L .59121 .4681 L p .553 .471 .717 r
F P
0 g
s
.38001 .27553 m .38509 .28215 L .3234 .31044 L p .658 .771 .933 r
F P
0 g
s
.3234 .31044 m .31531 .30577 L .38001 .27553 L p .658 .771 .933 r
F P
0 g
s
.46397 .29626 m .46519 .30306 L .40508 .30535 L p .554 .764 .976 r
F P
0 g
s
.40508 .30535 m .40013 .30018 L .46397 .29626 L p .554 .764 .976 r
F P
0 g
s
.55514 .74762 m .55042 .79452 L .57968 .79839 L p .413 .164 .424 r
F P
0 g
s
.57968 .79839 m .58642 .74585 L .55514 .74762 L p .413 .164 .424 r
F P
0 g
s
.52581 .32848 m .52317 .33586 L .46761 .31508 L p .432 .652 .951 r
F P
0 g
s
.46761 .31508 m .46641 .30937 L .52581 .32848 L p .432 .652 .951 r
F P
0 g
s
.64301 .49212 m .63328 .50624 L .608 .44133 L p .752 .635 .73 r
F P
0 g
s
.608 .44133 m .61647 .42978 L .64301 .49212 L p .752 .635 .73 r
F P
0 g
s
.50936 .65156 m .50622 .63478 L .51543 .63558 L p .403 .292 .613 r
F P
0 g
s
.51094 .61882 m .51543 .63558 L .50622 .63478 L p .405 .295 .615 r
F P
0 g
s
.54173 .58861 m .53639 .58285 L .52702 .52997 L p .462 .334 .619 r
F P
0 g
s
.52702 .52997 m .53134 .52972 L .54173 .58861 L p .462 .334 .619 r
F P
0 g
s
.52869 .60931 m .52304 .59827 L .52056 .56574 L p .445 .322 .618 r
F P
0 g
s
.52056 .56574 m .5258 .57142 L .52869 .60931 L p .445 .322 .618 r
F P
0 g
s
.50209 .6938 m .50061 .67887 L .51895 .70408 L p .381 .273 .605 r
F P
0 g
s
.51573 .6862 m .51895 .70408 L .50061 .67887 L p .384 .277 .607 r
F P
0 g
s
.59958 .45401 m .59121 .4681 L .55694 .40283 L p .585 .511 .738 r
F P
0 g
s
.55694 .40283 m .56289 .39365 L .59958 .45401 L p .585 .511 .738 r
F P
0 g
s
.51543 .63558 m .51094 .61882 L .51592 .60803 L p .418 .304 .616 r
F P
0 g
s
.52127 .62282 m .51592 .60803 L .51744 .58744 L p .432 .314 .618 r
F P
0 g
s
.51744 .58744 m .52304 .59827 L .52127 .62282 L p .432 .314 .618 r
F P
0 g
s
.57488 .3754 m .56887 .38449 L .52055 .34277 L p .485 .56 .857 r
F P
0 g
s
.52055 .34277 m .52317 .33586 L .57488 .3754 L p .485 .56 .857 r
F P
0 g
s
.3749 .26868 m .38001 .27553 L .31531 .30577 L p .66 .764 .927 r
F P
0 g
s
.31531 .30577 m .30718 .30086 L .3749 .26868 L p .66 .764 .927 r
F P
0 g
s
.54712 .59438 m .54173 .58861 L .53134 .52972 L p .465 .335 .618 r
F P
0 g
s
.53134 .52972 m .53567 .52936 L .54712 .59438 L p .465 .335 .618 r
F P
0 g
s
.51592 .60803 m .52127 .62282 L .51543 .63558 L p .418 .304 .616 r
F P
0 g
s
.63328 .50624 m .62362 .52277 L .59958 .45401 L p .751 .617 .71 r
F P
0 g
s
.59958 .45401 m .608 .44133 L .63328 .50624 L p .751 .617 .71 r
F P
0 g
s
.50357 .70892 m .50209 .6938 L .5222 .72234 L p .379 .27 .603 r
F P
0 g
s
.51895 .70408 m .5222 .72234 L .50209 .6938 L p .381 .273 .605 r
F P
0 g
s
.608 .44133 m .59958 .45401 L .56289 .39365 L p .609 .544 .757 r
F P
0 g
s
.56289 .39365 m .56887 .38449 L .608 .44133 L p .609 .544 .757 r
F P
0 g
s
.46273 .28909 m .46397 .29626 L .40013 .30018 L p .581 .757 .962 r
F P
0 g
s
.40013 .30018 m .39515 .29453 L .46273 .28909 L p .581 .757 .962 r
F P
0 g
s
.51253 .6687 m .50936 .65156 L .51996 .65276 L p .401 .289 .611 r
F P
0 g
s
.51543 .63558 m .51996 .65276 L .50936 .65156 L p .403 .292 .613 r
F P
0 g
s
.63204 .58994 m .62241 .61488 L .61402 .54248 L p .901 .731 .661 r
F P
0 g
s
.61402 .54248 m .62362 .52277 L .63204 .58994 L p .901 .731 .661 r
F P
0 g
s
.55254 .60019 m .54712 .59438 L .53567 .52936 L p .469 .336 .617 r
F P
0 g
s
.53567 .52936 m .54002 .52889 L .55254 .60019 L p .469 .336 .617 r
F P
0 g
s
.53438 .62057 m .52869 .60931 L .5258 .57142 L p .448 .323 .617 r
F P
0 g
s
.5258 .57142 m .53107 .57712 L .53438 .62057 L p .448 .323 .617 r
F P
0 g
s
.52847 .32077 m .52581 .32848 L .46641 .30937 L p .492 .67 .943 r
F P
0 g
s
.46641 .30937 m .46519 .30306 L .52847 .32077 L p .492 .67 .943 r
F P
0 g
s
.36975 .26164 m .3749 .26868 L .30718 .30086 L p .661 .757 .922 r
F P
0 g
s
.30718 .30086 m .299 .29577 L .36975 .26164 L p .661 .757 .922 r
F P
0 g
s
.51996 .65276 m .51543 .63558 L .52127 .62282 L p .417 .302 .614 r
F P
0 g
s
.61647 .42978 m .608 .44133 L .56887 .38449 L p .628 .572 .772 r
F P
0 g
s
.56887 .38449 m .57488 .3754 L .61647 .42978 L p .628 .572 .772 r
F P
0 g
s
.50506 .72424 m .50357 .70892 L .52548 .74099 L p .376 .268 .602 r
F P
0 g
s
.5222 .72234 m .52548 .74099 L .50357 .70892 L p .379 .27 .603 r
F P
0 g
s
.52667 .63797 m .52127 .62282 L .52304 .59827 L p .433 .313 .616 r
F P
0 g
s
.52304 .59827 m .52869 .60931 L .52667 .63797 L p .433 .313 .616 r
F P
0 g
s
.58092 .36641 m .57488 .3754 L .52317 .33586 L p .528 .59 .861 r
F P
0 g
s
.52317 .33586 m .52581 .32848 L .58092 .36641 L p .528 .59 .861 r
F P
0 g
s
.62498 .41912 m .61647 .42978 L .57488 .3754 L p .642 .595 .786 r
F P
0 g
s
.63354 .4092 m .62498 .41912 L .58092 .36641 L p .653 .614 .798 r
F P
0 g
s
.57488 .3754 m .58092 .36641 L .62498 .41912 L p .642 .595 .786 r
F P
0 g
s
.55799 .60602 m .55254 .60019 L .54002 .52889 L p .472 .338 .617 r
F P
0 g
s
.54002 .52889 m .54438 .52831 L .55799 .60602 L p .472 .338 .617 r
F P
0 g
s
.64215 .39988 m .63354 .4092 L .58701 .35752 L p .661 .63 .808 r
F P
0 g
s
.58092 .36641 m .58701 .35752 L .63354 .4092 L p .653 .614 .798 r
F P
0 g
s
.59121 .4681 m .59958 .45401 L .62362 .52277 L p .747 .596 .689 r
F P
0 g
s
.65081 .39106 m .64215 .39988 L .59312 .34875 L p .667 .643 .817 r
F P
0 g
s
.58701 .35752 m .59312 .34875 L .64215 .39988 L p .661 .63 .808 r
F P
0 g
s
.62362 .52277 m .61402 .54248 L .59121 .4681 L p .747 .596 .689 r
F P
0 g
s
.51573 .6862 m .51253 .6687 L .52453 .67038 L p .399 .286 .609 r
F P
0 g
s
.51996 .65276 m .52453 .67038 L .51253 .6687 L p .401 .289 .611 r
F P
0 g
s
.52127 .62282 m .52667 .63797 L .51996 .65276 L p .417 .302 .614 r
F P
0 g
s
.54013 .63204 m .53438 .62057 L .53107 .57712 L p .45 .324 .616 r
F P
0 g
s
.53107 .57712 m .53639 .58285 L .54013 .63204 L p .45 .324 .616 r
F P
0 g
s
.46149 .2816 m .46273 .28909 L .39515 .29453 L p .599 .751 .95 r
F P
0 g
s
.39515 .29453 m .39013 .2885 L .46149 .2816 L p .599 .751 .95 r
F P
0 g
s
.56348 .61187 m .55799 .60602 L .54438 .52831 L p .475 .339 .616 r
F P
0 g
s
.54438 .52831 m .54875 .52761 L .56348 .61187 L p .475 .339 .616 r
F P
0 g
s
.65951 .38264 m .65081 .39106 L .59928 .34007 L p .672 .655 .825 r
F P
0 g
s
.59312 .34875 m .59928 .34007 L .65081 .39106 L p .667 .643 .817 r
F P
0 g
s
.58289 .48402 m .59121 .4681 L .61402 .54248 L p .74 .573 .666 r
F P
0 g
s
.61291 .64679 m .62241 .61488 L .61518 .67323 L p .956 .858 .443 r
F P
0 g
s
.50656 .73977 m .50506 .72424 L .52879 .76004 L p .373 .265 .6 r
F P
0 g
s
.52548 .74099 m .52879 .76004 L .50506 .72424 L p .376 .268 .602 r
F P
0 g
s
.36457 .25443 m .36975 .26164 L .299 .29577 L p .661 .752 .917 r
F P
0 g
s
.299 .29577 m .29079 .2905 L .36457 .25443 L p .661 .752 .917 r
F P
0 g
s
.66825 .37458 m .65951 .38264 L .60548 .33149 L p .676 .665 .832 r
F P
0 g
s
.59928 .34007 m .60548 .33149 L .65951 .38264 L p .672 .655 .825 r
F P
0 g
s
.53114 .3128 m .52847 .32077 L .46519 .30306 L p .533 .681 .933 r
F P
0 g
s
.46519 .30306 m .46397 .29626 L .53114 .3128 L p .533 .681 .933 r
F P
0 g
s
.56901 .61775 m .56348 .61187 L .54875 .52761 L p .477 .34 .615 r
F P
0 g
s
.54875 .52761 m .55314 .52681 L .56901 .61775 L p .477 .34 .615 r
F P
0 g
s
.53213 .6535 m .52667 .63797 L .52869 .60931 L p .434 .313 .615 r
F P
0 g
s
.52869 .60931 m .53438 .62057 L .53213 .6535 L p .434 .313 .615 r
F P
0 g
s
.58701 .35752 m .58092 .36641 L .52581 .32848 L p .559 .613 .863 r
F P
0 g
s
.52581 .32848 m .52847 .32077 L .58701 .35752 L p .559 .613 .863 r
F P
0 g
s
.52453 .67038 m .51996 .65276 L .52667 .63797 L p .417 .3 .612 r
F P
0 g
s
.61402 .54248 m .60451 .56652 L .58289 .48402 L p .74 .573 .666 r
F P
0 g
s
.57461 .5023 m .58289 .48402 L .60451 .56652 L p .731 .547 .643 r
F P
0 g
s
.67705 .36681 m .66825 .37458 L .61172 .32298 L p .678 .673 .838 r
F P
0 g
s
.60548 .33149 m .61172 .32298 L .66825 .37458 L p .676 .665 .832 r
F P
0 g
s
.50807 .75549 m .50656 .73977 L .53214 .77951 L p .371 .262 .598 r
F P
0 g
s
.52879 .76004 m .53214 .77951 L .50656 .73977 L p .373 .265 .6 r
F P
0 g
s
.54594 .64374 m .54013 .63204 L .53639 .58285 L p .453 .324 .615 r
F P
0 g
s
.53639 .58285 m .54173 .58861 L .54594 .64374 L p .453 .324 .615 r
F P
0 g
s
.51895 .70408 m .51573 .6862 L .52915 .68844 L p .397 .284 .607 r
F P
0 g
s
.52453 .67038 m .52915 .68844 L .51573 .6862 L p .399 .286 .609 r
F P
0 g
s
.68589 .35928 m .67705 .36681 L .618 .31455 L p .68 .68 .843 r
F P
0 g
s
.61172 .32298 m .618 .31455 L .67705 .36681 L p .678 .673 .838 r
F P
0 g
s
.57458 .62366 m .56901 .61775 L .55314 .52681 L p .48 .341 .614 r
F P
0 g
s
.55314 .52681 m .55754 .52589 L .57458 .62366 L p .48 .341 .614 r
F P
0 g
s
.35935 .24706 m .36457 .25443 L .29079 .2905 L p .662 .748 .914 r
F P
0 g
s
.29079 .2905 m .28252 .28509 L .35935 .24706 L p .662 .748 .914 r
F P
0 g
s
.52667 .63797 m .53213 .6535 L .52453 .67038 L p .417 .3 .612 r
F P
0 g
s
.46024 .27385 m .46149 .2816 L .39013 .2885 L p .612 .746 .94 r
F P
0 g
s
.39013 .2885 m .38509 .28215 L .46024 .27385 L p .612 .746 .94 r
F P
0 g
s
.60451 .56652 m .61402 .54248 L .62241 .61488 L p .907 .716 .632 r
F P
0 g
s
.60451 .56652 m .5951 .59662 L .57461 .5023 L p .731 .547 .643 r
F P
0 g
s
.56639 .52372 m .57461 .5023 L .5951 .59662 L p .719 .52 .62 r
F P
0 g
s
.59312 .34875 m .58701 .35752 L .52847 .32077 L p .582 .63 .865 r
F P
0 g
s
.62241 .61488 m .61291 .64679 L .60451 .56652 L p .907 .716 .632 r
F P
0 g
s
.69478 .35198 m .68589 .35928 L .62433 .30617 L p .682 .686 .848 r
F P
0 g
s
.618 .31455 m .62433 .30617 L .68589 .35928 L p .68 .68 .843 r
F P
0 g
s
.50959 .77143 m .50807 .75549 L .53552 .79941 L p .368 .259 .597 r
F P
0 g
s
.53214 .77951 m .53552 .79941 L .50807 .75549 L p .371 .262 .598 r
F P
0 g
s
.58019 .62959 m .57458 .62366 L .55754 .52589 L p .483 .342 .613 r
F P
0 g
s
.55754 .52589 m .56196 .52487 L .58019 .62959 L p .483 .342 .613 r
F P
0 g
s
.53384 .30463 m .53114 .3128 L .46397 .29626 L p .561 .688 .925 r
F P
0 g
s
.46397 .29626 m .46273 .28909 L .53384 .30463 L p .561 .688 .925 r
F P
0 g
s
.52847 .32077 m .53114 .3128 L .59312 .34875 L p .582 .63 .865 r
F P
0 g
s
.55179 .65567 m .54594 .64374 L .54173 .58861 L p .455 .325 .614 r
F P
0 g
s
.54173 .58861 m .54712 .59438 L .55179 .65567 L p .455 .325 .614 r
F P
0 g
s
.53765 .66942 m .53213 .6535 L .53438 .62057 L p .435 .312 .613 r
F P
0 g
s
.53438 .62057 m .54013 .63204 L .53765 .66942 L p .435 .312 .613 r
F P
0 g
s
.52915 .68844 m .52453 .67038 L .53213 .6535 L p .416 .298 .611 r
F P
0 g
s
.70371 .34485 m .69478 .35198 L .63069 .29784 L p .683 .691 .852 r
F P
0 g
s
.62433 .30617 m .63069 .29784 L .69478 .35198 L p .682 .686 .848 r
F P
0 g
s
.5222 .72234 m .51895 .70408 L .53382 .70697 L p .395 .281 .605 r
F P
0 g
s
.52915 .68844 m .53382 .70697 L .51895 .70408 L p .397 .284 .607 r
F P
0 g
s
.3541 .23956 m .35935 .24706 L .28252 .28509 L p .662 .744 .911 r
F P
0 g
s
.28252 .28509 m .27422 .27955 L .3541 .23956 L p .662 .744 .911 r
F P
0 g
s
.58583 .63555 m .58019 .62959 L .56196 .52487 L p .486 .343 .612 r
F P
0 g
s
.56196 .52487 m .56639 .52372 L .58583 .63555 L p .486 .343 .612 r
F P
0 g
s
.59928 .34007 m .59312 .34875 L .53114 .3128 L p .599 .644 .866 r
F P
0 g
s
.51112 .78759 m .50959 .77143 L .53893 .81974 L p .366 .257 .595 r
F P
0 g
s
.53552 .79941 m .53893 .81974 L .50959 .77143 L p .368 .259 .597 r
F P
0 g
s
.7127 .33788 m .70371 .34485 L .63711 .28956 L p .684 .696 .855 r
F P
0 g
s
.63069 .29784 m .63711 .28956 L .70371 .34485 L p .683 .691 .852 r
F P
0 g
s
.45898 .26589 m .46024 .27385 L .38509 .28215 L p .622 .741 .932 r
F P
0 g
s
.38509 .28215 m .38001 .27553 L .45898 .26589 L p .622 .741 .932 r
F P
0 g
s
.53213 .6535 m .53765 .66942 L .52915 .68844 L p .416 .298 .611 r
F P
0 g
s
.5951 .59662 m .58583 .63555 L .56639 .52372 L p .719 .52 .62 r
F P
0 g
s
.55771 .66784 m .55179 .65567 L .54712 .59438 L p .457 .325 .613 r
F P
0 g
s
.54712 .59438 m .55254 .60019 L .55771 .66784 L p .457 .325 .613 r
F P
0 g
s
.53114 .3128 m .53384 .30463 L .59928 .34007 L p .599 .644 .866 r
F P
0 g
s
.72173 .33104 m .7127 .33788 L .64356 .28131 L p .684 .7 .859 r
F P
0 g
s
.63711 .28956 m .64356 .28131 L .7127 .33788 L p .684 .696 .855 r
F P
0 g
s
.60548 .33149 m .59928 .34007 L .53384 .30463 L p .613 .655 .868 r
F P
0 g
s
.3488 .23193 m .3541 .23956 L .27422 .27955 L p .663 .741 .908 r
F P
0 g
s
.27422 .27955 m .26587 .2739 L .3488 .23193 L p .663 .741 .908 r
F P
0 g
s
.53655 .29631 m .53384 .30463 L .46273 .28909 L p .582 .693 .918 r
F P
0 g
s
.46273 .28909 m .46149 .2816 L .53655 .29631 L p .582 .693 .918 r
F P
0 g
s
.54322 .68574 m .53765 .66942 L .54013 .63204 L p .436 .312 .612 r
F P
0 g
s
.54013 .63204 m .54594 .64374 L .54322 .68574 L p .436 .312 .612 r
F P
0 g
s
.51265 .80396 m .51112 .78759 L .54238 .84051 L p .364 .254 .593 r
F P
0 g
s
.53893 .81974 m .54238 .84051 L .51112 .78759 L p .366 .257 .595 r
F P
0 g
s
.52548 .74099 m .5222 .72234 L .53854 .72597 L p .393 .279 .603 r
F P
0 g
s
.53382 .70697 m .53854 .72597 L .5222 .72234 L p .395 .281 .605 r
F P
0 g
s
.53382 .70697 m .52915 .68844 L .53765 .66942 L p .415 .297 .609 r
F P
0 g
s
.5951 .59662 m .60451 .56652 L .61291 .64679 L p .911 .698 .602 r
F P
0 g
s
.73081 .32433 m .72173 .33104 L .65006 .27308 L p .684 .703 .862 r
F P
0 g
s
.64356 .28131 m .65006 .27308 L .72173 .33104 L p .684 .7 .859 r
F P
0 g
s
.45772 .25774 m .45898 .26589 L .38001 .27553 L p .629 .738 .926 r
F P
0 g
s
.38001 .27553 m .3749 .26868 L .45772 .25774 L p .629 .738 .926 r
F P
0 g
s
.61172 .32298 m .60548 .33149 L .53655 .29631 L p .624 .665 .869 r
F P
0 g
s
.53384 .30463 m .53655 .29631 L .60548 .33149 L p .613 .655 .868 r
F P
0 g
s
.56368 .68024 m .55771 .66784 L .55254 .60019 L p .459 .326 .611 r
F P
0 g
s
.55254 .60019 m .55799 .60602 L .56368 .68024 L p .459 .326 .611 r
F P
0 g
s
.55042 .79452 m .54587 .86175 L .57323 .87343 L p .426 .188 .447 r
F P
0 g
s
.57323 .87343 m .57968 .79839 L .55042 .79452 L p .426 .188 .447 r
F P
0 g
s
.54238 .84051 m .54587 .86175 L .51265 .80396 L p .364 .254 .593 r
F P
0 g
s
.65006 .27308 m .65661 .26487 L .73081 .32433 L p .684 .703 .862 r
F P
0 g
s
.53765 .66942 m .54322 .68574 L .53382 .70697 L p .415 .297 .609 r
F P
0 g
s
.53928 .28785 m .53655 .29631 L .46149 .2816 L p .598 .697 .912 r
F P
0 g
s
.46149 .2816 m .46024 .27385 L .53928 .28785 L p .598 .697 .912 r
F P
0 g
s
.52879 .76004 m .52548 .74099 L .54331 .74546 L p .391 .277 .602 r
F P
0 g
s
.53854 .72597 m .54331 .74546 L .52548 .74099 L p .393 .279 .603 r
F P
0 g
s
.54886 .70247 m .54322 .68574 L .54594 .64374 L p .437 .311 .61 r
F P
0 g
s
.54594 .64374 m .55179 .65567 L .54886 .70247 L p .437 .311 .61 r
F P
0 g
s
.618 .31455 m .61172 .32298 L .53928 .28785 L p .632 .672 .87 r
F P
0 g
s
.53655 .29631 m .53928 .28785 L .61172 .32298 L p .624 .665 .869 r
F P
0 g
s
.60358 .68877 m .61291 .64679 L .60664 .71049 L p .938 .82 .369 r
F P
0 g
s
.53854 .72597 m .53382 .70697 L .54322 .68574 L p .415 .295 .607 r
F P
0 g
s
.56972 .69288 m .56368 .68024 L .55799 .60602 L p .462 .326 .61 r
F P
0 g
s
.55799 .60602 m .56348 .61187 L .56972 .69288 L p .462 .326 .61 r
F P
0 g
s
.45644 .24943 m .45772 .25774 L .3749 .26868 L p .635 .735 .92 r
F P
0 g
s
.3749 .26868 m .36975 .26164 L .45644 .24943 L p .635 .735 .92 r
F P
0 g
s
.61291 .64679 m .60358 .68877 L .5951 .59662 L p .911 .698 .602 r
F P
0 g
s
.62433 .30617 m .618 .31455 L .54203 .2793 L p .639 .679 .872 r
F P
0 g
s
.53928 .28785 m .54203 .2793 L .618 .31455 L p .632 .672 .87 r
F P
0 g
s
.54322 .68574 m .54886 .70247 L .53854 .72597 L p .415 .295 .607 r
F P
0 g
s
.54203 .2793 m .53928 .28785 L .46024 .27385 L p .61 .7 .908 r
F P
0 g
s
.46024 .27385 m .45898 .26589 L .54203 .2793 L p .61 .7 .908 r
F P
0 g
s
.53214 .77951 m .52879 .76004 L .54814 .76545 L p .389 .274 .6 r
F P
0 g
s
.54331 .74546 m .54814 .76545 L .52879 .76004 L p .391 .277 .602 r
F P
0 g
s
.55456 .71962 m .54886 .70247 L .55179 .65567 L p .438 .311 .609 r
F P
0 g
s
.55179 .65567 m .55771 .66784 L .55456 .71962 L p .438 .311 .609 r
F P
0 g
s
.57581 .70578 m .56972 .69288 L .56348 .61187 L p .464 .327 .609 r
F P
0 g
s
.56348 .61187 m .56901 .61775 L .57581 .70578 L p .464 .327 .609 r
F P
0 g
s
.45515 .24097 m .45644 .24943 L .36975 .26164 L p .64 .733 .916 r
F P
0 g
s
.36975 .26164 m .36457 .25443 L .45515 .24097 L p .64 .733 .916 r
F P
0 g
s
.58583 .63555 m .5951 .59662 L .60358 .68877 L p .912 .68 .574 r
F P
0 g
s
.54331 .74546 m .53854 .72597 L .54886 .70247 L p .414 .294 .606 r
F P
0 g
s
.63069 .29784 m .62433 .30617 L .54481 .27065 L p .644 .684 .873 r
F P
0 g
s
.54203 .2793 m .54481 .27065 L .62433 .30617 L p .639 .679 .872 r
F P
0 g
s
.58198 .71892 m .57581 .70578 L .56901 .61775 L p .466 .327 .608 r
F P
0 g
s
.56901 .61775 m .57458 .62366 L .58198 .71892 L p .466 .327 .608 r
F P
0 g
s
.54481 .27065 m .54203 .2793 L .45898 .26589 L p .619 .703 .904 r
F P
0 g
s
.45898 .26589 m .45772 .25774 L .54481 .27065 L p .619 .703 .904 r
F P
0 g
s
.53552 .79941 m .53214 .77951 L .55303 .78595 L p .388 .272 .599 r
F P
0 g
s
.54814 .76545 m .55303 .78595 L .53214 .77951 L p .389 .274 .6 r
F P
0 g
s
.54886 .70247 m .55456 .71962 L .54331 .74546 L p .414 .294 .606 r
F P
0 g
s
.56033 .7372 m .55456 .71962 L .55771 .66784 L p .439 .31 .608 r
F P
0 g
s
.55771 .66784 m .56368 .68024 L .56033 .7372 L p .439 .31 .608 r
F P
0 g
s
.63711 .28956 m .63069 .29784 L .5476 .26192 L p .649 .689 .874 r
F P
0 g
s
.54481 .27065 m .5476 .26192 L .63069 .29784 L p .644 .684 .873 r
F P
0 g
s
.45385 .23238 m .45515 .24097 L .36457 .25443 L p .643 .731 .912 r
F P
0 g
s
.36457 .25443 m .35935 .24706 L .45385 .23238 L p .643 .731 .912 r
F P
0 g
s
.54814 .76545 m .54331 .74546 L .55456 .71962 L p .414 .292 .604 r
F P
0 g
s
.5882 .73233 m .58198 .71892 L .57458 .62366 L p .468 .328 .607 r
F P
0 g
s
.57458 .62366 m .58019 .62959 L .5882 .73233 L p .468 .328 .607 r
F P
0 g
s
.64356 .28131 m .63711 .28956 L .55042 .25312 L p .653 .693 .875 r
F P
0 g
s
.5476 .26192 m .55042 .25312 L .63711 .28956 L p .649 .689 .874 r
F P
0 g
s
.5476 .26192 m .54481 .27065 L .45772 .25774 L p .627 .705 .902 r
F P
0 g
s
.45772 .25774 m .45644 .24943 L .5476 .26192 L p .627 .705 .902 r
F P
0 g
s
.53893 .81974 m .53552 .79941 L .55798 .80699 L p .386 .27 .597 r
F P
0 g
s
.55303 .78595 m .55798 .80699 L .53552 .79941 L p .388 .272 .599 r
F P
0 g
s
.45254 .22368 m .45385 .23238 L .35935 .24706 L p .647 .73 .909 r
F P
0 g
s
.35935 .24706 m .3541 .23956 L .45254 .22368 L p .647 .73 .909 r
F P
0 g
s
.56617 .75523 m .56033 .7372 L .56368 .68024 L p .44 .31 .606 r
F P
0 g
s
.56368 .68024 m .56972 .69288 L .56617 .75523 L p .44 .31 .606 r
F P
0 g
s
.55456 .71962 m .56033 .7372 L .54814 .76545 L p .414 .292 .604 r
F P
0 g
s
.57968 .79839 m .57323 .87343 L .5903 .83205 L p .004 0 .302 r
F P
0 g
s
.59449 .74601 m .5882 .73233 L .58019 .62959 L p .469 .328 .606 r
F P
0 g
s
.58019 .62959 m .58583 .63555 L .59449 .74601 L p .469 .328 .606 r
F P
0 g
s
.65006 .27308 m .64356 .28131 L .55326 .24425 L p .656 .697 .876 r
F P
0 g
s
.55042 .25312 m .55326 .24425 L .64356 .28131 L p .653 .693 .875 r
F P
0 g
s
.55303 .78595 m .54814 .76545 L .56033 .7372 L p .413 .291 .603 r
F P
0 g
s
.55042 .25312 m .5476 .26192 L .45644 .24943 L p .633 .707 .899 r
F P
0 g
s
.45644 .24943 m .45515 .24097 L .55042 .25312 L p .633 .707 .899 r
F P
0 g
s
.59449 .74601 m .60358 .68877 L .59831 .76101 L p .918 .781 .301 r
F P
0 g
s
.60358 .68877 m .59449 .74601 L .58583 .63555 L p .912 .68 .574 r
F P
0 g
s
.54238 .84051 m .53893 .81974 L .563 .82857 L p .385 .268 .595 r
F P
0 g
s
.55798 .80699 m .563 .82857 L .53893 .81974 L p .386 .27 .597 r
F P
0 g
s
.45122 .21486 m .45254 .22368 L .3541 .23956 L p .649 .729 .907 r
F P
0 g
s
.3541 .23956 m .3488 .23193 L .45122 .21486 L p .649 .729 .907 r
F P
0 g
s
.65661 .26487 m .65006 .27308 L .55612 .23531 L p .658 .7 .877 r
F P
0 g
s
.55326 .24425 m .55612 .23531 L .65006 .27308 L p .656 .697 .876 r
F P
0 g
s
.57209 .77372 m .56617 .75523 L .56972 .69288 L p .441 .309 .605 r
F P
0 g
s
.56972 .69288 m .57581 .70578 L .57209 .77372 L p .441 .309 .605 r
F P
0 g
s
.56033 .7372 m .56617 .75523 L .55303 .78595 L p .413 .291 .603 r
F P
0 g
s
.55326 .24425 m .55042 .25312 L .45515 .24097 L p .638 .708 .897 r
F P
0 g
s
.45515 .24097 m .45385 .23238 L .55326 .24425 L p .638 .708 .897 r
F P
0 g
s
.55612 .23531 m .559 .22632 L .65661 .26487 L p .658 .7 .877 r
F P
0 g
s
.55798 .80699 m .55303 .78595 L .56617 .75523 L p .413 .289 .601 r
F P
0 g
s
.54587 .86175 m .54238 .84051 L .56808 .85071 L p .383 .266 .594 r
F P
0 g
s
.563 .82857 m .56808 .85071 L .54238 .84051 L p .385 .268 .595 r
F P
0 g
s
.57808 .79268 m .57209 .77372 L .57581 .70578 L p .442 .309 .604 r
F P
0 g
s
.57581 .70578 m .58198 .71892 L .57808 .79268 L p .442 .309 .604 r
F P
0 g
s
.56617 .75523 m .57209 .77372 L .55798 .80699 L p .413 .289 .601 r
F P
0 g
s
.55612 .23531 m .55326 .24425 L .45385 .23238 L p .643 .71 .896 r
F P
0 g
s
.45385 .23238 m .45254 .22368 L .55612 .23531 L p .643 .71 .896 r
F P
0 g
s
.56808 .85071 m .57323 .87343 L .54587 .86175 L p .383 .266 .594 r
F P
0 g
s
.563 .82857 m .55798 .80699 L .57209 .77372 L p .413 .288 .6 r
F P
0 g
s
.58415 .81212 m .57808 .79268 L .58198 .71892 L p .443 .309 .603 r
F P
0 g
s
.58198 .71892 m .5882 .73233 L .58415 .81212 L p .443 .309 .603 r
F P
0 g
s
.559 .22632 m .55612 .23531 L .45254 .22368 L p .646 .711 .895 r
F P
0 g
s
.45254 .22368 m .45122 .21486 L .559 .22632 L p .646 .711 .895 r
F P
0 g
s
.57209 .77372 m .57808 .79268 L .563 .82857 L p .413 .288 .6 r
F P
0 g
s
.56808 .85071 m .563 .82857 L .57808 .79268 L p .412 .287 .599 r
F P
0 g
s
.5903 .83205 m .58415 .81212 L .5882 .73233 L p .444 .308 .602 r
F P
0 g
s
.5882 .73233 m .59449 .74601 L .5903 .83205 L p .444 .308 .602 r
F P
0 g
s
.57808 .79268 m .58415 .81212 L .56808 .85071 L p .412 .287 .599 r
F P
0 g
s
.57323 .87343 m .56808 .85071 L .58415 .81212 L p .412 .286 .597 r
F P
0 g
s
.58415 .81212 m .5903 .83205 L .57323 .87343 L p .412 .286 .597 r
F P
0 g
s
.25 Mabswid
.41699 0 m
.39846 .53401 L
s
.39846 .53401 m
0 .89001 L
s
0 .89001 m
.08461 .38696 L
s
.08461 .38696 m
.41699 0 L
s
.41699 0 m
.39846 .53401 L
s
.39846 .53401 m
1 .81584 L
s
1 .81584 m
.90663 .30341 L
s
.90663 .30341 m
.41699 0 L
s
1 .81584 m
.54651 1.07206 L
s
.90333 .87046 m
.90229 .86335 L
s
[(-2)] .90539 .88469 -0.14509 -1 Mshowa
.75058 .95676 m
.74994 .9496 L
s
[(0)] .75186 .97108 -0.08924 -1 Mshowa
.61613 1.03272 m
.61582 1.02554 L
s
[(2)] .61674 1.04709 -0.04271 -1 Mshowa
.125 Mabswid
.86322 .89312 m
.86267 .88884 L
s
.82444 .91503 m
.82394 .91074 L
s
.78691 .93623 m
.78647 .93194 L
s
.71539 .97664 m
.71506 .97234 L
s
.68128 .99591 m
.681 .99161 L
s
.64821 1.0146 m
.64798 1.01029 L
s
.94482 .84702 m
.94413 .84276 L
s
.98777 .82275 m
.98701 .8185 L
s
.585 1.05031 m
.58486 1.046 L
s
.55477 1.06739 m
.55467 1.06308 L
s
gsave
.75825 1.04271 -65.5538 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{268.625, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004<00017b000`400?l00000o`00003oo`3oool=
0?ooo`00o`3oool=0?ooo`00J@3oool00`000000oooo0?ooo`2P0?ooo`00J03oool400000:00oooo
001W0?ooo`030000003oool000000080oooo0P00002N0?ooo`00IP3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo09/0oooo001V0?ooo`040000003oool0oooo000000D0oooo0P00
002K0?ooo`00I@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0V03o
ool006@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`800000V03oool0
06<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`800000UP3oool00680
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo09<0
oooo001Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool2000009<0oooo
001P0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`2@0?ooo`00H03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo0P00002@
0?ooo`00G`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo0P00002>0?oo
o`00GP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0R`3oool005d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0D0?ooo`800000
R`3oool005`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo08P0oooo001K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05`3oool2
000008P0oooo001J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool06@3oool20000
08H0oooo001J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`230?ooo`00F@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo
0P0000230?ooo`00F03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01h0oooo0P00
00210?ooo`00E`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0OP3oool005H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?oo
o`800000OP3oool005D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo07/0oooo001D0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
903oool2000007/0oooo001D0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool09P3o
ool2000007T0oooo001C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`1f0?ooo`00DP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
02T0oooo0P00001f0?ooo`00D@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool0L`3oool00500oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0/0?ooo`800000L`3oool004l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0^0?ooo`800000L@3oool004h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo06h0oooo001>0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0<@3oool2000006h0oooo001=0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`1[0?ooo`00C03oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo03@0oooo0P00001[0?ooo`00B`3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo03H0oooo0P00001Y0?ooo`00BP3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool0IP3oool004T0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0i0?ooo`800000IP3oool004P0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo06<0oooo00180?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0?03oool2000006<0oooo00170?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0?P3oool200000640oooo00160?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`1N0?ooo`00A@3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0480oooo0P00001N0?ooo`00A03oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo04@0oooo0P00001L0?ooo`00@`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool0F@3oool00480oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`170?ooo`800000F@3oool00480oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo05H0oooo00110?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0BP3oool2000005H0oooo00100?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0C03oool2000005@0oooo000o0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1A0?ooo`00?P3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo04l0oooo0P00001A0?ooo`00?@3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0CP3oool003`0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`1B0?ooo`800000CP3oool003`0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`1D0?ooo`800000C03oool003/0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo04T0oooo000j0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool01@3oool8000004X0oooo0P0000190?ooo`00>@3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0000000D000000`2V^^P00`000000YKKU0:Ffi@02
0:Ffi@T00000@`3oool00`000000oooo0?ooo`160?ooo`00>03oool00`000000oooo0?ooo`0W0?oo
o`L000001P2V^^P4000000d0YKKU2@00000k0?ooo`800000AP3oool003L0oooo00<000000?ooo`3o
ool08P3oool6000000D0Y[[X00<000000:Jjj00000001@0000030:Fjj0030000002T]ND0Y;GU0080
Y;GU2000000:0:Ffi@H00000=`3oool2000004@0oooo000f0?ooo`030000003oool0oooo01l0oooo
100000070:Jjj0H000001P2U^^P4000000`0Y;GU2@0000050:Ffi@040000002X/n000000000003L0
oooo00<000000?ooo`3oool0@@3oool003H0oooo00<000000?ooo`3oool07@3oool3000000D0Y[[X
1@0000040:Fjj0030000002U^^P0000000D000000`2T^nT00`000000XkGU0:>ei@020:>ei@P00000
2@2T]ND5000000@0Z;?P0`00000e0?ooo`800000@@3oool003D0oooo00<000000?ooo`3oool0703o
ool200000080ZKgX1@0000060:Fjj0H00000202T^nT3000000/0XkGU200000050:Bei@040000002W
/^000000000000@0Z;?P0`00000d0?ooo`800000?`3oool003@0oooo00<000000?ooo`3oool06`3o
ool200000080ZKgX0P0000000`2Y_^T000000:Fjj0030:Fjj0D00000102T^nT010000000Y;_Y0:Bk
j@2T^nT600000080Xk_Z00@000000::diP2R]>H0X[CV200000080:>ei@D00000102W/^03000000@0
Z;?P0P00000d0?ooo`030000003oool0oooo03`0oooo000c0?ooo`030000003oool0oooo01X0oooo
0P0000020:Vmj08000000`2Y_^T4000000P0Y;_Y1P0000060:>kjP<000002`2R]>H8000000@0XkGU
00@000000:Nag`0000000000102W/^03000000<0Z;?P0`00000b0?ooo`800000?03oool00380oooo
00<000000?ooo`3oool06@3oool200000080ZKgX0P0000030:Vnj@8000000P2Y_nT00`000000Y;_Y
0:Bkj@020:Bkj@D000000P2S^nX010000000Xk_Z0:>kjP2S^nX600000080X[c[00<000000:2diP2P
]>H01P00000;0::diPD000000`2W/Ml2000000D0Yk;P0P0000040:Rch0<00000<@3oool00`000000
oooo0?ooo`0i0?ooo`00<@3oool00`000000oooo0?ooo`0H0?ooo`8000000P2Y_NP2000000<0ZKkY
0P0000040:Voj@@000001`2S^nX5000000P0X[c[00<000000:2diP2P]>H01P2P]>H6000000T0X[CV
00<000000:J`g`0000000`2W/Ml3000000@0Yk;P0`0000040:Rch0800000<03oool2000003T0oooo
000`0?ooo`030000003oool0oooo01L0oooo0P0000020:Vmj08000000`2Y_^T2000000@0ZKoY0P00
00000`2Y`>X000000:>kjP030:>kjPD0000000<0X[c[0000002R_>/01@2R_>/6000000h0X;CV1P00
00020::diP030000002V/=l0Y[3O0080Y[3O0P0000030:Nag`8000001@2W/^03000000<0Z;?P0`00
000_0?ooo`800000=`3oool00300oooo00<000000?ooo`3oool05@3oool200000080ZKgX0P000003
0:Vnj@800000102Y_nT2000000<0ZL3Z100000040::lj`X000001@2Q_>d010000000W[?W09jci`2N
/nL7000000X0X;CV0`0000060:J`g`8000000`2W/Ml2000000H0Yk;P0P0000040:Rch0800000;`3o
ool00`000000oooo0?ooo`0d0?ooo`00;`3oool00`000000oooo0?ooo`0D0?ooo`8000000P2Y_NP2
000000<0ZKkY0P0000040:Voj@8000000`2Y`>X2000000030:W1k0000000000000D000000P2Q_>d0
0`000000XKc]0:6lk@060:6lk@D000002P2N/nL8000000@0X;CV00@000000:B_g`00000000001@2V
/=l2000000<0Yk7O0P0000060:Nbh0<000000P2X/n02000002l0oooo0P00000d0?ooo`00;P3oool0
0`000000oooo0?ooo`0C0?ooo`8000000`2Y_NP010000000ZKkY0:Vnj@2Y_^T2000000@0ZKoY0P00
00030:W0jP80000000<0ZL7/0000000000000P2X`nd00`000000XKc]0:6lk@030:6lk@X00000102O
_Nh010000000W;?X09bcj02L/nP7000000P0W[?W100000040:B_g`8000001@2V/=l2000000<0Yk7O
0`0000060:Nbh08000000P2_/m`2000002l0oooo00<000000?ooo`3oool0<@3oool002d0oooo00<0
00000?ooo`3oool04`3oool01@000000ZKgX0:Vmj02Y_NP0000000<0ZKkY0P0000040:Voj@800000
0`2Y`>X2000000030:W1k0000000000000@0Z<?]1P0000000`2O_Nh0000009nmkP0809nmkPD00000
2@2L/nP7000000@0W[?W00@000000:>]g`00000000000`2T[ml3000000@0Y[3O0P0000040:Nag`80
0000102W/^000`000000[k?K000000030:ncg0030000003oool0oooo02d0oooo0P00000a0?ooo`00
;03oool00`000000oooo0?ooo`0C0?ooo`040000002]_^H00000000000<0ZKkY0P0000040:Voj@80
00000P2Y`>X3000000030:W1k0000000000000@0Z<?]0P0000000`2XaNh0000009nmkP0409nmkPX0
0000102L__0010000000VK;Y09Vbj@2I/^T6000000L0W;?X100000040:>]g`800000102T[ml20000
00@0Y[3O0P0000040:Nag`8000000P2W/^0010000000[k?K0:ncf`0000030:ncg0030000003oool0
oooo02h0oooo0P00000_0?ooo`00:`3oool00`000000oooo0?ooo`0C0?ooo`050000002]_^H0[KkV
0000002]_^H00`0000040:Voj@8000000P2Y`>X200000080ZL7/0P0000040:S3k@8000000`2XaNh7
000000@0W;k`2P00000909Vbj@L000000`2L/nP00`000000XJcN000000040:>]g`800000102T[ml2
000000@0Y[3O0P0000040:Nag`800000102_/m/200000080[k?L00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0/0?ooo`00:P3oool00`000000oooo0?ooo`0C0?ooo`040000002]_^H0[KkV
00000080[KkV00<000000:joi`0000000P2Y_nT200000080ZL3Z0P0000020:W1k0800000102X`nd2
000000<0Z<G^0P0000000`2Xao00000000000008000000T0VL3c00@0000009Baj`2D/N/0U;7[1P00
000709Vbj@@000000`2Q[=h2000000<0XjgO0P0000040:B_g`<000000`2V/=l200000080Yk7O00<0
00000:nbfP0000001@2_/m/00`000000[k?L0:ncg00200000300oooo0P00000/0?ooo`00:P3oool0
0`000000oooo0?ooo`0B0?ooo`040000002]_^H0[KkV00000080[KkV00@000000:joi`2^_nL0[[oW
0P0000020:W0jP8000000P2Y`N`2000000@0Z<?]0P0000030:S5kP80000000D0Z<O`000000000000
Yl_b0000000309W0l`030000002I`?<0VL3c00<0VL3c2@00000909Baj`H00000102I/^T3000000<0
XJcN0P0000030:>]g`<00000102T[ml2000000<0Y[3O0P0000030:nbfP800000102_/m/01@000000
[k?L0:ncg02_/m`000000340oooo00<000000?ooo`3oool0:@3oool002T0oooo00<000000?ooo`3o
ool04P3oool01`000000[KkV0:fniP2]_^H000000:fniP0000000`2^_nL00`000000[/7W00000002
00000080ZL7/0P0000040:S3k@8000000P2XaNh3000000030:S7l0000000000000<0Yl_b2P000000
0`2D`OH00000000000070000000308n`k0000000000000@000001`2D/N/4000000<0Wj[N0P000003
0:6/gP800000102S[Ml2000000@0Y:oO0P0000020:J`g`800000102_/]X00`000000[k?K0:ncf`02
0:ncf`050000002_/m`0[k?L0:ncg0000000<@3oool2000002T0oooo000X0?ooo`030000003oool0
oooo0180oooo00L000000:fniP2]_^H0[KkV0000002]_^H0000000<0[[oW00D000000:k1i`2^`NL0
00000:o2j003000000@0Z<?]0P0000020:S5kP8000000P2Xao02000000<0Yl_b0P0000020:K?m@T0
0000202=`oT00`000000R:k^08R^kP040000000308n`k0000000000000@00000102D/N/3000000<0
Wj[N0P0000030:6/gP<000000`2S[Ml2000000@0Y:oO0P0000020:j`fP8000000`2_/]X00`000000
[k?K0:ncf`020:ncf`040000002_/m`0[k?L0:ncg0800000<@3oool2000002L0oooo000W0?ooo`03
0000003oool0oooo0180oooo00L000000:fniP2]_^H0[KkV0000002]_^H0000000<0[[oW00@00000
0:k1i`2^`NL000000P2_`^P00`000000/<?X000000020:S3k@8000000P2XaNh200000080Z<O`0P00
00030:O;lP8000000P2VcoD2000000030:CCn0000000000000L0SL?i2000000608R^kP@000000`2?
/>`4000000<0W:ON0P00000309nZgP800000102Q[=h2000000<0XjgO0P0000020:B_g`030000002^
[mT0000000<0[[3J00@000000:nbfP2_/]X0[k;J0P0000030:ncf`8000000`2_/m`00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo02@0oooo000V0?ooo`030000003oool0oooo01<0oooo00H0
00000:fniP2]_^H000000:fniP0000030:joi`040000002^`NL0[/7W00000080[l;X00@000000;33
j02``nP0/<?X0P0000020:S5kP8000000P2Xao0200000080Yl_b0`0000020:K?m@8000000`2TdoP9
000000L0PlGm00<0000007f[l@0000000P00000608R^kP@000000P2?/>`3000000<0W:ON0P000003
09nZgP800000102Q[=h2000000<0XjgO0P0000030:j_f@050000002^/=X0[[3J0:j`fP000000102_
/]X00`000000[k?K0:ncf`020:ncf`050000002_/m`0[k?L0:ncg0000000<03oool2000002H0oooo
000U0?ooo`030000003oool0oooo01<0oooo00@000000:fniP2]_^H000000P2]_^H010000000[[oW
0:joi`0000020:k1i`040000002_`^P0[l;X000000<0/<?X00<000000;75j@0000000P0000020:S7
l08000000P2Wbo8200000080Y/oe0`0000030:CCn080000000<0XMWk0000000000003P00000407f[
l@<000001`28[^h300000080VJCM0P00000309bWgP8000000`2OZ]h2000000@0XJcN0P0000020:>]
g`800000102^[mT010000000[[3J0:j`fP0000040:nbfP030000002_/m/0[k?K0080[k?K00D00000
0:ncg02_/m`0[k?L0000000]0?ooo`80000000<0oooo0000003oool09@3oool002@0oooo00<00000
0?ooo`3oool04`3oool010000000[KkV0:fniP0000020:fniP040000002^_nL0[[oW00000080[/7W
00D000000:o2j02_`^P0[l;X000000020;33j0050000002aaNT0/LGY0000002bb>X00`0000020:O;
lP8000000P2VcoD2000000<0Y=?h6`00000207f[l@@000001@28[^h300000080VJCM0P00000309bW
gP8000000`2OZ]h2000000@0XJcN0P0000020:j^e`8000000`2^[mT010000000[[3J0:j`fP000004
0:nbfP030000002_/m/0[k?K0080[k?K00@000000:ncg02_/m`0[k?L0P00000Z0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool08`3oool002@0oooo00<000000?ooo`3oool04P3oool0
10000000[KkV0:fniP0000020:fniP070000002^_nL0[[oW0:joi`000000[/7W000000030:o2j004
0000002``nP0/<?X00000080/LGY00D000000;;8jP2bb>X000000;C;j`0300000080Y/oe0P000002
0:CCn0H0000000<0V^3m0000000000000`0000000`1bh>T000000000000;0000000305JNm0000000
000000D000000P1mZo430000000308R^kP000000U:7M0080U:7M00@0000009VTg@2IY=d0VJCM0P00
000309bWgP8000000`2OZ]h200000080XJcN00<000000:f/eP0000000`2^[]L01@000000[ZoI0:j_
f@2^[mT000000080[[3J0P0000030:nbfP8000000`2_/m/00`000000[k?L0:ncg0020:ncg0030000
003oool0oooo02H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S0?ooo`008`3o
ool00`000000oooo0?ooo`0B0?ooo`040000002]_^H0[KkV00000080[KkV00D000000:joi`2^_nL0
[[oW000000020:k1i`040000002_`^P0[l;X00000080/<?X00@000000;75j@2aaNT000000P2bb>X0
1@000000]<_[0;C;j`000000]/o]00<000000P2TdoP2000000030:7In`00000000000080V^3m2000
00000`1hI:l000000000000:0000000402f<kP000000000005JNm08000000P1^Y_<40000000307f[
l@000000000000@0U:7M0P00000309VTg@8000000`2LYmh2000000<0Wj[N0P0000030:f/eP050000
002^[]L0[ZkG0:j^e`0000000`2^[mT01@000000[[3J0:j`fP2^/=X0000000@0[k;J00@000000:nc
f`2_/m/0[k?K0P0000030:ncg0030000003oool0oooo02@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0S0?ooo`008P3oool00`000000oooo0?ooo`0B0?ooo`070000002]_^H0[KkV
0:fniP000000[KkV000000030:joi`040000002^`NL0[/7W00000080[l;X00@000000;33j02``nP0
00000P2aaNT010000000//SZ0;;8jP0000020;C;j`050000002fcnd0]/o]0000002he>h01@000002
09[Po@T000000P1hI:l2000000D0OfN]20000000100]S>h000000000001FW_@3000000<0KZKc0P00
00000`2?W=`000000000000409BQg@030000002IY=d0VJCM0080VJCM0P00000309bWgP80000000@0
Wj[N0000002]Z]@000000`2][=H200000080[ZkG00@000000:j_f@2^[mT0[ZoI0P0000020:j`fP03
0000002_/]X0[k;J0080[k;J00<000000:ncf`2_/m/00P2_/m/01@000000[k?L0000002g^M/00000
02<0oooo0P0000060?ooo`8000009@3oool00240oooo00<000000?ooo`3oool04P3oool01`000000
[KkV0:fniP2]_^H000000:fniP0000000`2^_nL010000000[/7W0:k1i`0000020:o2j0040000002`
`nP0/<?X00000080/LGY00@000000;;8jP2bb>X000000P2dbn/010000000]/o]0;K?k@0000020;SD
kP040000002kf_0000000;kRl@T0000000D0JU^_0000001hI:l0N6B_0000000207MR[P030000001o
Ijd0OfN]0080OfN]00<00000085VZ`21IZ/00P000002089X[0<0000000<0;Hc^0000000000000P1F
W_@30000000306jVl`00000000000080SicL0P00000309BQg@800000102IY=d2000000<0W:ON00D0
00000:fZe02]Z]@0[J[D000000040:f/eP040000002^[]L0[ZkG000000@0[ZoI00@000000:j`fP2^
/=X00000102_/]X2000000<0[k?K00@000000;Nif`2g^M/000008P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo02<0oooo000P0?ooo`030000003oool0oooo0180oooo0P0000020:fn
iP030000002]_^H0000000<0[[oW00@000000:k1i`2^`NL000000P2_`^P010000000/<?X0;33j000
00030;75j@030000002bb>X000000080]<_[00@000000;K?k@2fcnd000000P2he>h00`000000^m[`
000000020;kRl@0400000031k?4000000<?fkPD0000000D0JU^_0000001hI:l0N6B_0000000207MR
[PH000001021IZ/600000080;Hc^0P00000305JNm08000000P27Um`010000000SicL08nLg0000004
09BQg@030000002IY=d0VJCM00<0VJCM0P0000000`2LYmh00000000000030:fZe0030000002][=H0
[JcF0080[JcF00<000000:j^e`2^[]L00P0000030:j_f@040000002^/=X0[[3J000000D0[k;J00@0
00000:ncf`000000^;WJ0`2g^M/00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool08`3oool001l0oooo00<000000?ooo`3oool04`3oool00`000000[K_S0000
000400000080[[oW00@000000:k1i`2^`NL000000`2_`^P00`000000/<?X000000030;75j@030000
002bb>X0000000<0]<_[00<000000;K?k@0000000P2he>h00`000000^m[`000000020;kRl@040000
0031k?4000000<?fkP80000000<0[_S40000000000001@00000207MR[P800000101mIJ`3000000@0
PFJ[1P00000202f<kP8000000P1FW_@200000080QiOL00<0000008nLg02?W=`00P00000309BQg@80
00001@2IY=d010000000[:OC0:bWd`0000030:fZe0030000002][=H0[JcF0080[JcF00D000000:j^
e`2^[]L0[ZkG000000030:j_f@030000002^/=X0[[3J00800000102_/]X010000000^;WJ0;RifP00
00020;Nif`030000003oool0oooo01d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0R0?ooo`007P3oool00`000000oooo0?ooo`0C0?ooo`080000002]^n<0[K_S0:fkh`000000[[_S
0000002__><200000080[/7W00L000000:o2j02_`^P0[l;X0000002``nP0000000<0/LGY00<00000
0;;8jP0000000`2dbn/00`000000]/o]000000020;SDkP030000002kf_0000000080_^;a00H00000
0<7/l@000000`oK^0000002ooN840000000406YK[`000000000000000080Mf:^00<0000007IQ[@1f
HJd01P0000000`1oIJX0000000000002085VZ`P000000P0]S>h200000080O8oK0P0000000`27Um`0
00000000000208nLg08000000`2DXMd01`000000VJCM09VTg@2IY=d000000:ZTd@0000000P2/Ym<0
1@000000[J[D0:fZe02]Z]@0000000@0[JcF00D000000:j^e`2^[]L0[ZkG000000030:j_f@800000
0P2^/=X01@000000[k;J000000000000^KSI00<0^;WJ00@000000;Nif`2g^M/00000703oool20000
00d0oooo00<000000?ooo`3oool00`3oool2000001d0oooo000N0?ooo`030000003oool0oooo01<0
oooo00H000000:fkh`2]^n<000000:jkh`0000030:nlh`@000000P2_`^P00`000000/<?X00000003
0;75j@030000002bb>X0000000<0]<_[00<000000;K?k@0000000`2he>h00`000000^m[`00000002
0;kRl@8000000P33m^h3000000040>ob``000000000006YK[`<0000000@0Mf:^0000001fHJd0MV6]
0P00000407aS[0<0000000<0OfFZ0000000000000P0000000`21HjL00000089TZ0050000000302f<
kP000000000000<0O8oK00@0000008NGg027Um`000000`2?W=`010000000U:7M09BQg@2DXMd20000
000509VTg@000000ZZCA0:ZTd@0000000P2/Ym<01@000000[J[D0:fZe02]Z]@0000000@0[JcF00D0
00000:j^e`2^[]L0[ZkG000000040:j_f@040000002^/=X00000000000<0^KSI00@000000;RifP2h
^MX000000`2g^M/00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`00000L0?ooo`007@3oool00`000000oooo0?ooo`0D0?oo
o`060000002]^n<0[K_S0000002^^n<000000P2__><01@000000/;cS0;2lh`000000/KgS00D00000
0P2aaNT00`000000//SZ000000030;C;j`030000002fcnd0000000<0^=C^00<000000;_Jl0000000
0P2nh_4200000080`oK^1P0000001P1ZFjl0000006YJ[P000000JUZ]00000080MV6]00<0000007EO
[0000000101lHj`010000000OV>Y07iSZ@00000207mUZP0500000020HZL0000000000022I:P01P00
000206b4f@050000001lSm/0O8oK07b?f`0000000P27Um`200000080SicL0P00000309BQg@030000
002ZY=40ZZCA0080ZZCA00@000000:bWd`2/Ym<000000`2]Z]@2000000<0[JcF00@000000:j^e`2^
[]L0[ZkG0P0000030:j_f@030000002j^=L0^[SG00@0^KSI00@000000;RifP2h^MX000000P2g^M/0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00d0oooo0P0000040?ooo`040000003oool0
oooo000001`0oooo000L0?ooo`030000003oool0oooo01D0oooo00H000000:fkh`2]^n<000000:jk
h`0000020:nlh`030000002`_><0000000<0/KgS00@000000;:nh`000000/koS1@0000020;C;j`03
0000002fcnd0000000<0^=C^00<000000;_Jl00000000P2nh_4200000080`oK^0P0000000`3Wk=40
00000>ob``020000000806YK[`000000JUZ^0000001ZFZd0000007IQ[@00000207EO[0H000000`1n
HjT400000004081RY`0000000000089TZ0H000000P1/Q=T010000000O8oK07b?f`1lSm/200000080
QiOL00@0000008nLg02?W=`0SicL0P0000000`2DXMd00000000000040:ZTd@040000002/Ym<0[:OC
000000@0[J[D00@000000:f/eP2][=H0[JcF0P0000030:j^e`040000002^[mT000000;ZgeP80^[SG
00D000000;Vhf@2i^=T0^KSI000000020;RifP050000002g^M/0]kWK0;Nif`0000005`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000703oool0
01/0oooo00<000000?ooo`3oool05@3oool01P000000[K_S0:fkh`000000[[_S000000<0[kcS00<0
00000;2lh`0000000P2a_N<00`000000/[kS000000030;>oh`040000002f`N<000000;S3hPD00000
0P2he>h00`000000^m[`000000020;kRl@D0000000D0g^?H0000003Wk=4000000>ob``0300000080
JUZ^0P000000101[FJ`0000007EO[01eGj`2000000@0Nf:[0`00000307iSZ@070000001nHJL00000
00000021HjL00000089TZ00300000003035Kc@00000000000080K8CI00<0000007b?f`1lSm/00P1l
Sm/010000000QiOL08NGg000000408nLg0040000002YXLh0ZJ7>000000@0ZZCA00<000000:bWd`2/
Ym<00P0000030:fZe0030000002][=H0[JcF0080[JcF00D000000:j^e`2^[]L0[ZkG000000020;Zg
eP040000002j^=L0^[SG000000<0^KSI00@000000;RifP2h^MX000000P2g^M/00`000000oooo0?oo
o`0C0?ooo`8000004P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000001`0oooo
000J0?ooo`030000003oool0oooo01H0oooo00H000000:fkh`2]^n<000000:jkh`0000020:nlh`04
0000002`_><0/;cS00000080/KgS00<000000;:nh`0000000P2c_n<00`000000]/7S000000030;S3
hP040000002kaN8000000;k8hPL0000000@0c]GO0000003Eg=`0eMcL0P0000020>O/d@030000003_
l/<00000008000000P1ZFZh20000000406]I[0000000MEn/00000080M5j[00<0000007]RZ`1kHZ/0
0P1kHZ/00`000000OF:Y0000000207iSZ@<0000000L0P6:W00000021HjL00000089TZ000000003Bi
0080<E_=0P00000206b4f@030000001lSm/0O8oK0080O8oK00<0000008NGg027Um`00P000000102?
W=`000000:NMc00000020:VQcP030000002ZY=40ZZCA0080ZZCA00D000000:bWd`2/Ym<0[:OC0000
00030:fZe0030000002][=H0[JcF0080[JcF00D000000:j^e`000000^kKD000000020;ZgeP030000
002j^=L0000000@0^KSI00<000000;RifP0000000`2g^M/00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01X0
oooo000I0?ooo`030000003oool0oooo01L0oooo00H000000:fkh`2]^n<000000:jkh`0000020:nl
h`030000002`_><0000000<0/KgS00<000000;:nh`0000000P2c_n<00`000000]/7S000000020;S3
hP030000002kaN80000000<0_/SR00<000000<;;h@0000000P37d>0200000080eMcL00H000000=kS
f0000000incA0000003_l/<90000000306]HZ`000000M5j[0080M5j[1P00000207eRZ@@0000000d0
OV6W00000020HZL00000085SY`000000P5nS000d^@000000<E_=0000001EM=D000000080K8CI0P00
000307b?f`8000000P27Um`01@000000Yig<0:NMc02WWL`000000080ZJ7>00<000000:ZTd@2ZY=40
0P2ZY=401@000000[:OC0:bWd`2/Ym<0000000<0[J[D00<000000:f/eP2][=H00P2][=H010000000
^kKD0;^fe00000020;ZgeP040000002j^=L0^[SG000000<0^KSI00@000000;RifP2h^MX000000`2g
^M/00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3o
ool2000001d0oooo000H0?ooo`030000003oool0oooo01L0oooo00L000000:fkh`2]^n<0[K_S0000
002^^n<000000080[kcS00<000000;2lh`0000000P2a_N<01P000000/[kS0;:nh`000000/koS0000
0080]/7S00H000000;S3hP2h`n8000000;_5hP0000020;k8hP0300000032bn4000000080am3P00<0
00000<kEg`0000000P3Eg=`020000000g^?H0000003Wk=4000000>ob``000000ilFc0P0000000`1K
Cj/00000000000020000000406]HZ`000000M5j[07ANZ`800000101iHJX2000000<0OF:Y00H00000
07ePYP000000OV6W00000020HZL200000008081OX`00000003Bi0000000aFld0000005Ede@000003
06b4f@030000001lSm/0O8oK0080O8oK00@0000008NGg000000000000`2WWL`010000000ZJ7>0:VQ
cP0000040:ZTd@050000002/Ym<0[:OC0:bWd`0000000`2]Z]@01P000000[JcF000000000000_;CB
00000080^kKD00@000000;ZgeP2j]mH000000P2j^=L01@000000^KSI0;Vhf@2i^=T000000080^;WJ
00@000000;Nif`2g^M/00000403oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0240
oooo000H0?ooo`030000003oool0oooo01L0oooo00H000000:fkh`2]^n<000000:jkh`0000030:nl
h`030000002`_><000000080/KgS00<000000;:nh`0000000P2c_n<00`000000]/7S000000030;S3
hP030000002kaN8000000080_/SR00<000000<;;h@0000000P37d>000`000000c]GO000000020=GL
g08000000P3Wk=43000000040>O5/`000000000005]?Z`80000000@0JeV/000000000000JeNZ0P00
000207AMZP8000000P1iHJX01@000000Nf6X000000000000OF:Y0080000000<0OF2V0000001nHJL0
0`000002081OX`0600000000=;T00000035Kc@000000EGCE0P00000206b4f@030000001lSm/0O8oK
0080O8oK00@000000:BHb@2TV<T000000`2WWL`010000000ZJ7>0:VQcP0000040:ZTd@050000002/
Ym<0[:OC0:bWd`0000000`2]Z]@01@000000_;CB0;bddP2l]=8000000080^kKD00L000000;ZgeP2j
]mH0^[OF0000002j^=L0000000<0^KSI00@000000;RifP2h^MX000000`2g^M/00`000000oooo0?oo
o`0;0?ooo`8000005`3oool2000002<0oooo000G0?ooo`030000003oool0oooo01P0oooo00H00000
0:fkh`2]^n<000000:jkh`0000020:nlh`030000002`_><0000000<0/KgS00<000000;:nh`000000
0P2c_n<00`000000]/7S000000020;S3hP030000002kaN80000000<0_/SR00D000000<;;h@000000
am3P000000020<kEg`060000003Eg=`000000=kSf0000000incA0P0000000`3N`[`000000>O5/`02
0000000405]?Z`000000000006]I[080000000@0JeNZ0000001dGJX0M5fZ0P000000101hGjT00000
00000000000307]QZ0<0000000D0OF2V0000001nHJL00000081RY`0200000007081OX`00000003Bi
000d^@000000<E_=0000000205Ede@040000001/Q=T0K8CI00000080O8oK00<000000:2Ba@000000
0P2TV<T01@000000Yig<0:NMc02WWL`000000080ZJ7>00<000000:ZTd@2ZY=400P2ZY=402@000000
[:OC0:bWd`2/Ym<000000:fZe0000000_K?@000000030;bddP040000002k]]@0^kKD00000080^[OF
00@000000;Zhe`2j^=L000000`2i^=T010000000^;WJ0;RifP0000030;Nif`030000003oool0oooo
00T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0000000S0?ooo`005P3oool00`000000
oooo0?ooo`0H0?ooo`070000002]^n<0[K_S0:fkh`000000[[_S000000020:nlh`030000002`_><0
00000080/KgS00H000000;:nh`2b_^<000000;>oh`0000020;K1h`060000002h`n80^<?R0000002k
aN8000000P2nb>8020000000`/_Q0<;;h@000000am3P0000003>eMl000000P3Eg=`01@000000g^?H
0000003Wk=4000000080g/:l00D000000>O5/`000000000005]?Z`030000000606]HZ`000000JeNZ
0000001dGJX000000P1cG:T00`000000N5nY07QOZ@02000000<0Nf6X00H0000007aOYP000000OF2V
0000001nHJL300000080P5nS00<00000000d^@0000000P0aFld010000000EGCE05Ede@00000206b4
f@050000001lSm/000000:2Ba@0000000P2TV<T00`000000Yig<0:NMc0020:NMc0040000002YXLh0
ZJ7>000000@0ZZCA00D000000:bWd`2/Ym<0[:OC000000020;fcd0050000002l]=80_;CB0;bddP00
00000P2k]]@01@000000^[OF0;ZgeP2j]mH000000080^[SG00@000000;Vhf@2i^=T000000P2h^MX0
1@000000]kWK0;Nif`2g^M/0000000X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0P0?ooo`005@3oool2000001X0oooo00H000000:fkh`2]^n<000000:jkh`0000030:nlh`030000
002`_><000000080/KgS00<000000;:nh`0000000P2c_n<010000000]/7S0;K1h`0000020;S3hP03
0000002kaN8000000080_/SR00<000000<;;h@0000000P37d>000`000000c]GO000000020=GLg003
0000003NhmP00000008000000P3N`[`01@000000ilFc0000001JCj`0Fdn[00<0000000D0JeR[0000
001[EjX0JeNY0000000307=LZ@8000000P1hGjT30000000807]QZ0000000000007aOYP000000OF2V
0000001nHJL300000005081OX`0000000000000d^@0000000P0aFld010000000EGCE05Ede@000002
06b4f@050000002PT/D0X9;50:2Ba@0000000P2TV<T01@000000Yig<0:NMc02WWL`0000000<0ZJ7>
00<000000:ZTd@2ZY=400P2ZY=401@000000[:OC0000002n/Ld000000080_K?@00D000000;bddP2l
]=80_;CB000000020;^fe0040000002j]mH0^[OF00000080^[SG00D000000;Vhf@2i^=T0^KSI0000
00020;RifP050000002g^M/0]kWK0;Nif`000000203oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo0200oooo000E0?ooo`040000003oool00000000001P0oooo00H000000:fkh`2]^n<0
00000:jkh`0000020:nlh`030000002`_><000000080/KgS00@000000;:nh`2b_^<000000P2c_n<0
0`000000]/7S000000020;S3hP030000002kaN8000000080_/SR00H000000<;;h@32bn4000000<O@
h00000020<kEg`030000003Eg=`00000008000000P3F_l<01`000000g/:l0=k2_0000000ilFc0000
001JCj`01@00000206]GZP0406]GZ@000000LebY07=LZ@80000000@0MefX00000000000000000P1j
GjP30000000407aOYP000000OF2V07ePYP@000000P20Gj<01P00000003Bi000d^@000000<E_=0000
00<0EGCE00@0000006b4f@00000000000`2PT/D010000000Y9S90:BHb@0000030:NMc0050000002Y
XLh0ZJ7>0:VQcP000000102ZY=4010000000_[7=0;jac@0000020;fcd0050000002l]=80_;CB0;bd
dP0000000P2k]]@01@000000^[OF0;ZgeP2j]mH000000080^[SG00L000000;Vhf@2i^=T0^KSI0000
002h^MX0000000<0]kWK00<000000?ooo`3oool0103oool2000001h0oooo00<000000?ooo`3oool0
803oool001D0oooo00@000000?ooo`3oool0oooo0P00000F0?ooo`060000002]^n<0[K_S0000002^
^n<000000P2__><00`000000/;cS000000020;6mh`060000002b_^<0/[kS0000002c_n<000000P2f
`N<01P000000^<?R0;S3hP000000^lGR00000080_/SR00H000000<;;h@32bn4000000<O@h0000002
0<kEg`050=GLg000000000000<nmb@0000000P3F_l<01`000000g/:l0=k2_0000000ilFc0000001J
Cj`01@000000101[EjX0000006]GZ@1[EZP200000080LU^X00<0000007MMZ01gGJP00`0000001`1j
GjP0000007]NY@000000O5nV0000001mH:H01@0000001@20Gj<0000000000000=;T000000080<E_=
00L0000005Ede@1EM=D0EGCE0000002KRl40000000@0X9;500@000000:BHb@2TV<T000000`2WWL`0
1@000000ZJ7>0:VQcP2YXLh000000080ZZCA00<000000;n_bP0000000P2n/Ld010000000_K?@0;fc
d00000030;bddP040000002k]]@0^kKD00000080^[OF00@000000;Zhe`2j^=L000000`2i^=T01000
0000^;WJ0;RifP0000030;Nif`030000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0P0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`8000004`3oool01000
0000[K_S0:fkh`2]^n<20:jkh`<0[kcS00<000000;2lh`0000000P2a_N<01P000000/[kS0;:nh`00
0000/koS00000080]/7S00H000000;S3hP2h`n8000000;_5hP0000020;k8hP0300000032bn40`/_Q
0080am3P00P0c]GO00000000000000000<RkcP000000ckg900000080e[o300L000000=k2_03N`[`0
00000>O5/`000000FTn/00L0000000<0JeNY06]FZ00000000`1bFjP400000080NEjW0`0000001@1k
GZD0000007aOYP000000OF2V00@0000000<0P5nS0000000000000P00=;T01`000000<E_=035Kc@00
0000EGCE0000002EP[`00P2KRl401@000000X9;50:2Ba@2PT/D0000000<0Y9S900D000000:NMc02W
WL`0Yig<000000030:VQcP050000002ZY=4000000;n_bP0000000P2n/Ld01@000000_K?@0;fcd02m
/m0000000080_;CB00D000000;^fe02k]]@0^kKD000000020;ZgeP040000002j^=L0^[SG000000<0
^KSI00@000000;RifP000000]kWK0`0000030?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0803oool001@0oooo00<000000?ooo`3oool01P3oool200000140oooo1`0000020:nlh`80
/;cS0`2a_N<30;:nh`80/koS0`2f`N<30;S3hP80^lGR0`2nb>800`32bn4000000000000300000007
0<>jd@000000b;_>0<RkcP000000ckg9000000020=Jo``050000003N`[`0g/:l0000003WaK<01`00
00001P1PD:P000000000001[EZP00000079KZ0<000000P1fG:L2000000<0NEjW0P0000001P1kGZD0
00000000001mH:H0000007eMX`<0000000<0P5nS0000000000000P00=;T010000000<E_=035Kc@00
000209F2_0040000002KRl40Vh_1000000<0X9;500D000000:BHb@2TV<T0Y9S9000000030:NMc005
0000002YXLh0ZJ7>0:VQcP0000000`2o[lX010000000_[7=0;jac@0000020;fcd0050000002l]=80
_;CB0;bddP0000000P2k]]@01@000000^[OF0;ZgeP2j]mH000000080^[SG00D000000;Vhf@2i^=T0
00000;RifP0200000080_lCN00@000000?ooo`3oool000008@3oool200000280oooo000D0?ooo`03
0000003oool0oooo00P0oooo0P00000?0?ooo`070000002[]n80ZkOR0000002[]^4000000:bfh@0H
000000040;Zhe`000000_[WD00000080`k[A00H000000<RkcP38^lh000000<nmb@0000020=Jo``03
0000003N`[`0g/:l00<0000000<0CdJW0000000000000`0000001P1PD:P000000000001[EZP0JeJW
000000<0LEVW00<0000007ILY`1fG:L00`0000000`1iGZL0000007YMY@020000000307aOYP000000
O5bS00@0000000@0P5nS0000000008d000000P00=;T00`000000<E_=0000000309F2_0040000002K
Rl40Vh_1000000<0X9;500@000000:BHb@2TV<T00000102WWL`010000000ZJ7>0000000000030;n_
bP040000002n/Ld0_[7=000000<0_K?@00D000000;bddP2l]=80_;CB000000020;^fe0040000002j
]mH0^[OF00000080^[SG00<000000;Vhf@2i^=T00P0000001031aMd000000;o4gP2oa=h3000002@0
oooo00<000000?ooo`3oool07`3oool001@0oooo00<000000?ooo`3oool02P3oool2000000d0oooo
00H000000:^ghP2[]n8000000:^fh@0000020:bfh@030000002/]^0000000080[KKP00H000000:jf
g`2^]]l000000:nfgP0000020;6fg@060000002b]]`0/[KL0000002d]m/000000P2g]mT01P000000
^[SG0;Zhe`000000_[WD00000080`k[A00H000000<RkcP38^lh000000<nmb@0000020=Jo``030000
003N`[`0g/:l0080000000<0_iR_000000000000100000001`1PD:P00000000000000000JeJW06]E
Y`0000000P1aFJL400000080N5bV100000002P1kGZD000000000001lG:<0000007eMX`000000OejS
00000020Gj<20000008003Bi0P0000001@2=N;L0000009F2_02EP[`000000080Vh_100D000000:2B
a@2PT/D0X9;5000000030:BHb@030000002WWL`0Yig<0080Yig<00@000000;n]a`2o[LL000000`2o
[lX010000000_[7=0;jac@0000020;fcd0050000002l]=80_;CB0;bddP0000000P2k]]@01@000000
^[OF0;ZgeP2j]mH000000080^[SG0P0000001033aM`000000<75g@0000020;o4gP030000003oool0
oooo02@0oooo00<000000?ooo`3oool07`3oool001@0oooo00<000000?ooo`3oool0303oool20000
00`0oooo0P2[]n800`000000ZkKQ0:^fh@020:bfh@030000002/]^0000000080[KKP00H000000:jf
g`2^]]l000000:nfgP0000020;6fg@060000002b]]`0/[KL0000002d]m/000000P2g]mT01P000000
^[SG0;Zhe`000000_[WD00000080`k[A00@000000<RkcP38^lh000000P3?_LT00`000000e[o30000
00020=k2_0030000002oV:l0_iR_00H0000000P0H52X000000000000000006]FY`1[EJL00000075I
Y`8000000P1eFjL200000080N5bV0P0000000`1jGJD0000007]NY@020000000907aLX`0000000000
0000001oGZ<0P5nS0000000008d00000008003Bi00@0000008eh]`2=N;L000000P2EP[`010000000
Vh_109^;`@0000030:2Ba@060000002TV<T0Y9S90:BHb@000000Yig<0`0000020;n]a`050000002o
[lX0_jo:0;n_bP0000000P2n/Ld01@000000_K?@0;fcd02m/m00000000<0_;CB00@000000;^fe02k
]]@000000P2j]mH010000000^[SG0000000000020<?5g00300000031aMd0000000<0_lCN00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0O0?ooo`00503oool00`000000oooo0?ooo`0>0?oo
o`8000002P3oool00`000000ZkOR000000020:^fh@030000002/]^4000000080[;KP0P2]]^001P00
0000[[KO0:jfg`000000[kKN00000080/KKM00H000000;:fg02b]]`000000;Bgf`0000020;Ngf@06
0000002j^=L0^[SG0000002n^M@000000P33^]4010000000b;_>0<RkcP0000020<nmb@040000003F
_l<000000=k2_08000000P2oV:l600000003061@Z00000000000008000000P1[EJL010000000LERW
075HY`00000207EKY`80000000D0N5bV000000000000000007YMY@030000000707aLX`000000OEfS
0000001oGZ<00000081OX`0200000003000d^@00000000000080SGRg00D0000009F2_02EP[`0UH:l
0000000209^;`@050000002PT/D0X9;50:2Ba@0000000`2TV<T01@000000`:W30<2Y``30ZL<00000
0080_jg700D000000;n_bP2o[lX0_jo:000000020;jac@050000002m/m00_K?@0;fcd00000000P2l
]=8010000000^kKD0;^fe00000020;ZgeP80000000L0aLGJ00000033aM`0`lGL00000031aMd00000
00<0_lCN00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0O0?ooo`00503oool00`000000
oooo0?ooo`0@0?ooo`<000001`3oool020000000ZkOR0:^ghP000000ZkKQ0000002/]^4000000P2/
]^0010000000[KKP0:ffh00000020:jfg`030000002_]]h000000080/KKM00<000000;:fg0000000
0P2d]m/00`000000]kOI000000020;Zhe`030000002n^M@000000080`k[A00@000000<RkcP38^lh0
00000P3?_LT01P000000e[o3000000000000^YVg00000080_iR_00<0000004m6Y`0000000`000000
0`1PD:P000000000000200000080JeFW00<00000075HY`1aF:L0100000000`1fFjH0000000000002
00000080NUfU0`0000002@1lG:<00000000000000000OejS081OX`000000002=00000002089//@04
0000002=N;L0SGRg00000080UH:l00@0000009^;`@2KRl400000102PT/D010000000Y9S900000000
00030<2Y``040000002o[LL0_jg7000000<0_jo:00@000000;jac@2n/Ld000000`2m/m001@000000
_;CB0;bddP2l]=8000000080^kKD0P0000001037a]T000000<G5fP0000020<?5g00400000031aMd0
`LGM00000080_lCN00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0O0?ooo`004`3oool0
0`000000oooo0?ooo`0D0?ooo`8000001@3oool01P000000ZkOR0:^ghP000000ZkKQ00000080[;KQ
00<000000:bfh00000000P2]]^001P000000[[KO0:jfg`000000[kKN00000080/KKM00<000000;:f
g00000000P2d]m/00`000000]kOI000000020;Zhe`030000002n^M@0000000<0`k[A00<000000<Rk
cP0000000P3?_LT00`000000e[o3000000030;ZI]`040000002oV:l0000004m6Y`@0000000<0H52X
0000000000000P0000000`1[EJL0000006]DYP0300000080LeZV0P0000000`1fFjH0000007MKY002
0000000;07YMY@00000000000000001lG:<0000007eMX`000000OejS00000020Gj<00P000002089/
/@040000002=N;L0SGRg000000<0UH:l00@0000009^;`@2KRl4000000`2PT/D01@000000Y9S90000
0030Y[l0000000<0`:W300@000000;n]a`2o[LL000000`2o[lX010000000_[7=0;jac@0000030;fc
d0050000002l]=80_;CB0000002k]]@00P0000020<O6f@0300000035aMX0000000<0`lGL00<00000
0<75g@0000000P2oa=h00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01l0oooo000C0?oo
o`030000003oool0oooo01H0oooo0P0000030?ooo`060000002[]n80ZkOR0000002[]^4000000P2/
]^400`000000[;KP000000020:ffh0060000002^]]l0[[KO0000002_]]h000000P2a]]d00`000000
/[KL000000020;Bgf`030000002g]mT0000000<0^[SG00<000000;jie00000000P33^]400`000000
b;_>000000020<nmb@<000000`2jVKL00`000000_iR_0;nH[`0500000003061@Z000000000000080
000000@0JeFW0000001[E:H000000P1`EjH01@000000LeZV000000000000MU^V00<0000000<0N5bU
0000001iFZ8010000000201mGJ<000000000001oGZ<0P5nS0000001cG:T000000P22K;4010000000
SGRg08eh]`00000209F2_0050000002KRl40Vh_109^;`@0000000`2PT/D010000000`:Jo0<2V_`00
00030<2Y``040000002o[LL0_jg7000000<0_jo:00@000000;jac@2n/Ld000000`2m/m000`000000
_;CB0;bddP02000000050<W6e`000000alKI0<O6f@0000000P35aMX01P000000`lGL0<?5g0000000
`LGM00000080_lCN00<000000?ooo`3oool08P3oool00`000000oooo0000000P0?ooo`004`3oool0
0`000000oooo0?ooo`0H0?ooo`80000000L0oooo0000002[]n80ZkOR0000002[]^4000000080[;KQ
00<000000:bfh00000000P2]]^001P000000[[KO0:jfg`000000[kKN00000080/KKM00H000000;:f
g02b]]`000000;Bgf`0000020;Ngf@060000002j^=L0^[SG0000002n^M@000000P33^]4010000000
b;_>0000003?_LT200000080]9^m00@000000;ZI]`2jVKL000000P2oV:l;00000080JeBV00<00000
071GYP1`EjH00`0000001@1eFZD00000000000000000Me^T0080000000T0NEZR0000000000000000
07aLX`000000OEfS0000001oGZ<00P0000001@1cG:T00000089//@22K;4000000080SGRg00D00000
09F2_02EP[`0UH:l0000000309^;`@040000002PT/D00000000000<0`:Jo00D000000<2Y``30ZL<0
`:W3000000020;n]a`050000002o[lX0_jo:0;n_bP0000000P2n/Ld010000000_K?@0;fcd02m/m02
000000040<c6e0000000bLKG00000080alKI00@000000<G5fP35aMX000000P33aM`00`000000`LGM
000000020;o4gP030000003oool0oooo02@0oooo00<000000?ooo`3oool07P3oool001<0oooo00<0
00000?ooo`3oool06P3oool3000000070:^ghP000000ZkKQ0:^fh@000000[;KQ000000020:bfh003
0000002]]^0000000080[[KO00<000000:nfgP0000000P2a]]d01P000000/[KL0;:fg0000000];OK
00000080]kOI00H000000;Zhe`2j^=L000000;jie00000020<>jd@0600000038^lh000000000002`
WL<000000P2dVkd010000000^YVg0;ZI]`0000020;nH[`D0000000<0FDZU0000000000000`000002
06]DYP0506]DY@00000000000000001bF:D00P0000000`1eFZD0000007IJY00300000080NEZR00D0
000007]KXP000000000007eMX`030000000407iKW`1cG:T0LebY00000080PVba00@0000008eh]`2=
N;L000000`2EP[`020000000Vh_109^;`@000000X9;500000030X[X000000P30Y[l01@000000`:W3
0<2Y``30ZL<000000080_jg700D000000;n_bP2o[lX0_jo:000000020;jac@030000002m/m000000
008000000P3<a]@00`000000bLKG000000030<O6f@0300000035aMX000000080`lGL00<000000<75
g@0000000P2oa=h00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01h0oooo000C0?ooo`03
0000003oool0oooo01`0oooo00<000000:^ghP0000000P2[]^400`000000[;KQ000000020:bfh003
0000002]]^0000000080[[KO00<000000:nfgP0000000P2a]]d01P000000/[KL0;:fg0000000];OK
00000080]kOI00H000000;Zhe`2j^=L000000;jie00000020<>jd@<000000P2`WL<010000000]9^m
0;BK_@0000020;ZI]`030000002oV:l0_iR_00D0000000<0FDZU0000000000001@000000101[E:D0
000006mFY@1_EZD20000000507AIY000000000000000001fFZ@00`0000003@1iFZ80000000000000
0000O5bS0000001mGJ<0000007eJW`1nFil0000007=LZ@0000000P22K;4010000000SGRg08eh]`00
000309F2_0050000002KRl40Vh_109^;`@0000000P30X[X01@000000`:Jo0<2V_`30Y[l0000000<0
`:W300@000000;n]a`2o[LL000000`2o[lX010000000_[7=0;jac@0000020<o6dP040000003<a]@0
c<KD00000080bLKG00H000000<O6f@37a]T000000<G5fP0000020<?5g00300000031aMd000000080
_lCN00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0N0?ooo`004`3oool00`000000oooo
0?ooo`0L0?ooo`030000002[]n8000000080ZkKQ00<000000:bfh@0000000P2/]^000`000000[KKP
000000020:jfg`030000002_]]h000000080/KKM00@000000;:fg02b]]`000000P2d]m/00`000000
]kOI000000020;Zhe`040000002n^M@000000<>jd@8000000P2]WlT30;2M``040000002dVkd0]9^m
00000080^YVg00<000000;nH[`0000002P0000001@1UD:D0000006]DY@000000KeJU0080000000<0
LURU0000001dFJ@00P0000001@1fFZ@00000000000000000NEZR0080000000H0Ne^R000000000000
OEfS0000001mFYl20000000307=LZ@000000PVba0080PVba00@0000008eh]`2=N;L000000`2EP[`0
10000000Vh_10000000000030<2R^P0400000030Y[l0`:Jo000000<0`:W300@000000;n]a`2o[LL0
00000`2o[lX010000000_[7=0000000000020<o6dP040000003<a]@0c<KD00000080bLKG00H00000
0<O6f@37a]T000000<G5fP0000020<?5g00300000031aMd000000080_lCN00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0N0?ooo`004P3oool00`000000oooo0?ooo`0M0?ooo`030000002[
]n8000000080ZkKQ00<000000:bfh@0000000P2/]^000`000000[KKP000000020:jfg`040000002_
]]h0[kKN00000080/KKM00<000000;:fg00000000P2d]m/00`000000]kOI000000020;Zhe`@00000
00D0Zj7=0000002]WlT0[Io9000000020;2M``040000002dVkd0]9^m00000080^YVg00<000000;nH
[`2oV:l02P0000001P1UD:D000000000001[DjD0000006mEY0<0000000D0M5VT0000001eFJ@00000
07IJY0030000000507UJXP000000Ne^R0000001lG:<00P0000000`1mFYl000000000000207=LZ@04
00000022K;40PVba00000080SGRg00T0000009F2_02EP[`0UH:l0000002KRl4000000<2M]@000000
0P30X[X010000000`:Jo0<2V_`0000040<2Y``040000002o[LL0_jg7000000<0_jo:00<000000=;6
c`0000000P3?a]801`000000c<KD0<c6e03<a]@000000<W6e`0000000P37a]T00`000000aLGJ0000
00020<?5g00300000031aMd000000080_lCN00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`020?ooo`@000005`3oool00180oooo00<000000?ooo`3oool07@3oool020000000ZkOR0:^ghP00
0000ZkKQ0000002/]^4000000P2/]^0010000000[KKP0:ffh00000020:jfg`030000002_]]h00000
0080/KKM00<000000;:fg00000000P2d]m/6000000030:RSd@000000Zj7=0080Zj7=00<000000:fO
b@0000000P2`WL<010000000]9^m0;BK_@0000020;ZI]`030000002oV:l0_iR_00H0000000@0FdZU
000000000000I52V0`0000001@1[DjD0000006mEY0000000LENT00D0000000D0MUZT000000000000
000007UJXP020000000:07]KXP00000000000000001mFYl0000007iKW`000000LebY00000080PVba
00D0000008eh]`2=N;L0SGRg0000000309F2_00400000030WKD0`9fe000000<0`::j00@000000<2V
_`30Y[l000000`30ZL<010000000_jg70;n]a`0000020;n_bP8000000P3Ba/l010000000clKB0<o6
dP0000020<c6e00300000039a]L000000080alKI00<000000<G5fP0000000P33aM`00`000000`LGM
000000030;o4gP030000003oool0oooo02<0oooo0P0000040?ooo`030000003oool0oooo01P0oooo
000B0?ooo`030000003oool0oooo01d0oooo00H000000:^ghP2[]n8000000:^fh@0000020:bfh@06
0000002/]^00[;KP0000002]]^0000000P2^]]l00`000000[kKN000000020;6fg@H0000000D0YZOG
0000002WYM@0YjGD000000020:RSd@040000002[XLd0Zj7=00000080[Io900<000000;2M``000000
0P2dVkd010000000^YVg0;ZI]`0000020;nH[`H0000000<0FdZU000000000000100000001`1[DjD0
Je>T000000000000LENT0000001cEj@00P0000000`1eFJ@0000007IHXP030000000307UJXP000000
Ne^R0080000000<0NeVO0000001mFYl00P00000207=LZ@0400000022K;40PVba00000080SGRg00D0
000009F2_02EP[`0UH:l000000030<2M]@0400000030X[X0`::j00000080`:Jo00<000000<2Y``30
ZL<00P30ZL<00`000000_jg70;n]a`02000000050=G6b`000000d/K?0=;6c`0000000P3?a]801P00
0000c<KD0<c6e0000000bLKG00000080alKI00<000000<G5fP0000000`33aM`00`000000`LGM0000
00020;o4gP030000003oool0oooo02<0oooo0P0000050?ooo`030000003oool0oooo01L0oooo000B
0?ooo`030000003oool0oooo01h0oooo00<000000:^ghP0000000P2[]^400`000000[;KQ00000002
0:bfh0030000002]]^0000000080[[KO1P0000020:BZf`80YJWI00@000000:JWe`2VYmL000000P2W
YM@00`000000Z:?A000000020:^Qc@040000002]WlT0[Io900000080/9g300@000000;BK_@2dVkd0
00000P2jVKL70000000505U:Y@00000000000000001OC:@0100000000`1[Dj@00000000000020000
000307=GY000000000000080000000D0MURR000000000000000007UJXP0300000080NeVO00@00000
07eJW`00000000000P1cG:T010000000PVba089//@00000308eh]`050000002EP[`000000;nH/000
00000P30WKD010000000`::j0<2R^P0000030<2V_`0500000030ZL<0`:W30<2Y``0000000P2o[LL0
10000000eLK;0=G6b`0000020=;6c`040000003?a]80clKB00000080c<KD00<000000<W6e`000000
0P37a]T010000000aLGJ0<G5fP0000020<?5g00300000031aMd000000080_lCN00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo000B0?ooo`030000
003oool0oooo01h0oooo00<000000:^ghP0000000P2[]^4010000000[;KQ0000002/]^0700000005
0:B]gP000000Y:cM0:B/g@0000000P2TZ]/01P000000YJWI0:FYf@000000YZOG00000080YjGD00@0
00000:RSd@2XXm4000000P2[XLd00`000000[Io9000000020;2M``040000002dVkd0]9^m00000080
^YVg1`0000000`1IBZD00000000000060000000406]CY00000000000071FY0T0000000D0N5VR0000
001iFZ80000007YIW`0207]IW`070000001mFYl0000007iKW`000000LebY00000003089//@080000
002=N;L0SGRg0000002EP[`000000;nH/00000030<2M]@0400000030X[X0`::j00000080`:Jo00<0
00000<2Y``30ZL<00P30ZL<300000080eLK;00@000000=;6c`3Ba/l000000P3?a]801P000000c<KD
0<c6e0000000bLKG00000080alKI00@000000<G5fP35aMX000000P33aM`00`000000`LGM00000002
0;o4gP030000003oool0oooo02@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>
0?ooo`8000001@3oool00180oooo00<000000?ooo`3oool07P3oool900000080Xk3Q0P2S[n030:>^
g`80Y:gN00@000000:B/g@2T[=d000000P2TZ]/00`000000YJWI000000020:JWe`060000002WYM@0
YjGD0000002XXm4000000P2[XLd00`000000[Io9000000020;2M``040000002dVkd0]9^m00000080
^YVg00<0000007ER[`0000003P000000101[DZ<0KUBT0000001`EZ@200000005079GX`0000000000
0000001fF:800`000000101iFZ80000007YIW`1kFIl40000000507iKW`000000LebY07=LZ@000000
0P22K;401@000000SGRg08eh]`2=N;L000000080_iR`00D000000<2M]@30WKD0`9fe000000020<2R
^P0500000030Y[l0`:Jo0<2V_`0000000`30ZL<00`000000f<G7000000030=G6b`030000003Ba/l0
00000080clKB00H000000<c6e03<a]@000000<W6e`0000030<O6f@0300000035aMX000000080`lGL
00@000000<75g@000000_lCN0P00000V0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000003`3oool010000000oooo0?ooo`0000040?ooo`004@3oool00`000000oooo0?ooo`0P0?oo
o`80Y;;S0`2T/^820:BahP<0Xk3Q00<000000:>_h00000000P2S[]l00`000000Y:gN000000020:B/
g@040000002TZ]/0Y:[K00000080YJWI00<000000:JWe`0000000P2WYM@00`000000Z:?A00000002
0:^Qc@060000002]WlT0[Io90000002`WL<000000`2dVkd30000000307ER[`000000000000d00000
00<0Je:S0000000000001P0000001@1dEj800000000000000000N5VR0080000000H0NUVO00000000
0000NeVO0000001mFYl200000080LebY00D00000089//@22K;40PVba0000000208eh]`050000002o
V;00_iR`0;nH/00000000P30WKD01@000000`::j0<2R^P30X[X000000080`:Jo00<000000<2Y``30
ZL<00P0000020=S5a`060000003Ea//0eLK;0000003Ba/l000000P3?a]8010000000c<KD0<c6e000
00020<W6e`0700000037a]T0alKI00000035aMX000000<?5g005000000030<CDiP000000oooo02H0
oooo00<000000?ooo`3oool00P3oool200000100oooo00<000000?ooo`3oool01@3oool00140oooo
00<000000?ooo`3oool0803oool00`000000Y;;S000000020:BbhP030000002T/N80000000<0Xk3Q
00<000000:>_h00000000P2S[]l00`000000Y:gN000000020:B/g@060000002TZ]/0Y:[K0000002U
ZMT000000P2VYmL00`000000YjGD000000020:RSd@060000002[XLd0Zj7=0000002]WlT000000P2`
WL<010000000]9^m0;BK_@00000207=X^0P0000000<0FdZU000000000000200000001@1_EJ<00000
000000000000LUNS00@0000000@0MeRR000000000000N5RP0P00000207]IW`040000001mFYl00000
000000<0LebY00P00000089//@22K;40000008eh]`000000_I:Z00000080_iR`00D000000<2M]@30
WKD0`9fe000000020<2R^P0400000030Y[l0`:Jo0<2V_`80000000D0flC30000003HaLL0f<G70000
00020=G6b`060000003Ba/l0d/K?0000003?a]8000000P3<a]@010000000bLKG0<W6e`0000020<O6
f@@0000000H0bMST00000037e^D000000<CDiP00000X0?ooo`030000003oool0oooo01@0oooo00@0
00000?ooo`3oool00000103oool00140oooo00<000000?ooo`3oool08@3oool00`000000Y;;S0000
00020:BbhP030000002T/N8000000080Xk3Q00<000000:>_h00000000P2S[]l00`000000Y:gN0000
00020:B/g@040000002TZ]/0Y:[K00000080YJWI00<000000:JWe`0000000P2WYM@00`000000Z:?A
000000020:^Qc@030000002]WlT000000080/9g31000000207=X^0030000001eHZl0MF:_00D00000
00@0FdZU000000000000GdbT1P0000001@1^Dj<00000000000000000LEJS00<0000000<0M5NR0000
000000000P000000101hF:00000007YIW`1kFIl40000000507iKW`000000LebY07=LZ@0000000`22
K;42000000050;fBZP000000_iR`0;nH/00000000`30WKD01@000000`::j0<2R^P30X[X000000080
`:Jo00@000000=_4``3Ka<<000000P3HaLL010000000eLK;0=G6b`0000020=;6c`030000003?a]80
000000<0c<KD00@000000<W6e`000000alKI0P0000001P3=f^<000000<WHi0000000amKU00000080
a=CV00<000000?ooo`3oool09@3oool2000001L0oooo0P0000050?ooo`004@3oool00`000000oooo
0?ooo`0Q0?ooo`030000002T/^<000000080Y;;R00@000000:BahP2T/N8000000P2S/>400`000000
XjoP000000020:>^g`030000002T[Mh000000080Y:cM00H000000:BZf`2TZ]/000000:FYf@000002
0:JWe`030000002WYM@000000080Z:?A00<000000:^Qc@0000000P2]WlT3000000<0Lfo000<00000
07=X^00000000P1eHZl?0000000306iCX`00000000000080000000<0LEJS00000000000010000000
101gEj00N5RP0000001jFIl50000000507iKW`000000LebY07=LZ@0000000`22K;4010000000_I:Z
0;fBZP0000030;nH/00500000030WKD0`9fe0<2M]@0000000P30X[X010000000`:Jo000000000003
0=_4``030000003HaLL000000080eLK;00@000000=;6c`3Ba/l000000P3?a]801@000000c<KD0<c6
e0000000bLKG0080000000<0d=gR0000000000000P39f>@00`000000amKU000000020<CDiP030000
003oool0oooo02@0oooo00<000000?ooo`0000007P3oool00140oooo00<000000?ooo`3oool08P3o
ool00`000000Y;;S000000020:BbhP030000002T/N8000000080Xk3Q00<000000:>_h00000000P2S
[]l00`000000Y:gN000000020:B/g@040000002TZ]/0Y:[K00000080YJWI00<000000:JWe`000000
0P2WYM@00`000000Z:?A000000020:^Qc@<0000000<0M7O80000001cKl000P1cKl000`000000LfRh
0000000207ER[``0000000<0IDjS0000000000001@000000201aEZ<00000000000000000M5NR0000
001fEZ00MeNP1@0000000`1kFIl0000007eJW`02000000<0LebY00@00000089//@22K;4000000`2m
TZX010000000_iR`0;nH/00000030<2M]@0400000030X[X0`::j0<2R^P<000000`3Ka<<00`000000
f<G7000000020=G6b`040000003Ba/l0d/K?00000080clKB00<000000<c6e03<a]@00`000000103@
gN8000000<gJh`0000020<WHi00500000037e^D000000<CDiP000000:@3oool00`000000oooo0?oo
o`0L0?ooo`004@3oool00`000000oooo0?ooo`0S0?ooo`030000002T/^<000000080Y;;R00<00000
0:BahP0000000P2S/>400`000000XjoP000000020:>^g`030000002T[Mh000000080Y:cM00H00000
0:BZf`2TZ]/000000:FYf@0000020:JWe`030000002WYM@000000080Z:?A0`0000001@1gOlh00000
07Agb01dMlP000000080Lfo000D0000007=X^0000000000007ER[`0<0000000306E>X`0000000000
00<0000000H0KeBR000000000000LEBQ0000001cEZ820000000407IFX0000000000007QHX0800000
00<0NeVO0000000000000P0000001P1nFil0000007=LZ@1cG:T00000089//@8000000`2mTZX01000
0000_iR`0;nH/00000040<2M]@0400000030X[X0`::j00000080g/>m00@000000=_4``3Ka<<00000
0P3HaLL00`000000eLK;000000020=;6c`050000003?a]80clKB0000003<a]@00`0000020=3MhP07
0000003=f^<000000<WHi0000000amKU000000020<CDiP030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0703oool00100oooo00<000000?ooo`3oool0903oool00`000000Y;;S000000020:Bb
hP030000002T/N8000000080Xk3Q00P000000:>_h02S[n0000000:>^g`000000Y:gN00000080Y:cM
00@000000:BZf`2TZ]/000000P2UZMT00`000000YZOG000000020:NUe0<000000P1jQ]@207MocP03
0000001dMlP0000000<0Lfo00`00000207ER[`D0000000<0FDNR000000000000300000000`1aE:40
0000000000040000000407MGX01hF:00000007YIW`D0000000<0OU^O0000001cG:T00P1cG:T20000
00050;^<Y0000000_I:Z0;fBZP0000000`2oV;001P000000`9fe0<2M]@30WKD000000<2R^P800000
0P3N`kd010000000flC30=_4``0000020=S5a`030000003Ea//0000000<0d/K?00D000000<o6dP00
000000000=SSgP0200000080d=gR0P0000020<WHi00300000037e^D000000080a=CV00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0K0?ooo`00403oool00`000000oooo0?ooo`0U0?ooo`03
0000002T/^<000000080Y;;R00<000000:BahP0000000P2S/>400`000000XjoP000000020:>^g`03
0000002T[Mh000000080Y:cM00H000000:BZf`2TZ]/000000:FYf@0000020:JWe`<000000P1nSMP2
07Z6e0030000001gOlh000000080M7O800<0000007=_`01cKl000`00000207ER[`D0000000<0FDNR
0000000000001`0000000`1[DJ8000000000000300000003075DX@00000000000080000000<0MUJP
0000000000001`0000000`1nFil0000007=LZ@0207=LZ@040000002kS:@0^hbT000000<0_I:Z00@0
00000;nH/02oV;0000001030WKD300000080g/>m00@000000=_4``3Ka<<000000P3HaLL010000000
eLK;0=G6b`0000020=;6c`<0000000P0f>?N0000003Dgn0000000=3MhP000000cM[S00000080bMST
00D000000<OFi@000000a=CV0000000[0?ooo`030000003oool0oooo01/0oooo000@0?ooo`030000
003oool0oooo02H0oooo00D000000:Bbh`000000Y;;R000000020:BahP030000002S/>4000000080
XjoP00D000000:>^g`000000Y:gN000000020:B/g@040000002TZ]/0Y:[K00000080YJWI0`000002
086Cg080OXgH00P0000007Z6e01jQ]@0000007MocP000000M7O8000000<0Lfo000@0000007=X^000
0000MF:_5@000000101aE:4000000000001dEJ080000000607]IW`00000000000000001nFil00000
0P1cG:T010000000^hbT0;^<Y00000030;fBZP040000002oV;00_iR`000000@0`9fe00<000000>71
]`0000000P3N`kd010000000flC30=_4``0000020=S5a`040000003Ea//0eLK;00000080d/K?0P00
00020=SSgP070000003Dgn0000000=3MhP000000cM[S000000020<WHi00500000037e^D000000<CD
iP000000:`3oool00`000000oooo0?ooo`0K0?ooo`00403oool00`000000oooo0?ooo`0V0?ooo`03
0000002T/^<000000080Y;;R00<000000:BahP0000000P2S/>400`000000XjoP000000020:>^g`03
0000002T[Mh000000080Y:cM00<000000:BZf`0000000`00000208BHgP80PI?L00P0000007j=f01n
SMP0000007Z6e0000000Mgo>00000080M7O800L0000007=_`01cKl00000007=X^0000000MF:_01L0
000000<0LeFP0000000000000`0000000`1hF:00000007YIW`050000000307iKW`000000LebY0080
00000P2kS:@01@000000_I:Z0;fBZP2mTZX0000000<0_iR`00<000000<2M]@30WKD00P0000020>71
]`030000003N`kd000000080flC300@000000=S5a`3HaLL000000P3Ea//500000080f>?N0P000002
0=3MhP090000003=f^<000000<WHi0000000amKU00000034e>H0000002`0oooo00<000000?ooo`3o
ool06`3oool00100oooo00<000000?ooo`3oool09`3oool00`000000Y;;S000000020:BbhP050000
002T/N8000000:>`h@0000000P2S[n001P000000XjkO0000002T[Mh000000:B/g@<000000P2;X>82
08RLh@80Q9SN00H00000086Cg021Tm`0000007j=f000000207Z6e0050000001gOlh0000007Agb000
00000P1cKl000`000000LfRh0000000207ER[`D0000000<0FDNR0000000000001@0000000`1WCj80
0000000000090000000307EFX0000000000000P0000000H0OU^O0000001cG:T000000;R5WP000002
0;^<Y0040000002mTZX0_I:Z000000<0_iR`00<000000<2M]@30WKD00P0000020>71]`060000003N
`kd0g/>m0000003Ka<<000000`3HaLL03`000000eLK;0000003RjML000000=gVf`000000f>?N0000
003Dgn0000000=3MhP000000cM[S000000020<WHi00500000037e^D000000<CDiP000000:`3oool2
000001d0oooo000@0?ooo`030000003oool0oooo02L0oooo00<000000:Bbh`0000000P2T/^802@00
0000Y;7R0:BahP000000Xk3Q0000002S[n0000000:>^g`0400000080SJCT00@0000008^PhP2;X>80
Rj3R0P28W>4208BHgP0600000021Tm`0PI?L0000001nSMP000000P1jQ]@200000080M7O800L00000
07=_`0000000000007=X^0000000MF:_01T0000000<0MEJP000000000000200000001P1nFil00000
07=LZ@000000^8FN00000080^hbT00D000000;fBZP2mTZX0_I:Z000000020;nH/00500000030WKD0
00000>Bn/00000000P3Q`KL010000000g/>m0=k3_@0000020=_4``030000003HaLL0f<G700<00000
00`0h^WG0000003Mi]/000000=SSgP000000e=oP0000003@gN8000000<gJh`0000020<WHi0050000
0037e^D000000<CDiP000000;@3oool00`000000oooo0?ooo`0J0?ooo`003`3oool00`000000oooo
0?ooo`0Y0?ooo`030000002T/^<000000080Y;;R00H000000:BahP000000Xk3Q0000002S[n020000
0080TZWU00<00000092Vi@0000000P2=Y>@01P000000Rj3R08^PhP000000R9cQ00000080Q9SN00d0
0000086Cg021Tm`0000007j=f0000000NXKD0000001gOlh0000007Agb0000000Lfo00080000000<0
LfRh0000001eHZl03@0000000`1WCZ4000000000000400000005071CX000000000000000001dEJ00
200000001P1kFIl00000000000000000OU^O00000080^8FN00@000000;^<Y02kS:@000000`2mTZX0
10000000_iR`0;nH/02oV;02000000050>Bn/0000000hL6g0>71]`0000000P3N`kd010000000flC3
0=_4``0000020=S5a`040000003Wk=8000000>;Ye`8000000P3Hhmh03@000000e=oP0000003@gN80
00000<gJh`000000bMST00000037e^D000000<CDiP000000;P3oool00`000000oooo0?ooo`0J0?oo
o`003`3oool00`000000oooo0?ooo`0Z0?ooo`060000002T/^<000000:BbhP000000Y;7R10000002
09B[iP060000002BZND0TZWU0000002@Y^D000000P2=Y>@01P000000Rj3R08^PhP000000R9cQ0000
0080Q9SN00D00000086Cg0000000OXgH0000000207Z6e08000000P1dMlP30000000407=X^0000000
MF:_07ER[aT0000000<0MEJP0000000000002P0000020;R5WP040000002kS:@0^hbT000000<0_I:Z
00D000000;nH/02oV;00_iR`000000030>Bn/0030000003Q`KL000000080g/>m00<000000=_4``3K
a<<01@000000303RjML000000=gVf`000000f>?N0000003Dgn0000000=3MhP000000cM[S00000080
bMST00D000000<OFi@000000a=CV0000000^0?ooo`030000003oool0oooo01X0oooo000?0?ooo`03
0000003oool0oooo02X0oooo00@000000:Bbh`000000Y;;R0P00000209N^i`030000002F[NL00000
0080U:_V00H0000009:Yi@2BZND00000092Vi@00000208fTi0080000002;X>80Rj3R00000028W>40
000008BHgP000002086Cg0030000001nSMP000000080NXKD0P0000001P1dMlP000000000001cKl00
000007=X^080MF:_1@0000000`1IAj8000000000000L0000000507aGW0000000^8FN0;R5WP000000
0`2kS:@01@000000_I:Z0;fBZP2mTZX000000080_iR`00L000000>Bn/03T_[00i;j`0000003Q`KL0
00000080g/>m01@000000=_4``3Ka<<000000>c^b`000000incB0000003RjML000000=gVf`000000
f>?N0000003Dgn0000000=3MhP000000cM[S00000080bMST00D000000<OFi@000000a=CV0000000^
0?ooo`030000003oool0oooo01X0oooo000?0?ooo`030000003oool0oooo02/0oooo0`00000209R_
i`060000002G[^L0UjkW0000002F[NL000000P2DZnH01P000000TZWU09:Yi@000000T:KU00000080
SJCT00P0000008^PhP2;X>80000008RLh@000000Q9SN00000080PI?L00@0000007j=f0000000NXKD
0P00000207Agb0<0000000<0LfRh0000000000006@0000000`1dE9h00000000000080000000307aG
W0000000^8FN0080^8FN00@000000;^<Y02kS:@000000`2mTZX010000000_iR`0000000000030>Bn
/0030000003Q`KL0000000<0g/>m0`0000001@3/k//000000>O/dP000000h^WG0080000000l0f>?N
0000003Dgn00e=oP0000003@gN8000000<gJh`000000bMST00000037e^D000000<CDiP000000;`3o
ool00`000000oooo0?ooo`0J0?ooo`003`3oool00`000000oooo0?ooo`0/0?ooo`030000002J/NL0
00000080V:oW00D0000009N^i`2G[^L0000009J]i`020000000709B[iP000000TZWU09:Yi@000000
T:KU0000000208fTi0080000002;X>80Rj3R00000028W>40000008BHgP000002086Cg08000000P1j
Q]@40000000307=_`000000000000100000000<0J4nQ000000000000200000000`1dE9h000000000
00060000000507YGW@1kEi`0O5NL07aGW00000000P2hQIh010000000^hbT0;^<Y00000030;fBZP04
0000002oV;000000000000<0i;j`00<000000>71]`0000000`3N`kd3000000050>c^b`000000incB
0000003RjML00P000000103Hhmh000000=COh03Dgn02000000030<gJh`000000bMST00H00000;`3o
ool00`000000oooo0?ooo`0J0?ooo`003`3oool00`000000oooo0?ooo`0]0?ooo`030000002J/NL0
00000080V:oW00@0000009N^i`2G[^L000000P2F[NL00`000000U:_V0000000209:Yi@030000002@
Y^D000000080SJCT00d0000008^PhP2;X>80000008RLh@000000Q9SN00000021Tm`0000007j=f000
0000NXKD0080000000<0M7O8000000000000100000000`2kHP000000000000080000000306=;X000
0000000000P0000000@0LE>O079CW`1cE9l0M5BN0`000000101gEIh000000000001iEYd207YGW@04
07]GW01lEi`0O5NL00000080^8FN00@000000;^<Y02kS:@00000102mTZX00`000000i[^Y00000003
0>Bn/0040000003Q`KL0hL6g00000080g/>m0P0000002`3/k//000000>O/dP000000h^WG0000003M
i]/000000=SSgP000000e=oP00L0000000@0`NOa0000002oho400000;`3oool00`000000oooo0000
000K0?ooo`003P3oool00`000000oooo0?ooo`0`0?ooo`030000002J/NL000000080V:oW00<00000
09N^i`0000000P2F[NL010000000U:_V00000000000209:Yi@8000000P2=Y>@01`000000Rj3R0000
0028W>40000008BHgP0000000P21Tm`20000000407Z6e000000000000000008000290P0000000`2X
B000^f800000000I0000000407ADWP1eE9h0MUFN07MEWP80N5JM00<0NEJM07YGW@1jEid00P000000
1@1lEi`000000;R5WP2hQIh0000000<0^hbT00D000000;fBZP2mTZX0_I:Z000000020>JkZ@040000
003T_[00i;j`00000080hL6g00<000000=k3_@0000000P0000001`3/k//000000>O/dP000000h^WG
0000003Mi]/00P000000303Dgn000000000000000000a>o`00000033jo0000000<7Wl@000000_n?a
00000380oooo00<000000?ooo`3oool06@3oool000h0oooo00<000000?ooo`3oool0<@3oool00`00
0000V[7W0000000209R_i`030000002G[^L000000080UZgW00@0000009B[iP2DZnH000000P2BZND2
00000080SJCT00P0000008^PhP000000R9cQ00000024V=h00000086Cg0<000000P00?L0200000006
0000R@000000001X0:Q800000000^f806@0000000`1dE9h0000007IEWP020000000307QFW@000000
000000<0000000D0O5NL0000002hQIh0^8FN000000030;^<Y0050000002mTZX0_I:Z0;fBZP000000
0P3V^jT010000000i;j`0>Bn/00000020>71]`80000000P0mO2f000000000000k>k;0000003Wk=80
00000>;Ye`L0000000P0a>o`00000033jo0000000<7Wl@000000_n?a000003<0oooo00<000000?oo
o`3oool06@3oool000h0oooo00<000000?ooo`3oool0<P3oool00`000000V[7W0000000209R_i`06
0000002G[^L000000000002F[NL000000P2DZnH00`000000TZWU09:Yi@0200000080SJCT00H00000
08^PhP000000R9cQ00000024V=h20000000301Y_g`0000000000008003g00P0000001@0008T00000
0000002XB000^f800140000000<0K52P0000000000001@0000000`1dE9h000000000000800000003
07aGW0000000^8FN0080^8FN00@000000;^<Y02kS:@000000P2mTZX200000080i[^Y00@000000>Bn
/03T_[0000000P3Q`KL020000000mO2f0000003al<8000000>c^b`000000incB1@0000002`37nNX0
000000000034ko0000000<?[l0000000`NOa0000002oho40000003@0oooo00<000000?ooo`3oool0
6@3oool000h0oooo00<000000?ooo`3oool0<`3oool01P000000V[7W000000000000V:oW00000080
UjkW00<0000009J]i`0000000P2DZnH00`000000TZWU09:Yi@0200000080SJCT00<0000008^PhP00
00001000000201Y_g`80000000L003g000000000000000290000000006P0Z4P00080^f8000@00000
05E2W`000000F4BO100000000`1QBJ00000006=;X0020000000306M=W`000000000000D0000000@0
LE>O000000000000M5BN20000000101jEid0000007aGW00000030;R5WP040000002kS:@0^hbT0000
0080_I:Z0P0000020>JkZ@080000003T_[00i;j`0>Bn/0000000hL6g0000003el;H2000000050>c^
b`000000incB0000003RjML00`0000002`37nNX0000000000034ko0000000<?[l0000000`NOa0000
002oho40000003D0oooo00<000000?ooo`3oool06@3oool000h0oooo00<000000?ooo`3oool0=03o
ool20000000409Zai`000000V:oW00000080UjkW00H0000009J]i`000000000009B[iP00000209:Y
i@80000000@0SJCT000000000000EIO`0`000000100bP>P0000001Y_g`0JKml200000004000m`000
000000000000R@<0000000<0^f800000000000003`0000000`1[Cil00000000000040000000307AD
WP000000000000@0000000L0NEJM0000001jEid0NeNL0000001lEi`000000080^8FN00@000000;^<
Y02kS:@0^hbT0P0000001@3X]j4000000>JkZ@3V^jT0000000<0i;j`0`0000001P3el;H000000000
003/k//000000>O/dP<0000000`0aogT00000000000000000<C_l0000000`n_`00000031io400000
0;oSl@00000f0?ooo`030000003oool0oooo01T0oooo000>0?ooo`030000003oool0oooo03H0oooo
00D0000009Zai`000000V:oW0000000209N^i`070000002F[NL0UZgW0000002DZnH0000009:Yi@03
00000080HYka0P0000001@1EUo0000000000000bP>P0000000806VoO0P0000001`00?L0000000000
000008T000000:Q8002kHP004@0000001@1[Cil00000000000000000L5:N00H0000000D0MeFN0000
00000000NEJM07YGW@030000000507aGW0000000^8FN0;R5WP0000000`2kS:@200000080j;NQ00<0
00000>JkZ@0000000`3T_[03000000080?G`]P00000000000>c^b`000000incB00000035o]X30000
00070<KdkP000000a>o`00000033jo0000000<7Wl@02000003P0oooo00<000000?ooo`3oool0603o
ool000d0oooo00<000000?ooo`3oool0>03oool010000000V[7W0000002H[nL20000000709N^i`00
0000UZgW09J]i`000000U:_V0000000207BXlP80000000/0HYka0000001RW_40000005FGl0000000
AXg]0000000bP>P0000001Y_g`0200000003000m`000000000000080000000@0^f80000000000000
ED:O100000000`1NB:0000000659X0060000000606U>W`1[Cil000000000001_DIl0L5:N0`000000
101dE9h000000000001gEIh20000000307UFW@00000000000080000000<0O5NL0000002hQIh00P2h
QIh010000000^hbT0;^<Y00000030>RgX@030000003V^jT0000000<0i;j`0P0000000`3el;H00000
0?7``P07000000080<OijP00000000000<C_l0000000`n_`00000031io42000003P0oooo0P000006
0?ooo`030000003oool0oooo0140oooo000=0?ooo`030000003oool0oooo03T0oooo00T0000009Za
i`000000000009R_i`000000UjkW0000002F[NL00P0000000`1kZo80000007BXlP0207BXlP800000
0P1RW_400`000000EIO`000000020000000303:0j00000006VoO0080000000H003g00000000008T0
00000:Q8002kHP030000000305Q4W`000000FdJO00@0000000<0I4ZO0000000000001`0000001@1`
DYh00000000000000000M5BN0080000000<0MeFN0000000000001@0000000`1lEi`000000;R5WP02
0;R5WP040000002kS:@0^hbT000000<0j;NQ00<000000>JkZ@0000000`3T_[02000000040?G`]P00
000000000>c^b`D0000000P0aoWZ000000000000a>o`00000033jo0000000<7Wl@800000>P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo000=0?ooo`030000003oool0oooo
03X0oooo0P0000001P2J/NL0000009R_i`000000UjkW00000080PJkb0P000000101kZo8000000000
001dZ?8300000080HYka00<0000005FGl00000000`000000100JKml0000000000000?L0300000003
0;]R00000000000000X0000000<0ID^O0000000000000P0000000`1[Cil0000006i@WP0=00000004
07YGW@000000O5NL000000<0^8FN00@000000;^<Y000000000000`3X]j401@000000i[^Y0>JkZ@00
0000i;j`00<0000000<0mO2f0000000000001@0000002037nNX0000000000034ko0000000<?[l000
0000`NOa0P00000k0?ooo`040000003oool0oooo0?ooo`D000004P3oool000d0oooo00<000000?oo
o`3oool0?03oool00`000000V[7W000000020000000308F`l@00000000000080PJkb0P000000101k
Zo80000007BXlP1dZ?830000000306:Nl@000000000000@0000000<06VoO0000000000000`000000
0`2kHP000000000000050000000305i8X0000000HTRN0080000000<0ID^O00000000000010000000
0`1^D9h000000000000200000003079BW@000000000000H0000000@0NUNM00000000000000000`2h
QIh010000000^hbT0000000000030>RgX@090000003V^jT0i[^Y0000003T_[0000000?S^Z0000000
mO2f00H0000000P0aoWZ000000000000a>o`00000033jo0000000<7Wl@800000?03oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool04@3oool000d0oooo00<000000?ooo`3o
ool0?@3oool00`000000SK?`000000030000000508F`l@000000000000000021[_800P0000000`1k
Zo80000007BXlP040000000306:Nl@000000EIO`00X0000000@0DT2N000000000000F4BO20000000
1@1UBih000000000001YCIh0JdnO00@0000000<0LE:N0000001bDYd01P0000000`1iEYd0000007YG
W@020000000607aGW0000000^8FN0;R5WP000000^hbT0P0000030>RgX@030000003V^jT0i[^Y00<0
000000<0n>jX000000000000100000002@37oN@00000000000000000a>o`00000033jo0000000<7W
l@02000003h0oooo00L000000?ooo`3oool0oooo0000003oool0000001<0oooo000=0?ooo`030000
003oool0oooo03h0oooo0P0000000`2=/o000000000000020000000308F`l@00000000000080PJkb
00P0000007^[lP000000000007BXlP000000K:Cb00000080HYka2@0000000`2kHP00000000000003
0000000305]6W`000000000000@0000000<0ID^N0000000000000P0000001`1[CYh0000000000000
0000LE:N0000001bDYd00`000000101gEIh000000000001iEYd40000000307aGW0000000^8FN0080
^8FN0`0000030>RgX@030000003V^jT0i[^Y00<0000000<0n>jX0000000000000P0000000`35o]X0
000000000009000003l0oooo00<000000?ooo`3oool00P3oool2000001<0oooo000<0?ooo`030000
003oool0oooo0440oooo0P0000000`2=/o000000000000020000000408F`l@0000000000086^lP80
000000<0Nj_b000000000000100000000`1RW_4000000000000>0000000305m7W@000000000000<0
000000@0ID^N00000000000000000P1[CYh;0000000307UFW@00000000000080000000<0O5NL0000
002hQIh00P2hQIh010000000jK:J0>VbVP0000020>RgX@070000003V^jT0i[^Y0000003ijYL00000
0?S^Z009000000030:7^n0000000000000<00000@03oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0140oooo000<0?ooo`030000003oool0oooo04<0oooo0P0000000`2=/o0000000000
00020000000408F`l@0000000000086^lP80000000D0Nj_b000000000000000006bTlP0200000003
06:Nl@000000000000L0000000<0ED:O0000001HA9l0200000001@1UBih00000000000000000JdjN
00T0000000<0M5>M0000000000000`000000101jEid0000007aGW00000030;R5WP040000003Y/YX0
jK:J00000080j;NQ00D000000>JkZ@3V^jT000000?WZU`02000000030?G`]P000000000000@00000
00<0XNkh0000000000000`0000120?ooo`030000003oool0oooo01L0oooo000<0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool00P0000000`2=/o000000000000020000000408F`l@00
00000000086^lP80000000D0Nj_b000000000000000006bTlP020000000500f<h`00000000000000
002B00000P0000001P1B@9h000000000001HA9l0000005e5W@T0000000<0J4fN06]>WP0000000P00
0000101^D9h000000000001bDYd20000000307ACW@000000000000<0000000@0NUNM000000000000
00000`2hQIh010000000jK:J0>VbVP0000030>RgX@/0000000<0XNkh0000000000000`0000130?oo
o`8000006@3oool000`0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`030?ooo`80
000000<0SK?`0000000000000P0000001025/?40000000000021[_820000000507^[lP0000000000
0000000/WO001P0000000`3<ER4000000000000<0000000306I;W@00000000000080JdjN00D00000
06i@WP0000000000079BW@060000000307UFW@000000NUNM0080000000D0O5NL0000002hQIh0^8FN
000000020>VbVP040000003X]j40j;NQ0>RgX@T0000000<0XNkh0000000000000`0000160?ooo`03
0000003oool0oooo01L0oooo000<0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
1P3oool20000000308fcl000000000000080000000D0QK3a000000000000PJkb0000000205N`n`/0
000000<0ED:O0000001K@i`01P000000101SBId000000000001VBid200000080JdjN00D0000006i@
WP0000000000079BW@020000000307ACW@000000000000<0000000H0NUNM000000000000O5NL0000
002hQIh200000080jK:J00@000000>RgX@3X]j40j;NQ0P0000000`3ijYL000000?S^Z00200000003
0:7^n0000000000000<00000B@3oool00`000000oooo0?ooo`0F0?ooo`00303oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo00T0oooo0P0000000`2=/o000000000000020000000408F`
l@000000000006Ffo08000000P1G/?/:0000000505]3W0000000GDFM0000001OAid00`0000002@1S
BId00000000000000000J4bM0000001[CYh0000006i@WP050000000307ACW@000000000000H00000
00<0O5NL0000002hQIh00P0000020>VbVP040000003X]j40j;NQ0>RgX@80000000@0nNZG0000003h
kZP0XNkh1@00001;0?ooo`030000003oool0oooo01H0oooo000;0?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool0303oool20000000308fcl00000000000008000000P1`^O`200000005
06Ffo000000000000000001G/?/0100000000`1B@9h00000000000080000000506=9W@0000000000
0000001XC9d0100000000`1^D9d00000000000020000000507ACW@00000000000000001fDi`01000
00000`1lEi`000000;R5WP0200000080jK:J00@000000>RgX@3X]j40j;NQ2@00001=0?ooo`030000
003oool0oooo01H0oooo000;0?ooo`030000003oool0oooo03d0oooo0P00000A0?ooo`80000000@0
SK?`0000001h^o/0N;_k0`000002072io0T0000000<0FD6L0000001K@i`01@0000001@1RB9d00000
06=9W@000000IDZM00<0000000D0JdfM0000001^D9d0000006m@W@060000000407ICW00000000000
07YGW@<0000000H0^8FN0000003Y[Y8000000>VbVP0000030>RgX@L00000C`3oool00`000000oooo
0?ooo`0F0?ooo`002`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01<0oooo00@0
000007nlnP1o_?X0Okcj0`0000000`1h^o/000000000000200000003072io0000000000000d00000
00/0HdVM0000001UBYd0000006M;W@000000JdfM0000001^D9d0000006m@W@060000000307ICW000
0000000000H0000000@0jJjB0000003Y/YX000000P3X]j4600000540oooo00<000000?ooo`3oool0
5P3oool000/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0G0?ooo`<000000P1o
_?X90000000305HoV`000000000000L0000000<0HTRM0000000000000P000000201WBid0000006]=
W@000000KU2M0000001_D9d0KdnL0P000000101dDid0000007ECW01fDi`20000000607MCV`000000
000007aGW0000000jJjB0P000000103Y/YX000000>RgX@3X]j44000005<0oooo0P00000G0?ooo`00
2`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01`0oooo100000000`1o_?X00000
000000070000000305]3W0000000GDFM00@0000000@0HTRM00000000000000000P1WBid01P000000
JTfM000000000000Ke2M06m?W080000000@0M5>M0000001eDi`0MU>L0P0000001@1gDi/000000000
001lEi`000000080jJjB10000000103X]j40000000000000001D0?ooo`8000005`3oool000/0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0Q0?oooa40000000<0HTRM0000001TBI`0
100000001@1ZCId000000000001_D9d0KdnL0080000000@0M5>M000000000000MU>L0P0000000`1g
Di/000000000000200000080jJjB00<000000>VbVP3Y/YX01@00001E0?ooo`030000003oool0oooo
01D0oooo000:0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool09`3oool200000005
05HoV`000000FD6L0000001K@i`00`0000000`1PAY`000000000000300000080IdZL00<0000006Y=
W@1ZCId00P000000101_Ci`000000000001dDid50000000507MCV`000000000007QCV`0000000P3Y
[Y800`000000jK:J0>VbVP05000005D0oooo00<000000?ooo`3oool05@3oool000X0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0Z0?ooo`@0000000<0Fd>L0000001MAId01`000002
06M:W0030000001ZCId000000080000000@0KdnL000000000000M5>M100000001P1fDi/0Me>K0000
00000000N5>K00000080jJjB00D000000>VbVP3Y/YX000000?CKL@02000000030?ooo`0000000000
05<0oooo00<000000?ooo`3oool05@3oool000X0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0[0?ooo`T0000000@0H4JL000000000000HdRL0P00000206M:W00506Y=W@0000000000
0000001_Ci`01`0000001P1fDi/00000000000000000N5>K00000080jJjB00D000000>VbVP3Y/YX0
00000?CKL@02000000<0oooo0P00001A0?ooo`030000003oool0oooo01D0oooo000:0?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool0;03oool01P000000ESnK0000001I@I`0000005]3
W080000000@0GdFK00000000000000000P1SB9`400000080JTbL00<0000006m?W00000001P000000
1P1fDi/0000007MCV`000000N5>K00000080jJjB00D000000>VbVP3Y/YX000000?CKL@02000000D0
oooo0P00001@0?ooo`030000003oool0oooo01@0oooo000:0?ooo`030000003oool0oooo03@0oooo
0P00000`0?ooo`T0000000D0H4JL000000000000HdRL0000000206I9W0030000001ZC9`0JTbL0080
000000<0KdnL0000001_Ci`00`0000001`1fDi`000000000001gDi/0000007QCV`0000000P3Y[Y80
1P000000jK:J0>VbVP000000m=]a000000P0oooo0P00001>0?ooo`030000003oool0oooo01@0oooo
000:0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<03oool80000000305m5V`00
0000H4JL00<000000P1VBI`00`000000JTbL06Y<W0020000000306m?W0000000KdnL00<0000000<0
MU>L0000000000000P1gDi/01P1hDi/000000>V^TP3Y[Y8000000>VbVP80000000<0m=]a0000003o
ool02@3oool2000004`0oooo00<000000?ooo`3oool0503oool000T0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0a0?ooo`80000000H0Ed6K000000000000Fd>L0000001NA9/20000
00030616W0000000HdNK008000000P1VBI`40000000306m?W0000000KdnL0080000000D0ME>L07IC
W0000000000007MCV`0300000080jJjB00<000000>VbVP0000000`00000<0?ooo`800000B@3oool2
000001H0oooo00090?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool80000
000505m5V`00000000000000001SAi/00P000000201VBI`000000000001ZC9`0000006m?W0000000
KdnL0P0000001@1eDi`00000000000000000Me>K0080000000@0N5>K0000003Y[Y80jJjB1@00000>
0?ooo`800000B03oool00`000000oooo0?ooo`0D0?ooo`002@3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo03@0oooo0`0000000`1I@I`00000000000020000000705m5V`0000000000
0000001SAi/0000006I9V`0200000080JTbL00@0000006m?W0000000KdnL1P0000001@1gDi/00000
0000001hDi/000000080jJjB1000000A0?ooo`800000AP3oool00`000000oooo0?ooo`0D0?ooo`00
2@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo03D0oooo0P0000000`1G@I/00000
000000040000000305m5V`000000HTJK008000000P1VBI/01`000000JTbL06Y<W0000000KdnL0000
001_Ci`01P0000001@1gDi/000000000001hDi/000000080jJjB1000000C0?ooo`<00000A03oool0
0`000000oooo0?ooo`0C0?ooo`002@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
03L0oooo20000000101OAI/000000696V`1RAY/20000000506I9V`000000JTbL0000001ZC9/00P00
0000101_Ci`000000000001`Ci/30000000507MCV`000000000007QCV`0000000P3Y[Y8010000000
l=5N00000000000F0?ooo`800000@P3oool00`000000oooo0?ooo`0C0?ooo`002@3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo03P0oooo0`0000000`1I@I`0000005e3VP0500000003
0696V`00000000000080ITVK0P0000001`1ZC9/00000000000000000L4nK0000001`Ci/00`000000
1@1gDi/000000000001hDi/000000080jJjB0P0000000`3dfg4000000?ooo`0G0?ooo`800000@03o
ool00`000000oooo0?ooo`0C0?ooo`00203oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo03T0oooo0P0000000`1G@I/0000000000005000000030655VP000000HTJK00@000000`1ZC9/2
00000003071?V`000000L4nK0080000000H0MU>K000000000000000007QCV`0000020>V^TP800000
00<0m=]a0?ooo`3oool06@3oool2000003h0oooo00<000000?ooo`3oool04`3oool000P0oooo00<0
00000?ooo`3oool0;03oool2000003d0oooo1@000000201M@iX00000000000000000HDFJ0000001R
AY/000000P1UB9/00`000000JTbK06Y<V`0300000003071?V`000000L4nK0080000000H0MU>K0000
00000000000007QCV`0000020>V^TP<000007@3oool2000003`0oooo00<000000?ooo`3oool04`3o
ool000P0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0m0?ooo`80000000<0Ed6K
000000000000100000020655VP8000000P1UB9/00`000000JTbK06Y<V`0300000003071?V`000000
L4nK0080000000H0MU>K000000000000000007QCV`0000020>V^TP<000007`3oool2000003X0oooo
0P00000D0?ooo`00203oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03h0oooo0P00
00000`1G@I/00000000000020000000305i4V`00000000000080HDFJ0P00000206E8V`8000000P1Z
Bi/010000000L4nK0000001`Ci/40000000407MCV`000000N5>K00000080jJjB0`00000Q0?ooo`80
0000>@3oool00`000000oooo0?ooo`030?ooo`8000003@3oool000P0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`100?ooo`<0000000<0Fd6I0000001M@iX00`0000030655VP800000
00<0IDRK0000000000000P1ZBi/010000000L4nK0000001`Ci/40000000507MCV`000000N5>K0000
003Y[Y800`00000T0?ooo`800000=`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000`0oooo00080?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0@@3oool20000
000305Y0V@00000000000080000000<0GTBK0000000000000P1QAIX010000000IDNJ000000000003
06Y;V`040000001`Ci/00000071?V`80000000L0L4nJ0000001gDi/0000007QCV`000000jJjB00<0
00009P3oool2000003D0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000<0?oo
o`001`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0480oooo0P0000001@1J@9T0
0000000000000000GD>J0080000000@0HDFJ0000001QAIX000000P1UAiX01@000000JT^K06Y;V`00
0000JD^K00<0000000<0L4nK0000001`CiX01@000000103Y[Y80000000000000000X0?ooo`<00000
<P3oool00`000000oooo0?ooo`020?ooo`<000003@3oool000L0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`140?ooo`80000000<0FT2I000000000000100000000`1QAIX000000000
000306E7VP040000001ZBi/0000006U;V`<0000000<0L4nK0000001`CiX01@000000103Y[Y800000
00000000000[0?ooo`800000<03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0
oooo00070?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0A@3oool20000000505Y0
V@00000000000000001M@iX00P0000000`1QAIX000000000000306E7VP030000001ZBi/000000080
JD^K0P0000001@1`Ci/00000071?VP000000LDnJ00<0000000@0jJjB0000000000000000;@3oool2
000002l0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`001`3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo04H0oooo00/0000005ToV@000000000005]1V@000000GD>J0000001P
A9X000000655VP0300000080IDNJ00@0000006U;V`1YBi/0JD^K0P0000001@1`Ci/00000071?VP00
0000LDnJ0080000000<0N5>K0000000000000P00000_0?ooo`800000;03oool2000000@0oooo0`00
000<0?ooo`001`3oool00`000000oooo0?ooo`0S0?ooo`800000BP3oool20000000305Y0V@000000
000000@0000000@0HDFJ0000001TAiX0I4NJ0`00000206U;V`<0000000D0L4nK0000001`CiX00000
075?VP020000000407QCV`00000000000?3AGS80oooo0P00000Y0?ooo`030000003oool0000001<0
oooo00070?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0BP3oool01@000000FCnI
000000000000Fd6I00<0000000<0H4BJ000000000000101TAiX02P000000JD^K06U;V`000000JDZJ
0000001`Ci/00000071?VP000002075?VP030000001hDi/0000000800000=03oool2000002T0oooo
00<000000?ooo`3oool04@3oool000H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`1<0?ooo`<0000000H0Fd6I000000000000Gd>I0000001PA9X2000000<0I4NJ00<0000006U;V`00
00000P1YBYX01@000000L4nK0000001`CiX000000080LDnJ00<0000007QCV`0000000P00000f0?oo
o`8000009`3oool00`000000oooo0?ooo`0A0?ooo`001P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo04d0oooo00<0000005ToV@0000000`0000000`1O@iT000000614VP02000000@0
I4NJ0P00000206U:VP050000001`Ci/00000071?VP0000000P1aCiX5000003P0oooo0P00000U0?oo
o`030000003oool0oooo0140oooo00060?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0CP3oool01@000000FCnI000000000000Fd6I0080000000<0Gd>I0000001PA9X00`00000206A7
VP060000001YBYX0JDZJ06U:VP000000L4nK0P000003075?VPD00000>P3oool2000002@0oooo00<0
00000?ooo`3oool0403oool000H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1@
0?ooo`80000000@0FT2I00000000000000000P1O@iT200000080I4JJ0`00000206U:VP030000001Y
BYX00000008000000`1aCiX00`000000LDjJ00000002000003`0oooo0`00000Q0?ooo`030000003o
ool0oooo0100oooo00060?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0D@3oool0
1@000000FCnI000000000000Fd6I0080000000<0Gd>I000000000000101TAYX01@000000JDZJ06U:
VP000000JDZJ00<000000`1aCiX010000000LDjJ0000000000100?ooo`8000007`3oool00`000000
oooo0?ooo`0@0?ooo`001P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05<0oooo
0`0000001@1K@IT0000005i3V@000000Gd>I008000000`1TAYX00`000000JDZJ0000000306U:VP80
00000`1aCiX010000000LDjJ0000000000120?ooo`8000007@3oool00`000000oooo0?ooo`0@0?oo
o`001@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05@0oooo00<0000005ToV@00
0000100000000`1O@iT000000000000406A6VP8000000`1YBYX200000005075?VP000000LDnJ0000
001aCYX00P0000140?ooo`8000006`3oool200000140oooo00050?ooo`030000003oool0oooo01/0
oooo0P00001G0?ooo`030000001I?iT0000000<0000000<0GT>I0000001O@iT00`00000206A6VP04
0000001YBYX0JDZJ06U:VP<0000000D0LDnJ0000001aCiX00000075>VP02000004H0oooo0P00000J
0?ooo`030000003oool0oooo00l0oooo00050?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0F03oool01`000000FCnI000000000000GT:H0000001N@iT00P00000206=6V@<000000`1Y
BYX020000000JDVI0000001aCiX00000075?VP000000LDjJ0P0000180?ooo`800000603oool00`00
0000oooo0?ooo`0?0?ooo`001@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05T0
oooo00@0000005ToV@00000000000P1N@YP00`000000GT>I0000000406=6V@040000001YBYX0JDZJ
00000080JDVI00H00000075?VP000000LDnJ0000001aCYX2000004X0oooo0P00000F0?ooo`030000
003oool0oooo00l0oooo00050?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0F`3o
ool01`000000FCnI000000000000GT:H0000001N@iT00P00000306=6V@040000001YBYX0JDZJ0000
0080JDVI00H00000075?VP000000LDnJ0000001aCYX2000004`0oooo0P00000D0?ooo`030000003o
ool0oooo00l0oooo00050?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G03oool0
10000000FCnI00000000000205i2V0040000001N@iT00000000000<0HdJI0P00000306U9V@040000
001aCiX0000000000080LDjJ0P00001>0?ooo`8000004P3oool00`000000oooo0?ooo`0?0?ooo`00
103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05h0oooo00T0000005ToV@000000
000005i2V0000000GT>I0000001SAIT00P0000000`1SAYT000000000000206U9V@030000001YBIT0
0000008000000P1aCYX00`000000oooo0?ooo`1?0?ooo`<000003`3oool00`000000oooo0?ooo`0?
0?ooo`00103oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05l0oooo00@0000005To
V@00000000000P1N@YP2000000<0HdFI0P00000306U9V@030000001YBIT00000008000000P1aCYX0
0`000000oooo0?ooo`1B0?ooo`8000003P3oool00`000000oooo0?ooo`0>0?ooo`00103oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0600oooo00<0000005ToV@0000000P00000205i2
V08000000`1SAIT010000000JDVI06U9V@00000306U9V@8000000P1aCYX00`000000oooo0?ooo`1D
0?ooo`800000303oool00`000000oooo0?ooo`0>0?ooo`00103oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo0680oooo0`0000000`1M@IP0000005i2V002000000<0HdFI00@0000006U9
V@1YBIT000000`1YBIT200000003075>VP000000000005P0oooo0P0000090?ooo`800000403oool0
00@0oooo00<000000?ooo`3oool04P3oool2000006D0oooo0P0000000`1M@IL000000000000205i2
V08000000`1SAIT2000000@0JDVI0P0000000`1aCYX000000000001J0?ooo`800000203oool00`00
0000oooo0?ooo`0>0?ooo`00103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo06H0
oooo00P0000005e1U`000000GD6H0000001N@YP000000695V080000000<0HdFI0000000000000`1Y
BIT300000003075>VP000000000005`0oooo0P0000060?ooo`030000003oool0oooo00h0oooo0003
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0I`3oool01@000000GD6G05e1U`00
0000GD6H008000000`1RAIP2000000@0JDVI00@0000006U9V@000000LDjJ0P00001N0?ooo`800000
103oool00`000000oooo0?ooo`0>0?ooo`000`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo06T0oooo00@0000005e1U`000000GD6H0P0000040695V0050000001YBIT0JDVI06U9V@00
00000P1YBIT010000000LDjJ00000000001P0?ooo`8000000`3oool00`000000oooo0?ooo`0=0?oo
o`000`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo06X0oooo00D0000005e1U`1M
@IL0000005e1V002000000@0HTFH00@0000006U9V@1YBIT000000P1YBIT010000000LDjJ00000000
001R0?ooo`80000000<0oooo0000003oool03P3oool000<0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`1/0?ooo`060000001M@IL0GD6G0000001M@IP00000101RAIP00`000000JDVI
0000000306U9V@030000001aCYX0000006<0oooo00@000000?ooo`00000000003`3oool000<0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1]0?ooo`050000001M@IL0GD6G0000001M
@IP00P0000030695V0030000001YBIT000000080JDVI00@0000006U9V00000000000H`3oool30000
0100oooo00030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0K`3oool00`000000
GD6G05e1U`02000000060694V000000000000000001RAIP000000`1YBIT010000000JDVH00000000
001R0?ooo`8000004P3oool00080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1`
0?ooo`030000001M@IL0GD6G00800000101RA9P200000080JDVI00D0000006U9V01YBIP0JDVH0000
001P0?ooo`800000503oool00080oooo00<000000?ooo`3oool02P3oool2000007@0oooo00<00000
05e1U`1M@IL00P0000040694V0040000001YBIT0JDVI000000<0JDVH00<000000?ooo`3oool0G03o
ool2000001H0oooo00020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0M@3oool0
10000000GD6G05e1U`0000040694V0030000001YBIT0000000@0JDVH00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`0F0?ooo`000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo07H0oooo00<0000005e1U`1M@IL00P0000040694V08000000`1YBIP00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo008000006@3oool00080oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`1h0?ooo`040000001M@IL000000694V0<0000000<0HTBH0000001YBIP00`1YBIP0
0`000000oooo0?ooo`1G0?ooo`<000006`3oool00080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`1i0?ooo`030000001M@IL0000000@0HTBH0P00000306U9V0030000003oool0oooo
05L0oooo0P00000M0?ooo`0000<0oooo0000003oool01`3oool00`000000oooo0?ooo`1k0?ooo`80
00001@1RA9P01@000000JDVH06U9V01YBIP0000005P0oooo00<000000?ooo`3oool07@3oool00003
0?ooo`000000oooo00H0oooo00<000000?ooo`3oool0O03oool2000000D0HTBH00@0000006U9V01Y
BIP00000E`3oool200000200oooo00000`3oool000000?ooo`050?ooo`030000003oool0oooo07h0
oooo0P0000040694V0040000001YBIP0JDVH000005D0oooo0P00000R0?ooo`0000<0oooo0000003o
ool0103oool00`000000oooo0?ooo`1o0?ooo`040000003oool00000000000<0HTBH0P00001A0?oo
o`030000003oool0oooo00800000903oool000030?ooo`000000oooo0080oooo0P0000220?ooo`04
0000003oool0oooo0?ooo`80000000<0HTBH000000000000DP3oool2000002H0oooo00001@3oool0
00000?ooo`3oool0000008@0oooo00<000000?ooo`3oool00`3oool200000580oooo00<000000?oo
o`3oool09P3oool000040000003oool0oooo000008D0oooo00<000000?ooo`3oool0E@3oool20000
02T0oooo00000`000000oooo000000260?ooo`030000003oool0oooo05<0oooo0P00000[0?ooo`00
0P0000270?ooo`030000003oool0oooo0540oooo0P00000]0?ooo`000`0000260?ooo`030000003o
ool0oooo04d0oooo00@000000?ooo`3oool00000;`3oool00080oooo0`0000240?ooo`030000003o
ool0oooo04h0oooo0P00000`0?ooo`001@3oool300000840oooo00<000000?ooo`3oool0C03oool2
000000`0oooo1000000R0?ooo`00203oool3000007h0oooo00<000000?ooo`3oool0BP3oool20000
00h0oooo00<000000?ooo`3oool08`3oool000/0oooo0`0000000`3oool000000?ooo`1h0?ooo`03
0000003oool0oooo04P0oooo0P00000A0?ooo`030000003oool0oooo0280oooo000>0?ooo`<00000
N03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00X0oooo100000040?ooo`030000
003oool0oooo0240oooo000A0?ooo`<00000M@3oool00`000000oooo0?ooo`140?ooo`<000005P3o
ool00`000000oooo0?ooo`0P0?ooo`00503oool300000780oooo00<000000?ooo`3oool0@`3oool2
000001D0oooo00@000000?ooo`3oool000008P3oool001L0oooo0`0000000`3oool000000?ooo`1/
0?ooo`030000003oool0oooo0440oooo0P00000H0?ooo`8000008`3oool001X0oooo0`00001/0?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool0?@3oool001/0oooo00<000000?ooo`00
00000P00001Y0?ooo`030000003oool0oooo03h0oooo0P0000100?ooo`00803oool3000006H0oooo
00<000000?ooo`3oool0>P3oool010000000oooo0000000000120?ooo`008`3oool3000000030?oo
o`000000oooo0600oooo00<000000?ooo`3oool0>P3oool2000004@0oooo000V0?ooo`<00000H03o
ool00`000000oooo0?ooo`0h0?ooo`800000AP3oool002T0oooo0`00001M0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0AP3oool002`0oooo0`00001J0?ooo`030000003oool0oooo
0340oooo00@000000?ooo`3oool0oooo0P0000190?ooo`006`3oool400000100oooo0`0000000`3o
ool000000?ooo`1D0?ooo`030000003oool0oooo0340oooo00@000000?ooo`0000000000B`3oool0
01/0oooo00<000000?ooo`3oool0503oool3000005@0oooo00<000000?ooo`3oool0<@3oool20000
04d0oooo000L0?ooo`030000003oool0oooo01H0oooo0`00001A0?ooo`030000003oool0oooo02l0
oooo0P00001?0?ooo`005@3oool4000000@0oooo00<000000?ooo`3oool0603oool3000004h0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1?0?ooo`007P3oool00`000000oooo0?oo
o`0J0?ooo`@00000BP3oool00`000000oooo0?ooo`0/0?ooo`800000DP3oool001/0oooo00@00000
0?ooo`3oool000007`3oool3000004P0oooo00<000000?ooo`3oool0:03oool010000000oooo0000
0000001D0?ooo`00703oool2000002<0oooo0`0000150?ooo`030000003oool0oooo02P0oooo0P00
001F0?ooo`00A03oool300000080oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo05H0oooo00170?ooo`<00000?`3oool00`000000oooo0?ooo`0U0?oo
o`8000002P3oool2000004d0oooo00190?ooo`@00000?03oool00`000000oooo0?ooo`0S0?ooo`80
00002`3oool010000000oooo0?ooo`00001<0?ooo`00C@3oool3000003T0oooo00<000000?ooo`3o
ool0803oool3000000d0oooo00@000000?ooo`3oool00000C03oool00500oooo0`0000000`3oool0
00000?ooo`0d0?ooo`030000003oool0oooo01h0oooo0P00000?0?ooo`040000003oool0oooo0000
04`0oooo001C0?ooo`<00000=03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00l0
oooo00@000000?ooo`3oool00000C03oool005H0oooo0`00000a0?ooo`030000003oool0oooo01/0
oooo0P00000B0?ooo`040000003oool0oooo000004`0oooo001I0?ooo`<00000;P3oool00`000000
oooo0?ooo`0I0?ooo`8000005@3oool2000004d0oooo001L0?ooo`@00000:P3oool00`000000oooo
0?ooo`0F0?ooo`<00000IP3oool004P0oooo0P00000E0?ooo`<00000:03oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo06H0oooo00170?ooo`040000003oool0oooo000001L0oooo0`00
000U0?ooo`030000003oool0oooo01@0oooo0P00001Y0?ooo`00A`3oool010000000oooo0?ooo`00
000J0?ooo`<0000000<0oooo0000003oool07`3oool00`000000oooo0?ooo`0B0?ooo`800000J`3o
ool004L0oooo00@000000?ooo`3oool000007@3oool3000001l0oooo00<000000?ooo`3oool03P3o
ool010000000oooo00000000001]0?ooo`00A`3oool010000000oooo0?ooo`00000P0?ooo`<00000
703oool00`000000oooo0?ooo`0>0?ooo`800000K`3oool004L0oooo00@000000?ooo`3oool00000
8`3oool300000080oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06l0oooo00180?ooo`8000009`3oool3000001H0oooo00<000000?ooo`3oool02`3o
ool200000780oooo001c0?ooo`@000004`3oool00`000000oooo0?ooo`090?ooo`800000M03oool0
07L0oooo0`00000@0?ooo`030000003oool0oooo00H0oooo0`00001f0?ooo`00NP3oool4000000`0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1f0?ooo`00O@3oool3000000X0oooo
00<000000?ooo`3oool0103oool2000002X0oooo1000001;0?ooo`00P03oool3000000L0oooo00<0
00000?ooo`3oool00P3oool2000000P0oooo1000000Q0?ooo`040000003oool0oooo000004X0oooo
00230?ooo`<0000000H0oooo0000003oool0oooo0000003oool3000000X0oooo00<000000?ooo`3o
ool08P3oool010000000oooo0?ooo`00001:0?ooo`00L@3oool400000140oooo0`000000103oool0
000000000000000=0?ooo`030000003oool0oooo0240oooo00@000000?ooo`3oool00000BP3oool0
0740oooo00<000000?ooo`3oool05@3oool200000100oooo00<000000?ooo`3oool0803oool30000
04/0oooo001b0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`1;0?ooo`00L`3oool00`000000oooo0?ooo`0S0?ooo`040000003oool0oooo00000200
oooo0P00001=0?ooo`00M03oool00`000000oooo0?ooo`0S0?ooo`800000L03oool004L0oooo0P00
00000`3oool000000?ooo`0U0?ooo`040000003oool0oooo000009L0oooo00160?ooo`040000003o
ool0oooo000002P0oooo0P00002H0?ooo`00A`3oool300000<80oooo00190?ooo`030000003oool0
oooo0<00oooo00170?ooo`800000``3oool00?l0oooo3@3oool00?l0oooo3@3oool00?l0oooo3@3o
ool00?l0oooo3@3oool00?l0oooo3@3oool00001\
\>"],
  ImageRangeCache->{{{0, 267.625}, {286.938, 0}} -> {0.0771478, -0.00998954, \
0.00344001, 0.00344001}}]
}, Open  ]],

Cell[BoxData[
    \(\(r2xRule = {r, \[Theta], \[Phi]} \[Rule] 
            CoordinatesFromCartesian[{x, y, z}, Spherical] // 
          Thread;\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\( (*for\ 0 < r < 
        1*) \)\(\[IndentingNewLine]\)\(eq1[y_, 
          z_] = \(potInQ /. r2xRule\) /. {Q \[Rule] 1, a \[Rule] 1, 
              x \[Rule] 0} // Simplify;\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(\( (*\ 
      for\ 1 < r\ *) \)\(\n\)\(eq2[y_, 
          z_] = \(potOutQ /. r2xRule\) /. {Q \[Rule] 1, a \[Rule] 1, 
              x \[Rule] 0}\  // Simplify;\)\)\)], "Input",
  Hyphenation->False],

Cell[BoxData[
    RowBox[{\(pot[y_, z_]\), ":=", 
      RowBox[{"If", "[", 
        RowBox[{
          FormBox[\(y\^2 + z\^2 < 1\),
            "TraditionalForm"], ",", \(eq1[y, z]\), ",", \(eq2[y, z]\)}], 
        "]"}]}]], "Input",
  Hyphenation->False],

Cell[BoxData[
    \(\(circle = {Thickness[0.02], Circle[{0, 0}, 1]}\  // 
          Graphics;\)\)], "Input",
  Hyphenation->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[{VEPlot[pot[y, z], {y, \(-2\), 2}, {z, \(-2\), 2}, 
            DisplayFunction \[Rule] 
              Identity], \[IndentingNewLine]circle}, \
\[IndentingNewLine]DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input",
  Hyphenation->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .98584 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.208426 0.48597 0.208426 [
[ 0 0 0 0 ]
[ 1 .98584 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.0001 w
[ ] 0 setdash
.08315 .06912 m
.12139 .02347 L
s
% Start of user PostScript
-2. -2. -1.81651 -2.21901 MAarrowhead1
% End of user PostScript
.08315 .12867 m
.11858 .0808 L
s
% Start of user PostScript
-2. -1.71429 -1.83003 -1.94394 MAarrowhead1
% End of user PostScript
.08315 .18822 m
.1129 .13663 L
s
% Start of user PostScript
-2. -1.42857 -1.85728 -1.67608 MAarrowhead1
% End of user PostScript
.08315 .24777 m
.10383 .19193 L
s
% Start of user PostScript
-2. -1.14286 -1.90075 -1.41078 MAarrowhead1
% End of user PostScript
.08315 .30732 m
.09118 .24831 L
s
% Start of user PostScript
-2. -0.857143 -1.96148 -1.14025 MAarrowhead1
% End of user PostScript
.08315 .36687 m
.07565 .30779 L
s
% Start of user PostScript
-2. -0.571429 -2.03596 -0.854871 MAarrowhead1
% End of user PostScript
.08315 .42642 m
.05925 .37187 L
s
% Start of user PostScript
-2. -0.285714 -2.11465 -0.547418 MAarrowhead1
% End of user PostScript
.08315 .48597 m
.04458 .4406 L
s
% Start of user PostScript
-2. 0 -2.18504 -0.217697 MAarrowhead1
% End of user PostScript
.08315 .54552 m
.03359 .5125 L
s
% Start of user PostScript
-2. 0.285714 -2.23776 0.127283 MAarrowhead1
% End of user PostScript
.08315 .60507 m
.02689 .58556 L
s
% Start of user PostScript
-2. 0.571429 -2.26994 0.477797 MAarrowhead1
% End of user PostScript
.08315 .66462 m
.02396 .6581 L
s
% Start of user PostScript
-2. 0.857143 -2.284 0.825855 MAarrowhead1
% End of user PostScript
.08315 .72417 m
.02381 .72918 L
s
% Start of user PostScript
-2. 1.14286 -2.2847 1.16687 MAarrowhead1
% End of user PostScript
.08315 .78372 m
.02545 .79845 L
s
% Start of user PostScript
-2. 1.42857 -2.27684 1.49922 MAarrowhead1
% End of user PostScript
.08315 .84327 m
.02809 .86595 L
s
% Start of user PostScript
-2. 1.71429 -2.26418 1.82311 MAarrowhead1
% End of user PostScript
.08315 .90282 m
.03119 .93191 L
s
% Start of user PostScript
-2. 2. -2.24931 2.13956 MAarrowhead1
% End of user PostScript
.1427 .06912 m
.19518 .04098 L
s
% Start of user PostScript
-1.71429 -2. -1.46248 -2.13501 MAarrowhead1
% End of user PostScript
.1427 .12867 m
.19348 .09756 L
s
% Start of user PostScript
-1.71429 -1.71429 -1.47065 -1.86353 MAarrowhead1
% End of user PostScript
.1427 .18822 m
.18942 .1513 L
s
% Start of user PostScript
-1.71429 -1.42857 -1.49012 -1.60572 MAarrowhead1
% End of user PostScript
.1427 .24777 m
.18183 .20288 L
s
% Start of user PostScript
-1.71429 -1.14286 -1.52655 -1.35824 MAarrowhead1
% End of user PostScript
.1427 .30732 m
.16924 .25401 L
s
% Start of user PostScript
-1.71429 -0.857143 -1.58694 -1.11291 MAarrowhead1
% End of user PostScript
.1427 .36687 m
.15109 .30791 L
s
% Start of user PostScript
-1.71429 -0.571429 -1.67403 -0.854293 MAarrowhead1
% End of user PostScript
.1427 .42642 m
.12947 .36836 L
s
% Start of user PostScript
-1.71429 -0.285714 -1.77776 -0.564289 MAarrowhead1
% End of user PostScript
.1427 .48597 m
.10914 .43678 L
s
% Start of user PostScript
-1.71429 0 -1.87529 -0.236029 MAarrowhead1
% End of user PostScript
.1427 .54552 m
.0943 .51083 L
s
% Start of user PostScript
-1.71429 0.285714 -1.94652 0.119285 MAarrowhead1
% End of user PostScript
.1427 .60507 m
.08607 .58666 L
s
% Start of user PostScript
-1.71429 0.571429 -1.98601 0.48311 MAarrowhead1
% End of user PostScript
.1427 .66462 m
.08324 .6614 L
s
% Start of user PostScript
-1.71429 0.857143 -1.99958 0.841689 MAarrowhead1
% End of user PostScript
.1427 .72417 m
.08393 .73376 L
s
% Start of user PostScript
-1.71429 1.14286 -1.99627 1.18887 MAarrowhead1
% End of user PostScript
.1427 .78372 m
.08655 .80355 L
s
% Start of user PostScript
-1.71429 1.42857 -1.9837 1.52371 MAarrowhead1
% End of user PostScript
.1427 .84327 m
.09003 .87107 L
s
% Start of user PostScript
-1.71429 1.71429 -1.96696 1.84765 MAarrowhead1
% End of user PostScript
.1427 .90282 m
.09377 .93676 L
s
% Start of user PostScript
-1.71429 2. -1.94906 2.16282 MAarrowhead1
% End of user PostScript
.20225 .06912 m
.2616 .06425 L
s
% Start of user PostScript
-1.42857 -2. -1.14381 -2.02338 MAarrowhead1
% End of user PostScript
.20225 .12867 m
.26124 .12056 L
s
% Start of user PostScript
-1.42857 -1.71429 -1.14552 -1.75321 MAarrowhead1
% End of user PostScript
.20225 .18822 m
.25992 .17337 L
s
% Start of user PostScript
-1.42857 -1.42857 -1.15189 -1.49983 MAarrowhead1
% End of user PostScript
.20225 .24777 m
.2562 .22255 L
s
% Start of user PostScript
-1.42857 -1.14286 -1.16974 -1.26385 MAarrowhead1
% End of user PostScript
.20225 .30732 m
.24747 .26858 L
s
% Start of user PostScript
-1.42857 -0.857143 -1.21159 -1.04303 MAarrowhead1
% End of user PostScript
.20225 .36687 m
.23031 .31434 L
s
% Start of user PostScript
-1.42857 -0.571429 -1.29396 -0.823443 MAarrowhead1
% End of user PostScript
.20225 .42642 m
.20392 .36689 L
s
% Start of user PostScript
-1.42857 -0.285714 -1.42053 -0.571315 MAarrowhead1
% End of user PostScript
.20225 .48597 m
.17544 .4328 L
s
% Start of user PostScript
-1.42857 0 -1.55722 -0.255112 MAarrowhead1
% End of user PostScript
.20225 .54552 m
.15479 .50955 L
s
% Start of user PostScript
-1.42857 0.285714 -1.65626 0.113118 MAarrowhead1
% End of user PostScript
.20225 .60507 m
.14485 .58921 L
s
% Start of user PostScript
-1.42857 0.571429 -1.70396 0.495317 MAarrowhead1
% End of user PostScript
.20225 .66462 m
.14273 .66654 L
s
% Start of user PostScript
-1.42857 0.857143 -1.71414 0.866358 MAarrowhead1
% End of user PostScript
.20225 .72417 m
.14485 .74002 L
s
% Start of user PostScript
-1.42857 1.14286 -1.70399 1.21888 MAarrowhead1
% End of user PostScript
.20225 .78372 m
.14877 .80992 L
s
% Start of user PostScript
-1.42857 1.42857 -1.68516 1.55426 MAarrowhead1
% End of user PostScript
.20225 .84327 m
.15319 .87703 L
s
% Start of user PostScript
-1.42857 1.71429 -1.66393 1.87627 MAarrowhead1
% End of user PostScript
.20225 .90282 m
.1575 .94212 L
s
% Start of user PostScript
-1.42857 2. -1.64325 2.18853 MAarrowhead1
% End of user PostScript
.2618 .06912 m
.31848 .08738 L
s
% Start of user PostScript
-1.14286 -2. -0.870902 -1.91241 MAarrowhead1
% End of user PostScript
.2618 .12867 m
.31934 .14402 L
s
% Start of user PostScript
-1.14286 -1.71429 -0.866793 -1.64065 MAarrowhead1
% End of user PostScript
.2618 .18822 m
.32061 .19759 L
s
% Start of user PostScript
-1.14286 -1.42857 -0.860705 -1.38359 MAarrowhead1
% End of user PostScript
.2618 .24777 m
.32135 .2473 L
s
% Start of user PostScript
-1.14286 -1.14286 -0.857152 -1.14512 MAarrowhead1
% End of user PostScript
.2618 .30732 m
.31931 .29186 L
s
% Start of user PostScript
-1.14286 -0.857143 -0.86694 -0.931319 MAarrowhead1
% End of user PostScript
.2618 .36687 m
.30928 .33093 L
s
% Start of user PostScript
-1.14286 -0.571429 -0.915033 -0.74385 MAarrowhead1
% End of user PostScript
.2618 .42642 m
.28326 .37087 L
s
% Start of user PostScript
-1.14286 -0.285714 -1.03987 -0.552223 MAarrowhead1
% End of user PostScript
.2618 .48597 m
.24422 .42907 L
s
% Start of user PostScript
-1.14286 0 -1.22719 -0.272985 MAarrowhead1
% End of user PostScript
.2618 .54552 m
.21459 .50923 L
s
% Start of user PostScript
-1.14286 0.285714 -1.36938 0.111588 MAarrowhead1
% End of user PostScript
.2618 .60507 m
.20322 .59435 L
s
% Start of user PostScript
-1.14286 0.571429 -1.4239 0.519979 MAarrowhead1
% End of user PostScript
.2618 .66462 m
.20306 .6744 L
s
% Start of user PostScript
-1.14286 0.857143 -1.42469 0.90408 MAarrowhead1
% End of user PostScript
.2618 .72417 m
.20736 .74831 L
s
% Start of user PostScript
-1.14286 1.14286 -1.40405 1.25867 MAarrowhead1
% End of user PostScript
.2618 .78372 m
.21279 .81755 L
s
% Start of user PostScript
-1.14286 1.42857 -1.37798 1.5909 MAarrowhead1
% End of user PostScript
.2618 .84327 m
.21805 .88367 L
s
% Start of user PostScript
-1.14286 1.71429 -1.35276 1.90813 MAarrowhead1
% End of user PostScript
.2618 .90282 m
.22272 .94775 L
s
% Start of user PostScript
-1.14286 2. -1.33036 2.21558 MAarrowhead1
% End of user PostScript
.32135 .06912 m
.36816 .10592 L
s
% Start of user PostScript
-0.857143 -2. -0.632531 -1.82342 MAarrowhead1
% End of user PostScript
.32135 .12867 m
.36973 .16339 L
s
% Start of user PostScript
-0.857143 -1.71429 -0.625007 -1.54772 MAarrowhead1
% End of user PostScript
.32135 .18822 m
.37245 .2188 L
s
% Start of user PostScript
-0.857143 -1.42857 -0.611969 -1.28187 MAarrowhead1
% End of user PostScript
.32135 .24777 m
.37608 .27125 L
s
% Start of user PostScript
-0.857143 -1.14286 -0.594569 -1.03022 MAarrowhead1
% End of user PostScript
.32135 .30732 m
.37978 .3188 L
s
% Start of user PostScript
-0.857143 -0.857143 -0.576788 -0.802062 MAarrowhead1
% End of user PostScript
.32135 .36687 m
.38021 .35785 L
s
% Start of user PostScript
-0.857143 -0.571429 -0.574727 -0.614717 MAarrowhead1
% End of user PostScript
.32135 .42642 m
.31003 .36795 L
s
% Start of user PostScript
-0.857143 -0.285714 -0.911435 -0.566223 MAarrowhead1
% End of user PostScript
.32135 .48597 m
.31129 .42728 L
s
% Start of user PostScript
-0.857143 0 -0.905418 -0.281606 MAarrowhead1
% End of user PostScript
.32135 .54552 m
.31229 .48666 L
s
% Start of user PostScript
-0.857143 0.285714 -0.900588 0.00332237 MAarrowhead1
% End of user PostScript
.32135 .60507 m
.26181 .60423 L
s
% Start of user PostScript
-0.857143 0.571429 -1.14283 0.567415 MAarrowhead1
% End of user PostScript
.32135 .66462 m
.26575 .68596 L
s
% Start of user PostScript
-0.857143 0.857143 -1.12388 0.959533 MAarrowhead1
% End of user PostScript
.32135 .72417 m
.27281 .75867 L
s
% Start of user PostScript
-0.857143 1.14286 -1.09003 1.30837 MAarrowhead1
% End of user PostScript
.32135 .78372 m
.2795 .82609 L
s
% Start of user PostScript
-0.857143 1.42857 -1.05794 1.63183 MAarrowhead1
% End of user PostScript
.32135 .84327 m
.28511 .89052 L
s
% Start of user PostScript
-0.857143 1.71429 -1.03103 1.941 MAarrowhead1
% End of user PostScript
.32135 .90282 m
.28967 .95324 L
s
% Start of user PostScript
-0.857143 2. -1.00914 2.24193 MAarrowhead1
% End of user PostScript
.3809 .06912 m
.41377 .11877 L
s
% Start of user PostScript
-0.571429 -2. -0.413697 -1.76177 MAarrowhead1
% End of user PostScript
.3809 .12867 m
.41537 .17723 L
s
% Start of user PostScript
-0.571429 -1.71429 -0.406062 -1.48129 MAarrowhead1
% End of user PostScript
.3809 .18822 m
.41816 .23467 L
s
% Start of user PostScript
-0.571429 -1.42857 -0.392668 -1.20569 MAarrowhead1
% End of user PostScript
.3809 .24777 m
.42234 .29054 L
s
% Start of user PostScript
-0.571429 -1.14286 -0.372622 -0.937653 MAarrowhead1
% End of user PostScript
.3809 .30732 m
.4282 .3435 L
s
% Start of user PostScript
-0.571429 -0.857143 -0.344509 -0.683534 MAarrowhead1
% End of user PostScript
.3809 .36687 m
.37217 .30796 L
s
% Start of user PostScript
-0.571429 -0.571429 -0.6133 -0.854058 MAarrowhead1
% End of user PostScript
.3809 .42642 m
.37328 .36736 L
s
% Start of user PostScript
-0.571429 -0.285714 -0.607992 -0.569079 MAarrowhead1
% End of user PostScript
.3809 .48597 m
.37414 .4268 L
s
% Start of user PostScript
-0.571429 0 -0.60387 -0.283866 MAarrowhead1
% End of user PostScript
.3809 .54552 m
.37482 .48628 L
s
% Start of user PostScript
-0.571429 0.285714 -0.60058 0.00149102 MAarrowhead1
% End of user PostScript
.3809 .60507 m
.37538 .54578 L
s
% Start of user PostScript
-0.571429 0.571429 -0.597892 0.286943 MAarrowhead1
% End of user PostScript
.3809 .66462 m
.33399 .70131 L
s
% Start of user PostScript
-0.571429 0.857143 -0.796487 1.03316 MAarrowhead1
% End of user PostScript
.3809 .72417 m
.34299 .7701 L
s
% Start of user PostScript
-0.571429 1.14286 -0.753315 1.3632 MAarrowhead1
% End of user PostScript
.3809 .78372 m
.34972 .83445 L
s
% Start of user PostScript
-0.571429 1.42857 -0.721048 1.67198 MAarrowhead1
% End of user PostScript
.3809 .84327 m
.35469 .89674 L
s
% Start of user PostScript
-0.571429 1.71429 -0.697199 1.97083 MAarrowhead1
% End of user PostScript
.3809 .90282 m
.35843 .95797 L
s
% Start of user PostScript
-0.571429 2. -0.679231 2.2646 MAarrowhead1
% End of user PostScript
.44045 .06912 m
.45733 .12623 L
s
% Start of user PostScript
-0.285714 -2. -0.204744 -1.726 MAarrowhead1
% End of user PostScript
.44045 .12867 m
.45831 .18548 L
s
% Start of user PostScript
-0.285714 -1.71429 -0.200034 -1.44172 MAarrowhead1
% End of user PostScript
.44045 .18822 m
.46002 .24446 L
s
% Start of user PostScript
-0.285714 -1.42857 -0.191796 -1.15873 MAarrowhead1
% End of user PostScript
.44045 .24777 m
.46267 .30302 L
s
% Start of user PostScript
-0.285714 -1.14286 -0.179087 -0.877785 MAarrowhead1
% End of user PostScript
.44045 .30732 m
.43529 .24799 L
s
% Start of user PostScript
-0.285714 -0.857143 -0.310466 -1.14178 MAarrowhead1
% End of user PostScript
.44045 .36687 m
.43605 .30748 L
s
% Start of user PostScript
-0.285714 -0.571429 -0.30682 -0.856362 MAarrowhead1
% End of user PostScript
.44045 .42642 m
.43662 .36699 L
s
% Start of user PostScript
-0.285714 -0.285714 -0.304109 -0.570836 MAarrowhead1
% End of user PostScript
.44045 .48597 m
.43705 .42652 L
s
% Start of user PostScript
-0.285714 0 -0.302014 -0.285249 MAarrowhead1
% End of user PostScript
.44045 .54552 m
.4374 .48605 L
s
% Start of user PostScript
-0.285714 0.285714 -0.300347 0.000374953 MAarrowhead1
% End of user PostScript
.44045 .60507 m
.43768 .54558 L
s
% Start of user PostScript
-0.285714 0.571429 -0.298989 0.286023 MAarrowhead1
% End of user PostScript
.44045 .66462 m
.43792 .60512 L
s
% Start of user PostScript
-0.285714 0.857143 -0.297861 0.571687 MAarrowhead1
% End of user PostScript
.44045 .72417 m
.41917 .77979 L
s
% Start of user PostScript
-0.285714 1.14286 -0.387817 1.4097 MAarrowhead1
% End of user PostScript
.44045 .78372 m
.42361 .84084 L
s
% Start of user PostScript
-0.285714 1.42857 -0.366487 1.70263 MAarrowhead1
% End of user PostScript
.44045 .84327 m
.42661 .90119 L
s
% Start of user PostScript
-0.285714 1.71429 -0.3521 1.99218 MAarrowhead1
% End of user PostScript
.44045 .90282 m
.42876 .96121 L
s
% Start of user PostScript
-0.285714 2. -0.341823 2.28015 MAarrowhead1
% End of user PostScript
.5 .06912 m
.5 .12867 L
s
% Start of user PostScript
0 -2. 0 -1.71429 MAarrowhead1
% End of user PostScript
.5 .12867 m
.5 .18822 L
s
% Start of user PostScript
0 -1.71429 0 -1.42857 MAarrowhead1
% End of user PostScript
.5 .18822 m
.5 .24777 L
s
% Start of user PostScript
0 -1.42857 0 -1.14286 MAarrowhead1
% End of user PostScript
.5 .24777 m
.5 .30732 L
s
% Start of user PostScript
0 -1.14286 0 -0.857143 MAarrowhead1
% End of user PostScript
.5 .30732 m
.5 .24777 L
s
% Start of user PostScript
0 -0.857143 0 -1.14286 MAarrowhead1
% End of user PostScript
.5 .36687 m
.5 .30732 L
s
% Start of user PostScript
0 -0.571429 0 -0.857143 MAarrowhead1
% End of user PostScript
.5 .42642 m
.5 .36687 L
s
% Start of user PostScript
0 -0.285714 0 -0.571429 MAarrowhead1
% End of user PostScript
.5 .48597 m
.5 .42642 L
s
% Start of user PostScript
0 0 0 -0.285714 MAarrowhead1
% End of user PostScript
.5 .54552 m
.5 .48597 L
s
% Start of user PostScript
0 0.285714 0 0 MAarrowhead1
% End of user PostScript
.5 .60507 m
.5 .54552 L
s
% Start of user PostScript
0 0.571429 0 0.285714 MAarrowhead1
% End of user PostScript
.5 .66462 m
.5 .60507 L
s
% Start of user PostScript
0 0.857143 0 0.571429 MAarrowhead1
% End of user PostScript
.5 .72417 m
.5 .78372 L
s
% Start of user PostScript
0 1.14286 0 1.42857 MAarrowhead1
% End of user PostScript
.5 .78372 m
.5 .84327 L
s
% Start of user PostScript
0 1.42857 0 1.71429 MAarrowhead1
% End of user PostScript
.5 .84327 m
.5 .90282 L
s
% Start of user PostScript
0 1.71429 0 2. MAarrowhead1
% End of user PostScript
.5 .90282 m
.5 .96237 L
s
% Start of user PostScript
0 2. 0 2.28571 MAarrowhead1
% End of user PostScript
.55955 .06912 m
.54267 .12623 L
s
% Start of user PostScript
0.285714 -2. 0.204744 -1.726 MAarrowhead1
% End of user PostScript
.55955 .12867 m
.54169 .18548 L
s
% Start of user PostScript
0.285714 -1.71429 0.200034 -1.44172 MAarrowhead1
% End of user PostScript
.55955 .18822 m
.53998 .24446 L
s
% Start of user PostScript
0.285714 -1.42857 0.191796 -1.15873 MAarrowhead1
% End of user PostScript
.55955 .24777 m
.53733 .30302 L
s
% Start of user PostScript
0.285714 -1.14286 0.179087 -0.877785 MAarrowhead1
% End of user PostScript
.55955 .30732 m
.56471 .24799 L
s
% Start of user PostScript
0.285714 -0.857143 0.310466 -1.14178 MAarrowhead1
% End of user PostScript
.55955 .36687 m
.56395 .30748 L
s
% Start of user PostScript
0.285714 -0.571429 0.30682 -0.856362 MAarrowhead1
% End of user PostScript
.55955 .42642 m
.56338 .36699 L
s
% Start of user PostScript
0.285714 -0.285714 0.304109 -0.570836 MAarrowhead1
% End of user PostScript
.55955 .48597 m
.56295 .42652 L
s
% Start of user PostScript
0.285714 0 0.302014 -0.285249 MAarrowhead1
% End of user PostScript
.55955 .54552 m
.5626 .48605 L
s
% Start of user PostScript
0.285714 0.285714 0.300347 0.000374953 MAarrowhead1
% End of user PostScript
.55955 .60507 m
.56232 .54558 L
s
% Start of user PostScript
0.285714 0.571429 0.298989 0.286023 MAarrowhead1
% End of user PostScript
.55955 .66462 m
.56208 .60512 L
s
% Start of user PostScript
0.285714 0.857143 0.297861 0.571687 MAarrowhead1
% End of user PostScript
.55955 .72417 m
.58083 .77979 L
s
% Start of user PostScript
0.285714 1.14286 0.387817 1.4097 MAarrowhead1
% End of user PostScript
.55955 .78372 m
.57639 .84084 L
s
% Start of user PostScript
0.285714 1.42857 0.366487 1.70263 MAarrowhead1
% End of user PostScript
.55955 .84327 m
.57339 .90119 L
s
% Start of user PostScript
0.285714 1.71429 0.3521 1.99218 MAarrowhead1
% End of user PostScript
.55955 .90282 m
.57124 .96121 L
s
% Start of user PostScript
0.285714 2. 0.341823 2.28015 MAarrowhead1
% End of user PostScript
.6191 .06912 m
.58623 .11877 L
s
% Start of user PostScript
0.571429 -2. 0.413697 -1.76177 MAarrowhead1
% End of user PostScript
.6191 .12867 m
.58463 .17723 L
s
% Start of user PostScript
0.571429 -1.71429 0.406062 -1.48129 MAarrowhead1
% End of user PostScript
.6191 .18822 m
.58184 .23467 L
s
% Start of user PostScript
0.571429 -1.42857 0.392668 -1.20569 MAarrowhead1
% End of user PostScript
.6191 .24777 m
.57766 .29054 L
s
% Start of user PostScript
0.571429 -1.14286 0.372622 -0.937653 MAarrowhead1
% End of user PostScript
.6191 .30732 m
.5718 .3435 L
s
% Start of user PostScript
0.571429 -0.857143 0.344509 -0.683534 MAarrowhead1
% End of user PostScript
.6191 .36687 m
.62783 .30796 L
s
% Start of user PostScript
0.571429 -0.571429 0.6133 -0.854058 MAarrowhead1
% End of user PostScript
.6191 .42642 m
.62672 .36736 L
s
% Start of user PostScript
0.571429 -0.285714 0.607992 -0.569079 MAarrowhead1
% End of user PostScript
.6191 .48597 m
.62586 .4268 L
s
% Start of user PostScript
0.571429 0 0.60387 -0.283866 MAarrowhead1
% End of user PostScript
.6191 .54552 m
.62518 .48628 L
s
% Start of user PostScript
0.571429 0.285714 0.60058 0.00149102 MAarrowhead1
% End of user PostScript
.6191 .60507 m
.62462 .54578 L
s
% Start of user PostScript
0.571429 0.571429 0.597892 0.286943 MAarrowhead1
% End of user PostScript
.6191 .66462 m
.66601 .70131 L
s
% Start of user PostScript
0.571429 0.857143 0.796487 1.03316 MAarrowhead1
% End of user PostScript
.6191 .72417 m
.65701 .7701 L
s
% Start of user PostScript
0.571429 1.14286 0.753315 1.3632 MAarrowhead1
% End of user PostScript
.6191 .78372 m
.65028 .83445 L
s
% Start of user PostScript
0.571429 1.42857 0.721048 1.67198 MAarrowhead1
% End of user PostScript
.6191 .84327 m
.64531 .89674 L
s
% Start of user PostScript
0.571429 1.71429 0.697199 1.97083 MAarrowhead1
% End of user PostScript
.6191 .90282 m
.64157 .95797 L
s
% Start of user PostScript
0.571429 2. 0.679231 2.2646 MAarrowhead1
% End of user PostScript
.67865 .06912 m
.63184 .10592 L
s
% Start of user PostScript
0.857143 -2. 0.632531 -1.82342 MAarrowhead1
% End of user PostScript
.67865 .12867 m
.63027 .16339 L
s
% Start of user PostScript
0.857143 -1.71429 0.625007 -1.54772 MAarrowhead1
% End of user PostScript
.67865 .18822 m
.62755 .2188 L
s
% Start of user PostScript
0.857143 -1.42857 0.611969 -1.28187 MAarrowhead1
% End of user PostScript
.67865 .24777 m
.62392 .27125 L
s
% Start of user PostScript
0.857143 -1.14286 0.594569 -1.03022 MAarrowhead1
% End of user PostScript
.67865 .30732 m
.62022 .3188 L
s
% Start of user PostScript
0.857143 -0.857143 0.576788 -0.802062 MAarrowhead1
% End of user PostScript
.67865 .36687 m
.61979 .35785 L
s
% Start of user PostScript
0.857143 -0.571429 0.574727 -0.614717 MAarrowhead1
% End of user PostScript
.67865 .42642 m
.68997 .36795 L
s
% Start of user PostScript
0.857143 -0.285714 0.911435 -0.566223 MAarrowhead1
% End of user PostScript
.67865 .48597 m
.68871 .42728 L
s
% Start of user PostScript
0.857143 0 0.905418 -0.281606 MAarrowhead1
% End of user PostScript
.67865 .54552 m
.68771 .48666 L
s
% Start of user PostScript
0.857143 0.285714 0.900588 0.00332237 MAarrowhead1
% End of user PostScript
.67865 .60507 m
.73819 .60423 L
s
% Start of user PostScript
0.857143 0.571429 1.14283 0.567415 MAarrowhead1
% End of user PostScript
.67865 .66462 m
.73425 .68596 L
s
% Start of user PostScript
0.857143 0.857143 1.12388 0.959533 MAarrowhead1
% End of user PostScript
.67865 .72417 m
.72719 .75867 L
s
% Start of user PostScript
0.857143 1.14286 1.09003 1.30837 MAarrowhead1
% End of user PostScript
.67865 .78372 m
.7205 .82609 L
s
% Start of user PostScript
0.857143 1.42857 1.05794 1.63183 MAarrowhead1
% End of user PostScript
.67865 .84327 m
.71489 .89052 L
s
% Start of user PostScript
0.857143 1.71429 1.03103 1.941 MAarrowhead1
% End of user PostScript
.67865 .90282 m
.71033 .95324 L
s
% Start of user PostScript
0.857143 2. 1.00914 2.24193 MAarrowhead1
% End of user PostScript
.7382 .06912 m
.68152 .08738 L
s
% Start of user PostScript
1.14286 -2. 0.870902 -1.91241 MAarrowhead1
% End of user PostScript
.7382 .12867 m
.68066 .14402 L
s
% Start of user PostScript
1.14286 -1.71429 0.866793 -1.64065 MAarrowhead1
% End of user PostScript
.7382 .18822 m
.67939 .19759 L
s
% Start of user PostScript
1.14286 -1.42857 0.860705 -1.38359 MAarrowhead1
% End of user PostScript
.7382 .24777 m
.67865 .2473 L
s
% Start of user PostScript
1.14286 -1.14286 0.857152 -1.14512 MAarrowhead1
% End of user PostScript
.7382 .30732 m
.68069 .29186 L
s
% Start of user PostScript
1.14286 -0.857143 0.86694 -0.931319 MAarrowhead1
% End of user PostScript
.7382 .36687 m
.69072 .33093 L
s
% Start of user PostScript
1.14286 -0.571429 0.915033 -0.74385 MAarrowhead1
% End of user PostScript
.7382 .42642 m
.71674 .37087 L
s
% Start of user PostScript
1.14286 -0.285714 1.03987 -0.552223 MAarrowhead1
% End of user PostScript
.7382 .48597 m
.75578 .42907 L
s
% Start of user PostScript
1.14286 0 1.22719 -0.272985 MAarrowhead1
% End of user PostScript
.7382 .54552 m
.78541 .50923 L
s
% Start of user PostScript
1.14286 0.285714 1.36938 0.111588 MAarrowhead1
% End of user PostScript
.7382 .60507 m
.79678 .59435 L
s
% Start of user PostScript
1.14286 0.571429 1.4239 0.519979 MAarrowhead1
% End of user PostScript
.7382 .66462 m
.79694 .6744 L
s
% Start of user PostScript
1.14286 0.857143 1.42469 0.90408 MAarrowhead1
% End of user PostScript
.7382 .72417 m
.79264 .74831 L
s
% Start of user PostScript
1.14286 1.14286 1.40405 1.25867 MAarrowhead1
% End of user PostScript
.7382 .78372 m
.78721 .81755 L
s
% Start of user PostScript
1.14286 1.42857 1.37798 1.5909 MAarrowhead1
% End of user PostScript
.7382 .84327 m
.78195 .88367 L
s
% Start of user PostScript
1.14286 1.71429 1.35276 1.90813 MAarrowhead1
% End of user PostScript
.7382 .90282 m
.77728 .94775 L
s
% Start of user PostScript
1.14286 2. 1.33036 2.21558 MAarrowhead1
% End of user PostScript
.79775 .06912 m
.7384 .06425 L
s
% Start of user PostScript
1.42857 -2. 1.14381 -2.02338 MAarrowhead1
% End of user PostScript
.79775 .12867 m
.73876 .12056 L
s
% Start of user PostScript
1.42857 -1.71429 1.14552 -1.75321 MAarrowhead1
% End of user PostScript
.79775 .18822 m
.74008 .17337 L
s
% Start of user PostScript
1.42857 -1.42857 1.15189 -1.49983 MAarrowhead1
% End of user PostScript
.79775 .24777 m
.7438 .22255 L
s
% Start of user PostScript
1.42857 -1.14286 1.16974 -1.26385 MAarrowhead1
% End of user PostScript
.79775 .30732 m
.75253 .26858 L
s
% Start of user PostScript
1.42857 -0.857143 1.21159 -1.04303 MAarrowhead1
% End of user PostScript
.79775 .36687 m
.76969 .31434 L
s
% Start of user PostScript
1.42857 -0.571429 1.29396 -0.823443 MAarrowhead1
% End of user PostScript
.79775 .42642 m
.79608 .36689 L
s
% Start of user PostScript
1.42857 -0.285714 1.42053 -0.571315 MAarrowhead1
% End of user PostScript
.79775 .48597 m
.82456 .4328 L
s
% Start of user PostScript
1.42857 0 1.55722 -0.255112 MAarrowhead1
% End of user PostScript
.79775 .54552 m
.84521 .50955 L
s
% Start of user PostScript
1.42857 0.285714 1.65626 0.113118 MAarrowhead1
% End of user PostScript
.79775 .60507 m
.85515 .58921 L
s
% Start of user PostScript
1.42857 0.571429 1.70396 0.495317 MAarrowhead1
% End of user PostScript
.79775 .66462 m
.85727 .66654 L
s
% Start of user PostScript
1.42857 0.857143 1.71414 0.866358 MAarrowhead1
% End of user PostScript
.79775 .72417 m
.85515 .74002 L
s
% Start of user PostScript
1.42857 1.14286 1.70399 1.21888 MAarrowhead1
% End of user PostScript
.79775 .78372 m
.85123 .80992 L
s
% Start of user PostScript
1.42857 1.42857 1.68516 1.55426 MAarrowhead1
% End of user PostScript
.79775 .84327 m
.84681 .87703 L
s
% Start of user PostScript
1.42857 1.71429 1.66393 1.87627 MAarrowhead1
% End of user PostScript
.79775 .90282 m
.8425 .94212 L
s
% Start of user PostScript
1.42857 2. 1.64325 2.18853 MAarrowhead1
% End of user PostScript
.8573 .06912 m
.80482 .04098 L
s
% Start of user PostScript
1.71429 -2. 1.46248 -2.13501 MAarrowhead1
% End of user PostScript
.8573 .12867 m
.80652 .09756 L
s
% Start of user PostScript
1.71429 -1.71429 1.47065 -1.86353 MAarrowhead1
% End of user PostScript
.8573 .18822 m
.81058 .1513 L
s
% Start of user PostScript
1.71429 -1.42857 1.49012 -1.60572 MAarrowhead1
% End of user PostScript
.8573 .24777 m
.81817 .20288 L
s
% Start of user PostScript
1.71429 -1.14286 1.52655 -1.35824 MAarrowhead1
% End of user PostScript
.8573 .30732 m
.83076 .25401 L
s
% Start of user PostScript
1.71429 -0.857143 1.58694 -1.11291 MAarrowhead1
% End of user PostScript
.8573 .36687 m
.84891 .30791 L
s
% Start of user PostScript
1.71429 -0.571429 1.67403 -0.854293 MAarrowhead1
% End of user PostScript
.8573 .42642 m
.87053 .36836 L
s
% Start of user PostScript
1.71429 -0.285714 1.77776 -0.564289 MAarrowhead1
% End of user PostScript
.8573 .48597 m
.89086 .43678 L
s
% Start of user PostScript
1.71429 0 1.87529 -0.236029 MAarrowhead1
% End of user PostScript
.8573 .54552 m
.9057 .51083 L
s
% Start of user PostScript
1.71429 0.285714 1.94652 0.119285 MAarrowhead1
% End of user PostScript
.8573 .60507 m
.91393 .58666 L
s
% Start of user PostScript
1.71429 0.571429 1.98601 0.48311 MAarrowhead1
% End of user PostScript
.8573 .66462 m
.91676 .6614 L
s
% Start of user PostScript
1.71429 0.857143 1.99958 0.841689 MAarrowhead1
% End of user PostScript
.8573 .72417 m
.91607 .73376 L
s
% Start of user PostScript
1.71429 1.14286 1.99627 1.18887 MAarrowhead1
% End of user PostScript
.8573 .78372 m
.91345 .80355 L
s
% Start of user PostScript
1.71429 1.42857 1.9837 1.52371 MAarrowhead1
% End of user PostScript
.8573 .84327 m
.90997 .87107 L
s
% Start of user PostScript
1.71429 1.71429 1.96696 1.84765 MAarrowhead1
% End of user PostScript
.8573 .90282 m
.90623 .93676 L
s
% Start of user PostScript
1.71429 2. 1.94906 2.16282 MAarrowhead1
% End of user PostScript
.91685 .06912 m
.87861 .02347 L
s
% Start of user PostScript
2. -2. 1.81651 -2.21901 MAarrowhead1
% End of user PostScript
.91685 .12867 m
.88142 .0808 L
s
% Start of user PostScript
2. -1.71429 1.83003 -1.94394 MAarrowhead1
% End of user PostScript
.91685 .18822 m
.8871 .13663 L
s
% Start of user PostScript
2. -1.42857 1.85728 -1.67608 MAarrowhead1
% End of user PostScript
.91685 .24777 m
.89617 .19193 L
s
% Start of user PostScript
2. -1.14286 1.90075 -1.41078 MAarrowhead1
% End of user PostScript
.91685 .30732 m
.90882 .24831 L
s
% Start of user PostScript
2. -0.857143 1.96148 -1.14025 MAarrowhead1
% End of user PostScript
.91685 .36687 m
.92435 .30779 L
s
% Start of user PostScript
2. -0.571429 2.03596 -0.854871 MAarrowhead1
% End of user PostScript
.91685 .42642 m
.94075 .37187 L
s
% Start of user PostScript
2. -0.285714 2.11465 -0.547418 MAarrowhead1
% End of user PostScript
.91685 .48597 m
.95542 .4406 L
s
% Start of user PostScript
2. 0 2.18504 -0.217697 MAarrowhead1
% End of user PostScript
.91685 .54552 m
.96641 .5125 L
s
% Start of user PostScript
2. 0.285714 2.23776 0.127283 MAarrowhead1
% End of user PostScript
.91685 .60507 m
.97311 .58556 L
s
% Start of user PostScript
2. 0.571429 2.26994 0.477797 MAarrowhead1
% End of user PostScript
.91685 .66462 m
.97604 .6581 L
s
% Start of user PostScript
2. 0.857143 2.284 0.825855 MAarrowhead1
% End of user PostScript
.91685 .72417 m
.97619 .72918 L
s
% Start of user PostScript
2. 1.14286 2.2847 1.16687 MAarrowhead1
% End of user PostScript
.91685 .78372 m
.97455 .79845 L
s
% Start of user PostScript
2. 1.42857 2.27684 1.49922 MAarrowhead1
% End of user PostScript
.91685 .84327 m
.97191 .86595 L
s
% Start of user PostScript
2. 1.71429 2.26418 1.82311 MAarrowhead1
% End of user PostScript
.91685 .90282 m
.96881 .93191 L
s
% Start of user PostScript
2. 2. 2.24931 2.13956 MAarrowhead1
% End of user PostScript
.5 Mabswid
.47448 .66423 m
.49149 .66402 L
.50851 .66402 L
.52552 .66423 L
.54205 .66462 L
.54254 .66464 L
.55955 .66509 L
.57656 .66586 L
.59056 .68163 L
.57656 .68959 L
.55955 .69667 L
.55527 .69865 L
.54254 .70767 L
.52552 .70833 L
.50851 .71021 L
.49149 .71021 L
.47448 .70833 L
.45746 .70767 L
.44473 .69865 L
.44045 .69667 L
.42344 .68959 L
.40944 .68163 L
.42344 .66586 L
.44045 .66509 L
.45746 .66464 L
.45795 .66462 L
.47448 .66423 L
s
.37239 .63926 m
.38941 .63905 L
.40642 .63824 L
.42344 .63716 L
.44045 .6363 L
.45746 .63565 L
.47448 .63522 L
.49149 .635 L
.50851 .635 L
.52552 .63522 L
.54254 .63565 L
.55955 .6363 L
.57656 .63716 L
.59358 .63824 L
.61059 .63905 L
.62761 .63926 L
.63409 .64761 L
.62761 .66045 L
.62513 .66462 L
.61059 .6813 L
.61015 .68163 L
.59358 .69793 L
.58963 .69865 L
.57656 .70669 L
.55955 .71482 L
.5573 .71566 L
.54254 .72047 L
.52552 .72415 L
.50851 .72597 L
.49149 .72597 L
.47448 .72415 L
.45746 .72047 L
.4427 .71566 L
.44045 .71482 L
.42344 .70669 L
.41037 .69865 L
.40642 .69793 L
.38985 .68163 L
.38941 .6813 L
.37487 .66462 L
.37239 .66045 L
.36591 .64761 L
.37239 .63926 L
s
.35538 .61277 m
.37239 .61098 L
.38941 .60941 L
.40642 .60806 L
.42344 .60693 L
.44045 .60603 L
.45746 .60535 L
.47448 .6049 L
.49149 .60467 L
.50851 .60467 L
.52552 .6049 L
.54254 .60535 L
.55955 .60603 L
.57656 .60693 L
.59358 .60806 L
.61059 .60941 L
.62761 .61098 L
.64462 .61277 L
.65869 .61358 L
.66063 .63059 L
.65542 .64761 L
.64708 .66462 L
.64462 .66885 L
.63596 .68163 L
.62761 .6918 L
.6211 .69865 L
.61059 .70818 L
.6009 .71566 L
.59358 .72058 L
.57656 .73008 L
.57102 .73268 L
.55955 .73724 L
.54254 .74238 L
.52552 .74573 L
.50851 .74737 L
.49149 .74737 L
.47448 .74573 L
.45746 .74238 L
.44045 .73724 L
.42898 .73268 L
.42344 .73008 L
.40642 .72058 L
.3991 .71566 L
.38941 .70818 L
.3789 .69865 L
.37239 .6918 L
.36404 .68163 L
.35538 .66885 L
.35292 .66462 L
.34458 .64761 L
Mistroke
.33937 .63059 L
.34131 .61358 L
.35538 .61277 L
Mfstroke
.37239 .57946 m
.38941 .57781 L
.40642 .57639 L
.42344 .57521 L
.44045 .57426 L
.45746 .57354 L
.47448 .57307 L
.49149 .57283 L
.50851 .57283 L
.52552 .57307 L
.54254 .57354 L
.55955 .57426 L
.57656 .57521 L
.59358 .57639 L
.61059 .57781 L
.62761 .57946 L
.62846 .57955 L
.64462 .58134 L
.66164 .58345 L
.67865 .58588 L
.68523 .59656 L
.68491 .61358 L
.6832 .63059 L
.67956 .64761 L
.67865 .65083 L
.67374 .66462 L
.66561 .68163 L
.66164 .68847 L
.65485 .69865 L
.64462 .71153 L
.6409 .71566 L
.62761 .72854 L
.62272 .73268 L
.61059 .74176 L
.59803 .74969 L
.59358 .75218 L
.57656 .76035 L
.55955 .76661 L
.55925 .76671 L
.54254 .77115 L
.52552 .77411 L
.50851 .77557 L
.49149 .77557 L
.47448 .77411 L
.45746 .77115 L
.44075 .76671 L
.44045 .76661 L
.42344 .76035 L
.40642 .75218 L
.40197 .74969 L
Mistroke
.38941 .74176 L
.37728 .73268 L
.37239 .72854 L
.3591 .71566 L
.35538 .71153 L
.34515 .69865 L
.33836 .68847 L
.33439 .68163 L
.32626 .66462 L
.32135 .65083 L
.32044 .64761 L
.3168 .63059 L
.31509 .61358 L
.31477 .59656 L
.32135 .58588 L
.33836 .58345 L
.35538 .58134 L
.37154 .57955 L
.37239 .57946 L
Mfstroke
.38941 .54449 m
.40642 .54299 L
.42344 .54174 L
.44045 .54074 L
.45746 .53998 L
.47448 .53948 L
.49149 .53923 L
.50851 .53923 L
.52552 .53948 L
.54254 .53998 L
.55955 .54074 L
.57656 .54174 L
.59358 .54299 L
.61059 .54449 L
.6209 .54552 L
.62761 .54624 L
.64462 .54823 L
.66164 .55046 L
.67865 .55292 L
.69566 .55536 L
.70618 .56253 L
.70736 .57955 L
.71113 .59656 L
.71268 .6073 L
.71321 .61358 L
.71333 .63059 L
.71268 .6392 L
.71159 .64761 L
.70803 .66462 L
.70263 .68163 L
.69566 .69785 L
.69527 .69865 L
.68576 .71566 L
.67865 .72623 L
.6738 .73268 L
.66164 .74679 L
.65884 .74969 L
.64462 .76289 L
.63998 .76671 L
.62761 .77588 L
.61535 .78372 L
.61059 .78646 L
.59358 .79504 L
.5798 .80074 L
.57656 .80191 L
.55955 .80722 L
.54254 .81112 L
.52552 .81368 L
.50851 .81495 L
.49149 .81495 L
Mistroke
.47448 .81368 L
.45746 .81112 L
.44045 .80722 L
.42344 .80191 L
.4202 .80074 L
.40642 .79504 L
.38941 .78646 L
.38465 .78372 L
.37239 .77588 L
.36002 .76671 L
.35538 .76289 L
.34116 .74969 L
.33836 .74679 L
.3262 .73268 L
.32135 .72623 L
.31424 .71566 L
.30473 .69865 L
.30434 .69785 L
.29737 .68163 L
.29197 .66462 L
.28841 .64761 L
.28732 .6392 L
.28667 .63059 L
.28679 .61358 L
.28732 .6073 L
.28887 .59656 L
.29264 .57955 L
.29382 .56253 L
.30434 .55536 L
.32135 .55292 L
.33836 .55046 L
.35538 .54823 L
.37239 .54624 L
.3791 .54552 L
.38941 .54449 L
Mfstroke
.37239 .511 m
.38941 .50914 L
.40642 .50754 L
.42344 .50621 L
.44045 .50514 L
.45746 .50433 L
.47448 .5038 L
.49149 .50353 L
.50851 .50353 L
.52552 .5038 L
.54254 .50433 L
.55955 .50514 L
.57656 .50621 L
.59358 .50754 L
.61059 .50914 L
.62761 .511 L
.63176 .51149 L
.64462 .51312 L
.66164 .51549 L
.67865 .51811 L
.69566 .52098 L
.71239 .52851 L
.71268 .5291 L
.72765 .54552 L
.72969 .5483 L
.73868 .56253 L
.74671 .5795 L
.74673 .57955 L
.75237 .59656 L
.75602 .61358 L
.75792 .63059 L
.75821 .64761 L
.75696 .66462 L
.75422 .68163 L
.74998 .69865 L
.74671 .70887 L
.74419 .71566 L
.73679 .73268 L
.72969 .74615 L
.72763 .74969 L
.71653 .76671 L
.71268 .77194 L
.70318 .78372 L
.69566 .79208 L
.68713 .80074 L
.67865 .80855 L
.66761 .81775 L
.66164 .82231 L
.64462 .8339 L
.64324 .83476 L
Mistroke
.62761 .84369 L
.61089 .85178 L
.61059 .85191 L
.59358 .85872 L
.57656 .86425 L
.55955 .86858 L
.55865 .86879 L
.54254 .87178 L
.52552 .87389 L
.50851 .87494 L
.49149 .87494 L
.47448 .87389 L
.45746 .87178 L
.44135 .86879 L
.44045 .86858 L
.42344 .86425 L
.40642 .85872 L
.38941 .85191 L
.38911 .85178 L
.37239 .84369 L
.35676 .83476 L
.35538 .8339 L
.33836 .82231 L
.33239 .81775 L
.32135 .80855 L
.31287 .80074 L
.30434 .79208 L
.29682 .78372 L
.28732 .77194 L
.28347 .76671 L
.27237 .74969 L
.27031 .74615 L
.26321 .73268 L
.25581 .71566 L
.25329 .70887 L
.25002 .69865 L
.24578 .68163 L
.24304 .66462 L
.24179 .64761 L
.24208 .63059 L
.24398 .61358 L
.24763 .59656 L
.25327 .57955 L
.25329 .5795 L
.26132 .56253 L
.27031 .5483 L
.27235 .54552 L
.28732 .5291 L
.28761 .52851 L
.30434 .52098 L
Mistroke
.32135 .51811 L
.33836 .51549 L
.35538 .51312 L
.36824 .51149 L
.37239 .511 L
Mfstroke
.72383 .90282 m
.72969 .89796 L
.74328 .88581 L
.74671 .88252 L
.76004 .86879 L
.76372 .86471 L
.7746 .85178 L
.78074 .84383 L
.78727 .83476 L
.79775 .81865 L
.7983 .81775 L
.80784 .80074 L
.81477 .78651 L
.81602 .78372 L
.82292 .76671 L
.82863 .74969 L
.83178 .73842 L
.83317 .73268 L
.83659 .71566 L
.83888 .69865 L
.84005 .68163 L
.84007 .66462 L
.83891 .64761 L
.8365 .63059 L
.83275 .61358 L
.83178 .60991 L
.82751 .59656 L
.8206 .57955 L
.81477 .56791 L
.81169 .56253 L
.8003 .54552 L
.79775 .54222 L
.78555 .52851 L
.78074 .52385 L
.7656 .51149 L
.76372 .51017 L
.74671 .49995 L
.73474 .49448 L
.72969 .49253 L
.71268 .48746 L
.69566 .48403 L
.67865 .48095 L
.66164 .47814 L
.65728 .47746 L
.64462 .4756 L
.62761 .47332 L
.61059 .47133 L
.59358 .46961 L
.57656 .46817 L
.55955 .46702 L
Mistroke
.54254 .46616 L
.52552 .46558 L
.50851 .46529 L
.49149 .46529 L
.47448 .46558 L
.45746 .46616 L
.44045 .46702 L
.42344 .46817 L
.40642 .46961 L
.38941 .47133 L
.37239 .47332 L
.35538 .4756 L
.34272 .47746 L
.33836 .47814 L
.32135 .48095 L
.30434 .48403 L
.28732 .48746 L
.27031 .49253 L
.26526 .49448 L
.25329 .49995 L
.23628 .51017 L
.2344 .51149 L
.21926 .52385 L
.21445 .52851 L
.20225 .54222 L
.1997 .54552 L
.18831 .56253 L
.18523 .56791 L
.1794 .57955 L
.17249 .59656 L
.16822 .60991 L
.16725 .61358 L
.1635 .63059 L
.16109 .64761 L
.15993 .66462 L
.15995 .68163 L
.16112 .69865 L
.16341 .71566 L
.16683 .73268 L
.16822 .73842 L
.17137 .74969 L
.17708 .76671 L
.18398 .78372 L
.18523 .78651 L
.19216 .80074 L
.2017 .81775 L
.20225 .81865 L
.21273 .83476 L
.21926 .84383 L
.2254 .85178 L
Mistroke
.23628 .86471 L
.23996 .86879 L
.25329 .88252 L
.25672 .88581 L
.27031 .89796 L
.27617 .90282 L
Mfstroke
.08315 .45659 m
.10016 .44692 L
.10731 .44343 L
.11718 .43915 L
.13419 .43314 L
.15121 .42877 L
.16428 .42642 L
.16822 .42594 L
.18523 .42459 L
.20225 .42464 L
.21926 .42602 L
.22351 .42642 L
.23628 .42867 L
.25329 .43249 L
.27031 .43736 L
.28732 .44309 L
.28915 .44343 L
.30434 .44424 L
.30976 .44343 L
.32135 .44091 L
.33836 .43786 L
.35538 .43509 L
.37239 .43262 L
.38941 .43045 L
.40642 .42858 L
.42344 .42702 L
.43096 .42642 L
.44045 .42577 L
.45746 .42482 L
.47448 .42419 L
.49149 .42388 L
.50851 .42388 L
.52552 .42419 L
.54254 .42482 L
.55955 .42577 L
.56904 .42642 L
.57656 .42702 L
.59358 .42858 L
.61059 .43045 L
.62761 .43262 L
.64462 .43509 L
.66164 .43786 L
.67865 .44091 L
.69024 .44343 L
.69566 .44424 L
.71085 .44343 L
.71268 .44309 L
.72969 .43736 L
.74671 .43249 L
.76372 .42867 L
Mistroke
.77649 .42642 L
.78074 .42602 L
.79775 .42464 L
.81477 .42459 L
.83178 .42594 L
.83572 .42642 L
.84879 .42877 L
.86581 .43314 L
.88282 .43915 L
.89269 .44343 L
.89984 .44692 L
.91685 .45659 L
Mfstroke
.6134 .06912 m
.62761 .07871 L
.63717 .08613 L
.64462 .09252 L
.65574 .10315 L
.66164 .10942 L
.6708 .12016 L
.67865 .13054 L
.68323 .13718 L
.69353 .15419 L
.69566 .15815 L
.70204 .1712 L
.70896 .18822 L
.71268 .19923 L
.71446 .20523 L
.71864 .22225 L
.72158 .23926 L
.72333 .25628 L
.72391 .27329 L
.72333 .29031 L
.72159 .30732 L
.71867 .32433 L
.71452 .34135 L
.71268 .34797 L
.70903 .35836 L
.70211 .37538 L
.69566 .38897 L
.69279 .39239 L
.67865 .39737 L
.66164 .3938 L
.65398 .39239 L
.64462 .39075 L
.62761 .38803 L
.61059 .38563 L
.59358 .38356 L
.57656 .38182 L
.55955 .38043 L
.54254 .37939 L
.52552 .37869 L
.50851 .37834 L
.49149 .37834 L
.47448 .37869 L
.45746 .37939 L
.44045 .38043 L
.42344 .38182 L
.40642 .38356 L
.38941 .38563 L
.37239 .38803 L
.35538 .39075 L
.34602 .39239 L
Mistroke
.33836 .3938 L
.32135 .39737 L
.30721 .39239 L
.30434 .38897 L
.29789 .37538 L
.29097 .35836 L
.28732 .34797 L
.28548 .34135 L
.28133 .32433 L
.27841 .30732 L
.27667 .29031 L
.27609 .27329 L
.27667 .25628 L
.27842 .23926 L
.28136 .22225 L
.28554 .20523 L
.28732 .19923 L
.29104 .18822 L
.29796 .1712 L
.30434 .15815 L
.30647 .15419 L
.31677 .13718 L
.32135 .13054 L
.3292 .12016 L
.33836 .10942 L
.34426 .10315 L
.35538 .09252 L
.36283 .08613 L
.37239 .07871 L
.3866 .06912 L
Mfstroke
.45746 .23489 m
.47448 .23126 L
.49149 .22948 L
.50851 .22948 L
.52552 .23126 L
.54254 .23489 L
.55639 .23926 L
.55955 .24052 L
.57656 .24842 L
.58966 .25628 L
.59358 .25901 L
.61059 .27312 L
.61077 .27329 L
.62596 .29031 L
.62761 .29211 L
.63718 .30732 L
.64462 .32183 L
.64543 .32433 L
.64462 .34107 L
.62761 .33868 L
.61059 .33574 L
.59358 .33306 L
.57656 .33109 L
.55955 .32951 L
.54254 .32831 L
.52552 .32752 L
.50851 .32712 L
.49149 .32712 L
.47448 .32752 L
.45746 .32831 L
.44045 .32951 L
.42344 .33109 L
.40642 .33306 L
.38941 .33574 L
.37239 .33868 L
.35538 .34107 L
.35457 .32433 L
.35538 .32183 L
.36282 .30732 L
.37239 .29211 L
.37404 .29031 L
.38923 .27329 L
.38941 .27312 L
.40642 .25901 L
.41034 .25628 L
.42344 .24842 L
.44045 .24052 L
.44361 .23926 L
.45746 .23489 L
s
.02 w
newpath
.5 .48597 .20843 0 365.73 arc
s
0 0 m
1 0 L
1 .98584 L
0 .98584 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 283.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00016b000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`008P3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo0240oooo000Q0?ooo`80
0000f@3oool200000280oooo000P0?ooo`800000f`3oool200000240oooo000O0?ooo`<00000f`3o
ool300000200oooo000N0?ooo`@00000f`3oool4000001l0oooo000N0?ooo`<000005P3oool20000
0:d0oooo0P00000F0?ooo`<000007`3oool001d0oooo00@000000?ooo`3oool000004`3oool40000
0:l0oooo1000000C0?ooo`040000003oool0oooo000001h0oooo000L0?ooo`030000003oool0oooo
01<0oooo1@00002a0?ooo`D000005@3oool00`000000oooo0?ooo`0K0?ooo`006`3oool00`000000
oooo0?ooo`0C0?ooo`@00000]@3oool3000001H0oooo00<000000?ooo`3oool06P3oool001X0oooo
00<000000?ooo`3oool04P3oool200000080oooo00<000000?ooo`3oool0]@3oool010000000oooo
00000000000E0?ooo`030000003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo0100oooo
0P0000300?ooo`8000004`3oool00`000000oooo0?ooo`0I0?ooo`006@3oool00`000000oooo0?oo
o`0?0?ooo`800000603oool3000008h0oooo1000000G0?ooo`8000004P3oool00`000000oooo0?oo
o`0H0?ooo`00603oool00`000000oooo0?ooo`0>0?ooo`800000603oool9000008L0oooo2@00000G
0?ooo`8000004@3oool00`000000oooo0?ooo`0G0?ooo`005`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo2@0000020?ooo`D0000000<0oooo0000000000003`3oool00`00
0000oooo0?ooo`0>0?ooo`8000003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03@3oool200000100oooo00<000000?ooo`3oool03@3oool20000
00030?ooo`000000000000<000000P3oool900000100oooo0P00000@0?ooo`030000003oool0oooo
01H0oooo00150?ooo`8000001P3oool2000000h0oooo00<000000?ooo`3oool0303oool3000000l0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo0P00000?0?ooo`030000003oool0oooo00/0oooo0`0000060?ooo`800000AP3oool004l0oooo
0`00000<0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000403oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool010000000
oooo00000000000<0?ooo`030000003oool0oooo00X0oooo0P00001A0?ooo`00DP3oool300000003
0?ooo`000000oooo00L0oooo0P0000090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo0P0000080?ooo`03
0000003oool0000000800000D`3oool00280oooo00<000000?ooo`3oool0<03oool4000000P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
1000000b0?ooo`030000003oool0oooo0240oooo000Q0?ooo`030000003oool0oooo0340oooo1P00
00070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`050?ooo`H00000<`3oool00`000000oooo0?ooo`0P0?ooo`007`3oool3000003H0oooo10000007
0?ooo`030000003oool0oooo008000002@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00L0oooo0P0000020?ooo`030000003oool0oooo00D0oooo0`00000g0?ooo`<00000803oool0
01h0oooo0`0000130?ooo`@000002@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00L0oooo100000130?ooo`<000007`3oool001d0oooo100000130?ooo`@000002P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo0`0000140?ooo`@000007P3oool001h0oooo
0P00000D0?ooo`@00000:`3oool6000000T0oooo00<000000?ooo`000000303oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
000000090?ooo`H00000:`3oool3000001D0oooo0P00000O0?ooo`007@3oool00`000000oooo0?oo
o`0A0?ooo`H00000:`3oool010000000oooo0?ooo`3oool3000000X0oooo0P00000<0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`800000
2P3oool3000000<0oooo00<000000?ooo`3oool0:@3oool6000001<0oooo00<000000?ooo`3oool0
703oool001d0oooo00<000000?ooo`3oool04P3oool4000002`0oooo00<000000?ooo`3oool00`3o
ool2000000P0oooo1000000;0?ooo`800000303oool00`000000oooo0?ooo`090?ooo`<000002`3o
ool4000000P0oooo0P0000050?ooo`030000003oool0oooo02X0oooo1000000D0?ooo`030000003o
ool0oooo01`0oooo000L0?ooo`030000003oool0oooo01<0oooo0`00000/0?ooo`030000003oool0
oooo00l0oooo0`00000:0?ooo`<000002`3oool3000000X0oooo1000000:0?ooo`<000004@3oool0
0`000000oooo0?ooo`0Z0?ooo`<000005@3oool00`000000oooo0?ooo`0K0?ooo`006`3oool00`00
0000oooo0?ooo`0B0?ooo`80000000<0oooo0000003oool0:`3oool00`000000oooo0?ooo`0A0?oo
o`8000002`3oool2000000/0oooo0`00000:0?ooo`<000002`3oool2000001<0oooo00<000000?oo
o`3oool0:P3oool010000000oooo00000000000D0?ooo`030000003oool0oooo01X0oooo000J0?oo
o`030000003oool0oooo0140oooo0P00000_0?ooo`030000003oool0oooo01<0oooo0P00000:0?oo
o`8000002`3oool3000000X0oooo0`00000:0?ooo`8000005@3oool00`000000oooo0?ooo`0]0?oo
o`8000004`3oool00`000000oooo0?ooo`0I0?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01D0oooo1P00000C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool02@3oool2000000X0oooo0`00000:0?ooo`8000002`3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo0140oooo1P00000G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0603oool001T0oooo00<000000?ooo`3oool03`3oool2000001D0oooo1`00000D0?ooo`030000
003oool0oooo0280oooo0P00000;0?ooo`030000003oool0oooo00T0oooo0P00000T0?ooo`030000
003oool0oooo0180oooo1P00000F0?ooo`8000004@3oool00`000000oooo0?ooo`0H0?ooo`00603o
ool00`000000oooo0?ooo`0>0?ooo`8000004P3oool5000000<0oooo0P00000F0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0503oool200000080oooo1P00000B0?ooo`800000403o
ool00`000000oooo0?ooo`0G0?ooo`005`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00l0oooo0`00000>0?ooo`8000003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`<000003P3oool3
00000140oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0F0?ooo`00C@3oool40000
00D0oooo00<000000?ooo`3oool00P3oool010000000oooo00000000000?0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03@3oool2000000030?ooo`000000oooo00<0oooo00<00000
0?ooo`3oool00P3oool4000004l0oooo000P0?ooo`030000003oool0oooo02h0oooo100000001P3o
ool00000000000000000oooo000000@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
000600000340oooo00<000000?ooo`3oool07`3oool001l0oooo0P00000d0?ooo`H000001@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`030?ooo`H00000=03oool200000200oooo000N0?ooo`800000=@3oool70000
00D0oooo0P00000=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool20000
00D0oooo1`00000e0?ooo`8000007`3oool001d0oooo0`00000h0?ooo`030000003oool0oooo00P0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00P0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0f0?ooo`<000007P3oool0
01`0oooo1000000E0?ooo`8000008@3oool00`000000oooo0?ooo`090?ooo`@000002P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo1000000;0?ooo`030000003oool0oooo
01l0oooo0P00000E0?ooo`@000007@3oool001d0oooo0P00000C0?ooo`@000008@3oool00`000000
oooo0?ooo`0:0?ooo`D000002@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0
oooo1@00000<0?ooo`030000003oool0oooo01l0oooo0`00000D0?ooo`8000007P3oool001`0oooo
00<000000?ooo`0000004@3oool500000280oooo00<000000?ooo`3oool02`3oool4000000X0oooo
00<000000?ooo`0000002P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0203oool00`000000oooo0000000:0?ooo`<000003P3oool00`000000oooo
0?ooo`0P0?ooo`@000004P3oool00`000000oooo0000000M0?ooo`00703oool00`000000oooo0?oo
o`0B0?ooo`@000008P3oool00`000000oooo0?ooo`0=0?ooo`<000002@3oool3000000/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo0`00
00090?ooo`800000403oool00`000000oooo0?ooo`0P0?ooo`@00000503oool00`000000oooo0?oo
o`0K0?ooo`006`3oool00`000000oooo0?ooo`0C0?ooo`<000008P3oool00`000000oooo0?ooo`0@
0?ooo`8000001`3oool5000000X0oooo0`00000;0?ooo`030000003oool0oooo00T0oooo0`00000:
0?ooo`D000001`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0200oooo0`00000E
0?ooo`030000003oool0oooo01X0oooo000K0?ooo`030000003oool0oooo0140oooo0P0000000`3o
ool000000?ooo`0R0?ooo`030000003oool0oooo01X0oooo100000090?ooo`@000002P3oool30000
00X0oooo100000090?ooo`@00000703oool00`000000oooo0?ooo`0Q0?ooo`030000003oool00000
01@0oooo00<000000?ooo`3oool06P3oool001X0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0C0?ooo`L000002P3oool00`000000oooo0?ooo`0M0?ooo`<000002@3oool3000000X0
oooo0`00000:0?ooo`<000002@3oool3000001l0oooo00<000000?ooo`3oool0203oool7000001@0
oooo0P00000C0?ooo`030000003oool0oooo01T0oooo000I0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0503oool6000000/0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`070?ooo`<000002P3oool3000000X0oooo0`0000090?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool02@3oool6000001H0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0H0?ooo`006@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01<0oooo1P00
000<0?ooo`030000003oool0oooo02/0oooo0P00000:0?ooo`<000002P3oool2000002d0oooo00<0
00000?ooo`3oool02P3oool5000001H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0H0?ooo`00603oool00`000000oooo0?ooo`0?0?ooo`8000004`3oool3000000<0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0[0?ooo`8000002`3oool00`000000oooo0?ooo`09
0?ooo`800000;@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@000004`3oool2
00000140oooo00<000000?ooo`3oool05`3oool001P0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0@0?ooo`<00000503oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
0180oooo0`00000B0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05`3oool001L0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`8000003`3oool5000000<0
oooo00<000000?ooo`3oool00P0000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`04
0000003oool0oooo0?ooo`D000003`3oool200000140oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0F0?ooo`007@3oool00`000000oooo0?ooo`0`0?ooo`/000000P3oool2000000l0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`8000000P3oool;00000380
oooo00<000000?ooo`3oool0703oool001`0oooo0P00000d0?ooo`040000003oool0oooo0?ooo`L0
00000P3oool2000000h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`80
00000P3oool7000000<0oooo00<000000?ooo`3oool0<P3oool2000001d0oooo000L0?ooo`800000
=03oool010000000oooo0?ooo`3oool3000000P0oooo0P00000=0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02`3oool2000000L0oooo100000030?ooo`030000003oool0oooo0380
oooo0P00000M0?ooo`006`3oool3000001H0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0>0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`070?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0D0?ooo`<00000703oool001/0oooo0`00000D0?ooo`8000007@3oool00`000000
oooo0?ooo`0@0?ooo`@000002@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0
oooo1000000B0?ooo`030000003oool0oooo01/0oooo0P00000D0?ooo`<00000703oool001X0oooo
1000000B0?ooo`@000007@3oool00`000000oooo0?ooo`0A0?ooo`@000002@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00L0oooo1000000C0?ooo`030000003oool0oooo01/0oooo
1000000B0?ooo`@000006`3oool001/0oooo0`00000A0?ooo`@000007P3oool00`000000oooo0?oo
o`0A0?ooo`D000002@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo1@00
000C0?ooo`030000003oool0oooo01`0oooo1000000A0?ooo`<00000703oool001X0oooo00<00000
0?ooo`3oool04`3oool3000001d0oooo00<000000?ooo`3oool05@3oool3000000T0oooo0P00000;
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`09
0?ooo`8000002@3oool3000001L0oooo00<000000?ooo`3oool06`3oool3000001D0oooo00<00000
0?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0000000F0?oo
o`8000001P3oool00`000000oooo0?ooo`0P0?ooo`@000002P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool400000280oooo00<000000?oo
o`3oool0103oool2000001H0oooo00<000000?ooo`000000503oool00`000000oooo0?ooo`0I0?oo
o`006P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01@0oooo100000070?ooo`03
0000003oool0oooo0240oooo0`00000;0?ooo`8000002`3oool00`000000oooo0?ooo`090?ooo`80
00002`3oool3000002<0oooo00<000000?ooo`3oool01@3oool4000001H0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0I0?ooo`006@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0180oooo1@0000080?ooo`030000003oool0oooo0280oooo0`0000080?ooo`@00000
1`3oool9000000L0oooo100000080?ooo`<00000903oool00`000000oooo0?ooo`060?ooo`D00000
503oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01P0oooo000I0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool04`3oool3000000T0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`070?ooo`<000000P3oool5000000<0oooo0`0000030?ooo`D000000P3o
ool3000000T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`070?ooo`<000005@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo000I0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool04P3oool2000000030?ooo`000000oooo00T0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`060?ooo`D00000203oool3000000P0oooo10000009
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool010000000oooo00000000
000D0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0603oool001P0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`8000003P3oool00`000000oooo0?ooo`0]
0?ooo`80000000@0oooo00000000000000002@3oool3000000T0oooo1P00000_0?ooo`030000003o
ool0oooo00`0oooo0P00000C0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05`3o
ool001P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`800000403oool0
0`000000oooo0?ooo`040?ooo`8000009@3oool2000000@0oooo0P00000:0?ooo`030000003oool0
oooo00P0oooo0P0000040?ooo`8000009@3oool2000000H0oooo00<000000?ooo`3oool03P3oool2
00000180oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`005`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo0P00000B0?ooo`030000003oool0oooo
00@0oooo1@00000P0?ooo`8000001`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01@3oool200000200oooo1@0000060?ooo`030000003oool0oooo
0100oooo0P00000A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05P3oool001L0
oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00h0oooo4`00000?0?ooo`030000003oool0oooo00P0oooo0`000000103oool000000?ooo`00000@
0?ooo`030000003oool0oooo00h0oooo00@000000?ooo`000000oooo0P00000;0?ooo`030000003o
ool0oooo00d0oooo4`00000@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3o
ool010000000oooo0?ooo`00000H0?ooo`006@3oool2000003@0oooo00<000000?ooo`3oool0103o
ool3000000D0oooo0P00000>0?ooo`030000003oool0oooo00D0oooo0P0000040?ooo`030000003o
ool000000100oooo00<000000?ooo`3oool03P3oool00`000000oooo000000030?ooo`800000203o
ool00`000000oooo0?ooo`0<0?ooo`800000103oool4000000H0oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0I0?ooo`006@3oool2000001D0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0>0?ooo`<00000303oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo0P0000000`3oool000000?ooo`0>0?ooo`030000003oool0oooo00d0oooo00@00000
0?ooo`00000000001@3oool2000000D0oooo00<000000?ooo`3oool02P3oool300000100oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`8000006P3oool001P0oooo0`00000D
0?ooo`8000007P3oool00`000000oooo0?ooo`0A0?ooo`8000000P3oool00`000000oooo0?ooo`06
0?ooo`050000003oool0oooo0?ooo`0000001`3oool2000000030?ooo`000000oooo00d0oooo0`00
000>0?ooo`040000003oool00000000000L0oooo00D000000?ooo`3oool0oooo000000080?ooo`03
0000003oool0oooo008000004`3oool00`000000oooo0?ooo`0L0?ooo`800000503oool2000001X0
oooo000H0?ooo`<000004`3oool3000001h0oooo00<000000?ooo`3oool04`3oool4000000P0oooo
00<000000?ooo`0000001`3oool5000000h0oooo0`00000>0?ooo`@00000203oool00`000000oooo
000000070?ooo`D000005@3oool00`000000oooo0?ooo`0L0?ooo`<000004`3oool3000001T0oooo
000G0?ooo`@000004P3oool3000001l0oooo00<000000?ooo`3oool0503oool5000000H0oooo0P00
00080?ooo`@0000000<0oooo0000003oool0303oool3000000d0oooo00<000000?ooo`0000000P00
00090?ooo`8000001P3oool5000001H0oooo00<000000?ooo`3oool07@3oool300000180oooo0`00
000I0?ooo`006@3oool200000140oooo1000000F0?ooo`8000001`3oool00`000000oooo0?ooo`0D
0?ooo`H00000103oool010000000oooo0?ooo`0000070?ooo`<000000P3oool00`000000oooo0?oo
o`070?ooo`/000002@3oool00`000000oooo0?ooo`02000000P0oooo00@000000?ooo`3oool00000
103oool6000001H0oooo00<000000?ooo`3oool01@3oool2000001H0oooo1000000A0?ooo`800000
6P3oool001T0oooo00<000000?ooo`3oool04@3oool3000001<0oooo100000080?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000060?ooo`050000003o
ool0oooo0?ooo`0000000P3ooolG00000080oooo00D000000?ooo`3oool0oooo000000060?ooo`03
0000003oool0000000@0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`@0
00004`3oool3000001<0oooo00<000000?ooo`3oool0603oool001T0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`D000002@3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00@0oooo0`0000050?ooobD000001@3oool3000000H0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`070?ooo`D000004`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01P0oooo000H0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04`3o
ool4000000T0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`040?ooo`@000000`3o
oolY000000<0oooo100000060?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01`3o
ool4000001D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`00603oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01<0oooo0`00000:0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool01@3ooole000000L0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`080?ooo`<000005@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo01L0oooo000H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0000000;0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01`3ooolD0000
00@0oooo0`0000040?oooa@000002@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`0000005@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
01L0oooo000H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo1`00000>0?ooo`8000002@3oool?000000X0
oooo0`0000090?oooa0000002@3oool2000000h0oooo1`0000050?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01L0
oooo000H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00<0oooo1P00000?0?ooo`030000003oool0oooo00H0oooo
300000030?ooo`8000002P3oool3000000T0oooo0`0000030?ooo``00000203oool00`000000oooo
0?ooo`0=0?ooo`H000001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`00603oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0100oooo0P00000@0?ooo`040000003oool0oooo0?ooo`H00000
403oool00`000000oooo0?ooo`040?ooo`/000000`3oool00`000000oooo0?ooo`020?ooo`800000
2@3oool3000000T0oooo0P0000040?ooo`040000003oool0oooo0?ooo`/000001P3oool00`000000
oooo0?ooo`0>0?ooo`D00000103oool00`000000oooo0?ooo`0>0?ooo`8000004P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo000G0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`@000000`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00<0oooo2`0000040?ooo`030000003oool0oooo0080oooo
0P00000:0?ooo`030000003oool0oooo00P0oooo0P0000040?ooo`030000003oool0oooo0080oooo
2`0000050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@00000B0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`005`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3o
ool3000001P0oooo00<000000?ooo`3oool00`3oool:000000H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`X000001@3oool00`000000oooo0?ooo`0F0?ooo`<000004@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05P3o
ool001D0oooo00<000000?ooo`000000403oool010000000oooo0?ooo`00000>0?ooo`030000003o
ool0oooo00h0oooo0P0000020?ooo`030000003oool0oooo00X0oooo0`0000090?ooo`040000003o
ool000000?ooo`X000001`3oool200000100oooo00<000000?ooo`3oool03P3oool2000000L0oooo
2P000000103oool000000?ooo`0000090?ooo`<00000303oool00`000000oooo0?ooo`0200000100
oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`00000@0?ooo`030000003oool00000
01H0oooo000E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0=0?ooo`H000000P3oool2000000030?ooo`000000000000L000002P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool900000003
0?ooo`00000000000080oooo1P00000?0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0D0?ooo`005@3oool2000001<0oooo0P00000F0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool04`3oool=000000/0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0>0?ooo`8000002`3oool=000001D0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0D0?ooo`8000004`3oool2000001H0oooo000E0?ooo`8000004`3o
ool2000001D0oooo0P00000=0?ooo`030000003oool0oooo01@0oooo2`00000;0?ooo`800000403o
ool00`000000oooo0?ooo`0>0?ooo`8000002`3oool;000001H0oooo00<000000?ooo`3oool02`3o
ool2000001D0oooo0P00000C0?ooo`8000005P3oool001D0oooo0P00000B0?ooo`<00000503oool2
000000h0oooo00<000000?ooo`3oool04`3oool:00000080oooo00<000000?ooo`3oool01`3oool3
000000l0oooo0`00000>0?ooo`@000002@3oool00`000000oooo0?ooo`0:000001D0oooo00<00000
0?ooo`3oool0303oool2000001<0oooo1000000B0?ooo`8000005P3oool001D0oooo0`00000A0?oo
o`<000004`3oool3000000h0oooo00<000000?ooo`3oool04P3oool9000000D0oooo0P0000070?oo
o`<00000303oool9000000/0oooo100000070?ooo`8000001@3oool9000001@0oooo00<000000?oo
o`3oool0303oool300000180oooo1000000A0?ooo`<000005P3oool001D0oooo0`00000B0?ooo`80
00004P3oool4000000h0oooo00<000000?ooo`3oool04@3oool8000000T0oooo00<000000?ooo`00
0000103oool?000000<0oooo0`0000030?ooo`l00000103oool00`000000oooo000000090?ooo`P0
00004`3oool00`000000oooo0?ooo`0<0?ooo`@000004@3oool300000180oooo0`00000F0?ooo`00
5P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo0P00000?0?ooo`030000
003oool0oooo00@0oooo0P00000:0?ooo`T000001P3oool:000000030?ooo`000000oooo0100oooo
00<000000?ooo`3oool03`3oool00`000000oooo00000009000000H0oooo2@00000:0?ooo`800000
1P3oool00`000000oooo0?ooo`0=0?ooo`800000503oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01D0oooo000F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3o
ool200000100oooo00@000000?ooo`3oool0oooo0`00000:0?ooo`L000000P3oool00`000000oooo
00000004000000<0oooo100000040?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`020?ooo`@000000`3oool5000000040?ooo`000000oooo0?ooo`L0
00002P3oool3000000<0oooo00<000000?ooo`3oool03P3oool2000001@0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0E0?ooo`005P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo00000004000000T0oooo
3000000:0?ooo`<00000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool00P3oool3000000X0oooo300000090?ooo`D0000000<0oooo0000003oool0
4@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
5@3oool001H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool00`0000090?ooo`L000001@3oool00`000000oooo0?oo
o`0:0?ooo`8000000`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00@0
00000?ooo`3oool0oooo0P00000<0?ooo`030000003oool0oooo00<0oooo1`0000090?ooo`<00000
0P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0E0?ooo`005P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool04P3oool2000000030?ooo`000000oooo00T0oooo1P00
00060?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool6000000X0oooo00@0
00000?ooo`0000000000503oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool05@3oool001H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0140oooo0P00000<0?ooo`H000001`3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00D0oooo1P00000<0?ooo`8000004`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05@3oool001L0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00@00000
0?ooo`3oool000002P3oool7000000L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`050?ooo`L000002P3oool010000000oooo0?ooo`00000C0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`005`3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool01@000000oooo0?oo
o`3oool0000000T0oooo1`0000030?ooo`L00000403oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool7000000<0oooo1`0000090?ooo`050000
003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool05P3oool001L0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00l0oooo0P0000040?ooo`030000003oool0oooo00L0oooo
1P0000020?ooo`L0000000<0oooo0000003oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool900000080oooo1P0000090?ooo`030000
003oool0oooo0080oooo0P00000A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0F0?ooo`005`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo2@0000020?ooo`<000000`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00@000000P3oool9000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0F0?ooo`005`3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo00000140oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000
0P3oool6000000H0oooo00L000000?ooo`3oool0oooo0000003oool0000000l0oooo0P00000@0?oo
o`030000003oool0oooo00h0oooo0P00000?0?ooo`030000003oool000000080oooo0P0000060?oo
o`H000000P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool05P3o
ool00140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00H000002P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo1P0000020?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0403oool00140oooo0P00000B0?ooo`8000004P3o
ool2000001D0oooo0P0000030?ooo`030000003oool0oooo00P000002`3oool200000100oooo0P00
000@0?ooo`030000003oool0oooo00h0oooo0P00000@0?ooo`8000002`3oool800000080oooo00@0
00000?ooo`3oool0oooo0P00000E0?ooo`8000004P3oool200000180oooo0P00000B0?ooo`004@3o
ool200000180oooo0P00000B0?ooo`800000503oool3000000<0oooo00<000000?ooo`3oool02000
000;0?ooo`800000403oool200000080oooo7@0000020?ooo`800000403oool2000000/0oooo2000
00020?ooo`040000003oool0oooo0?ooo`<00000503oool200000180oooo0P00000B0?ooo`800000
4P3oool00140oooo0`00000A0?ooo`8000004P3oool3000001<0oooo0`0000040?ooo`030000003o
ool0000000H000002`3oool3000000X0oooo2P00000=0?ooo`<000003@3oool:000000X0oooo0`00
000;0?ooo`L0000000<0oooo0000003oool00`3oool3000001<0oooo0`00000B0?ooo`8000004@3o
ool300000180oooo000A0?ooo`<000004@3oool300000100oooo1000000B0?ooo`<000001@3oool0
0`000000oooo00000005000000`0oooo3@0000050?ooo`@000003P3oool3000000h0oooo10000005
0?ooo`d00000303oool6000000030?ooo`000000oooo00@0oooo0`00000B0?ooo`@00000403oool3
00000140oooo0P00000C0?ooo`004@3oool400000100oooo0`00000@0?ooo`@000004@3oool40000
00H0oooo1P00000;0?ooo`H000003P3oool4000000h0oooo0`00000>0?ooo`@000003P3oool50000
00`0oooo1P0000060?ooo`@000004@3oool400000100oooo0`00000@0?ooo`<000004`3oool00140
oooo0`00000B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool2000000H0
oooo1@0000060?ooo`H00000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo0?oo
o`H000001`3oool5000000H0oooo0P00000D0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0403oool2000001<0oooo000D0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo1@0000030?ooo`<0
00002P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo100000030?ooo`D0
0000203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0C0?ooo`00503oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`P00000
3@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo200000080?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo01<0oooo000D0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo1@00000A0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03`3oool5000000L0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04`3o
ool001D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool01P3oool600000100oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0>0?ooo`H00000203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`060?ooo`H00000403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00h0oooo1P0000080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0
oooo1@0000000`3oool000000?ooo`0@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo00000004000000L0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool001H0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool01P3oool5000000030?ooo`000000oooo0100oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0000000@00000203oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0E0?ooo`005P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`H000000P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`06000000L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool05@3oool001L0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`080?ooo`T000003`3oool00`000000oooo0?ooo`060?ooo`D000000`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3ooolC
000000L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0
oooo0?ooo`D00000203oool00`000000oooo0?ooo`0<0?ooo`X000002P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo01H0oooo000G0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool00P3oool6000000L0oooo00<000000?ooo`0000001@0000090?ooo`030000003oool0
oooo00H0oooo1P0000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000002@3oool?
000000T0oooo00<000000?ooo`3oool01`3oool?000000T0oooo00<000000?ooo`0000003P3oool0
0`000000oooo0?ooo`06000000P0oooo00<000000?ooo`3oool01`3oool500000080oooo00<00000
0?ooo`3oool01@3oool5000000D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0F
0?ooo`00:@3oool4000001D0oooo1@00000<0?ooo`D0000000<0oooo0000003oool0403oool00`00
0000oooo00000009000000H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00@0oooo2P0000000`3oool000000?ooo`0@0?ooo`030000003oool00000
00@00000303oool5000001@0oooo1@00000Z0?ooo`009@3oool4000000T0oooo00<000000?ooo`3o
ool04@3oool5000000P0oooo1@0000000`3oool00000000000090?ooo`T00000403oool200000100
oooo00<000000?ooo`3oool03P3oool200000100oooo2@0000090?ooo`80000000<0oooo00000000
00000`0000080?ooo`D000004`3oool00`000000oooo0?ooo`070?ooo`@000009P3oool001l0oooo
00@000000?ooo`3oool0oooo0P00000=0?ooo`8000004P3oool2000000<0oooo100000040?ooo`D0
000000<0oooo000000000000103oool5000000L0oooo0P00000@0?ooo`800000403oool00`000000
oooo0?ooo`0>0?ooo`800000403oool2000000L0oooo1@0000040?ooo`80000000<0oooo00000000
00000`0000040?ooo`@000000`3oool200000180oooo0P00000=0?ooo`8000000`3oool00`000000
oooo0?ooo`0N0?ooo`00303oool00`000000oooo0?ooo`0@0?ooo`@000003`3oool300000140oooo
0`0000060?ooo`80000000<0oooo0000000000000`0000000`3oool0000000000005000000/0oooo
0`00000?0?ooo`<000003`3oool3000000l0oooo0`00000?0?ooo`<000002`3oool7000000030?oo
o`000000000000<0000000<0oooo0000000000001P3oool300000140oooo0`00000?0?ooo`@00000
4P3oool00`000000oooo0?ooo`0;0?ooo`003@3oool00`000000oooo0?ooo`0=0?ooo`D00000403o
ool400000100oooo0`0000080?ooo`/000003P3oool4000000h0oooo1000000>0?ooo`<000003P3o
ool4000000h0oooo1000000>0?ooo`/00000203oool300000100oooo1000000@0?ooo`@00000403o
ool00`000000oooo0?ooo`0<0?ooo`003@3oool3000000`0oooo00@000000?ooo`3oool0oooo0`00
000@0?ooo`@000003`3oool4000000P0oooo1@0000000`3oool0000000000002000000h0oooo1000
000>0?ooo`@000003P3oool3000000h0oooo1000000>0?ooo`@000003P3oool4000000030?ooo`00
0000000000<00000203oool4000000l0oooo1000000@0?ooo`<000000P3oool2000000`0oooo0`00
000>0?ooo`003P3oool3000000T0oooo0P0000040?ooo`@000003`3oool300000100oooo0`000009
0?ooo`D000000`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03`3oool010000000oooo0?ooo`3oool5000000T0oooo0`00000@0?ooo`<000003`3o
ool4000000@0oooo0P0000090?ooo`<000003`3oool000h0oooo100000060?ooo`8000001`3oool2
00000100oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`070?ooo`D000000`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool0
10000000oooo0?ooo`3oool5000000T0oooo00<000000?ooo`3oool0403oool00`000000oooo0000
000@0?ooo`8000001`3oool2000000H0oooo1000000?0?ooo`003`3oool2000000H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0000000B0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool01`3oool5000000@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool5000000T0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0000000T0oooo00<00000
0?ooo`3oool0103oool200000100oooo000A0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo1@0000050?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00<0oooo1@0000070?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo000B0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00D0oooo1@0000050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0M00000080oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo1@0000070?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140
oooo000C0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00D0oooo1@0000050?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool00`3oool?000000h0oooo00<000000?ooo`3oool0303oool?000000D0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`D000001`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0B0?ooo`00503oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`D000001@3oool00`000000oooo0?oo
o`0:0?ooo`X00000303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool02P3oool9000000d0oooo00<000000?ooo`3oool00`3oool5000000H0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool04`3oool001@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool5000000D0oooo00<00000
0?ooo`3oool01P3oool4000000D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`02
0?ooo`@000002@3oool00`000000oooo0?ooo`030?ooo`D000001P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C
0?ooo`005@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`040?ooo`D000001P3oool00`000000oooo0?ooo`050000
00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`H000000P3oool00`00
0000oooo0?ooo`040?ooo`D000001P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`005P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`030?ooo`D00000103oool5000000h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0<0?ooo`D00000103oool5000000D0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05@3oool001L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool00`3oool900000080oooo00<000000?ooo`3oool0303oool00`000000oooo
0000000?0?ooo`800000403oool00`000000oooo0?ooo`0>0?ooo`8000003`3oool00`000000oooo
0000000>0?ooo`030000003oool0oooo00T000001@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0F0?ooo`00C`3o
ool7000000<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00l0oooo00@000000?ooo`3oool0oooo1`00001@0?ooo`00C@3oool200000080oooo1@00
00030?ooo`800000403oool200000100oooo0P00000@0?ooo`030000003oool0oooo00h0oooo0P00
000@0?ooo`800000403oool2000000<0oooo1@0000020?ooo`800000CP3oool004X0oooo0`000004
0?ooo`D000000`3oool200000100oooo0P00000@0?ooo`800000403oool00`000000oooo0?ooo`0>
0?ooo`800000403oool200000100oooo0P0000030?ooo`D00000103oool2000004`0oooo00180?oo
o`8000001`3oool5000000<0oooo0P00000?0?ooo`<000003`3oool3000000l0oooo0`00000?0?oo
o`<000003`3oool3000000l0oooo0P0000030?ooo`D000001P3oool3000004T0oooo00160?ooo`80
00002@3oool5000000<0oooo0`00000>0?ooo`@000003P3oool4000000030?ooo`000000000001/0
000000<0oooo0000000000000P00000>0?ooo`@000003P3oool3000000<0oooo1@0000090?ooo`80
0000A`3oool004@0oooo0P00000;0?ooo`D000000`3oool3000000h0oooo100000040?ooo`l00000
3@3oool3000000d0oooo3`0000040?ooo`@000003P3oool3000000<0oooo1@00000;0?ooo`800000
A@3oool001/0oooo0P00000?0?ooo`8000003`3oool2000000@0oooo00<000000?ooo`3oool02`3o
ool5000000@0oooo00<000000?ooo`3oool02`3oool:000000/0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo2P00000=0?ooo`030000003o
ool0oooo0080oooo1@00000=0?ooo`030000003oool0oooo0080oooo0P00000?0?ooo`8000003`3o
ool2000001`0oooo00090?ooo`8000004@3oool3000000h0oooo0`00000>0?ooo`<0000000<0oooo
0000003oool03P3oool5000000<0oooo00<000000?ooo`3oool01`3oool4000000@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`@000002@3oool010000000oooo0?ooo`3o
ool6000000h0oooo1@00000>0?ooo`<000003P3oool300000140oooo0P00000:0?ooo`002P3oool4
000000h0oooo1@00000=0?ooo`@000003@3oool4000000l0oooo1@0000030?ooo`X00000203oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo2P0000030?ooo`D000003P3oool5
000000d0oooo1000000=0?ooo`D000003P3oool4000000/0oooo000;0?ooo`D000003@3oool30000
00l0oooo0`00000=0?ooo`@000003`3oool8000000030?ooo`000000oooo00l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000L000003`3oool40000
00d0oooo0`00000?0?ooo`<000003@3oool5000000`0oooo000<0?ooo`<000003P3oool4000000l0
oooo0`00000;0?ooo`030000003oool0oooo00<000003P3oool5000000@0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00P3oool5000000h0oooo0`0000020?ooo`030000003oool0oooo00T0oooo0`00000?0?ooo`@0
00003P3oool3000000d0oooo000=0?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool0
0P00000@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0;0?ooo`D00000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`D000003@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool200000080oooo
00<000000?ooo`3oool02`3oool2000000030?ooo`000000oooo00d0oooo000@0?ooo`8000004@3o
ool00`000000oooo0?ooo`0>0?ooo`8000001P3oool00`000000oooo0?ooo`060?ooo`8000002P3o
ool6000000@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P3oool6000000X0oooo0P0000080?ooo`030000003o
ool0oooo00@0oooo0P00000@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403o
ool00180oooo0P00000@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@000003
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?
0?ooo`040000003oool0oooo0?ooo`D000000P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00h0oooo0P00000C0?ooo`00503oool00`000000oooo0?ooo`0>0?ooo`800000403oool0
1@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`05000000@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00D0oooo4`0000070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`020?ooo`D000000P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00X0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`800000403oool00`000000oooo
0?ooo`0C0?ooo`005@3oool200000100oooo00<000000?ooo`3oool03P3oool3000000h0oooo0P00
00040?ooo`040000003oool0oooo0?ooo`D00000103oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0080oooo500000090?ooo`030000003oool0oooo00L0oooo500000040?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool5000000<0oooo00<000000?ooo`3oool0
0P3oool2000000h0oooo0`00000@0?ooo`030000003oool0oooo00h0oooo0P00000F0?ooo`005`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo0P00000@0?ooo`040000003o
ool0oooo000000D0oooo1@0000030?ooo`030000003oool0oooo00T0oooo2P00000;0?ooo`800000
403oool00`000000oooo0?ooo`0>0?ooo`8000002`3oool9000000`0oooo00@000000?ooo`3oool0
oooo1@0000050?ooo`040000003oool0oooo00000100oooo0P00000@0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool05P3oool003P0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`040?ooo`D000002`3oool4000000<0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`05000000/0oooo1@0000060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0=`3oool003P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`D00000
00<0oooo000000000000200000070?ooo`800000403oool200000100oooo00<000000?ooo`3oool0
3P3oool200000100oooo0P0000070?ooo`X0000000<0oooo0000000000000`0000060?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0=`3oool003L0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`060?ooo`D000004@3oool200000100oooo0P00000@0?ooo`030000003o
ool0oooo00h0oooo0P00000@0?ooo`8000004@3oool5000000P0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0f0?ooo`00=`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00H0oooo1@00000@0?ooo`<000003`3oool3000000l0oooo0`00000?0?ooo`<000003`3oool3
00000100oooo1@0000080?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0=P3oool0
03H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`060?ooo`L000003`3oool40000
00h0oooo1000000>0?ooo`<000003P3oool4000000h0oooo1000000?0?ooo`L00000203oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo03D0oooo000f0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool01`3oool00`000000oooo00000004000000l0oooo1000000>0?ooo`@0
00003P3oool3000000h0oooo1000000>0?ooo`@000003`3oool5000000030?ooo`000000oooo00P0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0e0?ooo`00=@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000001000000A0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool5000000030?ooo`000000oooo00P0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0d0?ooo`00=03oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@00000@0?ooo`030000003o
ool0oooo00d0oooo9`00000?0?ooo`030000003oool0oooo00h0oooo1@0000030?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0c0?ooo`00=03oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@00000@
0?oooa0000000P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool04000000@0?ooo`D000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0<`3oool003<0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00D00000203oool900000140oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo2@0000080?oo
o`D000000`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0<P3oool003<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`04
0000003oool0oooo0?ooo`D000000P3oool5000000P0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`060?ooo`D000000P3oool5000000@0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0380oooo00070?ooo`L000002P3oool7000001<0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080
oooo1`00000=0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool7000000@0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140
oooo1`00000:0?ooo`L00000203oool000P0oooo1P00000;0?ooo`H000002P3oool700000080oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo
1`00000>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool7000000D0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L00000
2P3oool6000000/0oooo1P0000090?ooo`002P3oool5000000`0oooo1@00000:0?ooo`H0000000<0
oooo0000003oool01`3oool7000000H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`040?ooo`L000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo1`00
00060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool7000000P0oooo00<0
00000?ooo`0000001@0000090?ooo`H000002`3oool6000000/0oooo000<0?ooo`030000003oool0
oooo00@000002P3oool00`000000oooo0?ooo`04000000P0oooo0`0000000`3oool0000000000002
000000L0oooo200000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool6
000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`H000001`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo200000070?ooo`@0000000@0oooo
0000000000000000203oool3000000<0oooo00<000000?ooo`3oool0203oool3000000<0oooo00<0
00000?ooo`3oool02`3oool001<0oooo0`00000>0?ooo`<000001`3oool010000000oooo0?ooo`00
00020?ooo`@000001@3oool3000000<0oooo1P0000050?ooo`<0000000<0oooo0000003oool01P3o
ool7000000`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`L000001`3o
ool00`000000oooo00000002000000D0oooo1P0000030?ooo`<000001@3oool400000080oooo00@0
00000?ooo`3oool000001`3oool3000000h0oooo0`00000D0?ooo`005P3oool2000000l0oooo0P00
00080?ooo`030000003oool0oooo00@0oooo0`0000040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`0000005`00000<0?ooo`030000003oool0oooo00d0oooo0P0000020?oooad000000P3o
ool2000000l0oooo00<000000?ooo`3oool02P3ooolH000000030?ooo`000000oooo00H0oooo00<0
00000?ooo`3oool00P3oool3000000H0oooo00<000000?ooo`3oool01P3oool2000000l0oooo0P00
000G0?ooo`00<03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo10000000
0`3oool000000?ooo`060?ooo`030000003oool0000000D000002`3ooolD000000h0oooo00<00000
0?ooo`3oool0303ooolD000000/0oooo1P0000000`3oool000000?ooo`060?ooo`030000003oool0
000000<000001P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02l0oooo000`0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool2000000030?ooo`000000oooo
00H0oooo00<000000?ooo`3oool01P0000000`3oool000000000000700000100oooo0P00000@0?oo
o`030000003oool0oooo00h0oooo0P00000@0?ooo`T0000000<0oooo000000000000100000020?oo
o`030000003oool0oooo00D0oooo00@000000?ooo`0000000000203oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo02l0oooo000`0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L000006@3oool20000
0100oooo00<000000?ooo`3oool03P3oool2000001T0oooo1`0000020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
02l0oooo000`0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`050?ooo`040000003oool0oooo0?ooo`H00000603oool3000000l0oooo0`00000?0?oo
o`<00000603oool6000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0;`3oool002l0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3o
ool0oooo1`00000G0?ooo`@000003P3oool3000000h0oooo1000000G0?ooo`L000000`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0^0?ooo`00;`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`L000005P3oool4000000h0
oooo0`00000>0?ooo`@000005P3oool7000000@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0;P3oool002h0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00`3oool7000001H0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01@0oooo1`0000050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02d0oooo
000^0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo1`00000E0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`L000001P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0]0?ooo`00;P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`P000003P3ooola000000h0oooo20000006
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo02d0oooo000^0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`0000004`0000070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`050?oooa@0000000<0oooo0000003oool01@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0]0?oo
o`00;P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000L000004P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0403oool800000003
0?ooo`000000oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0;@3oool002h0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0800000140oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00l0oooo200000020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0;@3oool002h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0800000100oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00h0oooo200000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0;@3o
ool002h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool:000000d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo2P00
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0;@3oool000H0oooo1`00000=
0?ooo`@000003`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo2@00000<
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:
0?ooo`T00000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00d0oooo0`00000>
0?ooo`L000001`3oool000L0oooo300000040?ooo`T000003@3oool2000001H0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool9000000/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00T0oooo2@0000050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01@0oooo0P00000=0?oo
o`T00000103oool;000000T0oooo00090?ooo`@000001P3oool5000000030?ooo`000000000000<0
00000P3oool9000000030?ooo`000000000000<000000P3oool:000000X0oooo00@000000?ooo`3o
ool0oooo0`0000070?ooo`030000003oool0oooo00D0oooo0`0000070?ooo`030000003oool0oooo
00<0oooo2`0000060?ooobL000001P3oool;000000D0oooo00<000000?ooo`3oool01@3oool30000
00L0oooo00<000000?ooo`3oool01@3oool3000000<0oooo00<000000?ooo`3oool0203oool90000
00<0oooo1@0000000`3oool000000000000700000080oooo1@0000000`3oool00000000000030000
00H0oooo0`00000;0?ooo`002`3oool2000000l0oooo0P00000:0?ooo`T000003@3oool2000000<0
oooo1P00000:0?ooo`030000003oool0oooo0080oooo0`0000020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0000000800000080oooo0`00000W0?ooo`<0
00000P3oool9000000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`02000000D0oooo00<000000?ooo`3oool0203oool6000000<0oooo0P00000<0?ooo`X0
00002P3oool2000000l0oooo00<000000?ooo`3oool02`3oool002/0oooo1000000=0?ooo`L00000
0P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool00000000000H0oooo00<000000?ooo`3o
ool01@3oool010000000oooo0?ooo`3oool2000000030?ooo`000000oooo00X00000;@3oool:0000
00030?ooo`000000oooo008000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00<0oooo0`0000000`3oool000000?ooo`0=0?ooo`030000003oool0oooo00L000003@3oool30000
02d0oooo000]0?ooo`030000003oool0oooo00X0oooo1`0000050?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000000P0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`0;000002T0oooo2`0000020?ooo`070000003oool0oooo0?oo
o`000000oooo000000080?ooo`030000003oool0oooo00H0oooo0`0000000`3oool000000?ooo`09
0?ooo`030000003oool0oooo00<0oooo1`00000<0?ooo`030000003oool0oooo02`0oooo000]0?oo
o`030000003oool0oooo00d0oooo100000050?ooo`030000003oool0oooo00H0oooo100000020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool2000000D0oooo00<000000?oo
o`3oool00P3oool;000002<0oooo2`0000040?ooo`030000003oool0oooo00<0oooo0P0000070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0100000080?ooo`030000003oool0oooo
00<0oooo0`00000@0?ooo`030000003oool0oooo02`0oooo000]0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0103oool600000080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`040?ooo`<000001P3oool00`000000oooo0?ooo`020?oooa0000005`3oool@000000@0
oooo00<000000?ooo`3oool0103oool2000000L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`06000000H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0/0?ooo`00
;@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00<0oooo1`0000020?ooo`030000
003oool0oooo00P0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P3ooolE000000/0oooo5@0000040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P0000001@3oool000000?ooo`3oool0000000X0oooo00<00000
0?ooo`3oool01`0000050?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;03oool0
02d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00P0oooo100000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool_0000
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`@000002P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;03oool002h0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0
oooo1@0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool[000000L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`D000002P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool002h0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo
0`0000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3ooolW000000P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`@000002@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3oool002h0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo0P00
00000`3oool000000?ooo`070?ooo`030000003oool0oooo00D0oooo0P0000080?ooo`800000103o
oolG000000@0oooo0P0000070?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`@00000203o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;@3o
ool002h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo0P0000080?ooo`030000003oool0oooo00L0oooo2`0000080?ooo`8000001`3oool2
000000T0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`3oool2000000H0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo000^
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool2000000L0oooo0P00000I
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo02d0oooo000^0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool2000000L0oooo6@0000070?ooo`8000002P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo02d0oooo000^0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo0P00000:0?ooo`80
00008`3oool2000000X0oooo0P0000090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02d0oooo000^0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool3000001`0oooo1000000:0?ooo`800000
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0]0?ooo`00;P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`800000303o
ool5000001<0oooo1000000=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0;@3o
ool000/0oooo0P0000060?ooo`D000003P3oool3000000D0oooo00<000000?ooo`3oool0203oool2
000000l0oooo0P00000?0?ooo`8000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00D0oooo0P0000070?ooo`030000003oool0oooo00D0oooo1@0000040?ooo`030000003oool0
oooo0080oooo1@0000070?ooo`030000003oool0oooo00D0oooo0P0000070?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02@3oool2000000l0oooo0P00000?0?ooo`8000002P3oool0
0`000000oooo0?ooo`030?ooo`<000003P3oool5000000H0oooo0P00000<0?ooo`00203oool;0000
00T0oooo0P0000020?ooo`H000002@3oool00`000000oooo0?ooo`030?ooo`@000003`3oool30000
00l0oooo0`00000<0?ooo`040000003oool0oooo000000X0oooo0P0000050?ooo`030000003oool0
oooo00X0oooo2@00000<0?ooo`030000003oool0oooo00<0oooo0P00000:0?ooo`040000003oool0
oooo000000`0oooo0`00000?0?ooo`<000003`3oool4000000D0oooo00<000000?ooo`3oool01`3o
ool5000000<0oooo0P0000090?ooo`/000002@3oool000H0oooo1`00000=0?ooo`H000003P3oool2
00000080oooo0`00000A0?ooo`8000000`3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0
oooo000000d0oooo0P00000=0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo008000003@3oool2000000d0oooo00@000000?ooo`3oool0
00003@3oool010000000oooo0?ooo`3oool200000140oooo0`0000020?ooo`8000003@3oool70000
00d0oooo1`0000070?ooo`002@3oool4000000/0oooo1P00000>0?ooo`H000004@3oool3000000D0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo0P00000=0?ooo`@000004@3oool00`000000oooo0?ooo`0?0?ooo`<000003P3oool2000000d0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0
oooo0P00000B0?ooo`H000003@3oool7000000/0oooo0`00000;0?ooo`006`3oool3000000`0oooo
1P00000@0?ooo`<00000203oool00`000000oooo0?ooo`080?ooo`8000001P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo008000003P3oool3000000l0oooo00<000000?ooo`3oool0
3@3oool3000000h0oooo0P0000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
103oool2000000X0oooo00<000000?ooo`3oool01@3oool400000100oooo1P00000;0?ooo`<00000
7@3oool002T0oooo2000000=0?ooo`<000002`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00X0oooo00@000000?ooo`3oool0oooo0P00000=0?ooo`030000003oool0oooo00/0oooo
0P0000030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`090?ooo`<000003@3oool8000002X0oooo000`0?ooo`030000003oool0oooo00T0oooo1P00
000:0?ooo`030000003oool0oooo00<0oooo0`00000;0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo1000
00090?ooo`030000003oool0oooo00L0oooo100000050?ooo`030000003oool0oooo00P0oooo0P00
00070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool3000000D0oooo00<0
00000?ooo`3oool0203oool6000000/0oooo00<000000?ooo`3oool0;`3oool00340oooo00<00000
0?ooo`3oool01`3oool3000000l0oooo00@000000?ooo`3oool0oooo0P00000>0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool2000000P0oooo00<000000?ooo`3oool0203o
oolC000000X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0303oool2000000<0oooo00<000000?ooo`3oool0303o
ool4000000T0oooo00<000000?ooo`3oool0<03oool00340oooo00<000000?ooo`3oool06P3oool0
0`000000oooo00000003000000d0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`090?ooo`8000001P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0103oool2000000/0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`0;0?ooo`@0000000<0oooo0000003oool06`3oool00`000000oooo0?ooo`0`0?ooo`00<@3oool0
0`000000oooo0?ooo`0K0?ooo`<00000403oool00`000000oooo00000002000000h0oooo0P000004
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`02
0?ooo`8000003P3oool200000080oooo00<000000?ooo`3oool03P3oool3000001d0oooo00<00000
0?ooo`3oool0<03oool00340oooo00<000000?ooo`3oool06P3oool2000001<0oooo1@00000?0?oo
o`80000000<0oooo0000003oool04`3oool00`000000oooo0?ooo`0B0?ooo`040000003oool00000
000000l0oooo1@00000C0?ooo`800000703oool00`000000oooo0?ooo`0`0?ooo`00<P3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0100oooo1000000A0?ooo`<00000503oool00`00
0000oooo0?ooo`0B0?ooo`8000004P3oool3000001<0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0a0?ooo`00<P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0100
oooo1000000A0?ooo`D000004@3oool300000140oooo1000000B0?ooo`@000004P3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo0340oooo000b0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool03P3oool2000000<0oooo00<000000?ooo`3oool03P3oool300000080oooo
1000000=0?ooo`<000003@3oool400000080oooo0P00000A0?ooo`050000003oool0oooo0?ooo`00
00004@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0340oooo000b0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`800000
3P3oool3000000H0oooo1@0000080?ooo`<00000203oool5000000H0oooo0`00000>0?ooo`800000
1@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
<@3oool003<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00/0oooo0P00000<0?oooa<00000303oool2000000d0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0380oooo000c0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`8000005`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0380oooo000d0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool05@3oool200000240oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0<`3oool001D0
oooo0`00000?0?ooo`8000002`3oool2000000<0oooo0P00000@0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`<000003P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool300000100
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0
oooo0P0000030?ooo`8000002`3oool2000000l0oooo0P00000G0?ooo`00303oool00`000000oooo
0?ooo`020?ooo`@000003`3oool3000000h0oooo00@000000?ooo`0000000000403oool2000000/0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo0?oo
o`800000303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool02P3oool2000000<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00T0oooo0P00000@0?ooo`80000000<0oooo0000003oool03@3oool30000
00h0oooo100000050?ooo`030000003oool0oooo00/0oooo000:0?ooo`L00000303oool00`000000
oooo0?ooo`0400000140oooo0P00000A0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3o
ool000004@3oool00`000000oooo0?ooo`030?ooo`8000002@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool2000000D0oooo00<000000?oo
o`3oool03`3oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo00l0oooo0P00000A
0?ooo`<000000`3oool00`000000oooo0?ooo`090?ooo`@0000000@0oooo00000000000000002`3o
ool000P0oooo1P00000=0?ooo`D000003`3oool00`000000oooo0?ooo`03000000030?ooo`000000
oooo00h0oooo0P00000@0?ooo`8000004@3oool00`000000oooo0?ooo`060?ooo`8000001`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool3
000000P0oooo00<000000?ooo`3oool03`3oool200000100oooo0P00000?0?ooo`040000003oool0
0000000000<0oooo00<000000?ooo`3oool0303oool6000000d0oooo1P0000090?ooo`001`3oool7
000000/0oooo1P00000?0?ooo`@000001@3oool00`000000oooo0?ooo`0:0?ooo`8000004P3oool2
00000100oooo00<000000?ooo`3oool02@3oool3000000@0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo0P00000<0?ooo`030000003oool0
oooo00h0oooo0P00000B0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool5
000000l0oooo1P00000;0?ooo`L00000203oool001P0oooo1`00000=0?ooo`D000001P3oool00`00
0000oooo0?ooo`060?ooo`040000003oool0oooo000001<0oooo00@000000?ooo`3oool000003`3o
ool00`000000oooo0?ooo`0<0?ooo`@000004P3oool00`000000oooo0?ooo`0@0?ooo`@000003P3o
ool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo00000180oooo0P0000000`3oool00000
0?ooo`080?ooo`030000003oool0oooo00@0oooo1@00000=0?ooo`L000006@3oool002/0oooo1P00
00070?ooo`030000003oool0oooo00@0oooo1000000C0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0@0?ooo`D000003P3oool00`000000oooo0?oo
o`0<0?ooo`D000004P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool04@3oool3000000L0oooo00<000000?ooo`3oool01@3oool6000002`0oooo000Z
0?ooo`<000002`3oool00`000000oooo0?ooo`040?ooo`@00000403oool00`000000oooo00000006
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`02
0?ooo`D000002@3oool00`000000oooo0?ooo`070?ooo`D00000103oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000@
0?ooo`@000001P3oool00`000000oooo0?ooo`080?ooo`@00000:`3oool003T0oooo00<000000?oo
o`3oool00P3oool300000140oooo0`0000080?ooo`8000001`3oool00`000000oooo0000000C0?oo
o`030000003oool0oooo00L0oooo4`0000090?ooo`030000003oool0oooo0140oooo00<000000?oo
o`0000001`3oool2000000P0oooo0`00000A0?ooo`<00000103oool00`000000oooo0?ooo`0h0?oo
o`00>@3oool010000000oooo0?ooo`3oool2000001<0oooo100000090?ooo`030000003oool0oooo
00@0oooo0P00000C0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0A0?ooo`8000001P3oool00`000000oooo0?ooo`070?ooo`@000004`3oool20000
00<0oooo00<000000?ooo`3oool0>03oool003X0oooo00<000000?ooo`3oool0503oool4000000/0
oooo00<000000?ooo`3oool00P3oool400000100oooo0`00000C0?ooo`030000003oool0oooo0140
oooo0`00000@0?ooo`@00000103oool00`000000oooo0?ooo`090?ooo`@000005P3oool00`000000
oooo0?ooo`0i0?ooo`00>`3oool00`000000oooo0?ooo`0C0?ooo`8000003P3oool010000000oooo
0?ooo`3oool300000140oooo1000000A0?ooo`<000004@3oool400000140oooo0`0000030?ooo`03
0000003oool0oooo00`0oooo0P00000E0?ooo`030000003oool0oooo03X0oooo000k0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool03`3oool2000000030?ooo`00000000000180oooo
0`00000B0?ooo`<000004P3oool300000180oooo0P0000000`3oool000000000000A0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0>P3oool003`0oooo00<000000?ooo`3oool09@3o
ool2000001<0oooo0`00000B0?ooo`<000004P3oool3000001<0oooo0P00000W0?ooo`030000003o
ool0oooo03/0oooo000m0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`0000004P3oool2
000001<0oooo0`00000C0?ooo`8000004P3oool00`000000oooo0000000V0?ooo`030000003oool0
oooo03`0oooo000m0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool20000
01@0oooo00<000000?ooo`3oool04P3oool200000100oooo0P00000Y0?ooo`030000003oool0oooo
03`0oooo000n0?ooo`030000003oool0oooo02L0oooo0P00000?0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0?@3oool001H0oooo0P00000@0?ooo`030000003oool0oooo00l0oooo
00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool02`3oool2000000030?ooo`000000oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00@000000?ooo`00000000003@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000000A
0?ooo`030000003oool0oooo00h0oooo0P00000G0?ooo`00503oool200000100oooo0P00000@0?oo
o`8000001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03P3oool200000100oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00h0oooo0P00000@0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`030?ooo`800000403oool200000100oooo0P00000E0?oo
o`004@3oool300000100oooo0P00000@0?ooo`800000203oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo00000002000000d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0
oooo0`0000000`3oool000000?ooo`0@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`800000403oool200000100oooo0`00000B0?ooo`00
303oool00`000000oooo0?ooo`0200000140oooo0P00000A0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool200000100oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`030?ooo`8000002P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0203oool2000000D0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0>0?ooo`8000001@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo
0P00000A0?ooo`8000000P3oool00`000000oooo0?ooo`0;0?ooo`002P3oool5000000l0oooo00@0
00000?ooo`00000000004@3oool2000000`0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool3000000L0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo
0`0000070?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00X0oooo0P00000A0?ooo`80000000<0oooo0000003oool0
3P3oool4000000`0oooo00090?ooo`D000003`3oool3000000l0oooo00@000000?ooo`0000000000
3`3oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool02@3oool2000000D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00<0oooo0P00000;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0403oool010000000oooo0?ooo`00000?0?ooo`80000000<0oooo0000003oool03P3oool30000
00l0oooo1@00000:0?ooo`00203oool300000100oooo1@00000>0?ooo`<00000403oool010000000
oooo00000000000B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02`3oool40000
00030?ooo`000000oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo000000030000
00d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`80000000<0oooo0000
003oool03`3oool3000000h0oooo1@00000@0?ooo`<000002@3oool001X0oooo1000000?0?ooo`D0
00003P3oool500000140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`D0
00003P3oool00`000000oooo0?ooo`0<0?ooo`D000004P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00l0oooo1@00000>0?ooo`D000003`3oool4000001/0oooo000I0?ooo`800000
4@3oool400000100oooo100000000`3oool000000?ooo`0=0?ooo`8000004`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0080oooo2P0000040?ooo`030000003oool0oooo0080oooo
2P0000040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool2000000h0oooo
00<000000?ooo`0000000`00000@0?ooo`@000004@3oool2000001X0oooo000[0?ooo`8000004P3o
ool4000000<0oooo00<000000?ooo`3oool02P3oool400000100oooo0P00000C0?ooo`030000003o
ool0oooo00`0oooo2@00000>0?ooo`030000003oool0oooo0140oooo0P00000@0?ooo`@00000303o
ool010000000oooo0?ooo`3oool400000180oooo0P00000/0?ooo`00?`3oool2000000H0oooo00<0
00000?ooo`3oool02@3oool300000140oooo0`00000@0?ooo`<000004P3oool00`000000oooo0?oo
o`0@0?ooo`<00000403oool300000140oooo0`00000;0?ooo`030000003oool0oooo00@0oooo0P00
00100?ooo`00?P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0`00000A
0?ooo`<000004@3oool400000100oooo0`00000@0?ooo`@000004@3oool300000140oooo0`000009
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0?@3oool004T0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`8000004P3oool300000140oooo0`00000A0?oo
o`<000004P3oool2000001<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`180?oo
o`00BP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo0P00000B0?ooo`<0
00004@3oool300000140oooo0`00000B0?ooo`800000503oool00`000000oooo0?ooo`030?ooo`80
0000B`3oool004/0oooo0P00000H0?ooo`8000004`3oool200000180oooo0`00000B0?ooo`800000
4`3oool2000001P0oooo00<000000?ooo`3oool0B`3oool004d0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0B0?ooo`8000004`3oool00`000000oooo0?ooo`0A0?ooo`800000503o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04`0oooo001>0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0C@3oool001L0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000<
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0F0?ooo`005@3oool2
000000l0oooo0P00000A0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool2
000000l0oooo0P00000F0?ooo`004`3oool200000100oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03P3oool20000
01@0oooo000A0?ooo`800000403oool200000140oooo0P00000@0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`8000004@3oool200000100
oooo0P00000B0?ooo`003@3oool010000000oooo00000000000@0?ooo`8000004P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool200000003
0?ooo`000000oooo00d0oooo000<0?ooo`<000003`3oool00`000000oooo0000000C0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0403oool2000000030?ooo`000000oooo00h0oooo
0`00000=0?ooo`002P3oool5000000h0oooo0`00000@0?ooo`040000003oool0oooo00000140oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo
00@000000?ooo`3oool00000403oool3000000h0oooo1@00000;0?ooo`002@3oool6000000d0oooo
1@00000>0?ooo`@000003`3oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100
oooo00@000000?ooo`3oool000003`3oool4000000h0oooo1@00000=0?ooo`H000002P3oool000P0
oooo0`00000@0?ooo`@00000403oool4000000l0oooo0`00000B0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100
oooo0`00000?0?ooo`@00000403oool4000000l0oooo100000090?ooo`006P3oool200000180oooo
1000000?0?ooo`@000003`3oool300000180oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`800000403oool4000000l0oooo1000000B0?ooo`8000006`3oool002h0oooo0P00
000A0?ooo`<00000403oool4000000l0oooo0`00000B0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`<000003`3oool300000140oooo0`00
000A0?ooo`800000;`3oool002d0oooo00<000000?ooo`3oool0403oool300000140oooo0`00000@
0?ooo`@000003`3oool400000100oooo0`00000@0?ooo`@000003`3oool400000100oooo0`00000A
0?ooo`<000004P3oool00`000000oooo0?ooo`0/0?ooo`00@03oool00`000000oooo0?ooo`0@0?oo
o`<000004@3oool300000100oooo1000000@0?ooo`<00000403oool400000100oooo0`00000A0?oo
o`8000004`3oool00`000000oooo0?ooo`0o0?ooo`00?`3oool00`000000oooo0?ooo`0A0?ooo`80
00004P3oool200000140oooo0`00000A0?ooo`<000004@3oool300000140oooo0P00000B0?ooo`80
00004`3oool00`000000oooo0?ooo`0n0?ooo`00D`3oool00`000000oooo0?ooo`0@0?ooo`<00000
4P3oool200000140oooo0`00000A0?ooo`8000004P3oool300000180oooo00<000000?ooo`3oool0
DP3oool006H0oooo0P00000C0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0A0?ooo`800000I`3oool006H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`1U0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {282.875, 0}} -> {-2.39945, -2.33162, \
0.0167209, 0.0167209}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.07206 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0887636 1.1505 -3.05745e-17 1.1505 [
[.10718 .94059 -6.77329 0 ]
[.10718 .94059 5.22671 9 ]
[.29053 1.00145 -3.19569 0 ]
[.29053 1.00145 2.80431 9 ]
[.45748 1.05683 -3.02845 0 ]
[.45748 1.05683 2.97155 9 ]
[.28768 1.0738 -5.32312 0 ]
[.28768 1.0738 4.67688 9.8125 ]
[.90539 .88469 -5.12946 0 ]
[.90539 .88469 6.87054 9 ]
[.75186 .97108 -2.73227 0 ]
[.75186 .97108 3.26773 9 ]
[.61674 1.04709 -2.87186 0 ]
[.61674 1.04709 3.12814 9 ]
[.75825 1.04271 -4.55379 0 ]
[.75825 1.04271 5.44621 9.8125 ]
[.93099 .36573 0 -7.94995 ]
[.93099 .36573 6 1.05005 ]
[.9506 .4722 0 -7.7263 ]
[.9506 .4722 6 1.2737 ]
[.97204 .58865 0 -7.48579 ]
[.97204 .58865 6 1.51421 ]
[.99556 .71654 0 -7.22642 ]
[.99556 .71654 6 1.77358 ]
[1.0196 .48489 0 -8.3025 ]
[1.0196 .48489 10 1.51 ]
[ 0 0 0 0 ]
[ 1 1.07206 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .89001 m
.54651 1.07206 L
s
.10901 .92632 m
.10993 .91919 L
s
[(-2)] .10718 .94059 .12888 -1 Mshowa
.29147 .9871 m
.29194 .97993 L
s
[(0)] .29053 1.00145 .06523 -1 Mshowa
.45761 1.04244 m
.45768 1.03525 L
s
[(2)] .45748 1.05683 .00948 -1 Mshowa
.125 Mabswid
.15629 .94207 m
.15677 .93778 L
s
.20243 .95744 m
.20284 .95315 L
s
.24748 .97245 m
.24782 .96815 L
s
.33445 1.00142 m
.33466 .99711 L
s
.37644 1.01541 m
.3766 1.01109 L
s
.41748 1.02908 m
.41758 1.02476 L
s
.06057 .91018 m
.06119 .90592 L
s
.0109 .89364 m
.0116 .88938 L
s
.49685 1.05552 m
.49684 1.0512 L
s
.53523 1.0683 m
.53516 1.06399 L
s
gsave
.28768 1.0738 -66.3231 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
1.000 setlinewidth
grestore
.25 Mabswid
1 .81584 m
.54651 1.07206 L
s
.90333 .87046 m
.90229 .86335 L
s
[(-2)] .90539 .88469 -0.14509 -1 Mshowa
.75058 .95676 m
.74994 .9496 L
s
[(0)] .75186 .97108 -0.08924 -1 Mshowa
.61613 1.03272 m
.61582 1.02554 L
s
[(2)] .61674 1.04709 -0.04271 -1 Mshowa
.125 Mabswid
.86322 .89312 m
.86267 .88884 L
s
.82444 .91503 m
.82394 .91074 L
s
.78691 .93623 m
.78647 .93194 L
s
.71539 .97664 m
.71506 .97234 L
s
.68128 .99591 m
.681 .99161 L
s
.64821 1.0146 m
.64798 1.01029 L
s
.94482 .84702 m
.94413 .84276 L
s
.98777 .82275 m
.98701 .8185 L
s
.585 1.05031 m
.58486 1.046 L
s
.55477 1.06739 m
.55467 1.06308 L
s
gsave
.75825 1.04271 -65.5538 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
.25 Mabswid
.90663 .30341 m
1 .81584 L
s
.91958 .37448 m
.91388 .37885 L
s
[(0)] .93099 .36573 -1 .76666 Mshowa
.93891 .48058 m
.93307 .48477 L
s
[(2)] .9506 .4722 -1 .71696 Mshowa
.96005 .5966 m
.95406 .60058 L
s
[(4)] .97204 .58865 -1 .66351 Mshowa
.98326 .72399 m
.97711 .72772 L
s
[(6)] .99556 .71654 -1 .60587 Mshowa
.125 Mabswid
.92426 .40014 m
.92081 .40274 L
s
.92904 .42637 m
.92557 .42894 L
s
.93392 .45318 m
.93044 .45572 L
s
.94402 .5086 m
.94049 .51109 L
s
.94924 .53727 m
.94569 .53972 L
s
.95459 .56659 m
.95101 .56901 L
s
.96565 .62732 m
.96203 .62967 L
s
.97138 .65877 m
.96774 .66109 L
s
.97725 .69099 m
.97359 .69326 L
s
.915 .34935 m
.9116 .352 L
s
.91052 .32475 m
.90714 .32743 L
s
.98943 .75782 m
.98571 .76001 L
s
.99575 .79249 m
.99201 .79464 L
s
gsave
1.0196 .48489 -61 -12.3025 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
1.000 setlinewidth
grestore
.25 Mabswid
.41699 0 m
.39846 .53401 L
s
.39846 .53401 m
0 .89001 L
s
0 .89001 m
.08461 .38696 L
s
.08461 .38696 m
.41699 0 L
s
.90663 .30341 m
.53727 .59904 L
s
.53727 .59904 m
.54651 1.07206 L
s
.54651 1.07206 m
1 .81584 L
s
1 .81584 m
.90663 .30341 L
s
.41699 0 m
.39846 .53401 L
s
.39846 .53401 m
1 .81584 L
s
1 .81584 m
.90663 .30341 L
s
.90663 .30341 m
.41699 0 L
s
.08461 .38696 m
.53727 .59904 L
s
.53727 .59904 m
.54651 1.07206 L
s
.54651 1.07206 m
0 .89001 L
s
0 .89001 m
.08461 .38696 L
s
0 0 m
1 0 L
1 1.07206 L
0 1.07206 L
closepath
clip
newpath
.5 Mabswid
.46877 .63829 m .46826 .64165 L .38253 .62184 L p .499 .738 .98 r
F P
0 g
s
.46826 .64165 m .46877 .63829 L .55353 .64029 L p .479 .795 .999 r
F P
0 g
s
.55353 .64029 m .55571 .64296 L .46826 .64165 L p .479 .795 .999 r
F P
0 g
s
.38253 .62184 m .38573 .61822 L .46877 .63829 L p .499 .738 .98 r
F P
0 g
s
.46928 .63511 m .46877 .63829 L .38573 .61822 L p .472 .732 .983 r
F P
0 g
s
.46877 .63829 m .46928 .63511 L .55134 .63786 L p .439 .789 .997 r
F P
0 g
s
.55134 .63786 m .55353 .64029 L .46877 .63829 L p .439 .789 .997 r
F P
0 g
s
.38573 .61822 m .38253 .62184 L .30532 .58501 L p .551 .703 .94 r
F P
0 g
s
.55571 .64296 m .55353 .64029 L .63321 .62346 L p .54 .863 .996 r
F P
0 g
s
.63321 .62346 m .63796 .6251 L .55571 .64296 L p .54 .863 .996 r
F P
0 g
s
.30532 .58501 m .31109 .58165 L .38573 .61822 L p .551 .703 .94 r
F P
0 g
s
.38896 .61471 m .38573 .61822 L .31109 .58165 L p .538 .697 .942 r
F P
0 g
s
.38573 .61822 m .38896 .61471 L .46928 .63511 L p .472 .732 .983 r
F P
0 g
s
.4698 .63214 m .46928 .63511 L .38896 .61471 L p .438 .724 .986 r
F P
0 g
s
.46928 .63511 m .4698 .63214 L .54913 .63573 L p .385 .777 .988 r
F P
0 g
s
.54913 .63573 m .55134 .63786 L .46928 .63511 L p .385 .777 .988 r
F P
0 g
s
.55353 .64029 m .55134 .63786 L .62843 .62211 L p .505 .864 .988 r
F P
0 g
s
.62843 .62211 m .63321 .62346 L .55353 .64029 L p .505 .864 .988 r
F P
0 g
s
.31109 .58165 m .31688 .57833 L .38896 .61471 L p .538 .697 .942 r
F P
0 g
s
.3922 .61133 m .38896 .61471 L .31688 .57833 L p .522 .691 .944 r
F P
0 g
s
.38896 .61471 m .3922 .61133 L .4698 .63214 L p .438 .724 .986 r
F P
0 g
s
.47032 .62942 m .4698 .63214 L .3922 .61133 L p .395 .711 .986 r
F P
0 g
s
.4698 .63214 m .47032 .62942 L .54691 .63394 L p .315 .754 .966 r
F P
0 g
s
.54691 .63394 m .54913 .63573 L .4698 .63214 L p .315 .754 .966 r
F P
0 g
s
.55134 .63786 m .54913 .63573 L .62363 .62113 L p .456 .857 .97 r
F P
0 g
s
.62363 .62113 m .62843 .62211 L .55134 .63786 L p .456 .857 .97 r
F P
0 g
s
.31688 .57833 m .3227 .57507 L .3922 .61133 L p .522 .691 .944 r
F P
0 g
s
.39547 .60809 m .3922 .61133 L .3227 .57507 L p .504 .682 .946 r
F P
0 g
s
.3922 .61133 m .39547 .60809 L .47032 .62942 L p .395 .711 .986 r
F P
0 g
s
.47085 .62698 m .47032 .62942 L .39547 .60809 L p .34 .691 .981 r
F P
0 g
s
.47032 .62942 m .47085 .62698 L .54468 .63255 L p .221 .712 .923 r
F P
0 g
s
.54468 .63255 m .54691 .63394 L .47032 .62942 L p .221 .712 .923 r
F P
0 g
s
.54913 .63573 m .54691 .63394 L .61881 .62056 L p .388 .835 .932 r
F P
0 g
s
.61881 .62056 m .62363 .62113 L .54913 .63573 L p .388 .835 .932 r
F P
0 g
s
.31109 .58165 m .30532 .58501 L .24342 .53352 L p .602 .692 .906 r
F P
0 g
s
.3227 .57507 m .32856 .57186 L .39547 .60809 L p .504 .682 .946 r
F P
0 g
s
.39875 .60502 m .39547 .60809 L .32856 .57186 L p .482 .671 .947 r
F P
0 g
s
.39547 .60809 m .39875 .60502 L .47085 .62698 L p .34 .691 .981 r
F P
0 g
s
.63796 .6251 m .63321 .62346 L .70076 .58815 L p .66 .907 .98 r
F P
0 g
s
.70076 .58815 m .70783 .58849 L .63796 .6251 L p .66 .907 .98 r
F P
0 g
s
.24342 .53352 m .25142 .531 L .31109 .58165 L p .602 .692 .906 r
F P
0 g
s
.31688 .57833 m .31109 .58165 L .25142 .531 L p .597 .687 .905 r
F P
0 g
s
.47137 .62489 m .47085 .62698 L .39875 .60502 L p .268 .661 .968 r
F P
0 g
s
.47085 .62698 m .47137 .62489 L .54244 .63164 L p .1 .642 .846 r
F P
0 g
s
.4719 .62321 m .47244 .62202 L .512 .62786 L p .199 0 0 r
F P
0 g
s
.54244 .63164 m .54468 .63255 L .49056 .62847 L p .1 .642 .846 r
F P
0 g
s
.54244 .63164 m .49056 .62847 L .49273 .62841 L .1 .642 .846 r
F
.47137 .62489 m .4719 .62321 L .54018 .63131 L p 0 .538 .728 r
F P
0 g
s
.54018 .63131 m .53791 .63168 L .54122 .63128 L p .103 0 0 r
F P
0 g
s
.54691 .63394 m .54468 .63255 L .61397 .62048 L p .296 .791 .866 r
F P
0 g
s
.61397 .62048 m .61881 .62056 L .60357 .62339 L p .296 .791 .866 r
F P
0 g
s
.60357 .62339 m .54691 .63394 L p .59248 .62479 L .296 .791 .866 r
F P
0 g
s
.61397 .62048 m .60357 .62339 L .59248 .62479 L .296 .791 .866 r
F
.54468 .63255 m .54244 .63164 L .60911 .62099 L p .178 .713 .76 r
F P
0 g
s
.61143 .62092 m .58131 .62617 L p .60911 .62099 L .178 .713 .76 r
F P
0 g
s
.60911 .62099 m .58131 .62617 L .57727 .6267 L .178 .713 .76 r
F
.60643 .62142 m .56016 .62881 L p .60423 .62221 L 0 0 0 r
F P
0 g
s
.56016 .62881 m .54244 .63164 L p .56308 .62849 L 0 0 0 r
F P
0 g
s
.60423 .62221 m .56016 .62881 L .56308 .62849 L 0 0 0 r
F
.58131 .62617 m .54468 .63255 L p .57727 .6267 L .178 .713 .76 r
F P
0 g
s
.54244 .63164 m .54018 .63131 L .60423 .62221 L p 0 0 0 r
F P
0 g
s
.59933 .62428 m .60423 .62221 L .6014 .62261 L p .103 0 0 r
F P
0 g
s
.6014 .62261 m .54018 .63131 L p .59933 .62428 L .103 0 0 r
F P
0 g
s
.59933 .62428 m .59441 .62739 L .59699 .62616 L p 0 0 0 r
F P
0 g
s
.60423 .62221 m .59933 .62428 L .60175 .6231 L p 0 0 0 r
F P
0 g
s
.60423 .62221 m .60911 .62099 L .60643 .62142 L p 0 0 0 r
F P
0 g
s
.60911 .62099 m .60423 .62221 L .60651 .62107 L p .416 .855 .755 r
F P
0 g
s
.60651 .62107 m .65789 .59553 L p .60911 .62099 L .416 .855 .755 r
F P
0 g
s
.65069 .59922 m .65789 .59553 L .65337 .59777 L p 0 0 0 r
F P
0 g
s
.65337 .59777 m .60423 .62221 L p .63349 .60773 L 0 0 0 r
F P
0 g
s
.65069 .59922 m .65337 .59777 L .63349 .60773 L 0 0 0 r
F
.61397 .62048 m .60911 .62099 L .66508 .59275 L p .503 .91 .853 r
F P
0 g
s
.65789 .59553 m .66508 .59275 L .60911 .62099 L p .416 .855 .755 r
F P
0 g
s
.59699 .62616 m .64348 .60404 L p .6126 .61819 L 0 0 0 r
F P
0 g
s
.60175 .6231 m .65069 .59922 L p .63349 .60773 L 0 0 0 r
F P
0 g
s
.63349 .60773 m .60423 .62221 L .60182 .62307 L 0 0 0 r
F
.63349 .60773 m .60182 .62307 L .60175 .6231 L F
.6126 .61819 m .59933 .62428 L .59748 .62577 L F
.6126 .61819 m .59748 .62577 L .59699 .62616 L F
.55732 .62934 m .57769 .62689 L p .56234 .62868 L .103 0 0 r
F P
0 g
s
.57769 .62689 m .59933 .62428 L p .57392 .6273 L .103 0 0 r
F P
0 g
s
.57392 .6273 m .56234 .62868 L .57769 .62689 L .103 0 0 r
F
.60911 .62099 m .61397 .62048 L .61143 .62092 L p .178 .713 .76 r
F P
0 g
s
.54122 .63128 m .55732 .62934 L p .55143 .62997 L .103 0 0 r
F P
0 g
s
.56234 .62868 m .55143 .62997 L .55732 .62934 L .103 0 0 r
F
.55143 .62997 m .54018 .63131 L .54104 .63129 L F
.55143 .62997 m .54104 .63129 L .54122 .63128 L F
.54018 .63131 m .54244 .63164 L .53926 .63134 L p 0 .538 .728 r
F P
0 g
s
.53926 .63134 m .49064 .62672 L p .54018 .63131 L 0 .538 .728 r
F P
0 g
s
.49064 .62672 m .47137 .62489 L p .49263 .62687 L 0 .538 .728 r
F P
0 g
s
.54018 .63131 m .49064 .62672 L .49263 .62687 L 0 .538 .728 r
F
.53791 .63168 m .54018 .63131 L .49071 .62544 L p .199 0 0 r
F P
0 g
s
.49071 .62544 m .4719 .62321 L p .49252 .62585 L .199 0 0 r
F P
0 g
s
.53791 .63168 m .49071 .62544 L .49252 .62585 L .199 0 0 r
F
.50883 .62795 m .49252 .62585 L .512 .62786 L F
.49252 .62585 m .4719 .62321 L .49021 .62533 L F
.49252 .62585 m .49021 .62533 L .512 .62786 L F
.512 .62786 m .53791 .63168 L p .50883 .62795 L F P
0 g
s
.53563 .6329 m .53791 .63168 L .49077 .62472 L p .345 0 0 r
F P
0 g
s
.49077 .62472 m .47244 .62202 L p .4924 .62545 L .345 0 0 r
F P
0 g
s
.53563 .6329 m .49077 .62472 L .4924 .62545 L .345 0 0 r
F
.47297 .62142 m .48181 .62304 L p .47479 .62227 L F P
0 g
s
.49006 .62492 m .47244 .62202 L .48181 .62304 L .345 0 0 r
F
.50719 .628 m .47957 .62324 L .51014 .62823 L F
.47957 .62324 m .47244 .62202 L .47927 .62314 L F
.47957 .62324 m .47927 .62314 L .51014 .62823 L F
.47351 .62155 m .50827 .62945 L p .47589 .62208 L .465 0 0 r
F P
0 g
s
.47297 .62142 m .47351 .62155 L p .47589 .62208 L .465 0 0 r
F P
0 g
s
.50555 .62883 m .47297 .62142 L .50827 .62945 L .465 0 0 r
F
.48181 .62304 m .51014 .62823 L p .49006 .62492 L .345 0 0 r
F P
0 g
s
.51014 .62823 m .53563 .6329 L p .50719 .628 L .345 0 0 r
F P
0 g
s
.53334 .63515 m .53563 .6329 L .47297 .62142 L p .465 0 0 r
F P
0 g
s
.4121 .59515 m .41549 .59352 L .47351 .62155 L p 0 .317 .668 r
F P
0 g
s
.47297 .62142 m .41639 .597 L p .47038 .6202 L 0 .317 .668 r
F P
0 g
s
.47351 .62155 m .47297 .62142 L p .47038 .6202 L 0 .317 .668 r
F P
0 g
s
.40873 .59717 m .4121 .59515 L .47297 .62142 L p 0 .448 .799 r
F P
0 g
s
.47297 .62142 m .47244 .62202 L .40873 .59717 L p 0 .448 .799 r
F P
0 g
s
.47351 .62155 m .47085 .62026 L p .47223 .62126 L .428 0 0 r
F P
0 g
s
.47244 .62202 m .47297 .62142 L p .47479 .62227 L .345 0 0 r
F P
0 g
s
.47405 .62257 m .47351 .62155 L p .47223 .62126 L .428 0 0 r
F P
0 g
s
.47038 .6202 m .41639 .597 L .4193 .59824 L 0 .317 .668 r
F
.47085 .62026 m .41956 .59549 L p .46618 .61867 L .428 0 0 r
F P
0 g
s
.46618 .61867 m .41956 .59549 L .42231 .59691 L .428 0 0 r
F
.41549 .59352 m .4189 .59238 L .46633 .61835 L p F P
0 g
s
.47405 .62257 m .47085 .62026 L .46618 .61867 L .428 0 0 r
F
.46633 .61835 m .47405 .62257 L p .46055 .61587 L F P
0 g
s
.41956 .59549 m .41549 .59352 L p .42231 .59691 L .428 0 0 r
F P
0 g
s
.46055 .61587 m .41549 .59352 L .46633 .61835 L .428 0 0 r
F
.40539 .59952 m .40873 .59717 L .47244 .62202 L p .054 .547 .887 r
F P
0 g
s
.47244 .62202 m .4719 .62321 L .40539 .59952 L p .054 .547 .887 r
F P
0 g
s
.47459 .6247 m .47405 .62257 L .42274 .59449 L p .572 0 0 r
F P
0 g
s
.42274 .59449 m .4189 .59238 L p .42533 .59611 L .572 0 0 r
F P
0 g
s
.47459 .6247 m .42274 .59449 L .42533 .59611 L .572 0 0 r
F
.4189 .59238 m .42233 .59182 L .46706 .61996 L p F P
0 g
s
.46141 .61705 m .4189 .59238 L .46706 .61996 L .572 0 0 r
F
.4719 .62321 m .47137 .62489 L .40206 .60215 L p .174 .615 .94 r
F P
0 g
s
.40206 .60215 m .40539 .59952 L .4719 .62321 L p .174 .615 .94 r
F P
0 g
s
.46706 .61996 m .47459 .6247 L p .46141 .61705 L .572 0 0 r
F P
0 g
s
.49056 .62847 m .47085 .62698 L p .49273 .62841 L .1 .642 .846 r
F P
0 g
s
.39875 .60502 m .40206 .60215 L .47137 .62489 L p .268 .661 .968 r
F P
0 g
s
.47513 .62824 m .47459 .6247 L .42945 .5963 L p .68 .135 0 r
F P
0 g
s
.47513 .62824 m .42945 .5963 L .43045 .59722 L .68 .135 0 r
F
.47513 .62824 m .42594 .59409 L .42835 .59598 L F
.42945 .5963 m .42594 .59409 L p .43045 .59722 L F P
0 g
s
.42594 .59409 m .42233 .59182 L p .42835 .59598 L .68 .135 0 r
F P
0 g
s
.42233 .59182 m .42578 .59197 L .46778 .62284 L p .68 .135 0 r
F P
0 g
s
.46227 .61937 m .42233 .59182 L .46778 .62284 L .68 .135 0 r
F
.46778 .62284 m .47513 .62824 L p .46227 .61937 L F P
0 g
s
.47568 .63357 m .47513 .62824 L .43239 .59683 L p .754 .248 .011 r
F P
0 g
s
.43239 .59683 m .42578 .59197 L p .43411 .59892 L .754 .248 .011 r
F P
0 g
s
.47568 .63357 m .43239 .59683 L .43411 .59892 L .754 .248 .011 r
F
.42578 .59197 m .42925 .593 L .43236 .59572 L p F P
0 g
s
.43556 .59852 m .46852 .62731 L p .437 .60125 L .754 .248 .011 r
F P
0 g
s
.42925 .593 m .43274 .59513 L .43574 .59831 L p .8 .336 .13 r
F P
0 g
s
.46314 .62312 m .42578 .59197 L .46852 .62731 L .754 .248 .011 r
F
.43236 .59572 m .43556 .59852 L p .43405 .59881 L F P
0 g
s
.437 .60125 m .43405 .59881 L .43556 .59852 L .754 .248 .011 r
F
.43405 .59881 m .42578 .59197 L .43236 .59572 L F
.46852 .62731 m .47568 .63357 L p .46314 .62312 L F P
0 g
s
.47622 .64124 m .47568 .63357 L .43532 .59831 L p .8 .336 .13 r
F P
0 g
s
.43532 .59831 m .42925 .593 L p .4369 .60086 L .8 .336 .13 r
F P
0 g
s
.47622 .64124 m .43532 .59831 L .4369 .60086 L .8 .336 .13 r
F
.43574 .59831 m .43905 .60183 L p .43713 .60099 L F P
0 g
s
.43905 .60183 m .44239 .60536 L p .44031 .60421 L .8 .336 .13 r
F P
0 g
s
.4434 .60735 m .44031 .60421 L .44239 .60536 L .8 .336 .13 r
F
.44031 .60421 m .43713 .60099 L .43905 .60183 L F
.44239 .60536 m .46278 .62699 L p .4434 .60735 L F P
0 g
s
.43713 .60099 m .42925 .593 L .43574 .59831 L .8 .336 .13 r
F
.46278 .62699 m .47622 .64124 L p .45855 .6231 L F P
0 g
s
.45855 .6231 m .42925 .593 L .46278 .62699 L .8 .336 .13 r
F
.47677 .65202 m .47622 .64124 L .43825 .60097 L p .83 .402 .222 r
F P
0 g
s
.43825 .60097 m .43274 .59513 L p .43967 .60408 L .83 .402 .222 r
F P
0 g
s
.47677 .65202 m .43825 .60097 L .43967 .60408 L .83 .402 .222 r
F
.44073 .60537 m .43776 .60156 L .43932 .6027 L F
.43625 .59866 m .43932 .6027 L p .43776 .60156 L F P
0 g
s
.45965 .6299 m .44087 .60564 L .46376 .63489 L .83 .402 .222 r
F
.44087 .60564 m .43274 .59513 L .44073 .60537 L F
.44087 .60564 m .44073 .60537 L .46376 .63489 L F
.43932 .6027 m .46376 .63489 L p .44073 .60537 L F P
0 g
s
.46376 .63489 m .47677 .65202 L p .45965 .6299 L .83 .402 .222 r
F P
0 g
s
.47731 .66704 m .47677 .65202 L .43625 .59866 L p .848 .452 .292 r
F P
0 g
s
.40161 .54082 m .40797 .53871 L .43978 .60397 L p 0 0 .408 r
F P
0 g
s
.43534 .59516 m .43485 .59386 L .43314 .59061 L .66 .284 0 r
F
.43625 .59866 m .43978 .60397 L p .44176 .60779 L .848 .452 .292 r
F P
0 g
s
.43719 .59897 m .43668 .5977 L .43534 .59516 L .66 .284 0 r
F
.43978 .60397 m .4429 .60921 L p .44176 .60779 L .848 .452 .292 r
F P
0 g
s
.4429 .60921 m .46477 .64596 L p .44428 .61198 L .848 .452 .292 r
F P
0 g
s
.44428 .61198 m .44176 .60779 L .4429 .60921 L .848 .452 .292 r
F
.46477 .64596 m .47731 .66704 L p .46076 .63948 L F P
0 g
s
.46076 .63948 m .44444 .6123 L .46477 .64596 L .848 .452 .292 r
F
.44444 .6123 m .43625 .59866 L .44428 .61198 L F
.44444 .6123 m .44428 .61198 L .46477 .64596 L F
.4429 .60921 m .43978 .60397 L p .44611 .61795 L .861 .49 .346 r
F P
0 g
s
.43978 .60397 m .44333 .61162 L p .44588 .61743 L .861 .49 .346 r
F P
0 g
s
.47784 .68801 m .4429 .60921 L .44611 .61795 L .861 .49 .346 r
F
.46188 .65278 m .44611 .61795 L .45918 .64677 L F
.44611 .61795 m .43978 .60397 L .44588 .61743 L F
.44611 .61795 m .44588 .61743 L .45918 .64677 L F
.41007 .53791 m .41439 .53627 L .44333 .61162 L p .66 .284 0 r
F P
0 g
s
.43984 .60371 m .43994 .6033 L .43891 .60123 L .732 .384 0 r
F
.43978 .60397 m .43318 .59339 L .43188 .59091 L 0 0 .408 r
F
.43978 .60397 m .43625 .59866 L p .43521 .59665 L F P
0 g
s
.44333 .61162 m .43845 .6014 L .43719 .59897 L .66 .284 0 r
F
.43845 .6014 m .43668 .5977 L .43719 .59897 L F
.43668 .5977 m .43485 .59386 L .43534 .59516 L F
.43978 .60397 m .4372 .59868 L p .43845 .6014 L F P
0 g
s
.4372 .59868 m .43485 .59386 L p .43668 .5977 L .66 .284 0 r
F P
0 g
s
.43845 .6014 m .4372 .59868 L .43668 .5977 L .66 .284 0 r
F
.44333 .61162 m .43978 .60397 L p .43845 .6014 L F P
0 g
s
.43485 .59386 m .40797 .53871 L p .43314 .59061 L .66 .284 0 r
F P
0 g
s
.40797 .53871 m .41007 .53791 L p .44333 .61162 L .66 .284 0 r
F P
0 g
s
.46287 .65495 m .45918 .64677 L .46579 .66133 L .861 .49 .346 r
F
.46188 .65278 m .45918 .64677 L .46287 .65495 L F
.44333 .61162 m .46579 .66133 L p .44588 .61743 L F P
0 g
s
.46579 .66133 m .47784 .68801 L p .46188 .65278 L .861 .49 .346 r
F P
0 g
s
.47837 .71766 m .47784 .68801 L .44333 .61162 L p .869 .52 .386 r
F P
0 g
s
.44689 .62238 m .47837 .71766 L p .46504 .67732 L .869 .52 .386 r
F P
0 g
s
.44333 .61162 m .44689 .62238 L p .46504 .67732 L .869 .52 .386 r
F P
0 g
s
.44689 .62238 m .44128 .60698 L .43984 .60371 L .732 .384 0 r
F
.44128 .60698 m .43994 .6033 L .43984 .60371 L F
.43891 .60123 m .4365 .59386 L .43506 .59104 L F
.43994 .6033 m .4365 .59386 L .43891 .60123 L F
.44333 .61162 m .44075 .60492 L p .44128 .60698 L F P
0 g
s
.44075 .60492 m .4365 .59386 L p .43994 .6033 L .732 .384 0 r
F P
0 g
s
.44128 .60698 m .44075 .60492 L .43994 .6033 L .732 .384 0 r
F
.44689 .62238 m .44333 .61162 L p .44128 .60698 L F P
0 g
s
.4365 .59386 m .41439 .53627 L p .43506 .59104 L .732 .384 0 r
F P
0 g
s
.41439 .53627 m .41787 .53453 L p .44689 .62238 L .732 .384 0 r
F P
0 g
s
.47784 .68801 m .47731 .66704 L .4429 .60921 L p .861 .49 .346 r
F P
0 g
s
.41787 .53453 m .42087 .53303 L .44689 .62238 L p .732 .384 0 r
F P
0 g
s
.43188 .59091 m .4312 .59023 L .42939 .58678 L 0 0 .408 r
F
.43318 .59339 m .4312 .59023 L .43188 .59091 L F
.43274 .59513 m .43625 .59866 L p .43776 .60156 L .83 .402 .222 r
F P
0 g
s
.43625 .59866 m .4312 .59023 L p .43521 .59665 L 0 0 .408 r
F P
0 g
s
.4312 .59023 m .40161 .54082 L p .42939 .58678 L 0 0 .408 r
F P
0 g
s
.41639 .597 m .4121 .59515 L p .4193 .59824 L 0 .317 .668 r
F P
0 g
s
.47351 .62155 m .47405 .62257 L .5064 .63173 L p .553 .029 0 r
F P
0 g
s
.5064 .63173 m .53105 .63871 L p .50392 .63062 L .553 .029 0 r
F P
0 g
s
.50392 .63062 m .47351 .62155 L .5064 .63173 L .553 .029 0 r
F
.50827 .62945 m .53334 .63515 L p .50555 .62883 L .465 0 0 r
F P
0 g
s
.32856 .57186 m .33445 .56872 L .39875 .60502 L p .482 .671 .947 r
F P
0 g
s
.40206 .60215 m .39875 .60502 L .33445 .56872 L p .456 .658 .948 r
F P
0 g
s
.63321 .62346 m .62843 .62211 L .69367 .58814 L p .649 .92 .977 r
F P
0 g
s
.69367 .58814 m .70076 .58815 L .63321 .62346 L p .649 .92 .977 r
F P
0 g
s
.25142 .531 m .25946 .52848 L .31688 .57833 L p .597 .687 .905 r
F P
0 g
s
.3227 .57507 m .31688 .57833 L .25946 .52848 L p .592 .682 .904 r
F P
0 g
s
.25946 .52848 m .26752 .52595 L .3227 .57507 L p .592 .682 .904 r
F P
0 g
s
.32856 .57186 m .3227 .57507 L .26752 .52595 L p .586 .676 .903 r
F P
0 g
s
.33445 .56872 m .34038 .56566 L .40206 .60215 L p .456 .658 .948 r
F P
0 g
s
.40539 .59952 m .40206 .60215 L .34038 .56566 L p .423 .641 .947 r
F P
0 g
s
.62843 .62211 m .62363 .62113 L .68655 .58852 L p .632 .931 .969 r
F P
0 g
s
.68655 .58852 m .69367 .58814 L .62843 .62211 L p .632 .931 .969 r
F P
0 g
s
.26752 .52595 m .27562 .52342 L .32856 .57186 L p .586 .676 .903 r
F P
0 g
s
.33445 .56872 m .32856 .57186 L .27562 .52342 L p .579 .669 .901 r
F P
0 g
s
.34038 .56566 m .34633 .56268 L .40539 .59952 L p .423 .641 .947 r
F P
0 g
s
.40873 .59717 m .40539 .59952 L .34633 .56268 L p .384 .619 .944 r
F P
0 g
s
.62363 .62113 m .61881 .62056 L .67941 .58936 L p .606 .938 .95 r
F P
0 g
s
.67941 .58936 m .68655 .58852 L .62363 .62113 L p .606 .938 .95 r
F P
0 g
s
.27562 .52342 m .28375 .52087 L .33445 .56872 L p .579 .669 .901 r
F P
0 g
s
.34038 .56566 m .33445 .56872 L .28375 .52087 L p .571 .661 .898 r
F P
0 g
s
.34633 .56268 m .35232 .55979 L .40873 .59717 L p .384 .619 .944 r
F P
0 g
s
.4121 .59515 m .40873 .59717 L .35232 .55979 L p .335 .59 .938 r
F P
0 g
s
.28375 .52087 m .29191 .5183 L .34038 .56566 L p .571 .661 .898 r
F P
0 g
s
.34633 .56268 m .34038 .56566 L .29191 .5183 L p .563 .652 .895 r
F P
0 g
s
.61881 .62056 m .61397 .62048 L .67226 .59074 L p .565 .933 .915 r
F P
0 g
s
.67226 .59074 m .67941 .58936 L .61881 .62056 L p .565 .933 .915 r
F P
0 g
s
.29191 .5183 m .30011 .51569 L .34633 .56268 L p .563 .652 .895 r
F P
0 g
s
.35232 .55979 m .34633 .56268 L .30011 .51569 L p .553 .641 .891 r
F P
0 g
s
.35232 .55979 m .35835 .55701 L .4121 .59515 L p .335 .59 .938 r
F P
0 g
s
.41549 .59352 m .4121 .59515 L .35835 .55701 L p .274 .552 .927 r
F P
0 g
s
.25142 .531 m .24342 .53352 L .20351 .47082 L p .642 .699 .887 r
F P
0 g
s
.66508 .59275 m .67226 .59074 L .61397 .62048 L p .503 .91 .853 r
F P
0 g
s
.20351 .47082 m .21318 .46975 L .25142 .531 L p .642 .699 .887 r
F P
0 g
s
.25946 .52848 m .25142 .531 L .21318 .46975 L p .641 .696 .885 r
F P
0 g
s
.30011 .51569 m .30835 .51304 L .35232 .55979 L p .553 .641 .891 r
F P
0 g
s
.35835 .55701 m .35232 .55979 L .30835 .51304 L p .543 .628 .886 r
F P
0 g
s
.70783 .58849 m .70076 .58815 L .74908 .53622 L p .748 .888 .943 r
F P
0 g
s
.74908 .53622 m .75803 .53501 L .70783 .58849 L p .748 .888 .943 r
F P
0 g
s
.53791 .63168 m .53563 .6329 L .59441 .62739 L p .231 0 0 r
F P
0 g
s
.59441 .62739 m .59933 .62428 L .53791 .63168 L p .231 0 0 r
F P
0 g
s
.21318 .46975 m .22287 .46865 L .25946 .52848 L p .641 .696 .885 r
F P
0 g
s
.26752 .52595 m .25946 .52848 L .22287 .46865 L p .641 .693 .883 r
F P
0 g
s
.35835 .55701 m .36441 .55434 L .41549 .59352 L p .274 .552 .927 r
F P
0 g
s
.4189 .59238 m .41549 .59352 L .36441 .55434 L p .198 .501 .907 r
F P
0 g
s
.30835 .51304 m .31662 .51031 L .35835 .55701 L p .543 .628 .886 r
F P
0 g
s
.36441 .55434 m .35835 .55701 L .31662 .51031 L p .532 .613 .879 r
F P
0 g
s
.70076 .58815 m .69367 .58814 L .74013 .53776 L p .755 .903 .943 r
F P
0 g
s
.74013 .53776 m .74908 .53622 L .70076 .58815 L p .755 .903 .943 r
F P
0 g
s
.22287 .46865 m .23258 .4675 L .26752 .52595 L p .641 .693 .883 r
F P
0 g
s
.27562 .52342 m .26752 .52595 L .23258 .4675 L p .64 .69 .88 r
F P
0 g
s
.53105 .63871 m .53334 .63515 L .47351 .62155 L p .553 .029 0 r
F P
0 g
s
.23258 .4675 m .24231 .46629 L .27562 .52342 L p .64 .69 .88 r
F P
0 g
s
.28375 .52087 m .27562 .52342 L .24231 .46629 L p .64 .686 .877 r
F P
0 g
s
.53563 .6329 m .53334 .63515 L .58949 .63177 L p .336 0 0 r
F P
0 g
s
.58949 .63177 m .59441 .62739 L .53563 .6329 L p .336 0 0 r
F P
0 g
s
.31662 .51031 m .32494 .50749 L .36441 .55434 L p .532 .613 .879 r
F P
0 g
s
.37051 .55179 m .36441 .55434 L .32494 .50749 L p .519 .596 .871 r
F P
0 g
s
.36441 .55434 m .37051 .55179 L .4189 .59238 L p .198 .501 .907 r
F P
0 g
s
.69367 .58814 m .68655 .58852 L .73117 .53969 L p .762 .919 .941 r
F P
0 g
s
.73117 .53969 m .74013 .53776 L .69367 .58814 L p .762 .919 .941 r
F P
0 g
s
.42233 .59182 m .4189 .59238 L .37051 .55179 L p .105 .435 .875 r
F P
0 g
s
.24231 .46629 m .25206 .46502 L .28375 .52087 L p .64 .686 .877 r
F P
0 g
s
.29191 .5183 m .28375 .52087 L .25206 .46502 L p .64 .682 .874 r
F P
0 g
s
.25206 .46502 m .26182 .46365 L .29191 .5183 L p .64 .682 .874 r
F P
0 g
s
.30011 .51569 m .29191 .5183 L .26182 .46365 L p .641 .678 .869 r
F P
0 g
s
.32494 .50749 m .33329 .50452 L .37051 .55179 L p .519 .596 .871 r
F P
0 g
s
.37665 .54937 m .37051 .55179 L .33329 .50452 L p .506 .576 .86 r
F P
0 g
s
.37051 .55179 m .37665 .54937 L .42233 .59182 L p .105 .435 .875 r
F P
0 g
s
.68655 .58852 m .67941 .58936 L .72219 .54205 L p .769 .937 .938 r
F P
0 g
s
.72219 .54205 m .73117 .53969 L .68655 .58852 L p .769 .937 .938 r
F P
0 g
s
.47405 .62257 m .47459 .6247 L .52874 .64389 L p .614 .133 .089 r
F P
0 g
s
.52874 .64389 m .53105 .63871 L .47405 .62257 L p .614 .133 .089 r
F P
0 g
s
.26182 .46365 m .27161 .46216 L .30011 .51569 L p .641 .678 .869 r
F P
0 g
s
.30835 .51304 m .30011 .51569 L .27161 .46216 L p .642 .673 .864 r
F P
0 g
s
.42578 .59197 m .42233 .59182 L .37665 .54937 L p 0 .348 .825 r
F P
0 g
s
.53334 .63515 m .53105 .63871 L .58455 .63776 L p .414 0 .051 r
F P
0 g
s
.58455 .63776 m .58949 .63177 L .53334 .63515 L p .414 0 .051 r
F P
0 g
s
.27161 .46216 m .28143 .46053 L .30835 .51304 L p .642 .673 .864 r
F P
0 g
s
.31662 .51031 m .30835 .51304 L .28143 .46053 L p .644 .667 .858 r
F P
0 g
s
.33329 .50452 m .34169 .50135 L .37665 .54937 L p .506 .576 .86 r
F P
0 g
s
.38282 .54708 m .37665 .54937 L .34169 .50135 L p .493 .553 .846 r
F P
0 g
s
.37665 .54937 m .38282 .54708 L .42578 .59197 L p 0 .348 .825 r
F P
0 g
s
.63626 .61024 m .64348 .60404 L .64106 .60519 L p 0 0 0 r
F P
0 g
s
.64106 .60519 m .59441 .62739 L p .63626 .61024 L 0 0 0 r
F P
0 g
s
.62905 .61816 m .63626 .61024 L .63371 .61141 L p .076 0 0 r
F P
0 g
s
.63371 .61141 m .58949 .63177 L p .62905 .61816 L .076 0 0 r
F P
0 g
s
.62905 .61816 m .62184 .62827 L .62374 .62585 L p 0 0 0 r
F P
0 g
s
.63626 .61024 m .62905 .61816 L .63083 .61595 L p .635 .899 .581 r
F P
0 g
s
.6484 .60034 m .59933 .62428 L p .64348 .60404 L 0 0 0 r
F P
0 g
s
.59441 .62739 m .58949 .63177 L .63626 .61024 L p 0 0 0 r
F P
0 g
s
.63083 .61595 m .65934 .58066 L p .63626 .61024 L .635 .899 .581 r
F P
0 g
s
.62374 .62585 m .6504 .59186 L p .62905 .61816 L 0 0 0 r
F P
0 g
s
.64348 .60404 m .63626 .61024 L .63795 .60819 L p .704 .96 .703 r
F P
0 g
s
.63795 .60819 m .6683 .57152 L p .64348 .60404 L .704 .96 .703 r
F P
0 g
s
.64348 .60404 m .65069 .59922 L .6484 .60034 L p 0 0 0 r
F P
0 g
s
.67941 .58936 m .67226 .59074 L .71321 .54494 L p .775 .955 .93 r
F P
0 g
s
.71321 .54494 m .72219 .54205 L .67941 .58936 L p .775 .955 .93 r
F P
0 g
s
.28143 .46053 m .29127 .45871 L .31662 .51031 L p .644 .667 .858 r
F P
0 g
s
.32494 .50749 m .31662 .51031 L .29127 .45871 L p .646 .661 .85 r
F P
0 g
s
.47459 .6247 m .47513 .62824 L .52643 .65116 L p .655 .214 .191 r
F P
0 g
s
.52643 .65116 m .52874 .64389 L .47459 .6247 L p .655 .214 .191 r
F P
0 g
s
.34169 .50135 m .35013 .4979 L .38282 .54708 L p .493 .553 .846 r
F P
0 g
s
.38904 .54492 m .38282 .54708 L .35013 .4979 L p .479 .527 .829 r
F P
0 g
s
.38282 .54708 m .38904 .54492 L .42925 .593 L p 0 .24 .752 r
F P
0 g
s
.42925 .593 m .42578 .59197 L .38282 .54708 L p 0 .24 .752 r
F P
0 g
s
.29127 .45871 m .30113 .45665 L .32494 .50749 L p .646 .661 .85 r
F P
0 g
s
.33329 .50452 m .32494 .50749 L .30113 .45665 L p .649 .654 .842 r
F P
0 g
s
.67226 .59074 m .66508 .59275 L .70423 .54845 L p .779 .973 .916 r
F P
0 g
s
.70423 .54845 m .71321 .54494 L .67226 .59074 L p .779 .973 .916 r
F P
0 g
s
.30113 .45665 m .31103 .45427 L .33329 .50452 L p .649 .654 .842 r
F P
0 g
s
.34169 .50135 m .33329 .50452 L .31103 .45427 L p .654 .647 .831 r
F P
0 g
s
.53105 .63871 m .52874 .64389 L .57961 .64577 L p .471 .051 .161 r
F P
0 g
s
.57961 .64577 m .58455 .63776 L .53105 .63871 L p .471 .051 .161 r
F P
0 g
s
.38027 .36967 m .39094 .35485 L .39179 .39873 L p .906 .77 .7 r
F P
0 g
s
.39179 .39873 m .38146 .41355 L .38027 .36967 L p .906 .77 .7 r
F P
0 g
s
.38146 .41355 m .39179 .39873 L .40208 .45772 L p .749 .595 .685 r
F P
0 g
s
.39641 .40468 m .39179 .39873 L .39094 .35485 L p .354 .311 .672 r
F P
0 g
s
.39179 .39873 m .39641 .40468 L .40618 .4617 L p .312 .274 .655 r
F P
0 g
s
.40618 .4617 m .40208 .45772 L .39179 .39873 L p .312 .274 .655 r
F P
0 g
s
.35013 .4979 m .35862 .49404 L .38904 .54492 L p .479 .527 .829 r
F P
0 g
s
.3953 .54285 m .38904 .54492 L .35862 .49404 L p .467 .499 .808 r
F P
0 g
s
.38904 .54492 m .3953 .54285 L .43274 .59513 L p 0 .113 .655 r
F P
0 g
s
.43274 .59513 m .42925 .593 L .38904 .54492 L p 0 .113 .655 r
F P
0 g
s
.31103 .45427 m .32096 .45149 L .34169 .50135 L p .654 .647 .831 r
F P
0 g
s
.35013 .4979 m .34169 .50135 L .32096 .45149 L p .66 .639 .818 r
F P
0 g
s
.32096 .45149 m .33092 .44816 L .35013 .4979 L p .66 .639 .818 r
F P
0 g
s
.35862 .49404 m .35013 .4979 L .33092 .44816 L p .668 .631 .803 r
F P
0 g
s
.66508 .59275 m .65789 .59553 L .69524 .55269 L p .779 .989 .893 r
F P
0 g
s
.69524 .55269 m .70423 .54845 L .66508 .59275 L p .779 .989 .893 r
F P
0 g
s
.39009 .33726 m .3803 .34647 L .38314 .34362 L p .533 .848 .545 r
F P
0 g
s
.39009 .33726 m .39989 .32404 L .39821 .32982 L p .947 .957 .676 r
F P
0 g
s
.39565 .36204 m .39094 .35485 L .39989 .32404 L p .417 .358 .684 r
F P
0 g
s
.39989 .32404 m .40421 .33223 L .39565 .36204 L p .417 .358 .684 r
F P
0 g
s
.40421 .33223 m .39989 .32404 L .4181 .30576 L p .475 .397 .689 r
F P
0 g
s
.39989 .32404 m .39009 .33726 L .41031 .317 L p 0 0 0 r
F P
0 g
s
.38314 .34362 m .40251 .32421 L p .39009 .33726 L .533 .848 .545 r
F P
0 g
s
.39821 .32982 m .39094 .35485 L p .39009 .33726 L .947 .957 .676 r
F P
0 g
s
.39094 .35485 m .38027 .36967 L .39009 .33726 L p .947 .957 .676 r
F P
0 g
s
.39094 .35485 m .39565 .36204 L .39641 .40468 L p .354 .311 .672 r
F P
0 g
s
.40107 .41071 m .39641 .40468 L .39565 .36204 L p .359 .312 .669 r
F P
0 g
s
.39641 .40468 m .40107 .41071 L .41031 .46564 L p .32 .278 .654 r
F P
0 g
s
.41031 .46564 m .40618 .4617 L .39641 .40468 L p .32 .278 .654 r
F P
0 g
s
.33092 .44816 m .34092 .44411 L .35862 .49404 L p .668 .631 .803 r
F P
0 g
s
.36717 .4896 m .35862 .49404 L .34092 .44411 L p .679 .623 .786 r
F P
0 g
s
.35862 .49404 m .36717 .4896 L .3953 .54285 L p .467 .499 .808 r
F P
0 g
s
.47513 .62824 m .47568 .63357 L .52411 .66114 L p .683 .277 .27 r
F P
0 g
s
.52411 .66114 m .52643 .65116 L .47513 .62824 L p .683 .277 .27 r
F P
0 g
s
.40161 .54082 m .3953 .54285 L .36717 .4896 L p .456 .468 .782 r
F P
0 g
s
.3953 .54285 m .40161 .54082 L .43625 .59866 L p 0 0 .536 r
F P
0 g
s
.43625 .59866 m .43274 .59513 L .3953 .54285 L p 0 0 .536 r
F P
0 g
s
.40208 .45772 m .39322 .46922 L .38146 .41355 L p .749 .595 .685 r
F P
0 g
s
.39322 .46922 m .40208 .45772 L .42087 .53303 L p .46 .384 .685 r
F P
0 g
s
.40208 .45772 m .40618 .4617 L .42407 .53379 L p .306 .256 .637 r
F P
0 g
s
.42407 .53379 m .42087 .53303 L .40208 .45772 L p .306 .256 .637 r
F P
0 g
s
.36966 .38042 m .38027 .36967 L .38146 .41355 L p .871 .759 .736 r
F P
0 g
s
.38146 .41355 m .37123 .42447 L .36966 .38042 L p .871 .759 .736 r
F P
0 g
s
.37123 .42447 m .38146 .41355 L .39322 .46922 L p .727 .6 .715 r
F P
0 g
s
.40039 .36942 m .39565 .36204 L .40421 .33223 L p .417 .355 .68 r
F P
0 g
s
.39565 .36204 m .40039 .36942 L .40107 .41071 L p .359 .312 .669 r
F P
0 g
s
.34092 .44411 m .35097 .43908 L .36717 .4896 L p .679 .623 .786 r
F P
0 g
s
.37578 .4843 m .36717 .4896 L .35097 .43908 L p .691 .614 .765 r
F P
0 g
s
.36717 .4896 m .37578 .4843 L .40161 .54082 L p .456 .468 .782 r
F P
0 g
s
.58949 .63177 m .58455 .63776 L .62905 .61816 L p .076 0 0 r
F P
0 g
s
.35097 .43908 m .36107 .43271 L .37578 .4843 L p .691 .614 .765 r
F P
0 g
s
.38446 .47772 m .37578 .4843 L .36107 .43271 L p .707 .606 .741 r
F P
0 g
s
.37578 .4843 m .38446 .47772 L .40797 .53871 L p .45 .437 .753 r
F P
0 g
s
.40797 .53871 m .40161 .54082 L .37578 .4843 L p .45 .437 .753 r
F P
0 g
s
.40575 .41683 m .40107 .41071 L .40039 .36942 L p .364 .312 .666 r
F P
0 g
s
.40107 .41071 m .40575 .41683 L .41447 .46955 L p .328 .281 .652 r
F P
0 g
s
.41447 .46955 m .41031 .46564 L .40107 .41071 L p .328 .281 .652 r
F P
0 g
s
.39322 .46922 m .38446 .47772 L .37123 .42447 L p .727 .6 .715 r
F P
0 g
s
.38446 .47772 m .39322 .46922 L .41439 .53627 L p .45 .408 .72 r
F P
0 g
s
.42087 .53303 m .41439 .53627 L .39322 .46922 L p .46 .384 .685 r
F P
0 g
s
.36107 .43271 m .37123 .42447 L .38446 .47772 L p .707 .606 .741 r
F P
0 g
s
.41439 .53627 m .40797 .53871 L .38446 .47772 L p .45 .408 .72 r
F P
0 g
s
.65789 .59553 m .65069 .59922 L .68625 .55781 L p .77 .996 .854 r
F P
0 g
s
.68625 .55781 m .69524 .55269 L .65789 .59553 L p .77 .996 .854 r
F P
0 g
s
.52874 .64389 m .52643 .65116 L .57467 .65639 L p .513 .127 .246 r
F P
0 g
s
.57467 .65639 m .57961 .64577 L .52874 .64389 L p .513 .127 .246 r
F P
0 g
s
.21318 .46975 m .20351 .47082 L .19165 .40188 L p .668 .715 .884 r
F P
0 g
s
.40421 .33223 m .40853 .34067 L .40039 .36942 L p .417 .355 .68 r
F P
0 g
s
.40514 .37699 m .40039 .36942 L .40853 .34067 L p .417 .352 .676 r
F P
0 g
s
.40039 .36942 m .40514 .37699 L .40575 .41683 L p .364 .312 .666 r
F P
0 g
s
.19165 .40188 m .20212 .40281 L .21318 .46975 L p .668 .715 .884 r
F P
0 g
s
.22287 .46865 m .21318 .46975 L .20212 .40281 L p .669 .714 .882 r
F P
0 g
s
.40618 .4617 m .41031 .46564 L .4273 .53444 L p .314 .261 .637 r
F P
0 g
s
.4273 .53444 m .42407 .53379 L .40618 .4617 L p .314 .261 .637 r
F P
0 g
s
.35909 .38827 m .36966 .38042 L .37123 .42447 L p .839 .749 .765 r
F P
0 g
s
.37123 .42447 m .36107 .43271 L .35909 .38827 L p .839 .749 .765 r
F P
0 g
s
.20212 .40281 m .21258 .40368 L .22287 .46865 L p .669 .714 .882 r
F P
0 g
s
.23258 .4675 m .22287 .46865 L .21258 .40368 L p .672 .714 .88 r
F P
0 g
s
.75803 .53501 m .74908 .53622 L .77155 .47156 L p .769 .829 .899 r
F P
0 g
s
.77155 .47156 m .78165 .46858 L .75803 .53501 L p .769 .829 .899 r
F P
0 g
s
.21258 .40368 m .22304 .40447 L .23258 .4675 L p .672 .714 .88 r
F P
0 g
s
.24231 .46629 m .23258 .4675 L .22304 .40447 L p .674 .714 .878 r
F P
0 g
s
.41046 .42302 m .40575 .41683 L .40514 .37699 L p .368 .313 .664 r
F P
0 g
s
.40575 .41683 m .41046 .42302 L .41866 .47343 L p .336 .284 .651 r
F P
0 g
s
.41866 .47343 m .41447 .46955 L .40575 .41683 L p .336 .284 .651 r
F P
0 g
s
.41031 .317 m .4181 .30576 L .39989 .32404 L p 0 0 0 r
F P
0 g
s
.3803 .34647 m .39009 .33726 L .38027 .36967 L p .937 .949 .765 r
F P
0 g
s
.38027 .36967 m .36966 .38042 L .3803 .34647 L p .937 .949 .765 r
F P
0 g
s
.22304 .40447 m .23349 .40517 L .24231 .46629 L p .674 .714 .878 r
F P
0 g
s
.25206 .46502 m .24231 .46629 L .23349 .40517 L p .677 .713 .876 r
F P
0 g
s
.40853 .34067 m .41287 .34937 L .40514 .37699 L p .417 .352 .676 r
F P
0 g
s
.40992 .38475 m .40514 .37699 L .41287 .34937 L p .418 .349 .673 r
F P
0 g
s
.40514 .37699 m .40992 .38475 L .41046 .42302 L p .368 .313 .664 r
F P
0 g
s
.34856 .39401 m .35909 .38827 L .36107 .43271 L p .81 .74 .787 r
F P
0 g
s
.36107 .43271 m .35097 .43908 L .34856 .39401 L p .81 .74 .787 r
F P
0 g
s
.23349 .40517 m .24394 .40575 L .25206 .46502 L p .677 .713 .876 r
F P
0 g
s
.26182 .46365 m .25206 .46502 L .24394 .40575 L p .681 .713 .873 r
F P
0 g
s
.24394 .40575 m .25439 .4062 L .26182 .46365 L p .681 .713 .873 r
F P
0 g
s
.27161 .46216 m .26182 .46365 L .25439 .4062 L p .686 .713 .869 r
F P
0 g
s
.41031 .46564 m .41447 .46955 L .43054 .53497 L p .322 .265 .637 r
F P
0 g
s
.43054 .53497 m .4273 .53444 L .41031 .46564 L p .322 .265 .637 r
F P
0 g
s
.74908 .53622 m .74013 .53776 L .76146 .47482 L p .778 .836 .896 r
F P
0 g
s
.76146 .47482 m .77155 .47156 L .74908 .53622 L p .778 .836 .896 r
F P
0 g
s
.4181 .30576 m .42152 .31497 L .40421 .33223 L p .475 .397 .689 r
F P
0 g
s
.40853 .34067 m .40421 .33223 L .42152 .31497 L p .471 .391 .685 r
F P
0 g
s
.25439 .4062 m .26483 .40647 L .27161 .46216 L p .686 .713 .869 r
F P
0 g
s
.28143 .46053 m .27161 .46216 L .26483 .40647 L p .692 .714 .866 r
F P
0 g
s
.33805 .39821 m .34856 .39401 L .35097 .43908 L p .784 .733 .805 r
F P
0 g
s
.35097 .43908 m .34092 .44411 L .33805 .39821 L p .784 .733 .805 r
F P
0 g
s
.47568 .63357 m .47622 .64124 L .52179 .67472 L p .702 .325 .331 r
F P
0 g
s
.52179 .67472 m .52411 .66114 L .47568 .63357 L p .702 .325 .331 r
F P
0 g
s
.65069 .59922 m .64348 .60404 L .67727 .56401 L p .747 .99 .793 r
F P
0 g
s
.67727 .56401 m .68625 .55781 L .65069 .59922 L p .747 .99 .793 r
F P
0 g
s
.26483 .40647 m .27528 .40653 L .28143 .46053 L p .692 .714 .866 r
F P
0 g
s
.29127 .45871 m .28143 .46053 L .27528 .40653 L p .699 .714 .861 r
F P
0 g
s
.41519 .4293 m .41046 .42302 L .40992 .38475 L p .373 .313 .661 r
F P
0 g
s
.41046 .42302 m .41519 .4293 L .42287 .47726 L p .343 .287 .65 r
F P
0 g
s
.42287 .47726 m .41866 .47343 L .41046 .42302 L p .343 .287 .65 r
F P
0 g
s
.32756 .40124 m .33805 .39821 L .34092 .44411 L p .763 .727 .82 r
F P
0 g
s
.34092 .44411 m .33092 .44816 L .32756 .40124 L p .763 .727 .82 r
F P
0 g
s
.27528 .40653 m .28572 .40633 L .29127 .45871 L p .699 .714 .861 r
F P
0 g
s
.30113 .45665 m .29127 .45871 L .28572 .40633 L p .707 .716 .856 r
F P
0 g
s
.28572 .40633 m .29617 .40581 L .30113 .45665 L p .707 .716 .856 r
F P
0 g
s
.31103 .45427 m .30113 .45665 L .29617 .40581 L p .717 .717 .849 r
F P
0 g
s
.41287 .34937 m .41722 .35832 L .40992 .38475 L p .418 .349 .673 r
F P
0 g
s
.41471 .3927 m .40992 .38475 L .41722 .35832 L p .418 .346 .669 r
F P
0 g
s
.40992 .38475 m .41471 .3927 L .41519 .4293 L p .373 .313 .661 r
F P
0 g
s
.31709 .40339 m .32756 .40124 L .33092 .44816 L p .745 .723 .832 r
F P
0 g
s
.33092 .44816 m .32096 .45149 L .31709 .40339 L p .745 .723 .832 r
F P
0 g
s
.29617 .40581 m .30663 .40486 L .31103 .45427 L p .717 .717 .849 r
F P
0 g
s
.32096 .45149 m .31103 .45427 L .30663 .40486 L p .73 .72 .841 r
F P
0 g
s
.30663 .40486 m .31709 .40339 L .32096 .45149 L p .73 .72 .841 r
F P
0 g
s
.58455 .63776 m .57961 .64577 L .62184 .62827 L p .17 0 .038 r
F P
0 g
s
.62184 .62827 m .62905 .61816 L .58455 .63776 L p .17 0 .038 r
F P
0 g
s
.42152 .31497 m .42495 .32442 L .40853 .34067 L p .471 .391 .685 r
F P
0 g
s
.41287 .34937 m .40853 .34067 L .42495 .32442 L p .467 .386 .681 r
F P
0 g
s
.74013 .53776 m .73117 .53969 L .75138 .47842 L p .789 .845 .894 r
F P
0 g
s
.75138 .47842 m .76146 .47482 L .74013 .53776 L p .789 .845 .894 r
F P
0 g
s
.41447 .46955 m .41866 .47343 L .4338 .53538 L p .329 .269 .637 r
F P
0 g
s
.4338 .53538 m .43054 .53497 L .41447 .46955 L p .329 .269 .637 r
F P
0 g
s
.37052 .35276 m .3803 .34647 L .36966 .38042 L p .906 .922 .817 r
F P
0 g
s
.36966 .38042 m .35909 .38827 L .37052 .35276 L p .906 .922 .817 r
F P
0 g
s
.52643 .65116 m .52411 .66114 L .56974 .67041 L p .543 .185 .311 r
F P
0 g
s
.56974 .67041 m .57467 .65639 L .52643 .65116 L p .543 .185 .311 r
F P
0 g
s
.41996 .43566 m .41519 .4293 L .41471 .3927 L p .377 .313 .658 r
F P
0 g
s
.41519 .4293 m .41996 .43566 L .42712 .48106 L p .35 .29 .648 r
F P
0 g
s
.42712 .48106 m .42287 .47726 L .41519 .4293 L p .35 .29 .648 r
F P
0 g
s
.42495 .32442 m .42838 .33411 L .41287 .34937 L p .467 .386 .681 r
F P
0 g
s
.41722 .35832 m .41287 .34937 L .42838 .33411 L p .463 .38 .677 r
F P
0 g
s
.41722 .35832 m .42158 .36753 L .41471 .3927 L p .418 .346 .669 r
F P
0 g
s
.41954 .40086 m .41471 .3927 L .42158 .36753 L p .418 .343 .666 r
F P
0 g
s
.41471 .3927 m .41954 .40086 L .41996 .43566 L p .377 .313 .658 r
F P
0 g
s
.73117 .53969 m .72219 .54205 L .74131 .4824 L p .801 .854 .89 r
F P
0 g
s
.74131 .4824 m .75138 .47842 L .73117 .53969 L p .801 .854 .89 r
F P
0 g
s
.6683 .57152 m .67727 .56401 L .64348 .60404 L p .704 .96 .703 r
F P
0 g
s
.41866 .47343 m .42287 .47726 L .43708 .53567 L p .337 .273 .637 r
F P
0 g
s
.43708 .53567 m .4338 .53538 L .41866 .47343 L p .337 .273 .637 r
F P
0 g
s
.42838 .33411 m .43182 .34406 L .41722 .35832 L p .463 .38 .677 r
F P
0 g
s
.42158 .36753 m .41722 .35832 L .43182 .34406 L p .46 .375 .673 r
F P
0 g
s
.39471 .32847 m .40251 .32421 L .39919 .32754 L p .682 .969 .766 r
F P
0 g
s
.39919 .32754 m .3803 .34647 L p .39471 .32847 L .682 .969 .766 r
F P
0 g
s
.39471 .32847 m .3869 .33055 L .39087 .32927 L p .259 .762 .728 r
F P
0 g
s
.40251 .32421 m .39471 .32847 L .39897 .32725 L p 0 0 0 r
F P
0 g
s
.40669 .32062 m .39009 .33726 L p .40251 .32421 L .533 .848 .545 r
F P
0 g
s
.42495 .32442 m .42152 .31497 L .44602 .31239 L p .503 .409 .682 r
F P
0 g
s
.39897 .32725 m .42947 .31852 L p .40251 .32421 L 0 0 0 r
F P
0 g
s
.40251 .32421 m .41031 .317 L .40669 .32062 L p .533 .848 .545 r
F P
0 g
s
.41031 .317 m .40251 .32421 L .4343 .31645 L p .185 0 0 r
F P
0 g
s
.42947 .31852 m .4343 .31645 L .43094 .31727 L p 0 0 0 r
F P
0 g
s
.43094 .31727 m .40251 .32421 L p .41988 .32054 L 0 0 0 r
F P
0 g
s
.41988 .32054 m .42947 .31852 L .42874 .31792 L 0 0 0 r
F
.42464 .31842 m .42947 .31852 L .42421 .32002 L p .259 .762 .728 r
F P
0 g
s
.42421 .32002 m .39471 .32847 L p .42464 .31842 L .259 .762 .728 r
F P
0 g
s
.42152 .31497 m .4181 .30576 L .44391 .30229 L p .509 .416 .686 r
F P
0 g
s
.44391 .30229 m .44602 .31239 L .42152 .31497 L p .509 .416 .686 r
F P
0 g
s
.4343 .31645 m .43911 .31144 L .41031 .317 L p .185 0 0 r
F P
0 g
s
.42464 .31842 m .41978 .31672 L .425 .31707 L p .134 .658 .88 r
F P
0 g
s
.42947 .31852 m .42464 .31842 L .43017 .31908 L p .143 0 0 r
F P
0 g
s
.44602 .31239 m .44814 .32265 L .42495 .32442 L p .503 .409 .682 r
F P
0 g
s
.47477 .31837 m .47529 .32873 L .44602 .31239 L p .517 .413 .675 r
F P
0 g
s
.44814 .32265 m .44602 .31239 L .47529 .32873 L p .511 .407 .672 r
F P
0 g
s
.43911 .31144 m .4343 .31645 L .4724 .32682 L p .539 .032 0 r
F P
0 g
s
.4724 .32682 m .47358 .32458 L .46691 .32204 L p .539 .032 0 r
F P
0 g
s
.46128 .32168 m .4724 .32682 L .46691 .32204 L .539 .032 0 r
F
.51018 .36041 m .50761 .35936 L .49024 .33768 L p .782 .295 .064 r
F P
0 g
s
.49142 .3385 m .51018 .36041 L .49024 .33768 L .782 .295 .064 r
F
.48745 .33342 m .51018 .36041 L .48338 .32912 L F
.49024 .33768 m .48338 .32912 L p .49142 .3385 L F P
0 g
s
.47529 .32873 m .47477 .31837 L .50761 .35936 L p .511 .394 .657 r
F P
0 g
s
.47358 .32458 m .51018 .36041 L p .48745 .33342 L .782 .295 .064 r
F P
0 g
s
.48338 .32912 m .47477 .31837 L p .48745 .33342 L .782 .295 .064 r
F P
0 g
s
.47477 .31837 m .47358 .32458 L p .48745 .33342 L .782 .295 .064 r
F P
0 g
s
.47529 .32873 m .47582 .33916 L .44814 .32265 L p .511 .407 .672 r
F P
0 g
s
.50761 .35936 m .50642 .36869 L .47529 .32873 L p .511 .394 .657 r
F P
0 g
s
.47582 .33916 m .47529 .32873 L .50642 .36869 L p .506 .39 .656 r
F P
0 g
s
.51276 .35839 m .51018 .36041 L .48808 .33878 L p .666 .114 0 r
F P
0 g
s
.48808 .33878 m .47358 .32458 L p .49073 .33939 L .666 .114 0 r
F P
0 g
s
.49073 .33939 m .51276 .35839 L .48808 .33878 L .666 .114 0 r
F
.47358 .32458 m .4724 .32682 L .5062 .35326 L p F P
0 g
s
.47358 .32458 m .5062 .35326 L .50348 .35039 L .666 .114 0 r
F
.47121 .32631 m .4724 .32682 L .46258 .32415 L p .393 0 0 r
F P
0 g
s
.5062 .35326 m .51276 .35839 L p .50348 .35039 L .666 .114 0 r
F P
0 g
s
.51534 .35438 m .51276 .35839 L .4724 .32682 L p .408 0 0 r
F P
0 g
s
.4724 .32682 m .47121 .32631 L .50211 .34596 L p .408 0 0 r
F P
0 g
s
.4724 .32682 m .50211 .34596 L .50075 .34502 L .408 0 0 r
F
.47786 .32798 m .5064 .34297 L p .47121 .32631 L 0 .405 .825 r
F P
0 g
s
.5064 .34297 m .51794 .34903 L p .50464 .34257 L 0 .405 .825 r
F P
0 g
s
.47121 .32631 m .5064 .34297 L .50464 .34257 L 0 .405 .825 r
F
.50211 .34596 m .51534 .35438 L p .50075 .34502 L .408 0 0 r
F P
0 g
s
.47121 .32631 m .47001 .32386 L .47786 .32798 L p 0 .405 .825 r
F P
0 g
s
.46258 .32415 m .44847 .32031 L p .47121 .32631 L .393 0 0 r
F P
0 g
s
.44847 .32031 m .4343 .31645 L p .45037 .32075 L .393 0 0 r
F P
0 g
s
.45037 .32075 m .47121 .32631 L .44847 .32031 L .393 0 0 r
F
.42947 .31852 m .47121 .32631 L p .45037 .32075 L F P
0 g
s
.4343 .31645 m .42947 .31852 L p .45037 .32075 L .393 0 0 r
F P
0 g
s
.47001 .32386 m .47121 .32631 L .44277 .321 L p .143 0 0 r
F P
0 g
s
.44277 .321 m .42947 .31852 L p .44564 .32065 L .143 0 0 r
F P
0 g
s
.44564 .32065 m .47001 .32386 L .44277 .321 L .143 0 0 r
F
.43017 .31908 m .4414 .32043 L p .42947 .31852 L F P
0 g
s
.42947 .31852 m .4414 .32043 L .44639 .32074 L .143 0 0 r
F
.46691 .32204 m .43911 .31144 L p .46128 .32168 L .539 .032 0 r
F P
0 g
s
.42874 .31792 m .42947 .31852 L .43094 .31727 L 0 0 0 r
F
.425 .31707 m .45719 .31922 L p .42464 .31842 L .134 .658 .88 r
F P
0 g
s
.44602 .31239 m .44391 .30229 L .47477 .31837 L p .517 .413 .675 r
F P
0 g
s
.47358 .32458 m .47477 .31837 L .44391 .30229 L p .607 .171 .185 r
F P
0 g
s
.44391 .30229 m .43911 .31144 L .47358 .32458 L p .607 .171 .185 r
F P
0 g
s
.45719 .31922 m .46882 .31999 L p .45492 .3195 L .134 .658 .88 r
F P
0 g
s
.42464 .31842 m .45719 .31922 L .45492 .3195 L .134 .658 .88 r
F
.4414 .32043 m .45726 .32233 L p .44639 .32074 L .143 0 0 r
F P
0 g
s
.45726 .32233 m .47001 .32386 L p .4557 .32197 L .143 0 0 r
F P
0 g
s
.44639 .32074 m .45726 .32233 L .4557 .32197 L .143 0 0 r
F
.39087 .32927 m .39669 .3274 L p .39471 .32847 L .259 .762 .728 r
F P
0 g
s
.39669 .3274 m .42464 .31842 L p .40684 .3244 L .259 .762 .728 r
F P
0 g
s
.39471 .32847 m .39669 .3274 L .40684 .3244 L .259 .762 .728 r
F
.42158 .36753 m .42596 .377 L .41954 .40086 L p .418 .343 .666 r
F P
0 g
s
.42438 .40922 m .41954 .40086 L .42596 .377 L p .418 .341 .663 r
F P
0 g
s
.41954 .40086 m .42438 .40922 L .42475 .44211 L p .381 .314 .656 r
F P
0 g
s
.42475 .44211 m .41996 .43566 L .41954 .40086 L p .381 .314 .656 r
F P
0 g
s
.41996 .43566 m .42475 .44211 L .43139 .48482 L p .357 .292 .647 r
F P
0 g
s
.43139 .48482 m .42712 .48106 L .41996 .43566 L p .357 .292 .647 r
F P
0 g
s
.42087 .53303 m .42407 .53379 L .44884 .6184 L p .321 .252 .621 r
F P
0 g
s
.44884 .6184 m .44689 .62238 L .42087 .53303 L p .321 .252 .621 r
F P
0 g
s
.43911 .31144 m .44391 .30229 L .4181 .30576 L p .313 0 .095 r
F P
0 g
s
.4181 .30576 m .41031 .317 L .43911 .31144 L p .313 0 .095 r
F P
0 g
s
.36075 .35688 m .37052 .35276 L .35909 .38827 L p .87 .89 .847 r
F P
0 g
s
.35909 .38827 m .34856 .39401 L .36075 .35688 L p .87 .89 .847 r
F P
0 g
s
.72219 .54205 m .71321 .54494 L .73125 .48683 L p .814 .864 .885 r
F P
0 g
s
.73125 .48683 m .74131 .4824 L .72219 .54205 L p .814 .864 .885 r
F P
0 g
s
.43182 .34406 m .43526 .35426 L .42158 .36753 L p .46 .375 .673 r
F P
0 g
s
.42596 .377 m .42158 .36753 L .43526 .35426 L p .457 .37 .669 r
F P
0 g
s
.42287 .47726 m .42712 .48106 L .44038 .53584 L p .344 .277 .636 r
F P
0 g
s
.44038 .53584 m .43708 .53567 L .42287 .47726 L p .344 .277 .636 r
F P
0 g
s
.47622 .64124 m .47677 .65202 L .51948 .69318 L p .716 .363 .378 r
F P
0 g
s
.51948 .69318 m .52179 .67472 L .47622 .64124 L p .716 .363 .378 r
F P
0 g
s
.57961 .64577 m .57467 .65639 L .61465 .64119 L p .243 0 .149 r
F P
0 g
s
.61465 .64119 m .62184 .62827 L .57961 .64577 L p .243 0 .149 r
F P
0 g
s
.42596 .377 m .43035 .38675 L .42438 .40922 L p .418 .341 .663 r
F P
0 g
s
.42925 .41778 m .42438 .40922 L .43035 .38675 L p .418 .338 .659 r
F P
0 g
s
.42438 .40922 m .42925 .41778 L .42958 .44865 L p .385 .314 .654 r
F P
0 g
s
.42958 .44865 m .42475 .44211 L .42438 .40922 L p .385 .314 .654 r
F P
0 g
s
.42407 .53379 m .4273 .53444 L .45079 .6143 L p .328 .256 .622 r
F P
0 g
s
.45079 .6143 m .44884 .6184 L .42407 .53379 L p .328 .256 .622 r
F P
0 g
s
.42475 .44211 m .42958 .44865 L .43569 .48854 L p .363 .295 .645 r
F P
0 g
s
.43569 .48854 m .43139 .48482 L .42475 .44211 L p .363 .295 .645 r
F P
0 g
s
.42838 .33411 m .42495 .32442 L .44814 .32265 L p .497 .403 .679 r
F P
0 g
s
.43526 .35426 m .43872 .36473 L .42596 .377 L p .457 .37 .669 r
F P
0 g
s
.43035 .38675 m .42596 .377 L .43872 .36473 L p .454 .365 .666 r
F P
0 g
s
.71321 .54494 m .70423 .54845 L .7212 .49178 L p .829 .875 .878 r
F P
0 g
s
.7212 .49178 m .73125 .48683 L .71321 .54494 L p .829 .875 .878 r
F P
0 g
s
.35097 .35937 m .36075 .35688 L .34856 .39401 L p .835 .86 .863 r
F P
0 g
s
.34856 .39401 m .33805 .39821 L .35097 .35937 L p .835 .86 .863 r
F P
0 g
s
.65934 .58066 m .6683 .57152 L .63626 .61024 L p .635 .899 .581 r
F P
0 g
s
.44814 .32265 m .45025 .3331 L .42838 .33411 L p .497 .403 .679 r
F P
0 g
s
.43182 .34406 m .42838 .33411 L .45025 .3331 L p .492 .397 .675 r
F P
0 g
s
.42712 .48106 m .43139 .48482 L .4437 .53589 L p .351 .281 .636 r
F P
0 g
s
.4437 .53589 m .44038 .53584 L .42712 .48106 L p .351 .281 .636 r
F P
0 g
s
.4273 .53444 m .43054 .53497 L .45275 .61008 L p .334 .26 .622 r
F P
0 g
s
.45275 .61008 m .45079 .6143 L .4273 .53444 L p .334 .26 .622 r
F P
0 g
s
.43035 .38675 m .43476 .39677 L .42925 .41778 L p .418 .338 .659 r
F P
0 g
s
.43414 .42655 m .42925 .41778 L .43476 .39677 L p .418 .336 .656 r
F P
0 g
s
.42925 .41778 m .43414 .42655 L .43444 .45527 L p .389 .314 .651 r
F P
0 g
s
.43444 .45527 m .42958 .44865 L .42925 .41778 L p .389 .314 .651 r
F P
0 g
s
.43872 .36473 m .44218 .37545 L .43035 .38675 L p .454 .365 .666 r
F P
0 g
s
.43476 .39677 m .43035 .38675 L .44218 .37545 L p .45 .36 .662 r
F P
0 g
s
.52411 .66114 m .52179 .67472 L .56483 .689 L p .565 .231 .362 r
F P
0 g
s
.56483 .689 m .56974 .67041 L .52411 .66114 L p .565 .231 .362 r
F P
0 g
s
.42958 .44865 m .43444 .45527 L .44002 .49222 L p .369 .297 .644 r
F P
0 g
s
.44002 .49222 m .43569 .48854 L .42958 .44865 L p .369 .297 .644 r
F P
0 g
s
.45025 .3331 m .45237 .34372 L .43182 .34406 L p .492 .397 .675 r
F P
0 g
s
.43526 .35426 m .43182 .34406 L .45237 .34372 L p .487 .39 .672 r
F P
0 g
s
.3803 .34647 m .37052 .35276 L .39471 .32847 L p .682 .969 .766 r
F P
0 g
s
.34119 .36063 m .35097 .35937 L .33805 .39821 L p .806 .834 .872 r
F P
0 g
s
.33805 .39821 m .32756 .40124 L .34119 .36063 L p .806 .834 .872 r
F P
0 g
s
.70423 .54845 m .69524 .55269 L .71118 .49736 L p .846 .887 .869 r
F P
0 g
s
.71118 .49736 m .7212 .49178 L .70423 .54845 L p .846 .887 .869 r
F P
0 g
s
.43139 .48482 m .43569 .48854 L .44703 .53582 L p .358 .284 .636 r
F P
0 g
s
.44703 .53582 m .4437 .53589 L .43139 .48482 L p .358 .284 .636 r
F P
0 g
s
.43054 .53497 m .4338 .53538 L .45472 .60575 L p .34 .264 .623 r
F P
0 g
s
.45472 .60575 m .45275 .61008 L .43054 .53497 L p .34 .264 .623 r
F P
0 g
s
.45237 .34372 m .45449 .35452 L .43526 .35426 L p .487 .39 .672 r
F P
0 g
s
.43872 .36473 m .43526 .35426 L .45449 .35452 L p .481 .384 .668 r
F P
0 g
s
.44218 .37545 m .44565 .38645 L .43476 .39677 L p .45 .36 .662 r
F P
0 g
s
.43919 .40706 m .43476 .39677 L .44565 .38645 L p .447 .356 .659 r
F P
0 g
s
.43476 .39677 m .43919 .40706 L .43414 .42655 L p .418 .336 .656 r
F P
0 g
s
.43907 .43554 m .43414 .42655 L .43919 .40706 L p .418 .334 .653 r
F P
0 g
s
.43414 .42655 m .43907 .43554 L .43933 .46199 L p .392 .314 .649 r
F P
0 g
s
.43933 .46199 m .43444 .45527 L .43414 .42655 L p .392 .314 .649 r
F P
0 g
s
.3314 .36093 m .34119 .36063 L .32756 .40124 L p .781 .813 .878 r
F P
0 g
s
.32756 .40124 m .31709 .40339 L .3314 .36093 L p .781 .813 .878 r
F P
0 g
s
.43444 .45527 m .43933 .46199 L .44438 .49585 L p .375 .3 .643 r
F P
0 g
s
.44438 .49585 m .44002 .49222 L .43444 .45527 L p .375 .3 .643 r
F P
0 g
s
.45449 .35452 m .45662 .36551 L .43872 .36473 L p .481 .384 .668 r
F P
0 g
s
.44218 .37545 m .43872 .36473 L .45662 .36551 L p .476 .379 .665 r
F P
0 g
s
.4338 .53538 m .43708 .53567 L .45669 .60129 L p .346 .267 .624 r
F P
0 g
s
.45669 .60129 m .45472 .60575 L .4338 .53538 L p .346 .267 .624 r
F P
0 g
s
.69524 .55269 m .68625 .55781 L .70117 .50368 L p .864 .899 .857 r
F P
0 g
s
.70117 .50368 m .71118 .49736 L .69524 .55269 L p .864 .899 .857 r
F P
0 g
s
.32159 .36049 m .3314 .36093 L .31709 .40339 L p .761 .796 .881 r
F P
0 g
s
.31709 .40339 m .30663 .40486 L .32159 .36049 L p .761 .796 .881 r
F P
0 g
s
.43569 .48854 m .44002 .49222 L .45039 .53562 L p .364 .287 .635 r
F P
0 g
s
.45039 .53562 m .44703 .53582 L .43569 .48854 L p .364 .287 .635 r
F P
0 g
s
.44565 .38645 m .44914 .39772 L .43919 .40706 L p .447 .356 .659 r
F P
0 g
s
.44364 .41765 m .43919 .40706 L .44914 .39772 L p .445 .351 .656 r
F P
0 g
s
.43919 .40706 m .44364 .41765 L .43907 .43554 L p .418 .334 .653 r
F P
0 g
s
.6415 .60571 m .6504 .59186 L .64865 .5941 L p 0 0 0 r
F P
0 g
s
.64865 .5941 m .62184 .62827 L p .6415 .60571 L 0 0 0 r
F P
0 g
s
.63265 .62302 m .6415 .60571 L .63965 .60816 L p 0 0 0 r
F P
0 g
s
.63965 .60816 m .61465 .64119 L p .63265 .62302 L 0 0 0 r
F P
0 g
s
.62387 .64495 m .63265 .62302 L .6307 .62572 L p 0 0 .002 r
F P
0 g
s
.6307 .62572 m .60748 .65779 L p .62387 .64495 L 0 0 .002 r
F P
0 g
s
.61518 .67323 m .62387 .64495 L .6218 .64799 L p 0 0 .108 r
F P
0 g
s
.6218 .64799 m .60037 .67935 L p .61518 .67323 L 0 0 .108 r
F P
0 g
s
.60664 .71049 m .61518 .67323 L .61298 .67671 L p 0 0 .191 r
F P
0 g
s
.61298 .67671 m .59334 .70774 L p .60664 .71049 L 0 0 .191 r
F P
0 g
s
.59831 .76101 m .60664 .71049 L .60428 .71462 L p 0 0 .254 r
F P
0 g
s
.60428 .71462 m .58642 .74585 L p .59831 .76101 L 0 0 .254 r
F P
0 g
s
.5903 .83205 m .59831 .76101 L .57968 .79839 L p .004 0 .302 r
F P
0 g
s
.59831 .76101 m .5903 .83205 L .59099 .81784 L p .918 .781 .301 r
F P
0 g
s
.58642 .74585 m .57968 .79839 L .59831 .76101 L p 0 0 .254 r
F P
0 g
s
.59099 .81784 m .59449 .74601 L p .59831 .76101 L .918 .781 .301 r
F P
0 g
s
.60664 .71049 m .59831 .76101 L .59904 .75104 L p .938 .82 .369 r
F P
0 g
s
.60037 .67935 m .59334 .70774 L .61518 .67323 L p 0 0 .108 r
F P
0 g
s
.59334 .70774 m .58642 .74585 L .60664 .71049 L p 0 0 .191 r
F P
0 g
s
.59904 .75104 m .60358 .68877 L p .60664 .71049 L .938 .82 .369 r
F P
0 g
s
.61518 .67323 m .60664 .71049 L .60738 .70303 L p .956 .858 .443 r
F P
0 g
s
.61465 .64119 m .60748 .65779 L .63265 .62302 L p 0 0 0 r
F P
0 g
s
.60748 .65779 m .60037 .67935 L .62387 .64495 L p 0 0 .002 r
F P
0 g
s
.60738 .70303 m .61291 .64679 L p .61518 .67323 L .956 .858 .443 r
F P
0 g
s
.62387 .64495 m .61518 .67323 L .61591 .66736 L p .969 .891 .519 r
F P
0 g
s
.62184 .62827 m .61465 .64119 L .6415 .60571 L p 0 0 0 r
F P
0 g
s
.61591 .66736 m .62241 .61488 L p .62387 .64495 L .969 .891 .519 r
F P
0 g
s
.63265 .62302 m .62387 .64495 L .62458 .64015 L p .973 .917 .592 r
F P
0 g
s
.65766 .58273 m .62905 .61816 L p .6504 .59186 L 0 0 0 r
F P
0 g
s
.62458 .64015 m .63204 .58994 L p .63265 .62302 L .973 .917 .592 r
F P
0 g
s
.6415 .60571 m .63265 .62302 L .63334 .61897 L p .97 .933 .657 r
F P
0 g
s
.63334 .61897 m .64175 .56998 L p .6415 .60571 L .97 .933 .657 r
F P
0 g
s
.6504 .59186 m .6415 .60571 L .64218 .60221 L p .959 .939 .713 r
F P
0 g
s
.64218 .60221 m .65155 .5537 L p .6504 .59186 L .959 .939 .713 r
F P
0 g
s
.6504 .59186 m .65934 .58066 L .65766 .58273 L p 0 0 0 r
F P
0 g
s
.57467 .65639 m .56974 .67041 L .60748 .65779 L p .298 0 .236 r
F P
0 g
s
.60748 .65779 m .61465 .64119 L .57467 .65639 L p .298 0 .236 r
F P
0 g
s
.44402 .44474 m .43907 .43554 L .44364 .41765 L p .419 .331 .651 r
F P
0 g
s
.43907 .43554 m .44402 .44474 L .44425 .46879 L p .396 .315 .647 r
F P
0 g
s
.44425 .46879 m .43933 .46199 L .43907 .43554 L p .396 .315 .647 r
F P
0 g
s
.47677 .65202 m .47731 .66704 L .51718 .71849 L p .726 .392 .414 r
F P
0 g
s
.51718 .71849 m .51948 .69318 L .47677 .65202 L p .726 .392 .414 r
F P
0 g
s
.45662 .36551 m .45875 .37669 L .44218 .37545 L p .476 .379 .665 r
F P
0 g
s
.44565 .38645 m .44218 .37545 L .45875 .37669 L p .471 .373 .662 r
F P
0 g
s
.31176 .35946 m .32159 .36049 L .30663 .40486 L p .745 .782 .883 r
F P
0 g
s
.30663 .40486 m .29617 .40581 L .31176 .35946 L p .745 .782 .883 r
F P
0 g
s
.3869 .33055 m .39471 .32847 L .37052 .35276 L p .749 .99 .885 r
F P
0 g
s
.37052 .35276 m .36075 .35688 L .3869 .33055 L p .749 .99 .885 r
F P
0 g
s
.43933 .46199 m .44425 .46879 L .44876 .49945 L p .381 .302 .641 r
F P
0 g
s
.44876 .49945 m .44438 .49585 L .43933 .46199 L p .381 .302 .641 r
F P
0 g
s
.43708 .53567 m .44038 .53584 L .45867 .59672 L p .352 .271 .624 r
F P
0 g
s
.45867 .59672 m .45669 .60129 L .43708 .53567 L p .352 .271 .624 r
F P
0 g
s
.45025 .3331 m .44814 .32265 L .47582 .33916 L p .506 .401 .669 r
F P
0 g
s
.30191 .35796 m .31176 .35946 L .29617 .40581 L p .731 .771 .885 r
F P
0 g
s
.29617 .40581 m .28572 .40633 L .30191 .35796 L p .731 .771 .885 r
F P
0 g
s
.44002 .49222 m .44438 .49585 L .45376 .5353 L p .371 .291 .635 r
F P
0 g
s
.45376 .5353 m .45039 .53562 L .44002 .49222 L p .371 .291 .635 r
F P
0 g
s
.44914 .39772 m .45263 .40926 L .44364 .41765 L p .445 .351 .656 r
F P
0 g
s
.44811 .42852 m .44364 .41765 L .45263 .40926 L p .442 .347 .653 r
F P
0 g
s
.44364 .41765 m .44811 .42852 L .44402 .44474 L p .419 .331 .651 r
F P
0 g
s
.45875 .37669 m .46089 .38805 L .44565 .38645 L p .471 .373 .662 r
F P
0 g
s
.44914 .39772 m .44565 .38645 L .46089 .38805 L p .467 .367 .659 r
F P
0 g
s
.47582 .33916 m .47634 .34964 L .45025 .3331 L p .506 .401 .669 r
F P
0 g
s
.45237 .34372 m .45025 .3331 L .47634 .34964 L p .5 .395 .667 r
F P
0 g
s
.68625 .55781 m .67727 .56401 L .69118 .51089 L p .883 .911 .842 r
F P
0 g
s
.69118 .51089 m .70117 .50368 L .68625 .55781 L p .883 .911 .842 r
F P
0 g
s
.29205 .35608 m .30191 .35796 L .28572 .40633 L p .72 .762 .886 r
F P
0 g
s
.28572 .40633 m .27528 .40653 L .29205 .35608 L p .72 .762 .886 r
F P
0 g
s
.449 .45416 m .44402 .44474 L .44811 .42852 L p .419 .329 .648 r
F P
0 g
s
.44402 .44474 m .449 .45416 L .4492 .47569 L p .399 .315 .645 r
F P
0 g
s
.4492 .47569 m .44425 .46879 L .44402 .44474 L p .399 .315 .645 r
F P
0 g
s
.44038 .53584 m .4437 .53589 L .46065 .59203 L p .357 .275 .625 r
F P
0 g
s
.46065 .59203 m .45867 .59672 L .44038 .53584 L p .357 .275 .625 r
F P
0 g
s
.47634 .34964 m .47686 .36019 L .45237 .34372 L p .5 .395 .667 r
F P
0 g
s
.45449 .35452 m .45237 .34372 L .47686 .36019 L p .495 .39 .664 r
F P
0 g
s
.44425 .46879 m .4492 .47569 L .45317 .50301 L p .386 .304 .64 r
F P
0 g
s
.45317 .50301 m .44876 .49945 L .44425 .46879 L p .386 .304 .64 r
F P
0 g
s
.28215 .35389 m .29205 .35608 L .27528 .40653 L p .711 .755 .887 r
F P
0 g
s
.27528 .40653 m .26483 .40647 L .28215 .35389 L p .711 .755 .887 r
F P
0 g
s
.46089 .38805 m .46303 .39961 L .44914 .39772 L p .467 .367 .659 r
F P
0 g
s
.45263 .40926 m .44914 .39772 L .46303 .39961 L p .462 .362 .656 r
F P
0 g
s
.45263 .40926 m .45614 .42109 L .44811 .42852 L p .442 .347 .653 r
F P
0 g
s
.45261 .43969 m .44811 .42852 L .45614 .42109 L p .439 .343 .65 r
F P
0 g
s
.44811 .42852 m .45261 .43969 L .449 .45416 L p .419 .329 .648 r
F P
0 g
s
.52179 .67472 m .51948 .69318 L .55995 .71386 L p .581 .267 .402 r
F P
0 g
s
.55995 .71386 m .56483 .689 L .52179 .67472 L p .581 .267 .402 r
F P
0 g
s
.27224 .35146 m .28215 .35389 L .26483 .40647 L p .703 .75 .888 r
F P
0 g
s
.26483 .40647 m .25439 .4062 L .27224 .35146 L p .703 .75 .888 r
F P
0 g
s
.44438 .49585 m .44876 .49945 L .45715 .53485 L p .377 .294 .635 r
F P
0 g
s
.45715 .53485 m .45376 .5353 L .44438 .49585 L p .377 .294 .635 r
F P
0 g
s
.47686 .36019 m .47739 .37081 L .45449 .35452 L p .495 .39 .664 r
F P
0 g
s
.45662 .36551 m .45449 .35452 L .47739 .37081 L p .489 .384 .662 r
F P
0 g
s
.37906 .33098 m .3869 .33055 L .36075 .35688 L p .763 .962 .932 r
F P
0 g
s
.36075 .35688 m .35097 .35937 L .37906 .33098 L p .763 .962 .932 r
F P
0 g
s
.26229 .34881 m .27224 .35146 L .25439 .4062 L p .697 .745 .888 r
F P
0 g
s
.25439 .4062 m .24394 .40575 L .26229 .34881 L p .697 .745 .888 r
F P
0 g
s
.4437 .53589 m .44703 .53582 L .46264 .58722 L p .363 .279 .625 r
F P
0 g
s
.46264 .58722 m .46065 .59203 L .4437 .53589 L p .363 .279 .625 r
F P
0 g
s
.45402 .46381 m .449 .45416 L .45261 .43969 L p .419 .327 .645 r
F P
0 g
s
.449 .45416 m .45402 .46381 L .45418 .48268 L p .402 .315 .642 r
F P
0 g
s
.45418 .48268 m .4492 .47569 L .449 .45416 L p .402 .315 .642 r
F P
0 g
s
.46303 .39961 m .46517 .41137 L .45263 .40926 L p .462 .362 .656 r
F P
0 g
s
.45614 .42109 m .45263 .40926 L .46517 .41137 L p .458 .357 .653 r
F P
0 g
s
.47739 .37081 m .47791 .38149 L .45662 .36551 L p .489 .384 .662 r
F P
0 g
s
.45875 .37669 m .45662 .36551 L .47791 .38149 L p .484 .379 .659 r
F P
0 g
s
.25232 .34599 m .26229 .34881 L .24394 .40575 L p .692 .741 .889 r
F P
0 g
s
.24394 .40575 m .23349 .40517 L .25232 .34599 L p .692 .741 .889 r
F P
0 g
s
.67727 .56401 m .6683 .57152 L .68122 .5192 L p .903 .923 .821 r
F P
0 g
s
.68122 .5192 m .69118 .51089 L .67727 .56401 L p .903 .923 .821 r
F P
0 g
s
.4492 .47569 m .45418 .48268 L .45761 .50652 L p .392 .306 .639 r
F P
0 g
s
.45761 .50652 m .45317 .50301 L .4492 .47569 L p .392 .306 .639 r
F P
0 g
s
.24232 .34303 m .25232 .34599 L .23349 .40517 L p .688 .738 .889 r
F P
0 g
s
.23349 .40517 m .22304 .40447 L .24232 .34303 L p .688 .738 .889 r
F P
0 g
s
.45614 .42109 m .45967 .43321 L .45261 .43969 L p .439 .343 .65 r
F P
0 g
s
.45712 .45116 m .45261 .43969 L .45967 .43321 L p .437 .339 .647 r
F P
0 g
s
.45261 .43969 m .45712 .45116 L .45402 .46381 L p .419 .327 .645 r
F P
0 g
s
.44876 .49945 m .45317 .50301 L .46056 .53427 L p .383 .297 .634 r
F P
0 g
s
.46056 .53427 m .45715 .53485 L .44876 .49945 L p .383 .297 .634 r
F P
0 g
s
.47791 .38149 m .47844 .39223 L .45875 .37669 L p .484 .379 .659 r
F P
0 g
s
.46089 .38805 m .45875 .37669 L .47844 .39223 L p .479 .373 .657 r
F P
0 g
s
.23228 .33994 m .24232 .34303 L .22304 .40447 L p .684 .736 .89 r
F P
0 g
s
.22304 .40447 m .21258 .40368 L .23228 .33994 L p .684 .736 .89 r
F P
0 g
s
.44703 .53582 m .45039 .53562 L .46463 .5823 L p .369 .282 .626 r
F P
0 g
s
.46463 .5823 m .46264 .58722 L .44703 .53582 L p .369 .282 .626 r
F P
0 g
s
.22222 .33675 m .23228 .33994 L .21258 .40368 L p .681 .734 .89 r
F P
0 g
s
.21258 .40368 m .20212 .40281 L .22222 .33675 L p .681 .734 .89 r
F P
0 g
s
.46517 .41137 m .46733 .42333 L .45614 .42109 L p .458 .357 .653 r
F P
0 g
s
.45967 .43321 m .45614 .42109 L .46733 .42333 L p .453 .352 .65 r
F P
0 g
s
.3712 .33015 m .37906 .33098 L .35097 .35937 L p .757 .922 .944 r
F P
0 g
s
.35097 .35937 m .34119 .36063 L .3712 .33015 L p .757 .922 .944 r
F P
0 g
s
.21212 .33348 m .22222 .33675 L .20212 .40281 L p .679 .732 .89 r
F P
0 g
s
.20212 .40281 m .19165 .40188 L .21212 .33348 L p .679 .732 .89 r
F P
0 g
s
.56974 .67041 m .56483 .689 L .60037 .67935 L p .34 .04 .303 r
F P
0 g
s
.60037 .67935 m .60748 .65779 L .56974 .67041 L p .34 .04 .303 r
F P
0 g
s
.47844 .39223 m .47896 .40305 L .46089 .38805 L p .479 .373 .657 r
F P
0 g
s
.46303 .39961 m .46089 .38805 L .47896 .40305 L p .474 .368 .654 r
F P
0 g
s
.45906 .47368 m .45402 .46381 L .45712 .45116 L p .419 .325 .643 r
F P
0 g
s
.45402 .46381 m .45906 .47368 L .4592 .48976 L p .405 .315 .64 r
F P
0 g
s
.4592 .48976 m .45418 .48268 L .45402 .46381 L p .405 .315 .64 r
F P
0 g
s
.45039 .53562 m .45376 .5353 L .46663 .57725 L p .374 .286 .626 r
F P
0 g
s
.46663 .57725 m .46463 .5823 L .45039 .53562 L p .374 .286 .626 r
F P
0 g
s
.45418 .48268 m .4592 .48976 L .46208 .50999 L p .397 .308 .637 r
F P
0 g
s
.46208 .50999 m .45761 .50652 L .45418 .48268 L p .397 .308 .637 r
F P
0 g
s
.45967 .43321 m .4632 .44563 L .45712 .45116 L p .437 .339 .647 r
F P
0 g
s
.46167 .46293 m .45712 .45116 L .4632 .44563 L p .434 .335 .644 r
F P
0 g
s
.45712 .45116 m .46167 .46293 L .45906 .47368 L p .419 .325 .643 r
F P
0 g
s
.45317 .50301 m .45761 .50652 L .46398 .53357 L p .389 .3 .634 r
F P
0 g
s
.46398 .53357 m .46056 .53427 L .45317 .50301 L p .389 .3 .634 r
F P
0 g
s
.47896 .40305 m .47949 .41393 L .46303 .39961 L p .474 .368 .654 r
F P
0 g
s
.46517 .41137 m .46303 .39961 L .47949 .41393 L p .469 .363 .652 r
F P
0 g
s
.46733 .42333 m .46949 .43549 L .45967 .43321 L p .453 .352 .65 r
F P
0 g
s
.4632 .44563 m .45967 .43321 L .46949 .43549 L p .449 .347 .647 r
F P
0 g
s
.47731 .66704 m .47784 .68801 L .5149 .75371 L p .733 .415 .442 r
F P
0 g
s
.5149 .75371 m .51718 .71849 L .47731 .66704 L p .733 .415 .442 r
F P
0 g
s
.6683 .57152 m .65934 .58066 L .67129 .52886 L p .924 .932 .794 r
F P
0 g
s
.67129 .52886 m .68122 .5192 L .6683 .57152 L p .924 .932 .794 r
F P
0 g
s
.78165 .46858 m .77155 .47156 L .7631 .40038 L p .75 .769 .868 r
F P
0 g
s
.7631 .40038 m .77334 .3955 L .78165 .46858 L p .75 .769 .868 r
F P
0 g
s
.47784 .68801 m .47837 .71766 L .51265 .80396 L p .738 .433 .464 r
F P
0 g
s
.44689 .62238 m .44884 .6184 L .47872 .70763 L p .339 .25 .607 r
F P
0 g
s
.47872 .70763 m .47837 .71766 L .44689 .62238 L p .339 .25 .607 r
F P
0 g
s
.77155 .47156 m .76146 .47482 L .75289 .40546 L p .757 .77 .864 r
F P
0 g
s
.75289 .40546 m .7631 .40038 L .77155 .47156 L p .757 .77 .864 r
F P
0 g
s
.45376 .5353 m .45715 .53485 L .46864 .5721 L p .379 .289 .627 r
F P
0 g
s
.46864 .5721 m .46663 .57725 L .45376 .5353 L p .379 .289 .627 r
F P
0 g
s
.47949 .41393 m .48002 .42488 L .46517 .41137 L p .469 .363 .652 r
F P
0 g
s
.46733 .42333 m .46517 .41137 L .48002 .42488 L p .464 .358 .649 r
F P
0 g
s
.46414 .48379 m .45906 .47368 L .46167 .46293 L p .419 .323 .64 r
F P
0 g
s
.45906 .47368 m .46414 .48379 L .46426 .49694 L p .408 .315 .638 r
F P
0 g
s
.46426 .49694 m .4592 .48976 L .45906 .47368 L p .408 .315 .638 r
F P
0 g
s
.44884 .6184 m .45079 .6143 L .47906 .6976 L p .343 .254 .608 r
F P
0 g
s
.47906 .6976 m .47872 .70763 L .44884 .6184 L p .343 .254 .608 r
F P
0 g
s
.36332 .32834 m .3712 .33015 L .34119 .36063 L p .745 .885 .944 r
F P
0 g
s
.34119 .36063 m .3314 .36093 L .36332 .32834 L p .745 .885 .944 r
F P
0 g
s
.50642 .36869 m .50523 .37796 L .47582 .33916 L p .506 .39 .656 r
F P
0 g
s
.47634 .34964 m .47582 .33916 L .50523 .37796 L p .501 .386 .654 r
F P
0 g
s
.46949 .43549 m .47165 .44786 L .4632 .44563 L p .449 .347 .647 r
F P
0 g
s
.46676 .45834 m .4632 .44563 L .47165 .44786 L p .445 .342 .644 r
F P
0 g
s
.4632 .44563 m .46676 .45834 L .46167 .46293 L p .434 .335 .644 r
F P
0 g
s
.45761 .50652 m .46208 .50999 L .46742 .53274 L p .394 .303 .633 r
F P
0 g
s
.46742 .53274 m .46398 .53357 L .45761 .50652 L p .394 .303 .633 r
F P
0 g
s
.76146 .47482 m .75138 .47842 L .74272 .4108 L p .764 .772 .86 r
F P
0 g
s
.74272 .4108 m .75289 .40546 L .76146 .47482 L p .764 .772 .86 r
F P
0 g
s
.46624 .47502 m .46167 .46293 L .46676 .45834 L p .432 .332 .641 r
F P
0 g
s
.46167 .46293 m .46624 .47502 L .46414 .48379 L p .419 .323 .64 r
F P
0 g
s
.4592 .48976 m .46426 .49694 L .46658 .51341 L p .402 .31 .636 r
F P
0 g
s
.46658 .51341 m .46208 .50999 L .4592 .48976 L p .402 .31 .636 r
F P
0 g
s
.50523 .37796 m .50404 .38718 L .47634 .34964 L p .501 .386 .654 r
F P
0 g
s
.47686 .36019 m .47634 .34964 L .50404 .38718 L p .496 .381 .653 r
F P
0 g
s
.45079 .6143 m .45275 .61008 L .4794 .68756 L p .348 .257 .61 r
F P
0 g
s
.51265 .80396 m .5149 .75371 L .47784 .68801 L p .738 .433 .464 r
F P
0 g
s
.4794 .68756 m .47906 .6976 L .45079 .6143 L p .348 .257 .61 r
F P
0 g
s
.48002 .42488 m .48055 .4359 L .46733 .42333 L p .464 .358 .649 r
F P
0 g
s
.46949 .43549 m .46733 .42333 L .48055 .4359 L p .459 .353 .647 r
F P
0 g
s
.45715 .53485 m .46056 .53427 L .47065 .56682 L p .385 .293 .627 r
F P
0 g
s
.47065 .56682 m .46864 .5721 L .45715 .53485 L p .385 .293 .627 r
F P
0 g
s
.50404 .38718 m .50284 .39634 L .47686 .36019 L p .496 .381 .653 r
F P
0 g
s
.47739 .37081 m .47686 .36019 L .50284 .39634 L p .491 .377 .651 r
F P
0 g
s
.75138 .47842 m .74131 .4824 L .73258 .41641 L p .772 .773 .854 r
F P
0 g
s
.73258 .41641 m .74272 .4108 L .75138 .47842 L p .772 .773 .854 r
F P
0 g
s
.45275 .61008 m .45472 .60575 L .47974 .67752 L p .352 .261 .611 r
F P
0 g
s
.47974 .67752 m .4794 .68756 L .45275 .61008 L p .352 .261 .611 r
F P
0 g
s
.50284 .39634 m .50165 .40545 L .47739 .37081 L p .491 .377 .651 r
F P
0 g
s
.47791 .38149 m .47739 .37081 L .50165 .40545 L p .486 .373 .65 r
F P
0 g
s
.3554 .32577 m .36332 .32834 L .3314 .36093 L p .732 .855 .939 r
F P
0 g
s
.3314 .36093 m .32159 .36049 L .3554 .32577 L p .732 .855 .939 r
F P
0 g
s
.47165 .44786 m .47383 .46044 L .46676 .45834 L p .445 .342 .644 r
F P
0 g
s
.47033 .47137 m .46676 .45834 L .47383 .46044 L p .441 .337 .641 r
F P
0 g
s
.46676 .45834 m .47033 .47137 L .46624 .47502 L p .432 .332 .641 r
F P
0 g
s
.48055 .4359 m .48108 .44699 L .46949 .43549 L p .459 .353 .647 r
F P
0 g
s
.47165 .44786 m .46949 .43549 L .48108 .44699 L p .454 .348 .644 r
F P
0 g
s
.46926 .49414 m .46414 .48379 L .46624 .47502 L p .42 .322 .638 r
F P
0 g
s
.46414 .48379 m .46926 .49414 L .46935 .50422 L p .411 .316 .636 r
F P
0 g
s
.46935 .50422 m .46426 .49694 L .46414 .48379 L p .411 .316 .636 r
F P
0 g
s
.74131 .4824 m .73125 .48683 L .72248 .42235 L p .78 .775 .848 r
F P
0 g
s
.72248 .42235 m .73258 .41641 L .74131 .4824 L p .78 .775 .848 r
F P
0 g
s
.46208 .50999 m .46658 .51341 L .47087 .53179 L p .4 .306 .633 r
F P
0 g
s
.47087 .53179 m .46742 .53274 L .46208 .50999 L p .4 .306 .633 r
F P
0 g
s
.50165 .40545 m .50045 .4145 L .47791 .38149 L p .486 .373 .65 r
F P
0 g
s
.47844 .39223 m .47791 .38149 L .50045 .4145 L p .482 .369 .648 r
F P
0 g
s
.45472 .60575 m .45669 .60129 L .48008 .66748 L p .356 .264 .612 r
F P
0 g
s
.48008 .66748 m .47974 .67752 L .45472 .60575 L p .356 .264 .612 r
F P
0 g
s
.65934 .58066 m .6504 .59186 L .66139 .54021 L p .943 .939 .758 r
F P
0 g
s
.66139 .54021 m .67129 .52886 L .65934 .58066 L p .943 .939 .758 r
F P
0 g
s
.47084 .48743 m .46624 .47502 L .47033 .47137 L p .43 .328 .638 r
F P
0 g
s
.46624 .47502 m .47084 .48743 L .46926 .49414 L p .42 .322 .638 r
F P
0 g
s
.46056 .53427 m .46398 .53357 L .47266 .56143 L p .39 .296 .628 r
F P
0 g
s
.47266 .56143 m .47065 .56682 L .46056 .53427 L p .39 .296 .628 r
F P
0 g
s
.46426 .49694 m .46935 .50422 L .4711 .51679 L p .406 .311 .635 r
F P
0 g
s
.4711 .51679 m .46658 .51341 L .46426 .49694 L p .406 .311 .635 r
F P
0 g
s
.51948 .69318 m .51718 .71849 L .55514 .74762 L p .593 .295 .433 r
F P
0 g
s
.55514 .74762 m .55995 .71386 L .51948 .69318 L p .593 .295 .433 r
F P
0 g
s
.50045 .4145 m .49925 .42349 L .47844 .39223 L p .482 .369 .648 r
F P
0 g
s
.47896 .40305 m .47844 .39223 L .49925 .42349 L p .477 .365 .647 r
F P
0 g
s
.45669 .60129 m .45867 .59672 L .48043 .65743 L p .361 .268 .613 r
F P
0 g
s
.48043 .65743 m .48008 .66748 L .45669 .60129 L p .361 .268 .613 r
F P
0 g
s
.73125 .48683 m .7212 .49178 L .71241 .42867 L p .789 .776 .841 r
F P
0 g
s
.71241 .42867 m .72248 .42235 L .73125 .48683 L p .789 .776 .841 r
F P
0 g
s
.48108 .44699 m .48161 .45815 L .47165 .44786 L p .454 .348 .644 r
F P
0 g
s
.47383 .46044 m .47165 .44786 L .48161 .45815 L p .45 .343 .642 r
F P
0 g
s
.41978 .31672 m .42464 .31842 L .3869 .33055 L p .447 .876 .914 r
F P
0 g
s
.3869 .33055 m .37906 .33098 L .41978 .31672 L p .447 .876 .914 r
F P
0 g
s
.49925 .42349 m .49806 .43242 L .47896 .40305 L p .477 .365 .647 r
F P
0 g
s
.47949 .41393 m .47896 .40305 L .49806 .43242 L p .472 .361 .646 r
F P
0 g
s
.47383 .46044 m .47601 .47324 L .47033 .47137 L p .441 .337 .641 r
F P
0 g
s
.47393 .4847 m .47033 .47137 L .47601 .47324 L p .437 .333 .638 r
F P
0 g
s
.47033 .47137 m .47393 .4847 L .47084 .48743 L p .43 .328 .638 r
F P
0 g
s
.46398 .53357 m .46742 .53274 L .47468 .55592 L p .395 .299 .628 r
F P
0 g
s
.47468 .55592 m .47266 .56143 L .46398 .53357 L p .395 .299 .628 r
F P
0 g
s
.45867 .59672 m .46065 .59203 L .48077 .64738 L p .365 .271 .615 r
F P
0 g
s
.48077 .64738 m .48043 .65743 L .45867 .59672 L p .365 .271 .615 r
F P
0 g
s
.34746 .32259 m .3554 .32577 L .32159 .36049 L p .721 .83 .932 r
F P
0 g
s
.32159 .36049 m .31176 .35946 L .34746 .32259 L p .721 .83 .932 r
F P
0 g
s
.46658 .51341 m .4711 .51679 L .47434 .5307 L p .405 .308 .632 r
F P
0 g
s
.47434 .5307 m .47087 .53179 L .46658 .51341 L p .405 .308 .632 r
F P
0 g
s
.49806 .43242 m .49686 .4413 L .47949 .41393 L p .472 .361 .646 r
F P
0 g
s
.48002 .42488 m .47949 .41393 L .49686 .4413 L p .468 .356 .644 r
F P
0 g
s
.47441 .50473 m .46926 .49414 L .47084 .48743 L p .42 .32 .635 r
F P
0 g
s
.46926 .49414 m .47441 .50473 L .47447 .5116 L p .414 .316 .635 r
F P
0 g
s
.47447 .5116 m .46935 .50422 L .46926 .49414 L p .414 .316 .635 r
F P
0 g
s
.7212 .49178 m .71118 .49736 L .70237 .43544 L p .799 .777 .832 r
F P
0 g
s
.70237 .43544 m .71241 .42867 L .7212 .49178 L p .799 .777 .832 r
F P
0 g
s
.48161 .45815 m .48215 .46938 L .47383 .46044 L p .45 .343 .642 r
F P
0 g
s
.47601 .47324 m .47383 .46044 L .48215 .46938 L p .445 .339 .64 r
F P
0 g
s
.46065 .59203 m .46264 .58722 L .48111 .63733 L p .37 .275 .616 r
F P
0 g
s
.48111 .63733 m .48077 .64738 L .46065 .59203 L p .37 .275 .616 r
F P
0 g
s
.47547 .50017 m .47084 .48743 L .47393 .4847 L p .427 .325 .636 r
F P
0 g
s
.47084 .48743 m .47547 .50017 L .47441 .50473 L p .42 .32 .635 r
F P
0 g
s
.46935 .50422 m .47447 .5116 L .47565 .52013 L p .411 .313 .633 r
F P
0 g
s
.47565 .52013 m .4711 .51679 L .46935 .50422 L p .411 .313 .633 r
F P
0 g
s
.49686 .4413 m .49566 .45011 L .48002 .42488 L p .468 .356 .644 r
F P
0 g
s
.48055 .4359 m .48002 .42488 L .49566 .45011 L p .463 .352 .643 r
F P
0 g
s
.56483 .689 m .55995 .71386 L .59334 .70774 L p .371 .092 .354 r
F P
0 g
s
.59334 .70774 m .60037 .67935 L .56483 .689 L p .371 .092 .354 r
F P
0 g
s
.46742 .53274 m .47087 .53179 L .47671 .5503 L p .4 .303 .628 r
F P
0 g
s
.47671 .5503 m .47468 .55592 L .46742 .53274 L p .4 .303 .628 r
F P
0 g
s
.46264 .58722 m .46463 .5823 L .48145 .62728 L p .374 .278 .617 r
F P
0 g
s
.48145 .62728 m .48111 .63733 L .46264 .58722 L p .374 .278 .617 r
F P
0 g
s
.49566 .45011 m .49446 .45887 L .48055 .4359 L p .463 .352 .643 r
F P
0 g
s
.48108 .44699 m .48055 .4359 L .49446 .45887 L p .458 .348 .641 r
F P
0 g
s
.47601 .47324 m .4782 .48626 L .47393 .4847 L p .437 .333 .638 r
F P
0 g
s
.47754 .49836 m .47393 .4847 L .4782 .48626 L p .433 .329 .636 r
F P
0 g
s
.47393 .4847 m .47754 .49836 L .47547 .50017 L p .427 .325 .636 r
F P
0 g
s
.71118 .49736 m .70117 .50368 L .69238 .44274 L p .81 .777 .822 r
F P
0 g
s
.69238 .44274 m .70237 .43544 L .71118 .49736 L p .81 .777 .822 r
F P
0 g
s
.33947 .31891 m .34746 .32259 L .31176 .35946 L p .712 .811 .927 r
F P
0 g
s
.31176 .35946 m .30191 .35796 L .33947 .31891 L p .712 .811 .927 r
F P
0 g
s
.48215 .46938 m .48268 .48069 L .47601 .47324 L p .445 .339 .64 r
F P
0 g
s
.4782 .48626 m .47601 .47324 L .48268 .48069 L p .441 .334 .638 r
F P
0 g
s
.4711 .51679 m .47565 .52013 L .47782 .52948 L p .41 .311 .631 r
F P
0 g
s
.47782 .52948 m .47434 .5307 L .4711 .51679 L p .41 .311 .631 r
F P
0 g
s
.46463 .5823 m .46663 .57725 L .48179 .61722 L p .378 .282 .618 r
F P
0 g
s
.48179 .61722 m .48145 .62728 L .46463 .5823 L p .378 .282 .618 r
F P
0 g
s
.49446 .45887 m .49325 .46756 L .48108 .44699 L p .458 .348 .641 r
F P
0 g
s
.48161 .45815 m .48108 .44699 L .49325 .46756 L p .454 .344 .64 r
F P
0 g
s
.65155 .5537 m .66139 .54021 L .6504 .59186 L p .959 .939 .713 r
F P
0 g
s
.47087 .53179 m .47434 .5307 L .47873 .54456 L p .405 .306 .629 r
F P
0 g
s
.47873 .54456 m .47671 .5503 L .47087 .53179 L p .405 .306 .629 r
F P
0 g
s
.4796 .51557 m .47441 .50473 L .47547 .50017 L p .42 .318 .633 r
F P
0 g
s
.47441 .50473 m .4796 .51557 L .47963 .51908 L p .416 .316 .633 r
F P
0 g
s
.47963 .51908 m .47447 .5116 L .47441 .50473 L p .416 .316 .633 r
F P
0 g
s
.46663 .57725 m .46864 .5721 L .48213 .60717 L p .383 .285 .619 r
F P
0 g
s
.48213 .60717 m .48179 .61722 L .46663 .57725 L p .383 .285 .619 r
F P
0 g
s
.48013 .51324 m .47547 .50017 L .47754 .49836 L p .425 .321 .633 r
F P
0 g
s
.47547 .50017 m .48013 .51324 L .4796 .51557 L p .42 .318 .633 r
F P
0 g
s
.41491 .3138 m .41978 .31672 L .37906 .33098 L p .552 .894 .981 r
F P
0 g
s
.37906 .33098 m .3712 .33015 L .41491 .3138 L p .552 .894 .981 r
F P
0 g
s
.49325 .46756 m .49205 .4762 L .48161 .45815 L p .454 .344 .64 r
F P
0 g
s
.48215 .46938 m .48161 .45815 L .49205 .4762 L p .449 .34 .638 r
F P
0 g
s
.47447 .5116 m .47963 .51908 L .48023 .52342 L p .415 .315 .632 r
F P
0 g
s
.48023 .52342 m .47565 .52013 L .47447 .5116 L p .415 .315 .632 r
F P
0 g
s
.48268 .48069 m .48322 .49207 L .4782 .48626 L p .441 .334 .638 r
F P
0 g
s
.4804 .4995 m .4782 .48626 L .48322 .49207 L p .436 .33 .635 r
F P
0 g
s
.4782 .48626 m .4804 .4995 L .47754 .49836 L p .433 .329 .636 r
F P
0 g
s
.70117 .50368 m .69118 .51089 L .68242 .45068 L p .821 .776 .81 r
F P
0 g
s
.68242 .45068 m .69238 .44274 L .70117 .50368 L p .821 .776 .81 r
F P
0 g
s
.46864 .5721 m .47065 .56682 L .48247 .59711 L p .387 .289 .621 r
F P
0 g
s
.48247 .59711 m .48213 .60717 L .46864 .5721 L p .387 .289 .621 r
F P
0 g
s
.33146 .31484 m .33947 .31891 L .30191 .35796 L p .704 .795 .921 r
F P
0 g
s
.30191 .35796 m .29205 .35608 L .33146 .31484 L p .704 .795 .921 r
F P
0 g
s
.48117 .51234 m .47754 .49836 L .4804 .4995 L p .43 .324 .633 r
F P
0 g
s
.47754 .49836 m .48117 .51234 L .48013 .51324 L p .425 .321 .633 r
F P
0 g
s
.49205 .4762 m .49085 .48477 L .48215 .46938 L p .449 .34 .638 r
F P
0 g
s
.48268 .48069 m .48215 .46938 L .49085 .48477 L p .445 .336 .637 r
F P
0 g
s
.47434 .5307 m .47782 .52948 L .48076 .53871 L p .41 .309 .629 r
F P
0 g
s
.48076 .53871 m .47873 .54456 L .47434 .5307 L p .41 .309 .629 r
F P
0 g
s
.47565 .52013 m .48023 .52342 L .48132 .52814 L p .415 .314 .631 r
F P
0 g
s
.48132 .52814 m .47782 .52948 L .47565 .52013 L p .415 .314 .631 r
F P
0 g
s
.47065 .56682 m .47266 .56143 L .48281 .58705 L p .392 .292 .622 r
F P
0 g
s
.48281 .58705 m .48247 .59711 L .47065 .56682 L p .392 .292 .622 r
F P
0 g
s
.49085 .48477 m .48965 .49327 L .48268 .48069 L p .445 .336 .637 r
F P
0 g
s
.48322 .49207 m .48268 .48069 L .48965 .49327 L p .44 .332 .635 r
F P
0 g
s
.47266 .56143 m .47468 .55592 L .48315 .57699 L p .396 .296 .623 r
F P
0 g
s
.48315 .57699 m .48281 .58705 L .47266 .56143 L p .396 .296 .623 r
F P
0 g
s
.48322 .49207 m .48375 .50352 L .4804 .4995 L p .436 .33 .635 r
F P
0 g
s
.48261 .51296 m .4804 .4995 L .48375 .50352 L p .432 .326 .633 r
F P
0 g
s
.4804 .4995 m .48261 .51296 L .48117 .51234 L p .43 .324 .633 r
F P
0 g
s
.54511 .4206 m .53922 .42846 L .50761 .35936 L p 0 0 .554 r
F P
0 g
s
.50761 .35936 m .51018 .36041 L .54511 .4206 L p 0 0 .554 r
F P
0 g
s
.50642 .36869 m .50761 .35936 L .53922 .42846 L p .501 .373 .638 r
F P
0 g
s
.3234 .31044 m .33146 .31484 L .29205 .35608 L p .698 .783 .917 r
F P
0 g
s
.29205 .35608 m .28215 .35389 L .3234 .31044 L p .698 .783 .917 r
F P
0 g
s
.69118 .51089 m .68122 .5192 L .6725 .45939 L p .833 .775 .796 r
F P
0 g
s
.6725 .45939 m .68242 .45068 L .69118 .51089 L p .833 .775 .796 r
F P
0 g
s
.48483 .52666 m .4796 .51557 L .48013 .51324 L closepath p .42 .317 .631 r
F P
0 g
s
.48483 .52666 m .47963 .51908 L .4796 .51557 L closepath p .419 .316 .631 r
F P
0 g
s
.47782 .52948 m .48132 .52814 L .4828 .53274 L p .415 .312 .629 r
F P
0 g
s
.4828 .53274 m .48076 .53871 L .47782 .52948 L p .415 .312 .629 r
F P
0 g
s
.47468 .55592 m .47671 .5503 L .48348 .56692 L p .4 .299 .624 r
F P
0 g
s
.48348 .56692 m .48315 .57699 L .47468 .55592 L p .4 .299 .624 r
F P
0 g
s
.53922 .42846 m .53634 .43482 L .50642 .36869 L p .501 .373 .638 r
F P
0 g
s
.50523 .37796 m .50642 .36869 L .53634 .43482 L p .498 .371 .638 r
F P
0 g
s
.48483 .52666 m .48013 .51324 L .48117 .51234 L closepath p .423 .318 .631 r
F P
0 g
s
.48965 .49327 m .48844 .50172 L .48322 .49207 L p .44 .332 .635 r
F P
0 g
s
.48375 .50352 m .48322 .49207 L .48844 .50172 L p .436 .329 .634 r
F P
0 g
s
.48483 .52666 m .48023 .52342 L .47963 .51908 L closepath p .419 .316 .631 r
F P
0 g
s
.53634 .43482 m .53346 .44104 L .50523 .37796 L p .498 .371 .638 r
F P
0 g
s
.50404 .38718 m .50523 .37796 L .53346 .44104 L p .494 .368 .637 r
F P
0 g
s
.48483 .52666 m .48117 .51234 L .48261 .51296 L closepath p .426 .32 .631 r
F P
0 g
s
.47671 .5503 m .47873 .54456 L .48382 .55686 L p .405 .303 .625 r
F P
0 g
s
.48382 .55686 m .48348 .56692 L .47671 .5503 L p .405 .303 .625 r
F P
0 g
s
.53346 .44104 m .53057 .44713 L .50404 .38718 L p .494 .368 .637 r
F P
0 g
s
.50284 .39634 m .50404 .38718 L .53057 .44713 L p .49 .365 .637 r
F P
0 g
s
.48483 .52666 m .48132 .52814 L .48023 .52342 L closepath p .42 .316 .63 r
F P
0 g
s
.53057 .44713 m .52769 .4531 L .50284 .39634 L p .49 .365 .637 r
F P
0 g
s
.50165 .40545 m .50284 .39634 L .52769 .4531 L p .486 .362 .637 r
F P
0 g
s
.48844 .50172 m .48724 .5101 L .48375 .50352 L p .436 .329 .634 r
F P
0 g
s
.48429 .51505 m .48375 .50352 L .48724 .5101 L p .432 .325 .632 r
F P
0 g
s
.48375 .50352 m .48429 .51505 L .48261 .51296 L p .432 .326 .633 r
F P
0 g
s
.41001 .30994 m .41491 .3138 L .3712 .33015 L p .603 .876 .992 r
F P
0 g
s
.3712 .33015 m .36332 .32834 L .41001 .30994 L p .603 .876 .992 r
F P
0 g
s
.48483 .52666 m .48261 .51296 L .48429 .51505 L closepath p .428 .321 .631 r
F P
0 g
s
.52769 .4531 m .52481 .45894 L .50165 .40545 L p .486 .362 .637 r
F P
0 g
s
.50045 .4145 m .50165 .40545 L .52481 .45894 L p .481 .359 .636 r
F P
0 g
s
.47873 .54456 m .48076 .53871 L .48416 .54679 L p .409 .306 .626 r
F P
0 g
s
.48416 .54679 m .48382 .55686 L .47873 .54456 L p .409 .306 .626 r
F P
0 g
s
.48483 .52666 m .4828 .53274 L .48132 .52814 L closepath p .42 .315 .629 r
F P
0 g
s
.52481 .45894 m .52193 .46464 L .50045 .4145 L p .481 .359 .636 r
F P
0 g
s
.49925 .42349 m .50045 .4145 L .52193 .46464 L p .477 .356 .636 r
F P
0 g
s
.31531 .30577 m .3234 .31044 L .28215 .35389 L p .693 .773 .913 r
F P
0 g
s
.28215 .35389 m .27224 .35146 L .31531 .30577 L p .693 .773 .913 r
F P
0 g
s
.52193 .46464 m .51905 .47021 L .49925 .42349 L p .477 .356 .636 r
F P
0 g
s
.49806 .43242 m .49925 .42349 L .51905 .47021 L p .473 .353 .636 r
F P
0 g
s
.48076 .53871 m .4828 .53274 L .4845 .53673 L p .414 .31 .627 r
F P
0 g
s
.4845 .53673 m .48416 .54679 L .48076 .53871 L p .414 .31 .627 r
F P
0 g
s
.51905 .47021 m .51618 .47565 L .49806 .43242 L p .473 .353 .636 r
F P
0 g
s
.49686 .4413 m .49806 .43242 L .51618 .47565 L p .469 .35 .635 r
F P
0 g
s
.48724 .5101 m .48604 .51841 L .48429 .51505 L p .432 .325 .632 r
F P
0 g
s
.48483 .52666 m .48429 .51505 L .48604 .51841 L closepath p .427 .321 .631 r
F P
0 g
s
.51618 .47565 m .5133 .48096 L .49686 .4413 L p .469 .35 .635 r
F P
0 g
s
.49566 .45011 m .49686 .4413 L .5133 .48096 L p .465 .347 .635 r
F P
0 g
s
.68122 .5192 m .67129 .52886 L .66262 .46904 L p .846 .772 .78 r
F P
0 g
s
.66262 .46904 m .6725 .45939 L .68122 .5192 L p .846 .772 .78 r
F P
0 g
s
.64175 .56998 m .65155 .5537 L .6415 .60571 L p .97 .933 .657 r
F P
0 g
s
.5133 .48096 m .51043 .48614 L .49566 .45011 L p .465 .347 .635 r
F P
0 g
s
.49446 .45887 m .49566 .45011 L .51043 .48614 L p .461 .344 .634 r
F P
0 g
s
.48483 .52666 m .4845 .53673 L .4828 .53274 L closepath p .418 .313 .628 r
F P
0 g
s
.51043 .48614 m .50757 .49118 L .49446 .45887 L p .461 .344 .634 r
F P
0 g
s
.49325 .46756 m .49446 .45887 L .50757 .49118 L p .456 .341 .634 r
F P
0 g
s
.50757 .49118 m .50471 .49608 L .49325 .46756 L p .456 .341 .634 r
F P
0 g
s
.49205 .4762 m .49325 .46756 L .50471 .49608 L p .452 .338 .633 r
F P
0 g
s
.50471 .49608 m .50185 .50086 L .49205 .4762 L p .452 .338 .633 r
F P
0 g
s
.49085 .48477 m .49205 .4762 L .50185 .50086 L p .448 .335 .633 r
F P
0 g
s
.50185 .50086 m .499 .5055 L .49085 .48477 L p .448 .335 .633 r
F P
0 g
s
.48965 .49327 m .49085 .48477 L .499 .5055 L p .443 .332 .632 r
F P
0 g
s
.499 .5055 m .49615 .51 L .48965 .49327 L p .443 .332 .632 r
F P
0 g
s
.48844 .50172 m .48965 .49327 L .49615 .51 L p .439 .329 .632 r
F P
0 g
s
.49615 .51 m .49331 .51437 L .48844 .50172 L p .439 .329 .632 r
F P
0 g
s
.48724 .5101 m .48844 .50172 L .49331 .51437 L p .435 .326 .631 r
F P
0 g
s
.49331 .51437 m .49048 .5186 L .48724 .5101 L p .435 .326 .631 r
F P
0 g
s
.48604 .51841 m .48724 .5101 L .49048 .5186 L p .43 .323 .631 r
F P
0 g
s
.48483 .52666 m .4899 .53939 L .4891 .54107 L closepath p .423 .316 .628 r
F P
0 g
s
.48483 .52666 m .49016 .53631 L .4899 .53939 L closepath p .425 .317 .628 r
F P
0 g
s
.48483 .52666 m .48983 .53217 L .49016 .53631 L closepath p .425 .317 .628 r
F P
0 g
s
.48483 .52666 m .48897 .52746 L .48983 .53217 L closepath p .425 .317 .628 r
F P
0 g
s
.48483 .52666 m .48765 .5227 L .48897 .52746 L closepath p .424 .318 .629 r
F P
0 g
s
.48483 .52666 m .48604 .51841 L .48765 .5227 L closepath p .426 .319 .63 r
F P
0 g
s
.48483 .52666 m .48624 .53964 L .4845 .53673 L closepath p .417 .312 .628 r
F P
0 g
s
.48483 .52666 m .48783 .54115 L .48624 .53964 L closepath p .417 .313 .628 r
F P
0 g
s
.48483 .52666 m .4891 .54107 L .48783 .54115 L closepath p .42 .314 .628 r
F P
0 g
s
.49048 .5186 m .48765 .5227 L .48604 .51841 L p .43 .323 .631 r
F P
0 g
s
.46882 .31999 m .47001 .32386 L .42464 .31842 L p .134 .658 .88 r
F P
0 g
s
.30718 .30086 m .31531 .30577 L .27224 .35146 L p .688 .765 .91 r
F P
0 g
s
.27224 .35146 m .26229 .34881 L .30718 .30086 L p .688 .765 .91 r
F P
0 g
s
.48416 .54679 m .4845 .53673 L .48624 .53964 L p .413 .308 .626 r
F P
0 g
s
.51718 .71849 m .5149 .75371 L .55042 .79452 L p .602 .317 .457 r
F P
0 g
s
.55042 .79452 m .55514 .74762 L .51718 .71849 L p .602 .317 .457 r
F P
0 g
s
.48382 .55686 m .48416 .54679 L .48765 .55279 L p .408 .304 .624 r
F P
0 g
s
.48624 .53964 m .48765 .55279 L .48416 .54679 L p .413 .308 .626 r
F P
0 g
s
.49312 .52815 m .48897 .52746 L .48765 .5227 L p .429 .32 .629 r
F P
0 g
s
.48765 .5227 m .49048 .5186 L .49312 .52815 L p .429 .32 .629 r
F P
0 g
s
.48348 .56692 m .48382 .55686 L .48906 .5661 L p .404 .301 .623 r
F P
0 g
s
.48765 .55279 m .48906 .5661 L .48382 .55686 L p .408 .304 .624 r
F P
0 g
s
.48765 .55279 m .48624 .53964 L .48783 .54115 L p .413 .309 .626 r
F P
0 g
s
.40508 .30535 m .41001 .30994 L .36332 .32834 L p .629 .851 .984 r
F P
0 g
s
.36332 .32834 m .3554 .32577 L .40508 .30535 L p .629 .851 .984 r
F P
0 g
s
.49487 .53771 m .48983 .53217 L .48897 .52746 L p .429 .319 .627 r
F P
0 g
s
.48897 .52746 m .49312 .52815 L .49487 .53771 L p .429 .319 .627 r
F P
0 g
s
.48315 .57699 m .48348 .56692 L .49048 .57958 L p .4 .297 .621 r
F P
0 g
s
.48906 .5661 m .49048 .57958 L .48348 .56692 L p .404 .301 .623 r
F P
0 g
s
.4973 .52875 m .49312 .52815 L .49048 .5186 L p .434 .323 .629 r
F P
0 g
s
.49048 .5186 m .49331 .51437 L .4973 .52875 L p .434 .323 .629 r
F P
0 g
s
.299 .29577 m .30718 .30086 L .26229 .34881 L p .685 .759 .908 r
F P
0 g
s
.26229 .34881 m .25232 .34599 L .299 .29577 L p .685 .759 .908 r
F P
0 g
s
.67129 .52886 m .66139 .54021 L .65279 .47985 L p .858 .768 .762 r
F P
0 g
s
.65279 .47985 m .66262 .46904 L .67129 .52886 L p .858 .768 .762 r
F P
0 g
s
.48783 .54115 m .49084 .55596 L .48765 .55279 L p .413 .309 .626 r
F P
0 g
s
.49084 .55596 m .48783 .54115 L .4891 .54107 L p .417 .311 .626 r
F P
0 g
s
.48281 .58705 m .48315 .57699 L .49191 .59323 L p .397 .293 .619 r
F P
0 g
s
.49048 .57958 m .49191 .59323 L .48315 .57699 L p .4 .297 .621 r
F P
0 g
s
.55102 .41189 m .54511 .4206 L .51018 .36041 L p 0 .205 .723 r
F P
0 g
s
.51018 .36041 m .51276 .35839 L .55102 .41189 L p 0 .205 .723 r
F P
0 g
s
.49553 .54614 m .49016 .53631 L .48983 .53217 L p .428 .318 .627 r
F P
0 g
s
.48983 .53217 m .49487 .53771 L .49553 .54614 L p .428 .318 .627 r
F P
0 g
s
.4934 .55585 m .4891 .54107 L .4899 .53939 L p .422 .314 .626 r
F P
0 g
s
.4891 .54107 m .4934 .55585 L .49084 .55596 L p .417 .311 .626 r
F P
0 g
s
.48247 .59711 m .48281 .58705 L .49334 .60706 L p .393 .29 .617 r
F P
0 g
s
.49191 .59323 m .49334 .60706 L .48281 .58705 L p .397 .293 .619 r
F P
0 g
s
.50149 .52924 m .4973 .52875 L .49331 .51437 L p .438 .326 .628 r
F P
0 g
s
.49331 .51437 m .49615 .51 L .50149 .52924 L p .438 .326 .628 r
F P
0 g
s
.48906 .5661 m .48765 .55279 L .49084 .55596 L p .41 .305 .623 r
F P
0 g
s
.49502 .55245 m .4899 .53939 L .49016 .53631 L p .426 .317 .626 r
F P
0 g
s
.49016 .53631 m .49553 .54614 L .49502 .55245 L p .426 .317 .626 r
F P
0 g
s
.4899 .53939 m .49502 .55245 L .4934 .55585 L p .422 .314 .626 r
F P
0 g
s
.55995 .71386 m .55514 .74762 L .58642 .74585 L p .395 .132 .394 r
F P
0 g
s
.58642 .74585 m .59334 .70774 L .55995 .71386 L p .395 .132 .394 r
F P
0 g
s
.48213 .60717 m .48247 .59711 L .49478 .62106 L p .389 .286 .615 r
F P
0 g
s
.49334 .60706 m .49478 .62106 L .48247 .59711 L p .393 .29 .617 r
F P
0 g
s
.51794 .34903 m .51534 .35438 L .47121 .32631 L p 0 .405 .825 r
F P
0 g
s
.49994 .54326 m .49487 .53771 L .49312 .52815 L p .433 .321 .626 r
F P
0 g
s
.49312 .52815 m .4973 .52875 L .49994 .54326 L p .433 .321 .626 r
F P
0 g
s
.5057 .52963 m .50149 .52924 L .49615 .51 L p .442 .328 .628 r
F P
0 g
s
.49615 .51 m .499 .5055 L .5057 .52963 L p .442 .328 .628 r
F P
0 g
s
.48179 .61722 m .48213 .60717 L .49623 .63523 L p .385 .282 .614 r
F P
0 g
s
.49478 .62106 m .49623 .63523 L .48213 .60717 L p .389 .286 .615 r
F P
0 g
s
.29079 .2905 m .299 .29577 L .25232 .34599 L p .682 .754 .906 r
F P
0 g
s
.25232 .34599 m .24232 .34303 L .29079 .2905 L p .682 .754 .906 r
F P
0 g
s
.48145 .62728 m .48179 .61722 L .49768 .64959 L p .382 .279 .612 r
F P
0 g
s
.49623 .63523 m .49768 .64959 L .48179 .61722 L p .385 .282 .614 r
F P
0 g
s
.49048 .57958 m .48906 .5661 L .49388 .57107 L p .406 .301 .621 r
F P
0 g
s
.49084 .55596 m .49388 .57107 L .48906 .5661 L p .41 .305 .623 r
F P
0 g
s
.50993 .52991 m .5057 .52963 L .499 .5055 L p .447 .33 .628 r
F P
0 g
s
.499 .5055 m .50185 .50086 L .50993 .52991 L p .447 .33 .628 r
F P
0 g
s
.49388 .57107 m .49084 .55596 L .4934 .55585 L p .414 .307 .623 r
F P
0 g
s
.48111 .63733 m .48145 .62728 L .49914 .66414 L p .378 .276 .61 r
F P
0 g
s
.49768 .64959 m .49914 .66414 L .48145 .62728 L p .382 .279 .612 r
F P
0 g
s
.46761 .31508 m .46882 .31999 L .41978 .31672 L p .332 .746 .978 r
F P
0 g
s
.41978 .31672 m .41491 .3138 L .46761 .31508 L p .332 .746 .978 r
F P
0 g
s
.40013 .30018 m .40508 .30535 L .3554 .32577 L p .642 .828 .972 r
F P
0 g
s
.3554 .32577 m .34746 .32259 L .40013 .30018 L p .642 .828 .972 r
F P
0 g
s
.48077 .64738 m .48111 .63733 L .50061 .67887 L p .375 .272 .609 r
F P
0 g
s
.49914 .66414 m .50061 .67887 L .48111 .63733 L p .378 .276 .61 r
F P
0 g
s
.50094 .55617 m .49553 .54614 L .49487 .53771 L p .431 .319 .625 r
F P
0 g
s
.49487 .53771 m .49994 .54326 L .50094 .55617 L p .431 .319 .625 r
F P
0 g
s
.51418 .53009 m .50993 .52991 L .50185 .50086 L p .451 .333 .627 r
F P
0 g
s
.50185 .50086 m .50471 .49608 L .51418 .53009 L p .451 .333 .627 r
F P
0 g
s
.28252 .28509 m .29079 .2905 L .24232 .34303 L p .68 .749 .904 r
F P
0 g
s
.24232 .34303 m .23228 .33994 L .28252 .28509 L p .68 .749 .904 r
F P
0 g
s
.66139 .54021 m .65155 .5537 L .64301 .49212 L p .871 .762 .74 r
F P
0 g
s
.64301 .49212 m .65279 .47985 L .66139 .54021 L p .871 .762 .74 r
F P
0 g
s
.50504 .54885 m .49994 .54326 L .4973 .52875 L p .437 .323 .626 r
F P
0 g
s
.4973 .52875 m .50149 .52924 L .50504 .54885 L p .437 .323 .626 r
F P
0 g
s
.48043 .65743 m .48077 .64738 L .50209 .6938 L p .371 .269 .607 r
F P
0 g
s
.50061 .67887 m .50209 .6938 L .48077 .64738 L p .375 .272 .609 r
F P
0 g
s
.49773 .57101 m .4934 .55585 L .49502 .55245 L p .421 .312 .624 r
F P
0 g
s
.4934 .55585 m .49773 .57101 L .49388 .57107 L p .414 .307 .623 r
F P
0 g
s
.63204 .58994 m .64175 .56998 L .63265 .62302 L p .973 .917 .592 r
F P
0 g
s
.48008 .66748 m .48043 .65743 L .50357 .70892 L p .368 .266 .606 r
F P
0 g
s
.50209 .6938 m .50357 .70892 L .48043 .65743 L p .371 .269 .607 r
F P
0 g
s
.50017 .56583 m .49502 .55245 L .49553 .54614 L p .427 .316 .624 r
F P
0 g
s
.49553 .54614 m .50094 .55617 L .50017 .56583 L p .427 .316 .624 r
F P
0 g
s
.49191 .59323 m .49048 .57958 L .49693 .5865 L p .403 .297 .619 r
F P
0 g
s
.49388 .57107 m .49693 .5865 L .49048 .57958 L p .406 .301 .621 r
F P
0 g
s
.51844 .53016 m .51418 .53009 L .50471 .49608 L p .455 .335 .627 r
F P
0 g
s
.50471 .49608 m .50757 .49118 L .51844 .53016 L p .455 .335 .627 r
F P
0 g
s
.49502 .55245 m .50017 .56583 L .49773 .57101 L p .421 .312 .624 r
F P
0 g
s
.47974 .67752 m .48008 .66748 L .50506 .72424 L p .364 .262 .604 r
F P
0 g
s
.50357 .70892 m .50506 .72424 L .48008 .66748 L p .368 .266 .606 r
F P
0 g
s
.52273 .53012 m .51844 .53016 L .50757 .49118 L p .459 .337 .627 r
F P
0 g
s
.50757 .49118 m .51043 .48614 L .52273 .53012 L p .459 .337 .627 r
F P
0 g
s
.4794 .68756 m .47974 .67752 L .50656 .73977 L p .361 .259 .602 r
F P
0 g
s
.50506 .72424 m .50656 .73977 L .47974 .67752 L p .364 .262 .604 r
F P
0 g
s
.27422 .27955 m .28252 .28509 L .23228 .33994 L p .677 .746 .902 r
F P
0 g
s
.23228 .33994 m .22222 .33675 L .27422 .27955 L p .677 .746 .902 r
F P
0 g
s
.49693 .5865 m .49388 .57107 L .49773 .57101 L p .412 .304 .621 r
F P
0 g
s
.55694 .40283 m .55102 .41189 L .51276 .35839 L p .194 .359 .801 r
F P
0 g
s
.51276 .35839 m .51534 .35438 L .55694 .40283 L p .194 .359 .801 r
F P
0 g
s
.47906 .6976 m .4794 .68756 L .50807 .75549 L p .358 .256 .601 r
F P
0 g
s
.50656 .73977 m .50807 .75549 L .4794 .68756 L p .361 .259 .602 r
F P
0 g
s
.51018 .55445 m .50504 .54885 L .50149 .52924 L p .441 .325 .625 r
F P
0 g
s
.50149 .52924 m .5057 .52963 L .51018 .55445 L p .441 .325 .625 r
F P
0 g
s
.52702 .52997 m .52273 .53012 L .51043 .48614 L p .463 .339 .626 r
F P
0 g
s
.51043 .48614 m .5133 .48096 L .52702 .52997 L p .463 .339 .626 r
F P
0 g
s
.49334 .60706 m .49191 .59323 L .5 .60226 L p .4 .293 .617 r
F P
0 g
s
.49693 .5865 m .5 .60226 L .49191 .59323 L p .403 .297 .619 r
F P
0 g
s
.47872 .70763 m .47906 .6976 L .50959 .77143 L p .355 .253 .599 r
F P
0 g
s
.50807 .75549 m .50959 .77143 L .47906 .6976 L p .358 .256 .601 r
F P
0 g
s
.50639 .56639 m .50094 .55617 L .49994 .54326 L p .434 .32 .624 r
F P
0 g
s
.49994 .54326 m .50504 .54885 L .50639 .56639 L p .434 .32 .624 r
F P
0 g
s
.39515 .29453 m .40013 .30018 L .34746 .32259 L p .649 .809 .96 r
F P
0 g
s
.34746 .32259 m .33947 .31891 L .39515 .29453 L p .649 .809 .96 r
F P
0 g
s
.47837 .71766 m .47872 .70763 L .51112 .78759 L p .351 .25 .598 r
F P
0 g
s
.50959 .77143 m .51112 .78759 L .47872 .70763 L p .355 .253 .599 r
F P
0 g
s
.53134 .52972 m .52702 .52997 L .5133 .48096 L p .466 .341 .626 r
F P
0 g
s
.5133 .48096 m .51618 .47565 L .53134 .52972 L p .466 .341 .626 r
F P
0 g
s
.52055 .34277 m .51794 .34903 L .47001 .32386 L p .179 .549 .93 r
F P
0 g
s
.47001 .32386 m .46882 .31999 L .52055 .34277 L p .179 .549 .93 r
F P
0 g
s
.51112 .78759 m .51265 .80396 L .47837 .71766 L p .351 .25 .598 r
F P
0 g
s
.26587 .2739 m .27422 .27955 L .22222 .33675 L p .676 .743 .901 r
F P
0 g
s
.22222 .33675 m .21212 .33348 L .26587 .2739 L p .676 .743 .901 r
F P
0 g
s
.50209 .58655 m .49773 .57101 L .50017 .56583 L p .42 .31 .622 r
F P
0 g
s
.49773 .57101 m .50209 .58655 L .49693 .5865 L p .412 .304 .621 r
F P
0 g
s
.53567 .52936 m .53134 .52972 L .51618 .47565 L p .47 .344 .626 r
F P
0 g
s
.51618 .47565 m .51905 .47021 L .53567 .52936 L p .47 .344 .626 r
F P
0 g
s
.46641 .30937 m .46761 .31508 L .41491 .3138 L p .447 .769 .997 r
F P
0 g
s
.41491 .3138 m .41001 .30994 L .46641 .30937 L p .447 .769 .997 r
F P
0 g
s
.51535 .56008 m .51018 .55445 L .5057 .52963 L p .445 .326 .624 r
F P
0 g
s
.5057 .52963 m .50993 .52991 L .51535 .56008 L p .445 .326 .624 r
F P
0 g
s
.50538 .57955 m .50017 .56583 L .50094 .55617 L p .429 .315 .623 r
F P
0 g
s
.50094 .55617 m .50639 .56639 L .50538 .57955 L p .429 .315 .623 r
F P
0 g
s
.49478 .62106 m .49334 .60706 L .5031 .61835 L p .396 .29 .615 r
F P
0 g
s
.5 .60226 m .5031 .61835 L .49334 .60706 L p .4 .293 .617 r
F P
0 g
s
.54002 .52889 m .53567 .52936 L .51905 .47021 L p .474 .346 .625 r
F P
0 g
s
.51905 .47021 m .52193 .46464 L .54002 .52889 L p .474 .346 .625 r
F P
0 g
s
.50017 .56583 m .50538 .57955 L .50209 .58655 L p .42 .31 .622 r
F P
0 g
s
.5 .60226 m .49693 .5865 L .50209 .58655 L p .409 .301 .619 r
F P
0 g
s
.65155 .5537 m .64175 .56998 L .63328 .50624 L p .882 .754 .716 r
F P
0 g
s
.63328 .50624 m .64301 .49212 L .65155 .5537 L p .882 .754 .716 r
F P
0 g
s
.54438 .52831 m .54002 .52889 L .52193 .46464 L p .477 .348 .625 r
F P
0 g
s
.52193 .46464 m .52481 .45894 L .54438 .52831 L p .477 .348 .625 r
F P
0 g
s
.74272 .4108 m .73258 .41641 L .69478 .35198 L p .727 .719 .843 r
F P
0 g
s
.73258 .41641 m .72248 .42235 L .68589 .35928 L p .73 .715 .837 r
F P
0 g
s
.68589 .35928 m .69478 .35198 L .73258 .41641 L p .73 .715 .837 r
F P
0 g
s
.72248 .42235 m .71241 .42867 L .67705 .36681 L p .733 .711 .83 r
F P
0 g
s
.67705 .36681 m .68589 .35928 L .72248 .42235 L p .733 .711 .83 r
F P
0 g
s
.75289 .40546 m .74272 .4108 L .70371 .34485 L p .724 .722 .848 r
F P
0 g
s
.69478 .35198 m .70371 .34485 L .74272 .4108 L p .727 .719 .843 r
F P
0 g
s
.71241 .42867 m .70237 .43544 L .66825 .37458 L p .737 .706 .822 r
F P
0 g
s
.66825 .37458 m .67705 .36681 L .71241 .42867 L p .737 .706 .822 r
F P
0 g
s
.5119 .57681 m .50639 .56639 L .50504 .54885 L p .437 .32 .622 r
F P
0 g
s
.50504 .54885 m .51018 .55445 L .5119 .57681 L p .437 .32 .622 r
F P
0 g
s
.7631 .40038 m .75289 .40546 L .7127 .33788 L p .721 .724 .853 r
F P
0 g
s
.70371 .34485 m .7127 .33788 L .75289 .40546 L p .724 .722 .848 r
F P
0 g
s
.54875 .52761 m .54438 .52831 L .52481 .45894 L p .481 .349 .624 r
F P
0 g
s
.52481 .45894 m .52769 .4531 L .54875 .52761 L p .481 .349 .624 r
F P
0 g
s
.70237 .43544 m .69238 .44274 L .65951 .38264 L p .74 .701 .814 r
F P
0 g
s
.65951 .38264 m .66825 .37458 L .70237 .43544 L p .74 .701 .814 r
F P
0 g
s
.77334 .3955 m .7631 .40038 L .72173 .33104 L p .718 .726 .857 r
F P
0 g
s
.7127 .33788 m .72173 .33104 L .7631 .40038 L p .721 .724 .853 r
F P
0 g
s
.52056 .56574 m .51535 .56008 L .50993 .52991 L p .449 .328 .623 r
F P
0 g
s
.50993 .52991 m .51418 .53009 L .52056 .56574 L p .449 .328 .623 r
F P
0 g
s
.55314 .52681 m .54875 .52761 L .52769 .4531 L p .484 .351 .624 r
F P
0 g
s
.52769 .4531 m .53057 .44713 L .55314 .52681 L p .484 .351 .624 r
F P
0 g
s
.39013 .2885 m .39515 .29453 L .33947 .31891 L p .654 .793 .949 r
F P
0 g
s
.33947 .31891 m .33146 .31484 L .39013 .2885 L p .654 .793 .949 r
F P
0 g
s
.72173 .33104 m .73081 .32433 L .77334 .3955 L p .718 .726 .857 r
F P
0 g
s
.49623 .63523 m .49478 .62106 L .50622 .63478 L p .393 .286 .613 r
F P
0 g
s
.5031 .61835 m .50622 .63478 L .49478 .62106 L p .396 .29 .615 r
F P
0 g
s
.69238 .44274 m .68242 .45068 L .65081 .39106 L p .744 .694 .804 r
F P
0 g
s
.65081 .39106 m .65951 .38264 L .69238 .44274 L p .744 .694 .804 r
F P
0 g
s
.55754 .52589 m .55314 .52681 L .53057 .44713 L p .488 .353 .623 r
F P
0 g
s
.53057 .44713 m .53346 .44104 L .55754 .52589 L p .488 .353 .623 r
F P
0 g
s
.56289 .39365 m .55694 .40283 L .51534 .35438 L p .334 .456 .835 r
F P
0 g
s
.51534 .35438 m .51794 .34903 L .56289 .39365 L p .334 .456 .835 r
F P
0 g
s
.68242 .45068 m .6725 .45939 L .64215 .39988 L p .747 .686 .792 r
F P
0 g
s
.64215 .39988 m .65081 .39106 L .68242 .45068 L p .747 .686 .792 r
F P
0 g
s
.56196 .52487 m .55754 .52589 L .53346 .44104 L p .491 .355 .623 r
F P
0 g
s
.53346 .44104 m .53634 .43482 L .56196 .52487 L p .491 .355 .623 r
F P
0 g
s
.5065 .60248 m .50209 .58655 L .50538 .57955 L p .419 .308 .62 r
F P
0 g
s
.50209 .58655 m .5065 .60248 L .5 .60226 L p .409 .301 .619 r
F P
0 g
s
.56639 .52372 m .56196 .52487 L .53634 .43482 L p .494 .357 .622 r
F P
0 g
s
.53634 .43482 m .53922 .42846 L .56639 .52372 L p .494 .357 .622 r
F P
0 g
s
.5031 .61835 m .5 .60226 L .5065 .60248 L p .407 .298 .617 r
F P
0 g
s
.51062 .59362 m .50538 .57955 L .50639 .56639 L p .43 .315 .621 r
F P
0 g
s
.50639 .56639 m .5119 .57681 L .51062 .59362 L p .43 .315 .621 r
F P
0 g
s
.57461 .5023 m .56639 .52372 L .53922 .42846 L p .453 .361 .661 r
F P
0 g
s
.53922 .42846 m .54511 .4206 L .57461 .5023 L p .453 .361 .661 r
F P
0 g
s
.5258 .57142 m .52056 .56574 L .51418 .53009 L p .452 .329 .622 r
F P
0 g
s
.51418 .53009 m .51844 .53016 L .5258 .57142 L p .452 .329 .622 r
F P
0 g
s
.6725 .45939 m .66262 .46904 L .63354 .4092 L p .749 .676 .779 r
F P
0 g
s
.63354 .4092 m .64215 .39988 L .6725 .45939 L p .749 .676 .779 r
F P
0 g
s
.49768 .64959 m .49623 .63523 L .50936 .65156 L p .39 .283 .611 r
F P
0 g
s
.50622 .63478 m .50936 .65156 L .49623 .63523 L p .393 .286 .613 r
F P
0 g
s
.50538 .57955 m .51062 .59362 L .5065 .60248 L p .419 .308 .62 r
F P
0 g
s
.51744 .58744 m .5119 .57681 L .51018 .55445 L p .44 .321 .621 r
F P
0 g
s
.51018 .55445 m .51535 .56008 L .51744 .58744 L p .44 .321 .621 r
F P
0 g
s
.46519 .30306 m .46641 .30937 L .41001 .30994 L p .513 .77 .989 r
F P
0 g
s
.41001 .30994 m .40508 .30535 L .46519 .30306 L p .513 .77 .989 r
F P
0 g
s
.52317 .33586 m .52055 .34277 L .46882 .31999 L p .336 .618 .954 r
F P
0 g
s
.46882 .31999 m .46761 .31508 L .52317 .33586 L p .336 .618 .954 r
F P
0 g
s
.38509 .28215 m .39013 .2885 L .33146 .31484 L p .657 .781 .94 r
F P
0 g
s
.33146 .31484 m .3234 .31044 L .38509 .28215 L p .657 .781 .94 r
F P
0 g
s
.66262 .46904 m .65279 .47985 L .62498 .41912 L p .751 .664 .765 r
F P
0 g
s
.62498 .41912 m .63354 .4092 L .66262 .46904 L p .751 .664 .765 r
F P
0 g
s
.62241 .61488 m .63204 .58994 L .62387 .64495 L p .969 .891 .519 r
F P
0 g
s
.53107 .57712 m .5258 .57142 L .51844 .53016 L p .456 .331 .621 r
F P
0 g
s
.51844 .53016 m .52273 .53012 L .53107 .57712 L p .456 .331 .621 r
F P
0 g
s
.64175 .56998 m .63204 .58994 L .62362 .52277 L p .893 .744 .69 r
F P
0 g
s
.62362 .52277 m .63328 .50624 L .64175 .56998 L p .893 .744 .69 r
F P
0 g
s
.49914 .66414 m .49768 .64959 L .51253 .6687 L p .387 .28 .609 r
F P
0 g
s
.50936 .65156 m .51253 .6687 L .49768 .64959 L p .39 .283 .611 r
F P
0 g
s
.58289 .48402 m .57461 .5023 L .54511 .4206 L p .51 .422 .692 r
F P
0 g
s
.54511 .4206 m .55102 .41189 L .58289 .48402 L p .51 .422 .692 r
F P
0 g
s
.50622 .63478 m .5031 .61835 L .51094 .61882 L p .405 .295 .615 r
F P
0 g
s
.5065 .60248 m .51094 .61882 L .5031 .61835 L p .407 .298 .617 r
F P
0 g
s
.51094 .61882 m .5065 .60248 L .51062 .59362 L p .419 .306 .618 r
F P
0 g
s
.56887 .38449 m .56289 .39365 L .51794 .34903 L p .424 .518 .85 r
F P
0 g
s
.51794 .34903 m .52055 .34277 L .56887 .38449 L p .424 .518 .85 r
F P
0 g
s
.65279 .47985 m .64301 .49212 L .61647 .42978 L p .753 .651 .748 r
F P
0 g
s
.61647 .42978 m .62498 .41912 L .65279 .47985 L p .753 .651 .748 r
F P
0 g
s
.51592 .60803 m .51062 .59362 L .5119 .57681 L p .431 .314 .619 r
F P
0 g
s
.5119 .57681 m .51744 .58744 L .51592 .60803 L p .431 .314 .619 r
F P
0 g
s
.52304 .59827 m .51744 .58744 L .51535 .56008 L p .443 .322 .62 r
F P
0 g
s
.51535 .56008 m .52056 .56574 L .52304 .59827 L p .443 .322 .62 r
F P
0 g
s
.5149 .75371 m .51265 .80396 L .54587 .86175 L p .609 .334 .475 r
F P
0 g
s
.54587 .86175 m .55042 .79452 L .5149 .75371 L p .609 .334 .475 r
F P
0 g
s
.53639 .58285 m .53107 .57712 L .52273 .53012 L p .459 .332 .62 r
F P
0 g
s
.52273 .53012 m .52702 .52997 L .53639 .58285 L p .459 .332 .62 r
F P
0 g
s
.51062 .59362 m .51592 .60803 L .51094 .61882 L p .419 .306 .618 r
F P
0 g
s
.50061 .67887 m .49914 .66414 L .51573 .6862 L p .384 .277 .607 r
F P
0 g
s
.51253 .6687 m .51573 .6862 L .49914 .66414 L p .387 .28 .609 r
F P
0 g
s
.59121 .4681 m .58289 .48402 L .55102 .41189 L p .553 .471 .717 r
F P
0 g
s
.55102 .41189 m .55694 .40283 L .59121 .4681 L p .553 .471 .717 r
F P
0 g
s
.38001 .27553 m .38509 .28215 L .3234 .31044 L p .658 .771 .933 r
F P
0 g
s
.3234 .31044 m .31531 .30577 L .38001 .27553 L p .658 .771 .933 r
F P
0 g
s
.46397 .29626 m .46519 .30306 L .40508 .30535 L p .554 .764 .976 r
F P
0 g
s
.40508 .30535 m .40013 .30018 L .46397 .29626 L p .554 .764 .976 r
F P
0 g
s
.55514 .74762 m .55042 .79452 L .57968 .79839 L p .413 .164 .424 r
F P
0 g
s
.57968 .79839 m .58642 .74585 L .55514 .74762 L p .413 .164 .424 r
F P
0 g
s
.52581 .32848 m .52317 .33586 L .46761 .31508 L p .432 .652 .951 r
F P
0 g
s
.46761 .31508 m .46641 .30937 L .52581 .32848 L p .432 .652 .951 r
F P
0 g
s
.64301 .49212 m .63328 .50624 L .608 .44133 L p .752 .635 .73 r
F P
0 g
s
.608 .44133 m .61647 .42978 L .64301 .49212 L p .752 .635 .73 r
F P
0 g
s
.50936 .65156 m .50622 .63478 L .51543 .63558 L p .403 .292 .613 r
F P
0 g
s
.51094 .61882 m .51543 .63558 L .50622 .63478 L p .405 .295 .615 r
F P
0 g
s
.54173 .58861 m .53639 .58285 L .52702 .52997 L p .462 .334 .619 r
F P
0 g
s
.52702 .52997 m .53134 .52972 L .54173 .58861 L p .462 .334 .619 r
F P
0 g
s
.52869 .60931 m .52304 .59827 L .52056 .56574 L p .445 .322 .618 r
F P
0 g
s
.52056 .56574 m .5258 .57142 L .52869 .60931 L p .445 .322 .618 r
F P
0 g
s
.50209 .6938 m .50061 .67887 L .51895 .70408 L p .381 .273 .605 r
F P
0 g
s
.51573 .6862 m .51895 .70408 L .50061 .67887 L p .384 .277 .607 r
F P
0 g
s
.59958 .45401 m .59121 .4681 L .55694 .40283 L p .585 .511 .738 r
F P
0 g
s
.55694 .40283 m .56289 .39365 L .59958 .45401 L p .585 .511 .738 r
F P
0 g
s
.51543 .63558 m .51094 .61882 L .51592 .60803 L p .418 .304 .616 r
F P
0 g
s
.52127 .62282 m .51592 .60803 L .51744 .58744 L p .432 .314 .618 r
F P
0 g
s
.51744 .58744 m .52304 .59827 L .52127 .62282 L p .432 .314 .618 r
F P
0 g
s
.57488 .3754 m .56887 .38449 L .52055 .34277 L p .485 .56 .857 r
F P
0 g
s
.52055 .34277 m .52317 .33586 L .57488 .3754 L p .485 .56 .857 r
F P
0 g
s
.3749 .26868 m .38001 .27553 L .31531 .30577 L p .66 .764 .927 r
F P
0 g
s
.31531 .30577 m .30718 .30086 L .3749 .26868 L p .66 .764 .927 r
F P
0 g
s
.54712 .59438 m .54173 .58861 L .53134 .52972 L p .465 .335 .618 r
F P
0 g
s
.53134 .52972 m .53567 .52936 L .54712 .59438 L p .465 .335 .618 r
F P
0 g
s
.51592 .60803 m .52127 .62282 L .51543 .63558 L p .418 .304 .616 r
F P
0 g
s
.63328 .50624 m .62362 .52277 L .59958 .45401 L p .751 .617 .71 r
F P
0 g
s
.59958 .45401 m .608 .44133 L .63328 .50624 L p .751 .617 .71 r
F P
0 g
s
.50357 .70892 m .50209 .6938 L .5222 .72234 L p .379 .27 .603 r
F P
0 g
s
.51895 .70408 m .5222 .72234 L .50209 .6938 L p .381 .273 .605 r
F P
0 g
s
.608 .44133 m .59958 .45401 L .56289 .39365 L p .609 .544 .757 r
F P
0 g
s
.56289 .39365 m .56887 .38449 L .608 .44133 L p .609 .544 .757 r
F P
0 g
s
.46273 .28909 m .46397 .29626 L .40013 .30018 L p .581 .757 .962 r
F P
0 g
s
.40013 .30018 m .39515 .29453 L .46273 .28909 L p .581 .757 .962 r
F P
0 g
s
.51253 .6687 m .50936 .65156 L .51996 .65276 L p .401 .289 .611 r
F P
0 g
s
.51543 .63558 m .51996 .65276 L .50936 .65156 L p .403 .292 .613 r
F P
0 g
s
.63204 .58994 m .62241 .61488 L .61402 .54248 L p .901 .731 .661 r
F P
0 g
s
.61402 .54248 m .62362 .52277 L .63204 .58994 L p .901 .731 .661 r
F P
0 g
s
.55254 .60019 m .54712 .59438 L .53567 .52936 L p .469 .336 .617 r
F P
0 g
s
.53567 .52936 m .54002 .52889 L .55254 .60019 L p .469 .336 .617 r
F P
0 g
s
.53438 .62057 m .52869 .60931 L .5258 .57142 L p .448 .323 .617 r
F P
0 g
s
.5258 .57142 m .53107 .57712 L .53438 .62057 L p .448 .323 .617 r
F P
0 g
s
.52847 .32077 m .52581 .32848 L .46641 .30937 L p .492 .67 .943 r
F P
0 g
s
.46641 .30937 m .46519 .30306 L .52847 .32077 L p .492 .67 .943 r
F P
0 g
s
.36975 .26164 m .3749 .26868 L .30718 .30086 L p .661 .757 .922 r
F P
0 g
s
.30718 .30086 m .299 .29577 L .36975 .26164 L p .661 .757 .922 r
F P
0 g
s
.51996 .65276 m .51543 .63558 L .52127 .62282 L p .417 .302 .614 r
F P
0 g
s
.61647 .42978 m .608 .44133 L .56887 .38449 L p .628 .572 .772 r
F P
0 g
s
.56887 .38449 m .57488 .3754 L .61647 .42978 L p .628 .572 .772 r
F P
0 g
s
.50506 .72424 m .50357 .70892 L .52548 .74099 L p .376 .268 .602 r
F P
0 g
s
.5222 .72234 m .52548 .74099 L .50357 .70892 L p .379 .27 .603 r
F P
0 g
s
.52667 .63797 m .52127 .62282 L .52304 .59827 L p .433 .313 .616 r
F P
0 g
s
.52304 .59827 m .52869 .60931 L .52667 .63797 L p .433 .313 .616 r
F P
0 g
s
.58092 .36641 m .57488 .3754 L .52317 .33586 L p .528 .59 .861 r
F P
0 g
s
.52317 .33586 m .52581 .32848 L .58092 .36641 L p .528 .59 .861 r
F P
0 g
s
.62498 .41912 m .61647 .42978 L .57488 .3754 L p .642 .595 .786 r
F P
0 g
s
.63354 .4092 m .62498 .41912 L .58092 .36641 L p .653 .614 .798 r
F P
0 g
s
.57488 .3754 m .58092 .36641 L .62498 .41912 L p .642 .595 .786 r
F P
0 g
s
.55799 .60602 m .55254 .60019 L .54002 .52889 L p .472 .338 .617 r
F P
0 g
s
.54002 .52889 m .54438 .52831 L .55799 .60602 L p .472 .338 .617 r
F P
0 g
s
.64215 .39988 m .63354 .4092 L .58701 .35752 L p .661 .63 .808 r
F P
0 g
s
.58092 .36641 m .58701 .35752 L .63354 .4092 L p .653 .614 .798 r
F P
0 g
s
.59121 .4681 m .59958 .45401 L .62362 .52277 L p .747 .596 .689 r
F P
0 g
s
.65081 .39106 m .64215 .39988 L .59312 .34875 L p .667 .643 .817 r
F P
0 g
s
.58701 .35752 m .59312 .34875 L .64215 .39988 L p .661 .63 .808 r
F P
0 g
s
.62362 .52277 m .61402 .54248 L .59121 .4681 L p .747 .596 .689 r
F P
0 g
s
.51573 .6862 m .51253 .6687 L .52453 .67038 L p .399 .286 .609 r
F P
0 g
s
.51996 .65276 m .52453 .67038 L .51253 .6687 L p .401 .289 .611 r
F P
0 g
s
.52127 .62282 m .52667 .63797 L .51996 .65276 L p .417 .302 .614 r
F P
0 g
s
.54013 .63204 m .53438 .62057 L .53107 .57712 L p .45 .324 .616 r
F P
0 g
s
.53107 .57712 m .53639 .58285 L .54013 .63204 L p .45 .324 .616 r
F P
0 g
s
.46149 .2816 m .46273 .28909 L .39515 .29453 L p .599 .751 .95 r
F P
0 g
s
.39515 .29453 m .39013 .2885 L .46149 .2816 L p .599 .751 .95 r
F P
0 g
s
.56348 .61187 m .55799 .60602 L .54438 .52831 L p .475 .339 .616 r
F P
0 g
s
.54438 .52831 m .54875 .52761 L .56348 .61187 L p .475 .339 .616 r
F P
0 g
s
.65951 .38264 m .65081 .39106 L .59928 .34007 L p .672 .655 .825 r
F P
0 g
s
.59312 .34875 m .59928 .34007 L .65081 .39106 L p .667 .643 .817 r
F P
0 g
s
.58289 .48402 m .59121 .4681 L .61402 .54248 L p .74 .573 .666 r
F P
0 g
s
.61291 .64679 m .62241 .61488 L .61518 .67323 L p .956 .858 .443 r
F P
0 g
s
.50656 .73977 m .50506 .72424 L .52879 .76004 L p .373 .265 .6 r
F P
0 g
s
.52548 .74099 m .52879 .76004 L .50506 .72424 L p .376 .268 .602 r
F P
0 g
s
.36457 .25443 m .36975 .26164 L .299 .29577 L p .661 .752 .917 r
F P
0 g
s
.299 .29577 m .29079 .2905 L .36457 .25443 L p .661 .752 .917 r
F P
0 g
s
.66825 .37458 m .65951 .38264 L .60548 .33149 L p .676 .665 .832 r
F P
0 g
s
.59928 .34007 m .60548 .33149 L .65951 .38264 L p .672 .655 .825 r
F P
0 g
s
.53114 .3128 m .52847 .32077 L .46519 .30306 L p .533 .681 .933 r
F P
0 g
s
.46519 .30306 m .46397 .29626 L .53114 .3128 L p .533 .681 .933 r
F P
0 g
s
.56901 .61775 m .56348 .61187 L .54875 .52761 L p .477 .34 .615 r
F P
0 g
s
.54875 .52761 m .55314 .52681 L .56901 .61775 L p .477 .34 .615 r
F P
0 g
s
.53213 .6535 m .52667 .63797 L .52869 .60931 L p .434 .313 .615 r
F P
0 g
s
.52869 .60931 m .53438 .62057 L .53213 .6535 L p .434 .313 .615 r
F P
0 g
s
.58701 .35752 m .58092 .36641 L .52581 .32848 L p .559 .613 .863 r
F P
0 g
s
.52581 .32848 m .52847 .32077 L .58701 .35752 L p .559 .613 .863 r
F P
0 g
s
.52453 .67038 m .51996 .65276 L .52667 .63797 L p .417 .3 .612 r
F P
0 g
s
.61402 .54248 m .60451 .56652 L .58289 .48402 L p .74 .573 .666 r
F P
0 g
s
.57461 .5023 m .58289 .48402 L .60451 .56652 L p .731 .547 .643 r
F P
0 g
s
.67705 .36681 m .66825 .37458 L .61172 .32298 L p .678 .673 .838 r
F P
0 g
s
.60548 .33149 m .61172 .32298 L .66825 .37458 L p .676 .665 .832 r
F P
0 g
s
.50807 .75549 m .50656 .73977 L .53214 .77951 L p .371 .262 .598 r
F P
0 g
s
.52879 .76004 m .53214 .77951 L .50656 .73977 L p .373 .265 .6 r
F P
0 g
s
.54594 .64374 m .54013 .63204 L .53639 .58285 L p .453 .324 .615 r
F P
0 g
s
.53639 .58285 m .54173 .58861 L .54594 .64374 L p .453 .324 .615 r
F P
0 g
s
.51895 .70408 m .51573 .6862 L .52915 .68844 L p .397 .284 .607 r
F P
0 g
s
.52453 .67038 m .52915 .68844 L .51573 .6862 L p .399 .286 .609 r
F P
0 g
s
.68589 .35928 m .67705 .36681 L .618 .31455 L p .68 .68 .843 r
F P
0 g
s
.61172 .32298 m .618 .31455 L .67705 .36681 L p .678 .673 .838 r
F P
0 g
s
.57458 .62366 m .56901 .61775 L .55314 .52681 L p .48 .341 .614 r
F P
0 g
s
.55314 .52681 m .55754 .52589 L .57458 .62366 L p .48 .341 .614 r
F P
0 g
s
.35935 .24706 m .36457 .25443 L .29079 .2905 L p .662 .748 .914 r
F P
0 g
s
.29079 .2905 m .28252 .28509 L .35935 .24706 L p .662 .748 .914 r
F P
0 g
s
.52667 .63797 m .53213 .6535 L .52453 .67038 L p .417 .3 .612 r
F P
0 g
s
.46024 .27385 m .46149 .2816 L .39013 .2885 L p .612 .746 .94 r
F P
0 g
s
.39013 .2885 m .38509 .28215 L .46024 .27385 L p .612 .746 .94 r
F P
0 g
s
.60451 .56652 m .61402 .54248 L .62241 .61488 L p .907 .716 .632 r
F P
0 g
s
.60451 .56652 m .5951 .59662 L .57461 .5023 L p .731 .547 .643 r
F P
0 g
s
.56639 .52372 m .57461 .5023 L .5951 .59662 L p .719 .52 .62 r
F P
0 g
s
.59312 .34875 m .58701 .35752 L .52847 .32077 L p .582 .63 .865 r
F P
0 g
s
.62241 .61488 m .61291 .64679 L .60451 .56652 L p .907 .716 .632 r
F P
0 g
s
.69478 .35198 m .68589 .35928 L .62433 .30617 L p .682 .686 .848 r
F P
0 g
s
.618 .31455 m .62433 .30617 L .68589 .35928 L p .68 .68 .843 r
F P
0 g
s
.50959 .77143 m .50807 .75549 L .53552 .79941 L p .368 .259 .597 r
F P
0 g
s
.53214 .77951 m .53552 .79941 L .50807 .75549 L p .371 .262 .598 r
F P
0 g
s
.58019 .62959 m .57458 .62366 L .55754 .52589 L p .483 .342 .613 r
F P
0 g
s
.55754 .52589 m .56196 .52487 L .58019 .62959 L p .483 .342 .613 r
F P
0 g
s
.53384 .30463 m .53114 .3128 L .46397 .29626 L p .561 .688 .925 r
F P
0 g
s
.46397 .29626 m .46273 .28909 L .53384 .30463 L p .561 .688 .925 r
F P
0 g
s
.52847 .32077 m .53114 .3128 L .59312 .34875 L p .582 .63 .865 r
F P
0 g
s
.55179 .65567 m .54594 .64374 L .54173 .58861 L p .455 .325 .614 r
F P
0 g
s
.54173 .58861 m .54712 .59438 L .55179 .65567 L p .455 .325 .614 r
F P
0 g
s
.53765 .66942 m .53213 .6535 L .53438 .62057 L p .435 .312 .613 r
F P
0 g
s
.53438 .62057 m .54013 .63204 L .53765 .66942 L p .435 .312 .613 r
F P
0 g
s
.52915 .68844 m .52453 .67038 L .53213 .6535 L p .416 .298 .611 r
F P
0 g
s
.70371 .34485 m .69478 .35198 L .63069 .29784 L p .683 .691 .852 r
F P
0 g
s
.62433 .30617 m .63069 .29784 L .69478 .35198 L p .682 .686 .848 r
F P
0 g
s
.5222 .72234 m .51895 .70408 L .53382 .70697 L p .395 .281 .605 r
F P
0 g
s
.52915 .68844 m .53382 .70697 L .51895 .70408 L p .397 .284 .607 r
F P
0 g
s
.3541 .23956 m .35935 .24706 L .28252 .28509 L p .662 .744 .911 r
F P
0 g
s
.28252 .28509 m .27422 .27955 L .3541 .23956 L p .662 .744 .911 r
F P
0 g
s
.58583 .63555 m .58019 .62959 L .56196 .52487 L p .486 .343 .612 r
F P
0 g
s
.56196 .52487 m .56639 .52372 L .58583 .63555 L p .486 .343 .612 r
F P
0 g
s
.59928 .34007 m .59312 .34875 L .53114 .3128 L p .599 .644 .866 r
F P
0 g
s
.51112 .78759 m .50959 .77143 L .53893 .81974 L p .366 .257 .595 r
F P
0 g
s
.53552 .79941 m .53893 .81974 L .50959 .77143 L p .368 .259 .597 r
F P
0 g
s
.7127 .33788 m .70371 .34485 L .63711 .28956 L p .684 .696 .855 r
F P
0 g
s
.63069 .29784 m .63711 .28956 L .70371 .34485 L p .683 .691 .852 r
F P
0 g
s
.45898 .26589 m .46024 .27385 L .38509 .28215 L p .622 .741 .932 r
F P
0 g
s
.38509 .28215 m .38001 .27553 L .45898 .26589 L p .622 .741 .932 r
F P
0 g
s
.53213 .6535 m .53765 .66942 L .52915 .68844 L p .416 .298 .611 r
F P
0 g
s
.5951 .59662 m .58583 .63555 L .56639 .52372 L p .719 .52 .62 r
F P
0 g
s
.55771 .66784 m .55179 .65567 L .54712 .59438 L p .457 .325 .613 r
F P
0 g
s
.54712 .59438 m .55254 .60019 L .55771 .66784 L p .457 .325 .613 r
F P
0 g
s
.53114 .3128 m .53384 .30463 L .59928 .34007 L p .599 .644 .866 r
F P
0 g
s
.72173 .33104 m .7127 .33788 L .64356 .28131 L p .684 .7 .859 r
F P
0 g
s
.63711 .28956 m .64356 .28131 L .7127 .33788 L p .684 .696 .855 r
F P
0 g
s
.60548 .33149 m .59928 .34007 L .53384 .30463 L p .613 .655 .868 r
F P
0 g
s
.3488 .23193 m .3541 .23956 L .27422 .27955 L p .663 .741 .908 r
F P
0 g
s
.27422 .27955 m .26587 .2739 L .3488 .23193 L p .663 .741 .908 r
F P
0 g
s
.53655 .29631 m .53384 .30463 L .46273 .28909 L p .582 .693 .918 r
F P
0 g
s
.46273 .28909 m .46149 .2816 L .53655 .29631 L p .582 .693 .918 r
F P
0 g
s
.54322 .68574 m .53765 .66942 L .54013 .63204 L p .436 .312 .612 r
F P
0 g
s
.54013 .63204 m .54594 .64374 L .54322 .68574 L p .436 .312 .612 r
F P
0 g
s
.51265 .80396 m .51112 .78759 L .54238 .84051 L p .364 .254 .593 r
F P
0 g
s
.53893 .81974 m .54238 .84051 L .51112 .78759 L p .366 .257 .595 r
F P
0 g
s
.52548 .74099 m .5222 .72234 L .53854 .72597 L p .393 .279 .603 r
F P
0 g
s
.53382 .70697 m .53854 .72597 L .5222 .72234 L p .395 .281 .605 r
F P
0 g
s
.53382 .70697 m .52915 .68844 L .53765 .66942 L p .415 .297 .609 r
F P
0 g
s
.5951 .59662 m .60451 .56652 L .61291 .64679 L p .911 .698 .602 r
F P
0 g
s
.73081 .32433 m .72173 .33104 L .65006 .27308 L p .684 .703 .862 r
F P
0 g
s
.64356 .28131 m .65006 .27308 L .72173 .33104 L p .684 .7 .859 r
F P
0 g
s
.45772 .25774 m .45898 .26589 L .38001 .27553 L p .629 .738 .926 r
F P
0 g
s
.38001 .27553 m .3749 .26868 L .45772 .25774 L p .629 .738 .926 r
F P
0 g
s
.61172 .32298 m .60548 .33149 L .53655 .29631 L p .624 .665 .869 r
F P
0 g
s
.53384 .30463 m .53655 .29631 L .60548 .33149 L p .613 .655 .868 r
F P
0 g
s
.56368 .68024 m .55771 .66784 L .55254 .60019 L p .459 .326 .611 r
F P
0 g
s
.55254 .60019 m .55799 .60602 L .56368 .68024 L p .459 .326 .611 r
F P
0 g
s
.55042 .79452 m .54587 .86175 L .57323 .87343 L p .426 .188 .447 r
F P
0 g
s
.57323 .87343 m .57968 .79839 L .55042 .79452 L p .426 .188 .447 r
F P
0 g
s
.54238 .84051 m .54587 .86175 L .51265 .80396 L p .364 .254 .593 r
F P
0 g
s
.65006 .27308 m .65661 .26487 L .73081 .32433 L p .684 .703 .862 r
F P
0 g
s
.53765 .66942 m .54322 .68574 L .53382 .70697 L p .415 .297 .609 r
F P
0 g
s
.53928 .28785 m .53655 .29631 L .46149 .2816 L p .598 .697 .912 r
F P
0 g
s
.46149 .2816 m .46024 .27385 L .53928 .28785 L p .598 .697 .912 r
F P
0 g
s
.52879 .76004 m .52548 .74099 L .54331 .74546 L p .391 .277 .602 r
F P
0 g
s
.53854 .72597 m .54331 .74546 L .52548 .74099 L p .393 .279 .603 r
F P
0 g
s
.54886 .70247 m .54322 .68574 L .54594 .64374 L p .437 .311 .61 r
F P
0 g
s
.54594 .64374 m .55179 .65567 L .54886 .70247 L p .437 .311 .61 r
F P
0 g
s
.618 .31455 m .61172 .32298 L .53928 .28785 L p .632 .672 .87 r
F P
0 g
s
.53655 .29631 m .53928 .28785 L .61172 .32298 L p .624 .665 .869 r
F P
0 g
s
.60358 .68877 m .61291 .64679 L .60664 .71049 L p .938 .82 .369 r
F P
0 g
s
.53854 .72597 m .53382 .70697 L .54322 .68574 L p .415 .295 .607 r
F P
0 g
s
.56972 .69288 m .56368 .68024 L .55799 .60602 L p .462 .326 .61 r
F P
0 g
s
.55799 .60602 m .56348 .61187 L .56972 .69288 L p .462 .326 .61 r
F P
0 g
s
.45644 .24943 m .45772 .25774 L .3749 .26868 L p .635 .735 .92 r
F P
0 g
s
.3749 .26868 m .36975 .26164 L .45644 .24943 L p .635 .735 .92 r
F P
0 g
s
.61291 .64679 m .60358 .68877 L .5951 .59662 L p .911 .698 .602 r
F P
0 g
s
.62433 .30617 m .618 .31455 L .54203 .2793 L p .639 .679 .872 r
F P
0 g
s
.53928 .28785 m .54203 .2793 L .618 .31455 L p .632 .672 .87 r
F P
0 g
s
.54322 .68574 m .54886 .70247 L .53854 .72597 L p .415 .295 .607 r
F P
0 g
s
.54203 .2793 m .53928 .28785 L .46024 .27385 L p .61 .7 .908 r
F P
0 g
s
.46024 .27385 m .45898 .26589 L .54203 .2793 L p .61 .7 .908 r
F P
0 g
s
.53214 .77951 m .52879 .76004 L .54814 .76545 L p .389 .274 .6 r
F P
0 g
s
.54331 .74546 m .54814 .76545 L .52879 .76004 L p .391 .277 .602 r
F P
0 g
s
.55456 .71962 m .54886 .70247 L .55179 .65567 L p .438 .311 .609 r
F P
0 g
s
.55179 .65567 m .55771 .66784 L .55456 .71962 L p .438 .311 .609 r
F P
0 g
s
.57581 .70578 m .56972 .69288 L .56348 .61187 L p .464 .327 .609 r
F P
0 g
s
.56348 .61187 m .56901 .61775 L .57581 .70578 L p .464 .327 .609 r
F P
0 g
s
.45515 .24097 m .45644 .24943 L .36975 .26164 L p .64 .733 .916 r
F P
0 g
s
.36975 .26164 m .36457 .25443 L .45515 .24097 L p .64 .733 .916 r
F P
0 g
s
.58583 .63555 m .5951 .59662 L .60358 .68877 L p .912 .68 .574 r
F P
0 g
s
.54331 .74546 m .53854 .72597 L .54886 .70247 L p .414 .294 .606 r
F P
0 g
s
.63069 .29784 m .62433 .30617 L .54481 .27065 L p .644 .684 .873 r
F P
0 g
s
.54203 .2793 m .54481 .27065 L .62433 .30617 L p .639 .679 .872 r
F P
0 g
s
.58198 .71892 m .57581 .70578 L .56901 .61775 L p .466 .327 .608 r
F P
0 g
s
.56901 .61775 m .57458 .62366 L .58198 .71892 L p .466 .327 .608 r
F P
0 g
s
.54481 .27065 m .54203 .2793 L .45898 .26589 L p .619 .703 .904 r
F P
0 g
s
.45898 .26589 m .45772 .25774 L .54481 .27065 L p .619 .703 .904 r
F P
0 g
s
.53552 .79941 m .53214 .77951 L .55303 .78595 L p .388 .272 .599 r
F P
0 g
s
.54814 .76545 m .55303 .78595 L .53214 .77951 L p .389 .274 .6 r
F P
0 g
s
.54886 .70247 m .55456 .71962 L .54331 .74546 L p .414 .294 .606 r
F P
0 g
s
.56033 .7372 m .55456 .71962 L .55771 .66784 L p .439 .31 .608 r
F P
0 g
s
.55771 .66784 m .56368 .68024 L .56033 .7372 L p .439 .31 .608 r
F P
0 g
s
.63711 .28956 m .63069 .29784 L .5476 .26192 L p .649 .689 .874 r
F P
0 g
s
.54481 .27065 m .5476 .26192 L .63069 .29784 L p .644 .684 .873 r
F P
0 g
s
.45385 .23238 m .45515 .24097 L .36457 .25443 L p .643 .731 .912 r
F P
0 g
s
.36457 .25443 m .35935 .24706 L .45385 .23238 L p .643 .731 .912 r
F P
0 g
s
.54814 .76545 m .54331 .74546 L .55456 .71962 L p .414 .292 .604 r
F P
0 g
s
.5882 .73233 m .58198 .71892 L .57458 .62366 L p .468 .328 .607 r
F P
0 g
s
.57458 .62366 m .58019 .62959 L .5882 .73233 L p .468 .328 .607 r
F P
0 g
s
.64356 .28131 m .63711 .28956 L .55042 .25312 L p .653 .693 .875 r
F P
0 g
s
.5476 .26192 m .55042 .25312 L .63711 .28956 L p .649 .689 .874 r
F P
0 g
s
.5476 .26192 m .54481 .27065 L .45772 .25774 L p .627 .705 .902 r
F P
0 g
s
.45772 .25774 m .45644 .24943 L .5476 .26192 L p .627 .705 .902 r
F P
0 g
s
.53893 .81974 m .53552 .79941 L .55798 .80699 L p .386 .27 .597 r
F P
0 g
s
.55303 .78595 m .55798 .80699 L .53552 .79941 L p .388 .272 .599 r
F P
0 g
s
.45254 .22368 m .45385 .23238 L .35935 .24706 L p .647 .73 .909 r
F P
0 g
s
.35935 .24706 m .3541 .23956 L .45254 .22368 L p .647 .73 .909 r
F P
0 g
s
.56617 .75523 m .56033 .7372 L .56368 .68024 L p .44 .31 .606 r
F P
0 g
s
.56368 .68024 m .56972 .69288 L .56617 .75523 L p .44 .31 .606 r
F P
0 g
s
.55456 .71962 m .56033 .7372 L .54814 .76545 L p .414 .292 .604 r
F P
0 g
s
.57968 .79839 m .57323 .87343 L .5903 .83205 L p .004 0 .302 r
F P
0 g
s
.59449 .74601 m .5882 .73233 L .58019 .62959 L p .469 .328 .606 r
F P
0 g
s
.58019 .62959 m .58583 .63555 L .59449 .74601 L p .469 .328 .606 r
F P
0 g
s
.65006 .27308 m .64356 .28131 L .55326 .24425 L p .656 .697 .876 r
F P
0 g
s
.55042 .25312 m .55326 .24425 L .64356 .28131 L p .653 .693 .875 r
F P
0 g
s
.55303 .78595 m .54814 .76545 L .56033 .7372 L p .413 .291 .603 r
F P
0 g
s
.55042 .25312 m .5476 .26192 L .45644 .24943 L p .633 .707 .899 r
F P
0 g
s
.45644 .24943 m .45515 .24097 L .55042 .25312 L p .633 .707 .899 r
F P
0 g
s
.59449 .74601 m .60358 .68877 L .59831 .76101 L p .918 .781 .301 r
F P
0 g
s
.60358 .68877 m .59449 .74601 L .58583 .63555 L p .912 .68 .574 r
F P
0 g
s
.54238 .84051 m .53893 .81974 L .563 .82857 L p .385 .268 .595 r
F P
0 g
s
.55798 .80699 m .563 .82857 L .53893 .81974 L p .386 .27 .597 r
F P
0 g
s
.45122 .21486 m .45254 .22368 L .3541 .23956 L p .649 .729 .907 r
F P
0 g
s
.3541 .23956 m .3488 .23193 L .45122 .21486 L p .649 .729 .907 r
F P
0 g
s
.65661 .26487 m .65006 .27308 L .55612 .23531 L p .658 .7 .877 r
F P
0 g
s
.55326 .24425 m .55612 .23531 L .65006 .27308 L p .656 .697 .876 r
F P
0 g
s
.57209 .77372 m .56617 .75523 L .56972 .69288 L p .441 .309 .605 r
F P
0 g
s
.56972 .69288 m .57581 .70578 L .57209 .77372 L p .441 .309 .605 r
F P
0 g
s
.56033 .7372 m .56617 .75523 L .55303 .78595 L p .413 .291 .603 r
F P
0 g
s
.55326 .24425 m .55042 .25312 L .45515 .24097 L p .638 .708 .897 r
F P
0 g
s
.45515 .24097 m .45385 .23238 L .55326 .24425 L p .638 .708 .897 r
F P
0 g
s
.55612 .23531 m .559 .22632 L .65661 .26487 L p .658 .7 .877 r
F P
0 g
s
.55798 .80699 m .55303 .78595 L .56617 .75523 L p .413 .289 .601 r
F P
0 g
s
.54587 .86175 m .54238 .84051 L .56808 .85071 L p .383 .266 .594 r
F P
0 g
s
.563 .82857 m .56808 .85071 L .54238 .84051 L p .385 .268 .595 r
F P
0 g
s
.57808 .79268 m .57209 .77372 L .57581 .70578 L p .442 .309 .604 r
F P
0 g
s
.57581 .70578 m .58198 .71892 L .57808 .79268 L p .442 .309 .604 r
F P
0 g
s
.56617 .75523 m .57209 .77372 L .55798 .80699 L p .413 .289 .601 r
F P
0 g
s
.55612 .23531 m .55326 .24425 L .45385 .23238 L p .643 .71 .896 r
F P
0 g
s
.45385 .23238 m .45254 .22368 L .55612 .23531 L p .643 .71 .896 r
F P
0 g
s
.56808 .85071 m .57323 .87343 L .54587 .86175 L p .383 .266 .594 r
F P
0 g
s
.563 .82857 m .55798 .80699 L .57209 .77372 L p .413 .288 .6 r
F P
0 g
s
.58415 .81212 m .57808 .79268 L .58198 .71892 L p .443 .309 .603 r
F P
0 g
s
.58198 .71892 m .5882 .73233 L .58415 .81212 L p .443 .309 .603 r
F P
0 g
s
.559 .22632 m .55612 .23531 L .45254 .22368 L p .646 .711 .895 r
F P
0 g
s
.45254 .22368 m .45122 .21486 L .559 .22632 L p .646 .711 .895 r
F P
0 g
s
.57209 .77372 m .57808 .79268 L .563 .82857 L p .413 .288 .6 r
F P
0 g
s
.56808 .85071 m .563 .82857 L .57808 .79268 L p .412 .287 .599 r
F P
0 g
s
.5903 .83205 m .58415 .81212 L .5882 .73233 L p .444 .308 .602 r
F P
0 g
s
.5882 .73233 m .59449 .74601 L .5903 .83205 L p .444 .308 .602 r
F P
0 g
s
.57808 .79268 m .58415 .81212 L .56808 .85071 L p .412 .287 .599 r
F P
0 g
s
.57323 .87343 m .56808 .85071 L .58415 .81212 L p .412 .286 .597 r
F P
0 g
s
.58415 .81212 m .5903 .83205 L .57323 .87343 L p .412 .286 .597 r
F P
0 g
s
.25 Mabswid
.41699 0 m
.39846 .53401 L
s
.39846 .53401 m
0 .89001 L
s
0 .89001 m
.08461 .38696 L
s
.08461 .38696 m
.41699 0 L
s
.41699 0 m
.39846 .53401 L
s
.39846 .53401 m
1 .81584 L
s
1 .81584 m
.90663 .30341 L
s
.90663 .30341 m
.41699 0 L
s
1 .81584 m
.54651 1.07206 L
s
.90333 .87046 m
.90229 .86335 L
s
[(-2)] .90539 .88469 -0.14509 -1 Mshowa
.75058 .95676 m
.74994 .9496 L
s
[(0)] .75186 .97108 -0.08924 -1 Mshowa
.61613 1.03272 m
.61582 1.02554 L
s
[(2)] .61674 1.04709 -0.04271 -1 Mshowa
.125 Mabswid
.86322 .89312 m
.86267 .88884 L
s
.82444 .91503 m
.82394 .91074 L
s
.78691 .93623 m
.78647 .93194 L
s
.71539 .97664 m
.71506 .97234 L
s
.68128 .99591 m
.681 .99161 L
s
.64821 1.0146 m
.64798 1.01029 L
s
.94482 .84702 m
.94413 .84276 L
s
.98777 .82275 m
.98701 .8185 L
s
.585 1.05031 m
.58486 1.046 L
s
.55477 1.06739 m
.55467 1.06308 L
s
gsave
.75825 1.04271 -65.5538 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600.625, 643.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0002Pb000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00l@3oool00`000000oooo0?ooo`3o0?oo
ofD0oooo003`0?ooo`@00000o`3ooomU0?ooo`00k`3oool00`000000oooo000000020?ooo`800000
o`3ooomS0?ooo`00kP3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo
H03oool00>h0oooo00@000000?ooo`3oool000001@3oool200000?l0ooooH03oool00>d0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo0?l0ooooG@3oool00>`0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`800000o`3ooomM0?ooo`00j`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo0P00003o0?oooe/0oooo003Z0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oo
oeP0oooo003Y0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool200000?l0
ooooF03oool00>P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0?l0ooooE@3oool00>P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0>0?ooo`800000o`3ooomE0?ooo`00i`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0100oooo0P00003o0?oooe<0oooo003V0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`3o0?oooe00oooo003U0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool04`3oool200000?l0ooooD03oool00>@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0F0?ooo`800000o`3ooom>0?ooo`00h`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`00hP3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01T0oooo0P00003o0?oood/0oooo003Q0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?oo
odP0oooo003Q0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool200000?l0
ooooB03oool00>00oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0N0?ooo`800000
o`3ooom60?ooo`00g`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0o`3ooom30?ooo`00gP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0240oooo0P00003o0?oood<0oooo003M0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool08`3oool200000?l0oooo@@3oool00=`0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo0?l0oooo?P3oool00=/0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0V0?ooo`800000o`3oooln0?ooo`00f`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`00fP3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02T0oooo0P00003o0?oooc/0oooo003I0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0:`3oool200000?l0oooo>@3oool00=P0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0?l0
oooo=P3oool00=L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0^0?ooo`800000
o`3ooolf0?ooo`00eP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0o`3ooolc0?ooo`00e@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0340oooo0P00003o0?oooc<0oooo003E0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0<`3oool200000?l0oooo<@3oool00=@0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo0?l0oooo;P3oool00=<0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0f0?ooo`800000o`3oool^0?ooo`00dP3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo03P0oooo0P00003o0?ooob`0oooo003A0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`3o0?ooobT0oooo003@0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0>`3oool200000?l0oooo:@3oool00<l0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0?l0
oooo9P3oool00<l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0n0?ooo`800000
o`3ooolV0?ooo`00cP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0400oooo0P00
003o0?ooob@0oooo003=0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`3o0?ooob40oooo003<0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0A03oool200000?l0oooo8@3oool00</0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo0?l0oooo7P3oool00<X0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`170?ooo`800000o`3ooolN0?ooo`00b@3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo04T0oooo0P00003o0?oooa`0oooo00390?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3o0?oooaT0oooo00380?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0C03oool200000?l0oooo6@3oool00<L0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1>0?ooo`800000o`3ooolG0?ooo`00
aP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
o`3ooolD0?ooo`00a@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0540oooo0P00
003o0?oooa@0oooo00340?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`3o0?oooa40oooo00330?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0E03oool200000?l0oooo4@3oool00<80oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`1F0?ooo`800000o`3oool?0?ooo`00`P3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0o`3oool<0?ooo`00`@3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo05T0oooo0P00003o0?ooo``0oooo00300?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`3o0?ooo`T0oooo002o0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool0G03oool200000?l0oooo2@3oool00;h0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`1N0?ooo`800000o`3oool70?ooo`00
_@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0
o`3oool40?ooo`00_03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0640oooo0P00
003o0?ooo`@0oooo002l0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0H`3oool2
00000?l0oooo0P3oool00;/0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo0?h0oooo002j0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0IP3oool200000?h0oooo002i0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
J03oool00`000000oooo0?ooo`3k0?ooo`00^03oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo06T0oooo0P00003k0?ooo`00]`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo06/0oooo0P00003i0?ooo`00]P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
06d0oooo00<000000?ooo`3oool0mP3oool00;H0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`1^0?ooo`800000mP3oool00;D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`1`0?ooo`800000m03oool00;@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`1c0?ooo`030000003oool0oooo0?40oooo002c0?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool0M03oool200000?40oooo002b0?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool0MP3oool00`000000oooo0?ooo`3^0?ooo`00/@3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo07L0oooo0P00003^0?ooo`00/03oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo07T0oooo0P00003/0?ooo`00/03oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo07/0oooo00<000000?ooo`3oool0j@3oool00:l0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`1l0?ooo`800000j@3oool00:h0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`1n0?ooo`030000003oool0oooo0>H0oooo002]0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool0O`3oool200000>H0oooo002/0?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool0P@3oool200000>@0oooo002[0?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool0P`3oool00`000000oooo0?ooo`3Q0?ooo`00ZP3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo08@0oooo0P00003Q0?ooo`00Z@3oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo08H0oooo0P00003O0?ooo`00Z@3oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0g03oool00:P0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`290?ooo`800000g03oool00:L0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo0=T0oooo002V0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool0S03oool200000=T0oooo002U0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0SP3oool200000=L0oooo002T0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`3D0?ooo`00X`3oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo0940oooo0P00003D0?ooo`00X`3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0d@3oool00:80oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`2D0?ooo`800000d@3oool00:40oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`2F0?ooo`800000c`3oool00:00oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0<`0oooo002O0?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`3oool0V@3oool200000<`0oooo002N0?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0V`3oool200000<X0oooo002M0?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`370?ooo`00W@3oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo09h0oooo0P0000370?ooo`00W03oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0a03oool009/0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`2R0?ooo`800000a03oool009X0oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`2T0?ooo`800000`P3oool009T0oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0;l0oooo002H0?oo
o`030000003oool0oooo0580oooo00<000000?ooo`3oool0Y`3oool200000;l0oooo002G0?ooo`03
0000003oool0oooo05<0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`2l0?ooo`00
U`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0:X0oooo0P00002l0?ooo`00UP3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0:`0oooo0P00002j0?ooo`00U@3oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0]`3oool0
09@0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`2_0?ooo`800000]`3oool009<0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`2a0?ooo`800000]@3oool00980oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo0;80oooo
002A0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0]03oool200000;80oooo002A
0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`2_
0?ooo`00T03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0;L0oooo0P00002_0?oo
o`00S`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0;T0oooo0P00002]0?ooo`00
SP3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool0
ZP3oool008d0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`2l0?ooo`800000ZP3o
ool008`0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`2n0?ooo`800000Z03oool0
08/0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo
0:D0oooo002:0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0`@3oool200000:D0
oooo002:0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0``3oool00`000000oooo
0?ooo`2R0?ooo`00R@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0<@0oooo0P00
002R0?ooo`00R03oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0<H0oooo0P00002P
0?ooo`00Q`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0<P0oooo00<000000?oo
o`3oool0W@3oool008H0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0B0?ooo`L0
0000/03oool2000009d0oooo00250?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0
303oool600000080Y[[X00<000000:Ffi@2U]^D00P2U]^D900000:T0oooo00<000000?ooo`3oool0
VP3oool008@0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`060?ooo`H00000202V
^^P00`000000YKKU0:Ffi@0;0:Ffi@T00000X@3oool2000009X0oooo00240?ooo`030000003oool0
oooo06D0oooo00@000000?ooo`3oool0oooo1P00000?0:Jjj0030000002U]^D0YKKU01<0YKKU2@00
002J0?ooo`800000V03oool008<0oooo00<000000?ooo`3oool0I03oool6000001D0Y[[X00<00000
0:Ffi@2U]^D0702U]^D9000009<0oooo00<000000?ooo`3oool0U@3oool00880oooo00<000000?oo
o`3oool0G`3oool600000080Y[[X00<000000:Jjj02V^^P04`2V^^P4000002L0YKKU2@00002;0?oo
o`800000U@3oool00840oooo00<000000?ooo`3oool0FP3oool6000000P0Y[[X00<000000:Jjj02V
^^P03@2V^^P6000000<0YK[X00<000000:Bei@2T]ND00P2T]ND8000002@0YKKU2@0000240?ooo`80
0000T`3oool00800oooo00<000000?ooo`3oool0E@3oool6000000h0Y[[X00<000000:Jjj02V^^P0
1`2V^^P6000000T0YK[X00<000000:Bei@2T]ND02P2T]ND9000002@0YKKU1P0000200?ooo`030000
003oool0oooo0900oooo001o0?ooo`030000003oool0oooo0500oooo1P00000D0:Jjj0030000002V
^^P0Y[[X00L00000402U^^P00`000000Y;GU0:Bei@0B0:Bei@P00000802U]^D010000000Z;?P0000
0000001o0?ooo`800000T03oool007h0oooo00<000000?ooo`3oool0B`3oool6000001L0Y[[X1P00
000G0:Fjj0030000002T]ND0Y;GU01X0Y;GU2@00000F0:Ffi@030000002X/n00Z;?P0080Z;?P0`00
001n0?ooo`030000003oool0oooo08d0oooo001n0?ooo`030000003oool0oooo04L0oooo1000000G
0:Jjj0H000000`2U^^P00`000000YK[X0:Fjj00D0:Fjj0@000009@2T]ND9000000d0YKKU00<00000
0:Rch02X/n001@2X/n02000007d0oooo0P00002=0?ooo`00O@3oool00`000000oooo0?ooo`160?oo
o`8000000P2Y_NP00`000000Y[[X0:Jjj00?0:Jjj0L000002@2U^^P00`000000YK[X0:Fjj00>0:Fj
j0H000000`2T^nT00`000000XkGU0:>ei@020:>ei@P000008P2T]ND8000000@0YKKU00<000000:Rc
h02X/n00202X/n03000007`0oooo0P00002;0?ooo`00O03oool00`000000oooo0?ooo`150?ooo`80
0000102Y_NP00`000000Y[[X0:Jjj0090:Jjj0H00000402U^^P00`000000YK[X0:Fjj0080:Fjj0H0
00002@2T^nT00`000000XkGU0:>ei@0:0:>ei@P000008P2T]ND5000000d0Z;?P0P00001l0?ooo`03
0000003oool0oooo08P0oooo001k0?ooo`030000003oool0oooo04@0oooo0P0000070:Vmj0030000
002V^^P0Y[[X0080Y[[X1P00000F0:Fjj0030000002U^^P0YK[X0080YK[X1P00000@0:Bkj@030000
002S]ND0XkGU0140XkGU2000000N0:Bei@040000002W/^000000000000`0Z;?P0`00001j0?ooo`80
0000R03oool007X0oooo00<000000?ooo`3oool0@`3oool2000000T0ZKgX1@00000K0:Fjj0H00000
5P2T^nT00`000000XkGU0:>ei@0I0:>ei@P000005@2T]ND00`000000Yk;P0:Nbh0020:Nbh0<00000
302X/n03000007T0oooo00<000000?ooo`3oool0Q@3oool007T0oooo00<000000?ooo`3oool0@P3o
ool2000000T0ZKgX0P0000020:Vnj@030000002U^^P0YK[X01D0YK[X1P0000000`2T^nT000000:Bk
j@0F0:Bkj@@000008`2S]ND8000000d0Y;GU00<000000:Nbh02W/^001@2W/^02000000d0Z;?P0P00
001h0?ooo`800000Q@3oool007P0oooo00<000000?ooo`3oool0@@3oool2000000T0ZKgX0P000004
0:Vnj@030000002U^^P0YK[X00l0YK[X1P0000070:Bkj@030000002T^nT0Y;_Y00l0Y;_Y1P000003
0:>kjP040000002R]>H0X[CV0::diPP00000802S]ND8000000@0Y;GU00<000000:Nbh02W/^00202W
/^03000000`0Z;?P0`00001g0?ooo`800000P`3oool007P0oooo00<000000?ooo`3oool0?`3oool2
000000T0ZKgX0P0000070:Vnj@030000002U^^P0YK[X00P0YK[X1P00000=0:Bkj@030000002T^nT0
Y;_Y00P0Y;_Y1`0000090:>kjP030000002R]>H0X[CV00T0X[CV2000000P0:>ei@D000003@2W/^02
000000d0Z;?P0P00001g0?ooo`030000003oool0oooo0800oooo001g0?ooo`030000003oool0oooo
03h0oooo0P0000090:Vmj08000002@2Y_^T00`000000YK[X0:Fjj0020:Fjj0H000004`2T^nT01000
0000Y;_Y0:Bkj@2T^nT700000100Xk_Z00<000000::diP2R]>H04@2R]>H8000001`0XkGU00@00000
0:Nag`0000000000302W/^02000000d0Z;?P0`00001e0?ooo`800000P03oool007H0oooo00<00000
0?ooo`3oool0?@3oool2000000T0ZKgX0P00000;0:Vnj@D000005`2T^nT6000001L0Xk_Z00<00000
0::diP2R]>H06@2R]>H8000001@0XkGU00@000000:Nag`2W/Ml0Yk7O0`00000;0:Nbh0<000003@2X
/n02000007D0oooo0P00001n0?ooo`00M@3oool00`000000oooo0?ooo`0l0?ooo`8000002@2Y_NP2
000000/0ZKkY0P0000020:Voj@030000002T^nT0Y;_Y0100Y;_Y1`0000020:>kjP030000002S^nX0
Xk_Z01D0Xk_Z1000000S0::diPP000002`2S]ND00`000000Yk7O0:Nag`050:Nag`800000302W/^02
000000d0Z;?P0`00001d0?ooo`030000003oool0oooo07/0oooo001d0?ooo`030000003oool0oooo
03/0oooo0P0000090:Vmj08000002`2Y_^T2000000@0ZKoY00<000000:Bkj@2T^nT02@2T^nT70000
00T0Xk_Z00<000000:>kjP2S^nX03P2S^nX7000000<0X[c[00@000000:2diP2P]>H0X;CV2000000P
0::diPP000000`2S]ND00`000000Yk7O0:Nag`070:Nag`<000002`2W/^03000000d0Z;?P0P00001c
0?ooo`800000N`3oool007<0oooo00<000000?ooo`3oool0>P3oool2000000T0ZKgX0P00000;0:Vn
j@8000001`2Y_nT00`000000Y;_Y0:Bkj@020:Bkj@H00000402S^nX00`000000Xk_Z0:>kjP070:>k
jPL000002P2R_>/00`000000X;CV0:2diP090:2diPL000008@2R]>H4000000`0Yk7O0P00000<0:Nb
h08000003@2X/n0300000780oooo00<000000?ooo`3oool0N03oool00780oooo00<000000?ooo`3o
ool0>@3oool2000000T0ZKgX0P00000;0:Vnj@8000002@2Y_nT5000001H0Xk_Z00<000000:>kjP00
00001`00000B0::lj`030000002P]>H0X;CV00l0X;CV2000000L0::diP040000002V/=l000000000
00/0Yk7O0`00000;0:Nbh0<000003@2X/n0200000740oooo0P00001h0?ooo`00L@3oool00`000000
oooo0?ooo`0h0?ooo`8000002@2Y_NP2000000/0ZKkY0P0000090:Voj@8000000P2Y`>X00`000000
Xk_Z0:>kjP0A0:>kjPL000006P2R_>/00`000000X;CV0:2diP0G0:2diPP000004`2R]>H00`000000
Y[3O0:J`g`020:J`g`800000302W/Ml2000000`0Yk;P0P00000=0:Rch0<00000L03oool2000007H0
oooo001a0?ooo`030000003oool0oooo03H0oooo0P0000090:Vmj08000002`2Y_^T2000000T0ZKoY
0P0000040:W0jP030000002S^nX0Xk_Z00X0Xk_Z1`0000050::lj`030000002R_>/0X[c[01D0X[c[
1@00000Q0:2diPL00000302R]>H00`000000Y[3O0:J`g`040:J`g`<000002`2W/Ml3000000/0Yk;P
0`00000=0:Rch0<00000K`3oool00`000000oooo0?ooo`1c0?ooo`00L03oool00`000000oooo0?oo
o`0e0?ooo`8000002@2Y_NP2000000/0ZKkY0P0000090:Voj@8000001`2Y`>X00`000000Xk_Z0:>k
jP030:>kjPH00000302R_>/00`000000X[c[0::lj`0=0::lj`P00000102Q_>d010000000W[?W09jc
i`2N/nL7000001h0X;CV200000030::diP030000002V/=l0Y[3O00P0Y[3O0P00000<0:Nag`800000
302W/^02000000h0Z;?P0P00001^0?ooo`800000L`3oool006l0oooo00<000000?ooo`3oool0=03o
ool2000000T0ZKgX0P00000;0:Vnj@8000002@2Y_nT2000000T0ZL3Z1@00000C0::lj`030000002R
_>/0X[c[00D0X[c[2000000<0:6lk@030000002N/nL0W[?W00P0W[?W2000000N0:2diP@00000302V
/=l3000000/0Yk7O0`00000;0:Nbh0<000003@2X/n03000006d0oooo00<000000?ooo`3oool0L03o
ool006h0oooo00<000000?ooo`3oool0<`3oool2000000T0ZKgX0P00000;0:Vnj@8000002@2Y_nT2
000000T0ZL3Z0P0000020:W1k0030000002R_>/0X[c[01<0X[c[2000000E0:6lk@030000002N/nL0
W[?W00l0W[?W1`00000J0:2diP040000002T[ml00000000000`0Y[3O0P00000<0:Nag`<000002`2W
/^02000000h0Z;?P0P00001/0?ooo`800000L03oool006d0oooo00<000000?ooo`3oool0<P3oool2
000000T0ZKgX0P00000;0:Vnj@8000002@2Y_nT2000000T0ZL3Z0P0000040:W1k0030000002R_>/0
X[c[00/0X[c[2@00000I0:6lk@@00000602N/nL7000001<0X;CV00@000000:B_g`2T[ml0Y:oO0P00
000<0:J`g`8000003@2W/Ml2000000/0Yk;P0P00000>0:Rch0800000K03oool2000006h0oooo001/
0?ooo`030000003oool0oooo0340oooo0P0000090:Vmj08000002`2Y_^T2000000T0ZKoY0P000009
0:W0jP8000001`2Y`N`00`000000X[c[0::lj`030::lj`L00000202Q_>d00`000000XKc]0:6lk@0?
0:6lk@P000000`2O_Nh00`000000W;?X09bcj006000001L0W[?W2000000:0:2diP030000002T[ml0
Y:oO00@0Y:oO0P00000<0:J`g`<00000302W/Ml3000000X0Yk;P0`00000;0:Rch0030000002_/m`0
000006d0oooo00<000000?ooo`3oool0J`3oool006/0oooo00<000000?ooo`3oool0<03oool20000
00T0ZKgX0P00000;0:Vnj@8000002@2Y_nT2000000T0ZL3Z0P0000090:W1k0D000003`2Q_>d00`00
0000XKc]0:6lk@080:6lk@P000002`2O_Nh00`000000W;?X09bcj00609bcj0H000006@2N/nL70000
00<0X;CV00<000000:B_g`2T[ml01P2T[ml3000000`0Y[3O0P00000=0:Nag`8000002`2W/^020000
00P0Z;?P00@000000:ncg02_/m`0[k?L0P00001/0?ooo`800000J`3oool006/0oooo00<000000?oo
o`3oool0;P3oool2000000T0ZKgX0P00000;0:Vnj@8000002@2Y_nT2000000T0ZL3Z0P0000090:W1
k08000000P2X`nd00`000000XKc]0:6lk@0?0:6lk@040000002Q_>d0XKc]0:6lk@L00000502O_Nh0
0`000000W;?X09bcj00;09bcj0H000006P2N/nL4000000/0Y:oO0P00000<0:J`g`8000003@2W/Ml3
000000X0Yk;P0`0000050:Rch0030000002_/m`0[k?L00<0[k?L00<000000?ooo`3oool0J`3oool2
000006T0oooo001Z0?ooo`030000003oool0oooo02d0oooo0P0000090:Vmj08000002`2Y_^T20000
00T0ZKoY0P0000090:W0jP8000002@2Y`N`2000000@0Z<?]00<000000:6lk@2Q_>d02`2Q_>d80000
01/0Wkg^00<0000009bcj02L/nP04@2L/nP6000001L0W[?W00@000000:>]g`00000000002P2T[ml2
000000`0Y[3O0`00000=0:Nag`8000002`2W/^0200000080Z;?P00<000000:ncg02_/m`01@2_/m`0
0`000000oooo0?ooo`1/0?ooo`030000003oool0oooo06H0oooo001Y0?ooo`030000003oool0oooo
02d0oooo00<000000:Vmj02Y_NP01`2Y_NP2000000/0ZKkY0P0000090:Voj@8000002@2Y`>X20000
00T0ZL7/0P0000070:S3k@030000002Q_>d0XKc]00<0XKc]1`00000409nmkP030000002O_Nh0Wkg^
01P0Wkg^1@00000I09bcj0H00000402N/nL00`000000XjgO0:>]g`020:>]g`8000002P2T[ml30000
00`0Y[3O0P00000=0:Nag`<000002P2W/^02000000T0[k?L00<000000?ooo`3oool0K03oool20000
06H0oooo001X0?ooo`030000003oool0oooo02d0oooo00@000000:fniP00000000001P2Y_NP00`00
0000ZKkY0:Vnj@090:Vnj@8000002@2Y_nT2000000T0ZL3Z0P0000090:W1k08000002@2X`nd50000
00`0Wkg^00<0000009nmkP2O_Nh03`2O_Nh9000000@0W;k`00<0000009Vbj@2I/^T01P00000G09bc
j0H000002P2N/nL00`000000XjgO0:>]g`040:>]g`8000002`2T[ml2000000`0Y[3O0`00000=0:Na
g`800000202W/^000`000000[k?K000000090:ncg0800000KP3oool00`000000oooo0?ooo`1S0?oo
o`00I`3oool00`000000oooo0?ooo`0]0?ooo`030000002]_^H0[KkV0080[KkV0P0000020:Vmj003
0000002Y_^T0ZKkY00T0ZKkY0P0000090:Voj@8000002@2Y`>X2000000T0ZL7/0P0000090:S3k@80
00000P2XaNh00`000000Wkg^09nmkP0<09nmkP030000002O_Nh0Wkg^00H0Wkg^2@00000=09bnl003
0000002I/^T0VK;Y00H0VK;Y1P00000G09bcj0H000000`2N/nL00`000000XjgO0:>]g`070:>]g`80
00002`2T[ml2000000d0Y[3O0P00000=0:Nag`<000001@2W/^000`000000[k?K0:ncf`02000000T0
[k?L00<000000?ooo`3oool0K03oool2000006<0oooo001V0?ooo`030000003oool0oooo02d0oooo
00<000000:fniP2]_^H01@2]_^H00`000000ZKkY0:Vnj@090:Vnj@8000002@2Y_nT2000000T0ZL3Z
0P0000090:W1k08000002@2X`nd2000000@0Z<G^00<0000009nmkP2O_Nh0302O_Nh9000001H0W;k`
00<0000009Vbj@2I/^T0302I/^T5000001P0W;?X1000000;0:>]g`<000002P2T[ml2000000d0Y[3O
0P00000>0:Nag`8000000P2W/^000`000000[k?K0:ncf`030:ncf`030000002_/m`0[k?L00L0[k?L
00<000000?ooo`3oool0K@3oool200000640oooo001U0?ooo`030000003oool0oooo02d0oooo00<0
00000:fniP2]_^H01@2]_^H00`000000[KkV000000080:Vnj@8000002@2Y_nT2000000T0ZL3Z0P00
00090:W1k08000002@2X`nd2000000L0Z<G^00<0000009nmkP2O_Nh00`2O_Nh9000001h0W;k`00<0
000009Vbj@2I/^T04@2I/^T6000001D0W;?X00<000000:6/gP000000302S[Ml2000000X0Y:oO0`00
000<0:J`g`<000003@2W/Ml2000000L0[k?K00<000000:ncg02_/m`01`2_/m`2000006l0oooo00<0
00000?ooo`3oool0GP3oool006D0oooo00<000000?ooo`3oool0;@3oool00`000000[KkV0:fniP04
0:fniP040000002]_^H0[KkV0:fniP8000001@2Y_^T00`000000ZKoY0:Voj@070:Voj@8000002@2Y
`>X2000000T0ZL7/0P0000090:S3k@8000002@2XaNh6000000P0W;k`00<0000009bnl02L__005`2L
__06000001T0VK;Y1@00000?09bcj0030000002Q[=h0XJcN0080XJcN0P00000;0:>]g`8000002`2T
[ml2000000d0Y[3O0P00000;0:Nag`030000002_/]X0000000L0[k?K00<000000:ncg02_/m`0202_
/m`00`000000oooo0?ooo`1]0?ooo`800000GP3oool006@0oooo00<000000?ooo`3oool0;@3oool0
0`000000[KkV0:fniP040:fniP030000002]_^H0[KkV00@0[KkV00@000000:Vnj@2Y_^T000002@2Y
_nT2000000T0ZL3Z0P0000090:W1k08000002@2X`nd2000000T0Z<G^0P0000020:S7l0030000002L
__00W;k`00T0W;k`00<0000009bnl02L__003@2L__0:000000D0VL3c00<0000009Baj`2D/N/01P00
000F09Vbj@H000002@2L/nP00`000000XJcN0:6/gP040:6/gP8000002`2S[Ml2000000/0Y:oO0P00
000=0:J`g`<000001`2W/Ml010000000[k;J0:nbfP2_/]X2000000H0[k?K0P0000090:ncg0030000
003oool0oooo06h0oooo0P00001L0?ooo`00H`3oool00`000000oooo0?ooo`0]0?ooo`030000002]
_^H0[KkV00@0[KkV00<000000:fniP2]_^H01P2]_^H00`000000ZKoY0:Voj@070:Voj@8000002@2Y
`>X2000000T0ZL7/0P0000090:S3k@8000002@2XaNh2000000@0Z<O`00<0000009bnl02L__002@2L
__000`000000W;k`09bnl00309bnl0X000003`2I`?<00`000000U;7[09Baj`0609Baj`D000005`2I
/^T600000080W;?X00<000000:6/gP2Q[=h01`2Q[=h2000000/0XjgO0P00000;0:B_g`<000003@2V
/=l2000000D0Yk7O00<000000:nbfP2_/]X00`2_/]X00`000000[k?K0:ncf`050:ncf`030000002_
/m`0[k?L00L0[k?L00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1I0?ooo`00HP3oool0
0`000000oooo0?ooo`0]0?ooo`030000002]_^H0[KkV00@0[KkV00<000000:fniP2]_^H01P2]_^H0
10000000[[oW0000000000060:Voj@030000002Y`>X0ZL3Z00L0ZL3Z0P0000090:W1k08000002@2X
`nd2000000T0Z<G^0P0000070:S7l0030000002L__00W;k`00@0W;k`2P00000J09W0l`030000002D
/N/0U;7[00X0U;7[1P00000G09Vbj@<000002`2Q[=h2000000/0XjgO0P00000<0:B_g`8000003@2V
/=l200000080Yk7O00<000000:nbfP2_/]X01@2_/]X00`000000[k?K0:ncf`050:ncf`030000002_
/m`0[k?L00L0[k?L0P00001`0?ooo`800000F@3oool00640oooo00<000000?ooo`3oool0;@3oool0
0`000000[KkV0:fniP050:fniP030000002]_^H0[KkV00D0[KkV00<000000:joi`2^_nL00P2^_nL2
00000080ZKoY00<000000:W0jP2Y`>X01`2Y`>X2000000T0ZL7/0P0000090:S3k@8000002@2XaNh2
000000T0Z<O`1`00000409W0l`030000002I`?<0VL3c01L0VL3c1`00000B09Baj`D00000502I/^T3
000000/0XJcN0P00000;0:>]g`<000002`2T[ml2000000d0Y[3O0P0000090:nbfP030000002_/m/0
[k?K00D0[k?K0P0000090:ncg0030000003oool0oooo06l0oooo00<000000?ooo`3oool0EP3oool0
0600oooo00<000000?ooo`3oool0;@3oool00`000000[KkV0:fniP050:fniP030000002]_^H0[KkV
00D0[KkV00<000000:joi`2^_nL01@2^_nL00`000000ZL3Z0:W0jP070:W0jP8000002@2Y`N`20000
00T0Z<?]0P0000080:S5kP<000002@2Xao0200000080Yl_b00<0000009W0l`2I`?<01P2I`?<00`00
0000VL3c09W0l`0:09W0l`d000001P2D`OH00`000000Sk3/08n`k00400000140U;7[1P00000>09Vb
j@030000002OZ]h0Wj[N008000002`2Q[=h2000000`0XjgO0P00000;0:B_g`8000002`2V/=l00`00
0000[[3J000000090:nbfP030000002_/m/0[k?K00H0[k?K00<000000:ncg02_/m`01`2_/m`00`00
0000oooo0?ooo`1_0?ooo`800000EP3oool005l0oooo00<000000?ooo`3oool0;@3oool00`000000
[KkV0:fniP050:fniP030000002]_^H0[KkV00D0[KkV00<000000:joi`2^_nL01@2^_nL00`000000
[/7W000000060:W0jP8000002@2Y`N`2000000T0Z<?]0P0000080:S5kP8000002P2Xao02000000D0
Yl_b00<0000009W0l`2I`?<01@2I`?<=000001<0U<7f00<0000008n`k02?/>`0102?/>`500000180
U;7[1@00000809Vbj@030000002OZ]h0Wj[N00<0Wj[N0P00000;0:6/gP800000302S[Ml2000000/0
Y:oO0`0000070:J`g`050000002^/=X0[[3J0:j`fP0000002@2_/]X2000000L0[k?K00<000000:nc
g02_/m`01`2_/m`00`000000oooo0?ooo`1`0?ooo`800000E03oool005l0oooo00<000000?ooo`3o
ool0;03oool00`000000[KkV0:fniP050:fniP030000002]_^H0[KkV00D0[KkV00<000000:joi`2^
_nL01@2^_nL010000000[/7W0:k1i`2^`NL200000080ZL3Z0P0000090:W1k08000002@2X`nd20000
00P0Z<G^0P00000:0:S7l08000001`2Wbo8900000200U<7f00<0000008n`k02?/>`0202?/>`40000
01<0U;7[1P00000209Vbj@030000002OZ]h0Wj[N00D0Wj[N0P00000;0:6/gP800000302S[Ml20000
00`0Y:oO0P0000050:J`g`030000002^/=X0[[3J0080[[3J0P0000090:nbfP030000002_/m/0[k?K
00D0[k?K00<000000:ncg02_/m`01`2_/m`200000780oooo00<000000?ooo`3oool0D@3oool005h0
oooo00<000000?ooo`3oool0;03oool00`000000[KkV0:fniP050:fniP030000002]_^H0[KkV00D0
[KkV00<000000:joi`2^_nL01@2^_nL00`000000[/7W0:k1i`040:k1i`8000002@2Y`N`2000000T0
Z<?]0P0000080:S5kP8000002@2Xao03000000L0Yl_b0P0000020:K?m@030000002D`OH0U<7f00<0
U<7f00<0000009C1mP2D`OH05@2D`OH:000000h0Sk3/1@00000D09Baj`<000002@2OZ]h2000000/0
XJcN0P00000<0:>]g`800000302T[ml200000080Y[3O00<000000:j`fP2^/=X01@2^/=X00`000000
[k;J0:nbfP070:nbfP030000002_/m/0[k?K00D0[k?K0P0000090:ncg0030000003oool0oooo0700
oooo0P00001A0?ooo`00G@3oool00`000000oooo0?ooo`0]0?ooo`030000002]_^H0[KkV00@0[KkV
00<000000:fniP2]_^H01@2]_^H00`000000[[oW0:joi`050:joi`030000002^`NL0[/7W00@0[/7W
00@000000:o2j000000000001P2Y`N`2000000T0Z<?]0P0000080:S5kP8000002@2Xao02000000P0
Yl_b0P0000050:K?m@030000002D`OH0U<7f0080U<7f00<0000009C1mP2D`OH00`2D`OHB000000T0
SL?i00<0000008R^kP0000000`00000>08n`k0D000004@2D/N/3000000T0Wj[N0P00000;0:6/gP<0
00002`2S[Ml3000000/0Y:oO0P0000090:j`fP030000002_/]X0[k;J00L0[k;J00<000000:ncf`2_
/m/01P2_/m/00`000000[k?L0:ncg0070:ncg0030000003oool0oooo0740oooo00<000000?ooo`3o
ool0CP3oool005`0oooo00<000000?ooo`3oool0;@3oool00`000000[KkV0:fniP040:fniP030000
002]_^H0[KkV00H0[KkV00<000000:joi`2^_nL0102^_nL00`000000[/7W0:k1i`040:k1i`030000
002_`^P0[l;X0080[l;X0P0000020:W1k08000002@2X`nd2000000P0Z<G^0P0000090:S7l0800000
1`2Wbo83000000L0Y/oe2`00000K08g3n@0300000028[^h0R:k^00<0R:k^1000000?08n`k0@00000
302D/N/010000000W:ON09bWgP2LYmh2000000T0Wj[N0P00000<0:6/gP800000302S[Ml2000000T0
Y:oO00<000000:j_f@0000002@2^/=X00`000000[k;J0:nbfP070:nbfP030000002_/m/0[k?K00H0
[k?K00<000000:ncg02_/m`01`2_/m`00`000000oooo0?ooo`1a0?ooo`800000CP3oool005/0oooo
00<000000?ooo`3oool0;@3oool00`000000[KkV0:fniP040:fniP030000002]_^H0[KkV00H0[KkV
00<000000:joi`2^_nL0102^_nL00`000000[/7W0:k1i`040:k1i`030000002_`^P0[l;X00D0[l;X
0P0000090:S3k@8000001`2XaNh3000000P0Z<O`0`0000070:O;lP800000202VcoD200000080Y=?h
00@0000008g3n@2=`oT000008@2=`oT00`000000R:k^08R^kP0608R^kP@000003`2?/>`5000000L0
U;7[00<0000009bWgP2LYmh00`2LYmh2000000T0Wj[N0P00000<0:6/gP800000302S[Ml2000000L0
Y:oO00@000000:j_f@2^[mT000002@2^/=X00`000000[k;J0:nbfP070:nbfP8000001`2_/m/00`00
0000[k?L0:ncg0070:ncg0800000L`3oool2000004`0oooo001J0?ooo`030000003oool0oooo02d0
oooo00<000000:fniP2]_^H0102]_^H00`000000[KkV0:fniP060:fniP030000002^_nL0[[oW00@0
[[oW00<000000:k1i`2^`NL0102^`NL00`000000[l;X0:o2j0050:o2j0040000002``nP000000000
00H0Z<?]0P0000070:S5kP8000002@2Xao02000000P0Yl_b0P0000080:K?m@8000001@2TdoP00`00
0000SL?i0000000@08g3nA8000003028[^h400000100Sk3/1000000209Baj`030000002LYmh0W:ON
00H0W:ON0P00000909nZgP800000302Q[=h2000000`0XjgO0P0000040:B_g`030000002^[mT0[ZoI
0080[ZoI0P0000080:j`fP8000002@2_/]X00`000000[k?K0:ncf`050:ncf`8000002@2_/m`00`00
0000oooo0?ooo`1b0?ooo`030000003oool0oooo04T0oooo001I0?ooo`030000003oool0oooo02d0
oooo00<000000:fniP2]_^H0102]_^H00`000000[KkV0:fniP060:fniP030000002^_nL0[[oW00D0
[[oW00<000000:k1i`2^`NL00`2^`NL00`000000[l;X0:o2j0050:o2j0030000002``nP0/<?X0080
/<?X0P0000020:S3k@8000001`2XaNh2000000T0Z<O`0P0000080:O;lP8000001`2VcoD3000000L0
Y=?h4`00000A08?5o@030000001mZo40000000<000002`28[^h400000100Sk3/0`00000:09bWgP80
00002@2OZ]h2000000`0XJcN0P00000<0:>]g`8000000P2T[ml00`000000[ZoI0:j_f@040:j_f@03
0000002^/=X0[[3J00L0[[3J00<000000:nbfP2_/]X01`2_/]X00`000000[k?K0:ncf`060:ncf`03
0000002_/m`0[k?L00L0[k?L00<000000?ooo`3oool0L03oool2000004/0oooo001H0?ooo`030000
003oool0oooo02d0oooo00<000000:fniP2]_^H0102]_^H00`000000[KkV0:fniP060:fniP030000
002^_nL0[[oW00D0[[oW00<000000:k1i`2^`NL00`2^`NL00`000000[l;X0:o2j0050:o2j0030000
002``nP0/<?X00D0/<?X0P0000070:S5kP8000002@2Xao02000000L0Yl_b0`0000070:K?m@800000
202TdoP200000080XMWk00<0000008?5o@23aOd07`23aOd00`000000OJ_a07f[l@0307f[l@<00000
3028[^h4000000h0Sk3/0`00000:09bWgP8000002@2OZ]h2000000`0XJcN0P00000<0:>]g`800000
202^[mT00`000000[[3J0:j`fP070:j`fP030000002_/]X0[k;J00L0[k;J00<000000:ncf`2_/m/0
1P2_/m/00`000000[k?L0:ncg0070:ncg0030000003oool0oooo06d0oooo0P0000000`3oool00000
0?ooo`1:0?ooo`00F03oool00`000000oooo0?ooo`0/0?ooo`030000002]_^H0[KkV00D0[KkV00<0
00000:fniP2]_^H01@2]_^H00`000000[[oW0:joi`050:joi`030000002^`NL0[/7W00<0[/7W00<0
00000:o2j02_`^P01@2_`^P00`000000/<?X0;33j0050;33j0030000002aaNT0/LGY008000000`2X
aNh2000000P0Z<O`0`0000070:O;lP8000001`2VcoD3000000L0Y=?h0`0000040:7In`8000008023
aOd00`000000OJ_a07f[l@0607f[l@@000003028[^h4000000X0Sk3/00<0000009VTg@2IY=d00P00
000:09bWgP8000002@2OZ]h2000000`0XJcN0P00000:0:>]g`030000002^[]L0000000P0[ZoI00<0
00000:j`fP2^/=X01`2^/=X00`000000[k;J0:nbfP070:nbfP030000002_/m/0[k?K00H0[k?K0P00
00080:ncg0800000K03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04P0oooo001G
0?ooo`030000003oool0oooo02`0oooo00<000000:fniP2]_^H01@2]_^H00`000000[KkV0:fniP05
0:fniP030000002^_nL0[[oW00D0[[oW00<000000:k1i`2^`NL0102^`NL00`000000[l;X0:o2j004
0:o2j0030000002``nP0/<?X00D0/<?X00<000000;75j@2aaNT00`2aaNT3000000P0Z<O`0P000008
0:O;lP8000001`2VcoD2000000P0Y=?h0P0000070:7Inb<00000301mZo44000000`0R:k^10000005
08n`k0030000002IY=d0VJCM00<0VJCM0P00000:09bWgP8000002@2OZ]h2000000`0XJcN0P000007
0:>]g`050000002^[]L0[ZkG0:j^e`000000202^[mT00`000000[[3J0:j`fP070:j`fP030000002_
/]X0[k;J00L0[k;J0P0000080:ncf`030000002_/m`0[k?L00L0[k?L00<000000?ooo`3oool0J03o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04P0oooo001F0?ooo`030000003oool0
oooo02d0oooo00<000000:fniP2]_^H0102]_^H00`000000[KkV0:fniP050:fniP030000002^_nL0
[[oW00D0[[oW00<000000:k1i`2^`NL0102^`NL00`000000[l;X0:o2j0040:o2j0030000002``nP0
/<?X00D0/<?X00<000000;75j@2aaNT0102aaNT00`000000//SZ000000060:S7l08000001`2Wbo83
000000L0Y/oe0P0000080:CCn0800000202QfO/200000080V^3m00<0000007;4o`1ba?l0701ba?l0
0`000000KZKc00000002000000`0OJ_a0`00000=08R^kP@0000000<0Sk3/0000002IY=d01P2IY=d2
000000X0W:ON0P00000909nZgP800000302Q[=h2000000D0XjgO00<000000:j^e`2^[]L00P2^[]L0
0`000000[ZoI0:j_f@060:j_f@800000202^/=X2000000T0[k;J00<000000:ncf`2_/m/01P2_/m/0
0`000000[k?L0:ncg0070:ncg0030000003oool0oooo06H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`180?ooo`00E@3oool00`000000oooo0?ooo`0]0?ooo`030000002]_^H0[KkV
00@0[KkV00<000000:fniP2]_^H01@2]_^H00`000000[[oW0:joi`050:joi`030000002^`NL0[/7W
00@0[/7W00<000000:o2j02_`^P0102_`^P00`000000/<?X0;33j0050;33j0030000002aaNT0/LGY
00@0/LGY00@000000;;8jP2bb>X0//SZ0P0000020:S7l08000001`2Wbo82000000L0Y/oe0`000007
0:CCn0<000001`2QfO/30000000409[Po@000000V^3m09[PoA4000003`1ba?l010000000KZKc06jV
l`1^Y_<3000000`0OJ_a1000000=08R^kP8000002@2IY=d2000000X0W:ON0P00000909nZgP800000
302Q[=h200000080XjgO00<000000:j^e`2^[]L0102^[]L2000000P0[ZoI00<000000:j`fP2^/=X0
1`2^/=X00`000000[k;J0:nbfP070:nbfP030000002_/m/0[k?K00H0[k?K00<000000:ncg02_/m`0
1`2_/m`2000006@0oooo0P0000070?ooo`030000003oool0oooo04P0oooo001D0?ooo`030000003o
ool0oooo02d0oooo00<000000:fniP2]_^H0102]_^H00`000000[KkV0:fniP050:fniP030000002^
_nL0[[oW00D0[[oW00<000000:k1i`2^`NL0102^`NL00`000000[l;X0:o2j0040:o2j0030000002`
`nP0/<?X00D0/<?X00<000000;75j@2aaNT0102aaNT00`000000//SZ0;;8jP040;;8jP8000001`2W
bo82000000L0Y/oe0P0000080:CCn0800000202QfO/2000000@0V^3m0`00000208gTn`8000003@1D
__X@000000H0KZKc1000000<07f[l@<000002`28[^h3000000T0VJCM0P00000:09bWgP8000002@2O
Z]h2000000`0XJcN0P0000090:j^e`030000002^[mT0[ZoI00H0[ZoI00<000000:j`fP2^/=X01`2^
/=X00`000000[k;J0:nbfP070:nbfP030000002_/m/0[k?K00H0[k?K0P0000090:ncg0030000003o
ool0oooo0600oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`180?ooo`00D`3oool0
0`000000oooo0?ooo`0]0?ooo`030000002]_^H0[KkV00@0[KkV00<000000:fniP2]_^H01@2]_^H0
0`000000[[oW0:joi`050:joi`030000002^`NL0[/7W00@0[/7W00<000000:o2j02_`^P0102_`^P0
0`000000/<?X0;33j0050;33j0030000002aaNT0/LGY00@0/LGY00<000000;;8jP2bb>X0102bb>X0
0`000000]<_[0;C;j`02000000<0Yl_b0P0000060:K?m@<000001`2TdoP3000000L0XMWk0`000004
09[Po@<000001@2=i?/9000001@0E;kj00@0000005JNm000000000001`1^Y_<3000000`0OJ_a1000
000608R^kP040000002DXMd0U:7M09BQg@8000002@2IY=d2000000X0W:ON0P00000909nZgP800000
2P2Q[=h00`000000[JcF000000090:j^e`030000002^[mT0[ZoI00H0[ZoI00<000000:j`fP2^/=X0
1`2^/=X00`000000[k;J0:nbfP070:nbfP800000202_/m/00`000000[k?L0:ncg0070:ncg0030000
003oool0oooo05h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`180?ooo`00DP3o
ool00`000000oooo0?ooo`0]0?ooo`030000002]_^H0[KkV00@0[KkV00<000000:fniP2]_^H01@2]
_^H00`000000[[oW0:joi`050:joi`030000002^`NL0[/7W00@0[/7W00<000000:o2j02_`^P0102_
`^P00`000000/<?X0;33j0050;33j0030000002aaNT0/LGY00@0/LGY00<000000;;8jP2bb>X0102b
b>X00`000000]<_[0;C;j`030;C;j`<000001P2VcoD2000000P0Y=?h0P0000080:7In`8000001@2J
h?d20000000308gTn`000000SNCk0080SNCk0`00000307;PjA@000001`1D__X00`000000EYkd05JN
m003000000L0KZKc0`00000=07f[l@@000000P28[^h00`000000U:7M09BQg@0309BQg@8000002@2I
Y=d2000000X0W:ON0P00000909nZgP8000001`2Q[=h01@000000[JcF0:f/eP2][=H0000000T0[ZkG
00<000000:j_f@2^[mT01P2^[mT00`000000[[3J0:j`fP070:j`fP030000002_/]X0[k;J00P0[k;J
00<000000:ncf`2_/m/01P2_/m/00`000000[k?L0:ncg0070:ncg0030000003oool0oooo05`0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`170?ooo`00DP3oool00`000000oooo0?oo
o`0/0?ooo`030000002]_^H0[KkV00@0[KkV00<000000:fniP2]_^H01@2]_^H00`000000[[oW0:jo
i`050:joi`030000002^`NL0[/7W00@0[/7W00<000000:o2j02_`^P0102_`^P00`000000/<?X0;33
j0050;33j0030000002aaNT0/LGY00@0/LGY00<000000;;8jP2bb>X0102bb>X00`000000]<_[0;C;
j`040;C;j`040000002fcnd00000000000<0Y/oe0P0000080:CCn0800000202QfO/2000000@0V^3m
0`00000308gTn`@000000`1bh>T6000000<0P6R^2000000602:Xh@P000001@1FW_@3000000L0KZKc
0`00000>07f[l@800000202DXMd00`000000VJCM09VTg@0809VTg@8000002P2LYmh2000000T0Wj[N
0P0000050:6/gP030000002][=H0[JcF0080[JcF00<000000:j^e`2^[]L01`2^[]L00`000000[ZoI
0:j_f@060:j_f@800000202^/=X00`000000[k;J0:nbfP080:nbfP030000002_/m/0[k?K00H0[k?K
00<000000:ncg02_/m`01`2_/m`2000005X0oooo0P00000=0?ooo`030000003oool0oooo04L0oooo
001A0?ooo`030000003oool0oooo02`0oooo00<000000:fniP2]_^H0102]_^H00`000000[KkV0:fn
iP050:fniP030000002^_nL0[[oW00D0[[oW00<000000:k1i`2^`NL0102^`NL00`000000[l;X0:o2
j0040:o2j0030000002``nP0/<?X00D0/<?X00<000000;75j@2aaNT0102aaNT00`000000//SZ0;;8
jP040;;8jP030000002dbn/0]<_[00@0]<_[00<000000;K?k@2fcnd00P2fcnd3000000L0Y=?h0`00
00070:7In`<00000102Jh?d2000000@0SNCk0`00000307;Pj@H0000000<0N6B_00000020J:h01@20
J:h?000000@08ZSQ00@0000002f<kP00000000001@1FW_@2000000P0KZKc0`00000<07f[l@<00000
1`2DXMd2000000X0VJCM00<0000009bWgP2LYmh02@2LYmh2000000T0Wj[N0P0000020:6/gP030000
002][=H0[JcF00@0[JcF0P0000080:j^e`030000002^[mT0[ZoI00L0[ZoI00<000000:j`fP2^/=X0
1P2^/=X2000000T0[k;J00<000000:ncf`2_/m/01P2_/m/2000000T0[k?L00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04L0oooo001@0?ooo`030000003o
ool0oooo02`0oooo00<000000:fniP2]_^H0102]_^H00`000000[KkV0:fniP050:fniP030000002^
_nL0[[oW00D0[[oW00<000000:k1i`2^`NL0102^`NL00`000000[l;X0:o2j0040:o2j0030000002`
`nP0/<?X00D0/<?X00<000000;75j@2aaNT0102aaNT00`000000//SZ0;;8jP040;;8jP030000002d
bn/0]<_[00@0]<_[00<000000;K?k@2fcnd00`2fcnd00`000000^=C^0;SDkP02000000<0Y=?h0P00
00080:7In`800000102Jh?d3000000@0SNCk0P00000207;Pj@H000001@1hI:l7000000L0OfN]0`00
00000`22J:`0000000000007000000<0;Hc^0P00000505JNm0<00000201^Y_<4000000P0OJ_a00<0
000008nLg02?W=`00P00000709BQg@8000002@2IY=d2000000/0W:ON0P00000909nZgP8000002@2]
[=H00`000000[ZkG0:j^e`060:j^e`030000002^[mT0[ZoI00L0[ZoI00<000000:j`fP2^/=X01`2^
/=X00`000000[k;J0:nbfP070:nbfP030000002_/m/0[k?K00L0[k?K00<000000:ncg02_/m`01`2_
/m`00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0A`3o
ool004l0oooo00<000000?ooo`3oool0;03oool00`000000[KkV0:fniP040:fniP030000002]_^H0
[KkV00D0[KkV00<000000:joi`2^_nL01@2^_nL00`000000[/7W0:k1i`040:k1i`030000002_`^P0
[l;X00D0[l;X00<000000;33j02``nP0102``nP00`000000/LGY0;75j@040;75j@030000002bb>X0
//SZ00@0//SZ00<000000;C;j`2dbn/0102dbn/00`000000]/o]0;K?k@030;K?k@030000002he>h0
^=C^00<0^=C^0`0000070:7In`<00000102Jh?d2000000@0SNCk0`0000000`1bh>T0000000000005
000000H0N6B_0P00000=07mW[@0400000021IZ/0PFJ[000000D0PVR/1P00000302f<kP<000001@1F
W_@3000000T0KZKc0`00000407f[l@030000002?W=`0SicL00<0SicL00<0000009BQg@2DXMd01P2D
XMd2000000T0VJCM0P00000;09bWgP8000001`2OZ]h00`000000[J[D000000090:f/eP030000002^
[]L0[ZkG00H0[ZkG00<000000:j_f@2^[mT01`2^[mT00`000000[[3J0:j`fP070:j`fP030000002_
/]X0[k;J00L0[k;J0P0000080:ncf`030000002_/m`0[k?L00D0[k?L00<000000;Nif`000000E03o
ool00`000000oooo0?ooo`0>0?ooo`800000B@3oool004h0oooo00<000000?ooo`3oool0;@3oool0
0`000000[KkV0:fniP040:fniP030000002]_^H0[KkV00D0[KkV00<000000:joi`2^_nL0102^_nL0
0`000000[/7W0:k1i`040:k1i`030000002_`^P0[l;X00D0[l;X00<000000;33j02``nP0102``nP0
0`000000/LGY0;75j@040;75j@030000002bb>X0//SZ00@0//SZ00<000000;C;j`2dbn/0102dbn/0
0`000000]/o]0;K?k@030;K?k@030000002he>h0^=C^00@0^=C^00<000000;_Jl02kf_000P000003
0:7In`800000102Jh?d3000000<0SNCk0`0000000`1bh>T00000000000050000000307UU/0000000
N6B_00D0N6B_00@0000007MR[P1gHZh00000301oIjd010000000PFJ[085VZ`21IZ/2000000L0PVR/
1000000402f<kP8000001P1FW_@2000000X0KZKc0`0000000`1mZo40000008nLg00508nLg0800000
202DXMd00`000000VJCM09VTg@0809VTg@8000002`2LYmh2000000D0Wj[N00@000000:fZe02]Z]@0
00002@2][=H00`000000[ZkG0:j^e`060:j^e`800000202^[mT00`000000[[3J0:j`fP070:j`fP03
0000002_/]X0[k;J00P0[k;J00<000000:ncf`2_/m/01P2_/m/2000000<0[k?L0P0000020;Nif`03
0000003oool0oooo0500oooo0P00000@0?ooo`040000003oool0oooo000004P0oooo001=0?ooo`03
0000003oool0oooo02d0oooo00<000000:fniP2]_^H0102]_^H00`000000[KkV0:fniP050:fniP03
0000002^_nL0[[oW00@0[[oW00<000000:k1i`2^`NL0102^`NL00`000000[l;X0:o2j0050:o2j003
0000002``nP0/<?X00D0/<?X00<000000;75j@2aaNT00`2aaNT00`000000//SZ0;;8jP040;;8jP03
0000002dbn/0]<_[00@0]<_[00<000000;K?k@2fcnd00`2fcnd00`000000^=C^0;SDkP040;SDkP03
0000002kf_00^m[`00<0^m[`0`00000409[Po@8000000`2=i?/300000080L^3Y1@0000000`1ZFjl0
000007UU/002000000H0N6B_00D0000007MR[P1gHZh0Mf:^0000000=07mW[@0300000021IZ/0PFJ[
0080PFJ[0P000007089X[0@00000100]S>h2000000H0EYkd0`00000:06jVl`800000202?W=`00`00
0000U:7M09BQg@0609BQg@8000002P2IY=d2000000/0W:ON0P00000209nZgP030000002]Z]@0[J[D
0080[J[D00<000000:f/eP2][=H01`2][=H00`000000[ZkG0:j^e`070:j^e`030000002^[mT0[ZoI
00H0[ZoI0P0000080:j`fP030000002_/]X0[k;J00P0[k;J00<000000:ncf`2_/m/01`2_/m/00`00
0000[k?L000000050;Nif`030000003oool0oooo04h0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`160?ooo`00C03oool00`000000oooo0?ooo`0]0?ooo`030000002]_^H0[KkV00@0
[KkV00<000000:fniP2]_^H01@2]_^H00`000000[[oW0:joi`050:joi`030000002^`NL0[/7W00<0
[/7W00<000000:o2j02_`^P01@2_`^P00`000000/<?X0;33j0050;33j0030000002aaNT0/LGY00<0
/LGY00<000000;;8jP2bb>X0102bb>X00`000000]<_[0;C;j`040;C;j`030000002fcnd0]/o]00<0
]/o]00<000000;SDkP2he>h0102he>h00`000000^m[`0;_Jl0040;_Jl0030000002nh_40_^;a00h0
000000<0_ogR0000000000000P00000206YK[`8000001P1hI:l00`000000Mf:^07MR[P0207MR[P03
0000001oIjd0OfN]00/0OfN]00<00000085VZ`21IZ/01021IZ/00`000000PVR/089X[004089X[0H0
0000100]S>h2000000L0EYkd0`00000806jVl`<000001`2?W=`2000000P0U:7M0P00000:09VTg@80
00002`2LYmh2000000H0[J[D0P0000080:f/eP030000002^[]L0[ZkG00L0[ZkG00<000000:j_f@2^
[mT01`2^[mT00`000000[[3J0:j`fP060:j`fP8000002@2_/]X00`000000[k?K0:ncf`070:ncf`03
0000002g^M/0]kWK00@0]kWK00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo04H0oooo001<0?ooo`030000003oool0oooo02`0oooo00<000000:fniP2]_^H0
102]_^H00`000000[KkV0:fniP050:fniP030000002^_nL0[[oW00D0[[oW00<000000:k1i`2^`NL0
0`2^`NL00`000000[l;X0:o2j0050:o2j0030000002``nP0/<?X00D0/<?X00<000000;75j@2aaNT0
102aaNT00`000000//SZ0;;8jP030;;8jP030000002dbn/0]<_[00@0]<_[00<000000;K?k@2fcnd0
102fcnd00`000000^=C^0;SDkP030;SDkP030000002kf_00^m[`00@0^m[`00<000000;kRl@2nh_40
0P2nh_400`000000`Nca0<7/l@020<7/l@0500000033m^h0`oK^0<?fkP0000000`2ooN8500000080
JU^_0P00000607QT[`030000001gHZh0Mf:^00<0Mf:^00<0000007mW[@1oIjd0101oIjd7000000L0
PFJ[0P000004089X[00300000021HjL000000080000000<006OC000000000000100]S>h3000000L0
EYkd0P00000506jVl`0500000027Um`0QiOL08NGg0000000202?W=`2000000P0U:7M0P00000:09VT
g@8000002@2LYmh00`000000[:OC000000070:fZe0030000002][=H0[JcF00H0[JcF00<000000:j^
e`2^[]L01`2^[]L00`000000[ZoI0:j_f@070:j_f@030000002^/=X0[[3J00L0[[3J00<000000:nb
fP2_/]X01`2_/]X00`000000[k?K0:ncf`050:ncf`030000002h^MX0]kWK00H0]kWK00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo001;0?ooo`03
0000003oool0oooo02`0oooo0`0000040:fniP030000002]_^H0[KkV00D0[KkV00<000000:joi`2^
_nL01@2^_nL00`000000[/7W0:k1i`040:k1i`030000002_`^P0[l;X00@0[l;X00<000000;33j02`
`nP01@2``nP00`000000/LGY0;75j@040;75j@030000002bb>X0//SZ00<0//SZ00<000000;C;j`2d
bn/0102dbn/00`000000]/o]0;K?k@040;K?k@030000002he>h0^=C^00<0^=C^00<000000;_Jl02k
f_00102kf_000`000000_^;a0;kRl@020;kRl@0300000031k?40`Nca0080`Nca00D000000<?fkP33
m^h0`oK^000000030;omhP<0000000<0l_B]0000001ZFjl00P1ZFjl00`1ZFZh0000007QT[`0407QT
[`030000001gHZh0Mf:^00@0Mf:^1`00000607eU[0<000001`21IZ/020000000PVR/089X[022J:`0
0000085SY`000000PVBX0`0000000`00Im<000000000000502f<kP8000001`1FW_@300000080KZKc
00<0000008NGg027Um`00P27Um`00`000000SicL08nLg00708nLg0030000002DXMd0U:7M00L0U:7M
00<0000009VTg@2IY=d02@2IY=d2000000H0W:ON00D000000:bWd`2/Ym<0[:OC000000070:fZe003
0000002][=H0[JcF00H0[JcF0P0000080:j^e`030000002^[mT0[ZoI00L0[ZoI00<000000:j`fP2^
/=X01`2^/=X00`000000[k;J0:nbfP070:nbfP8000000`2_/m/200000080^;WJ00<000000;Nif`2g
^M/01@2g^M/00`000000oooo0?ooo`180?ooo`800000603oool00`000000oooo0?ooo`160?ooo`00
BP3oool00`000000oooo0?ooo`0]0?ooo`030000002]^n<0[K_S00D000001P2]_^H00`000000[[oW
0:joi`050:joi`030000002^`NL0[/7W00@0[/7W00<000000:o2j02_`^P0102_`^P00`000000/<?X
0;33j0050;33j0030000002aaNT0/LGY00@0/LGY00<000000;;8jP2bb>X0102bb>X00`000000]<_[
0;C;j`030;C;j`030000002fcnd0]/o]00@0]/o]00<000000;SDkP2he>h00`2he>h00`000000^m[`
0;_Jl0040;_Jl0030000002nh_40_^;a0080_^;a00<000000<7/l@31k?400P31k?401@000000`oK^
0<?fkP33m^h0000000<0_ogR0`0000020?;d[@060000001ZFjl0JU^_0000001ZFZh00000101hI:l0
0`000000Mf:^07MR[P0407MR[P800000301mIJ`010000000OfFZ07mUZP000007085VZ`8000000P22
J:`010000000PF>W00000022I:P30000008006OC00<0000002f<kP0]S>h0100]S>h2000000P0EYkd
0P00000608NGg0800000202?W=`2000000P0U:7M0P00000;09VTg@800000102LYmh00`000000[:OC
0:bWd`020:bWd`030000002]Z]@0[J[D00D0[J[D00<000000:f/eP2][=H01`2][=H00`000000[ZkG
0:j^e`060:j^e`030000002^[mT0[ZoI00L0[ZoI00<000000:j`fP2^/=X01`2^/=X00`000000[k;J
0:nbfP080:nbfP030000002_/m/0000000D0^;WJ00<000000;Nif`2g^M/0102g^M/00`000000oooo
0?ooo`170?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0AP3oool004T0oooo00<0
00000?ooo`3oool0;@3oool00`000000[K_S0:fkh`040:fkh`030000002^^n<00000008000000P2]
_^H00`000000[[oW0:joi`050:joi`030000002^`NL0[/7W00@0[/7W00<000000:o2j02_`^P0102_
`^P00`000000/<?X0;33j0050;33j0030000002aaNT0/LGY00@0/LGY00<000000;;8jP2bb>X0102b
b>X00`000000]<_[0;C;j`030;C;j`030000002fcnd0]/o]00@0]/o]00<000000;SDkP2he>h00`2h
e>h00`000000^m[`0;_Jl0040;_Jl0030000002nh_40_^;a0080_^;a00<000000<7/l@31k?400P31
k?401@000000`oK^0<?fkP33m^h0000000<0_ogR0`0000030?;d[@050000001ZFjl0JU^_0000001Z
FZh00P00000207QT[`030000001gHZh0Mf:^00@0Mf:^00@0000007IQ[@1fHJd000002`1mIJ`01000
0000OfFZ07mUZP1oIJX2000000L0PFJ[0`000002085SY`0300000022I:P0000000<0000000<006OC
0000000000001P0]S>h3000000H0EYkd0P00000708NGg0030000002?W=`0SicL00L0SicL00<00000
09BQg@2DXMd01`2DXMd2000000/0VJCM0P0000000`2LYmh000000:bWd`050:bWd`030000002]Z]@0
[J[D00D0[J[D00<000000:f/eP2][=H01`2][=H00`000000[ZkG0:j^e`060:j^e`030000002^[mT0
[ZoI00L0[ZoI0P0000080:j`fP030000002_/]X0[k;J00P0[k;J00<000000;RifP2h^MX0102h^MX0
0`000000]kWK0;Nif`050;Nif`030000003oool0oooo04D0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`150?ooo`00B03oool00`000000oooo0?ooo`0^0?ooo`030000002]^n<0[K_S
00<0[K_S00<000000:jkh`2^^n<00`2^^n<3000000H0[[oW00<000000:k1i`2^`NL0102^`NL00`00
0000[l;X0:o2j0040:o2j0030000002``nP0/<?X00D0/<?X00<000000;75j@2aaNT0102aaNT00`00
0000//SZ0;;8jP040;;8jP030000002dbn/0]<_[00@0]<_[00<000000;K?k@2fcnd00`2fcnd00`00
0000^=C^0;SDkP030;SDkP030000002kf_00^m[`00@0^m[`00<000000;kRl@2nh_400P2nh_400`00
0000`Nca0<7/l@020<7/l@0500000033m^h0`oK^0<?fkP0000000`2ooN8400000080l_B]0P000002
06YK[`060000001ZFZh000000000001hI:l000001P1gHZh01@000000MV6]07IQ[@1fHJd0000000`0
OFF/00<0000007mUZP1oIJX00P1oIJX00`000000PFJ[085VZ`06085VZ`0500000021HjL0PF>W085S
Y`0000000P22I:P00`000000J00000000002001Wd`8000001`0]S>h2000000@0EYkd00@0000007b?
f`00000000001P27Um`2000000P0SicL0P00000909BQg@8000002`2IY=d00`000000[:OC0:bWd`06
0:bWd`030000002]Z]@0[J[D00D0[J[D00<000000:f/eP2][=H01`2][=H00`000000[ZkG0:j^e`06
0:j^e`8000002@2^[mT00`000000[[3J0:j`fP060:j`fP8000001P2_/]X2000000030;Vhf@2h^MX0
^;WJ00D0^;WJ00<000000;Nif`2g^M/0102g^M/00`000000oooo0?ooo`140?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0A@3oool004L0oooo00<000000?ooo`3oool0;`3oool00`00
0000[K_S0:fkh`030:fkh`030000002^^n<0[[_S00@0[[_S00<000000:nlh`0000000P0000020:jo
i`030000002^`NL0[/7W00@0[/7W00<000000:o2j02_`^P0102_`^P00`000000/<?X0;33j0050;33
j0030000002aaNT0/LGY00@0/LGY00<000000;;8jP2bb>X0102bb>X00`000000]<_[0;C;j`040;C;
j`030000002fcnd0]/o]00<0]/o]00<000000;SDkP2he>h00`2he>h00`000000^m[`0;_Jl0040;_J
l0030000002nh_40_^;a0080_^;a00<000000<7/l@31k?400P31k?401@000000`oK^0<?fkP33m^h0
000000<0_ogR100000030?;d[@090000001ZFjl0JU^_06YK[`000000JUZ^0000001ZFZh0000000H0
Mf:^00<0000007IQ[@1fHJd00P1fHJd00`000000OFF/07eU[00:07eU[0030000001oIJX0OfFZ00<0
OfFZ0P000006085VZ`8000000P21HjL01P000000PVBX089TZ022I:P0000006P0008000000P00Im<2
000000L0;Hc^0P0000000`1FW_@0000007b?f`0307b?f`0300000027Um`0QiOL00D0QiOL00<00000
08nLg02?W=`01`2?W=`2000000T0U:7M00<0000009VTg@2IY=d01`2IY=d00`000000ZZCA00000008
0:bWd`030000002]Z]@0[J[D00D0[J[D00<000000:f/eP2][=H01`2][=H00`000000[ZkG0:j^e`07
0:j^e`030000002^[mT0[ZoI00L0[ZoI00<000000:j`fP2^/=X01`2^/=X00`000000[k;J0:nbfP02
0:nbfP050000002i^=T0^KSI0;Vhf@0000001`2h^MX00`000000]kWK0;Nif`040;Nif`030000003o
ool0oooo0440oooo0P00000N0?ooo`030000003oool0oooo04D0oooo00160?ooo`030000003oool0
oooo02l0oooo00<000000:fkh`2]^n<0102]^n<00`000000[[_S0:jkh`030:jkh`030000002__><0
[kcS00<0[kcS0`0000050:k1i`030000002_`^P0[l;X00@0[l;X00<000000;33j02``nP01@2``nP0
0`000000/LGY0;75j@040;75j@030000002bb>X0//SZ00@0//SZ00<000000;C;j`2dbn/0102dbn/0
0`000000]/o]0;K?k@030;K?k@030000002he>h0^=C^00<0^=C^00<000000;_Jl02kf_00102kf_00
0`000000_^;a0;kRl@020;kRl@0300000031k?40`Nca0080`Nca00D000000<?fkP33m^h0`oK^0000
00030;omhP8000000P3_l/<01@000000l_B]0?;d[@3bm:d000000080JU^_00H0000006YJ[P1ZFZh0
000006YJ[P00000507MR[P030000001fHJd0MV6]00@0MV6]00<0000007eU[01mIJ`02@1mIJ`00`00
0000OfFZ07mUZP0507mUZP0300000021IZ/0PFJ[00<0PFJ[00<00000081RY`0000000P21HjL01000
0000PVBX089TZ022I:P20000000306P0000000000000008006OC0P00000702f<kP8000001@1lSm/0
0`000000QiOL08NGg00508NGg0030000002?W=`0SicL00P0SicL00<0000009BQg@2DXMd01`2DXMd2
000000H0VJCM00D000000:ZTd@2ZY=40ZZCA000000080:bWd`030000002]Z]@0[J[D00D0[J[D0P00
00080:f/eP030000002^[]L0[ZkG00L0[ZkG00<000000:j_f@2^[mT01`2^[mT00`000000[[3J0:j`
fP070:j`fP040000002_/]X00000000000D0^KSI00<000000;RifP2h^MX0102h^MX00`000000]kWK
0;Nif`050;Nif`030000003oool0oooo03l0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`150?ooo`00AP3oool00`000000oooo0?ooo`0_0?ooo`030000002]^n<0[K_S00<0[K_S00<0
00000:jkh`2^^n<0102^^n<00`000000[kcS0:nlh`040:nlh`040000002`_><0000000000080[/7W
00<000000:o2j02_`^P0102_`^P00`000000/<?X0;33j0050;33j0030000002aaNT0/LGY00@0/LGY
00<000000;;8jP2bb>X0102bb>X00`000000]<_[0;C;j`040;C;j`030000002fcnd0]/o]00<0]/o]
00<000000;SDkP2he>h00`2he>h00`000000^m[`0;_Jl0030;_Jl0800000102nh_400`000000`Nca
0<7/l@020<7/l@0500000033m^h0`oK^0<?fkP0000000`2ooN82000000<0ko;300D000000?;d[@3b
m:d0l_B]0000000206YK[`030000001ZFZh0JUZ^0080000000<0JUZ]0000001gHZh00P1gHZh00`00
0000MV6]07IQ[@0507IQ[@d00000201oIJX2000000<0PFJ[00<00000081RY`0000000`21HjL01000
0000PVBX089TZ022I:P20000000306P000000000000000<006OC0P00000602f<kP8000001@1lSm/2
000000H0QiOL0P00000908nLg08000002@2DXMd2000000@0VJCM00<000000:ZTd@2ZY=400P2ZY=40
0`000000[:OC0:bWd`060:bWd`030000002]Z]@0[J[D00H0[J[D00<000000:f/eP2][=H01P2][=H0
0`000000[ZkG0:j^e`070:j^e`030000002^[mT0[ZoI00L0[ZoI00<000000:j`fP2^/=X01`2^/=X0
0`000000^KSI0;Vhf@050;Vhf@030000002h^MX0^;WJ00D0^;WJ00<000000;Nif`2g^M/0102g^M/0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0A@3oool0
04D0oooo00<000000?ooo`3oool0<03oool00`000000[K_S0:fkh`030:fkh`030000002^^n<0[[_S
00@0[[_S00<000000:nlh`2__><00`2__><00`000000/;cS0;2lh`020;2lh`@00000102_`^P00`00
0000/<?X0;33j0050;33j0030000002aaNT0/LGY00@0/LGY00<000000;;8jP2bb>X0102bb>X00`00
0000]<_[0;C;j`040;C;j`030000002fcnd0]/o]00<0]/o]00<000000;SDkP2he>h00`2he>h00`00
0000^m[`0;_Jl0030;_Jl0030000002nh_40_^;a00<0_^;a00<000000<7/l@31k?400P31k?401@00
0000`oK^0<?fkP33m^h0000000<0_ogR0P0000030>ob``050000003bm:d0l_B]0?;d[@0000000`1Z
Fjl00`000000JUZ^06YJ[P020000000506YJ[@000000Mf:^07MR[P0000001`1fHJd2000000/0O6>/
0`00000807mUZP0400000021IZ/0PFJ[00000080P6:W00D00000085SY`21HjL0PF>W00000003089T
Z08000000P1X0002000000<006OC0P00000302f<kP040000001/Q=T0K8CI000000H0O8oK00<00000
08NGg027Um`01@27Um`00`000000SicL08nLg00808nLg08000002@2DXMd20000000309VTg@000000
ZZCA00D0ZZCA00<000000:bWd`2/Ym<01P2/Ym<00`000000[J[D0:fZe0060:fZe0030000002][=H0
[JcF00H0[JcF00<000000:j^e`2^[]L01`2^[]L00`000000[ZoI0:j_f@070:j_f@8000001P2^/=X0
0`000000^[SG0;Vhf@070;Vhf@030000002h^MX0^;WJ00@0^;WJ00<000000;Nif`2g^M/01@2g^M/0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0A03oool0
04@0oooo00<000000?ooo`3oool0<@3oool00`000000[K_S0:fkh`030:fkh`030000002^^n<0[[_S
00<0[[_S00<000000:nlh`2__><0102__><00`000000/;cS0;2lh`030;2lh`030000002a_N<0/KgS
00D000001P2``nP00`000000/LGY0;75j@040;75j@030000002bb>X0//SZ00@0//SZ00<000000;C;
j`2dbn/0102dbn/00`000000]/o]0;K?k@030;K?k@030000002he>h0^=C^00<0^=C^00<000000;_J
l02kf_000`2kf_000`000000_^;a0;kRl@030;kRl@0300000031k?40`Nca0080`Nca00D000000<?f
kP33m^h0`oK^000000030;omhP<000000`3_l/<01@000000l_B]0?;d[@3bm:d000000080JU^_00@0
000006YJ[P1ZFZh0JUZ^0P00000206YJ[@8000001`1fHJd010000000MEn/07EO[000000:07aS[004
0000001nHjT0OV>Y000000P0OfFZ0`000003081RY`0500000021HjL0PF>W085SY`0000000`22I:P2
00000080J0000P000004001Wd`80000000<0;Hc^0000001/Q=T00P1/Q=T00`000000O8oK07b?f`04
07b?f`0300000027Um`0QiOL00D0QiOL0P00000:08nLg0030000002DXMd0U:7M00P0U:7M00<00000
0:ZTd@2ZY=401P2ZY=400`000000[:OC0:bWd`060:bWd`030000002]Z]@0[J[D00H0[J[D00<00000
0:f/eP2][=H01P2][=H2000000P0[ZkG00<000000:j_f@2^[mT0202^[mT010000000[[3J0:j`fP2^
/=X200000080^[SG00<000000;Vhf@2i^=T01P2i^=T00`000000^;WJ0;RifP040;RifP030000002g
^M/0]kWK00D0]kWK00<000000?ooo`3oool0>@3oool2000002@0oooo00<000000?ooo`3oool0A03o
ool004<0oooo00<000000?ooo`3oool0<@3oool00`000000[K_S0:fkh`040:fkh`030000002^^n<0
[[_S00<0[[_S00<000000:nlh`2__><0102__><00`000000/;cS0;2lh`020;2lh`030000002a_N<0
/KgS00@0/KgS00<000000;:nh`0000000P0000020;33j0030000002aaNT0/LGY00@0/LGY00<00000
0;;8jP2bb>X0102bb>X00`000000]<_[0;C;j`040;C;j`030000002fcnd0]/o]00<0]/o]00<00000
0;SDkP2he>h00`2he>h00`000000^m[`0;_Jl0030;_Jl0030000002nh_40_^;a00<0_^;a00<00000
0<7/l@31k?400P31k?401@000000`oK^0<?fkP33m^h0000000<0_ogR0`0000040>ob``050000003b
m:d0l_B]0?;d[@0000000P1ZFjl01@000000JUZ^06YJ[P1ZFZh0000000<0JUZ]00<0000007IQ[@1f
HJd01@1fHJd01@000000MEn/07EO[01eGj`0000000X0O6>/00@0000007iSZ@1nHjT0OV>Y0P000008
07mUZP0300000020HZL0P6:W0080P6:W00@00000085SY`21HjL000001022I:P300000080J0000P00
0004001Wd`030000001/Q=T0K8CI00<0K8CI0P00000507b?f`8000001`27Um`00`000000SicL08nL
g00808nLg08000001`2DXMd00`000000ZJ7>000000080:ZTd@030000002/Ym<0[:OC00H0[:OC00<0
00000:fZe02]Z]@01P2]Z]@00`000000[JcF0:f/eP070:f/eP030000002^[]L0[ZkG00H0[ZkG00<0
00000:j_f@2^[mT0202^[mT00`000000[[3J000000050;Zhe`030000002i^=T0^KSI00D0^KSI00<0
00000;RifP2h^MX01@2h^MX00`000000]kWK0;Nif`040;Nif`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool08`3oool2000004H0oooo00120?ooo`030000003oool0oooo0380oooo00<00000
0:fkh`2]^n<00`2]^n<00`000000[[_S0:jkh`040:jkh`030000002__><0[kcS00<0[kcS00<00000
0;2lh`2`_><00`2`_><00`000000/KgS0;6mh`030;6mh`030000002b_^<0/[kS00<0/[kS10000004
0;75j@030000002bb>X0//SZ00@0//SZ00<000000;C;j`2dbn/0102dbn/00`000000]/o]0;K?k@04
0;K?k@030000002he>h0^=C^0080^=C^00<000000;_Jl02kf_000`2kf_000`000000_^;a0;kRl@03
0;kRl@0300000031k?40`Nca0080`Nca00D000000<?fkP33m^h0`oK^000000030;omhP040000003W
k=40incA000000<0ko;300<000000?;d[@3bm:d00P3bm:d010000000JU^_06YK[`00000306YJ[P06
0000001ZFZd0JUZ]06YJ[@1[FJ`000001@1fHJd00`000000MEn/07EO[00207EO[0030000001lHj`0
O6>/00T0O6>/00<0000007iSZ@1nHjT00P1nHjT00`000000OfFZ07mUZP0507mUZP8000000`20HZL0
1@000000PF>W085SY`21HjL0000000@0PVBX0`00000206P0008000000`00Im<2000000H0K8CI00<0
000007b?f`1lSm/0101lSm/00`000000QiOL08NGg00508NGg08000002P2?W=`00`000000U:7M09BQ
g@0409BQg@040000002YXLh0ZJ7>000000P0ZZCA00<000000:bWd`2/Ym<01P2/Ym<00`000000[J[D
0:fZe0060:fZe0030000002][=H0[JcF00L0[JcF00<000000:j^e`2^[]L01P2^[]L00`000000[ZoI
0:j_f@080:j_f@030000002j^=L0^[SG00@0^[SG00<000000;Vhf@2i^=T01P2i^=T00`000000^;WJ
0;RifP040;RifP030000002g^M/0]kWK00D0]kWK00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0000004H0oooo00110?ooo`030000003oool0oooo03<0oooo00<0
00000:fkh`2]^n<00`2]^n<00`000000[[_S0:jkh`030:jkh`030000002__><0[kcS00@0[kcS00<0
00000;2lh`2`_><00`2`_><00`000000/KgS0;6mh`030;6mh`030000002b_^<0/[kS00@0/[kS00<0
00000;>oh`2c_n<01@0000050;;8jP030000002dbn/0]<_[00@0]<_[00<000000;K?k@2fcnd0102f
cnd00`000000^=C^0;SDkP020;SDkP030000002kf_00^m[`00<0^m[`00<000000;kRl@2nh_400`2n
h_400`000000`Nca0<7/l@020<7/l@0500000033m^h0`oK^0<?fkP0000000P2ooN82000000<0incA
00D000000>ob``3_l/<0ko;3000000030?;d[@040000001ZFjl0JU^_000000@0JUZ^00H0000006YJ
[@1ZFZd0JUZ]06]I[000000407IQ[@030000001eGj`0MEn/00@0MEn/00<0000007aS[01lHj`0201l
Hj`00`000000OV>Y07iSZ@0307iSZ@8000001@1oIJX2000000@0P6:W00D00000085SY`21HjL0PF>W
00000004089TZ0<000000`1X000300000080EGCE00<0000006b4f@1/Q=T0101/Q=T00`000000O8oK
07b?f`0407b?f`0300000027Um`0QiOL00H0QiOL00<0000008nLg02?W=`0202?W=`2000000<0U:7M
00<000000:VQcP2YXLh00P2YXLh00`000000ZZCA0:ZTd@060:ZTd@030000002/Ym<0[:OC00H0[:OC
00<000000:fZe02]Z]@01P2]Z]@00`000000[JcF0:f/eP070:f/eP030000002^[]L0[ZkG00H0[ZkG
0P0000070:j_f@030000002j]mH0^[SG00H0^[SG00<000000;Vhf@2i^=T01@2i^=T00`000000^;WJ
0;RifP050;RifP030000002g^M/0]kWK00@0]kWK00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo04@0oooo00100?ooo`030000003oool0oooo03<0oooo00<0
00000:fkh`2]^n<0102]^n<00`000000[[_S0:jkh`030:jkh`030000002__><0[kcS00@0[kcS00<0
00000;2lh`2`_><00`2`_><00`000000/KgS0;6mh`030;6mh`030000002b_^<0/[kS00<0/[kS00<0
00000;>oh`2c_n<0102c_n<010000000]/7S0000000000020;;8jP030000002dbn/0]<_[00@0]<_[
00<000000;K?k@2fcnd0102fcnd00`000000^=C^0;SDkP020;SDkP030000002kf_00^m[`00<0^m[`
00<000000;kRl@2nh_400`2nh_400`000000`Nca0<7/l@020<7/l@0400000033m^h0`oK^0<?fkP@0
000000<0g^?H0000003Wk=400P3Wk=401@000000ko;30>ob``3_l/<0000000<0l_B]00@0000006YK
[`1ZFjl00000101ZFZh010000000JUZ]06YJ[@00000206]I[0040000001fHJd0MV6]000000L0MEn/
3000000707iSZ@8000000`1oIJX00`000000OV6W00000004081RY`0500000021HjL0PF>W085SY`00
00001022I:P4000000<0J00000D0000005Ede@1EM=D0EGCE0000000606b4f@030000001lSm/0O8oK
00@0O8oK00<0000008NGg027Um`01P27Um`00`000000SicL08nLg00908nLg080000000<0U:7M0000
002YXLh0102YXLh00`000000ZZCA0:ZTd@060:ZTd@030000002/Ym<0[:OC00H0[:OC00<000000:fZ
e02]Z]@01P2]Z]@2000000P0[JcF00<000000:j^e`2^[]L01`2^[]L00`000000[ZoI0:j_f@030:j_
f@040000002j]mH0^[OF000000L0^[SG00<000000;Vhf@2i^=T01@2i^=T00`000000^;WJ0;RifP04
0;RifP030000002g^M/0]kWK00D0]kWK00<000000?ooo`3oool0<P3oool2000002T0oooo00<00000
0?ooo`3oool0203oool2000003X0oooo00100?ooo`030000003oool0oooo03<0oooo00<000000:fk
h`2]^n<00`2]^n<00`000000[[_S0:jkh`040:jkh`030000002__><0[kcS00<0[kcS00<000000;2l
h`2`_><00`2`_><00`000000/KgS0;6mh`030;6mh`030000002b_^<0/[kS00@0/[kS00<000000;>o
h`2c_n<00`2c_n<00`000000]/7S0;K1h`020;K1h`@00000102dbn/00`000000]/o]0;K?k@040;K?
k@030000002he>h0^=C^0080^=C^00<000000;_Jl02kf_000`2kf_000`000000_^;a0;kRl@030;kR
l@0300000031k?40`Nca0080`Nca00<000000<?fkP33m^h00`0000030=kSf0050000003Wk=40incA
0>O/d@000000103_l/<00`000000l_B]0?;d[@0200000080JU^_00@0000006YJ[P1ZFZh0JUZ^0P00
000206YJ[@060000001[FJ`0JeV/0000001fHJd000001`1eGj`2000000X0Nf:[0`00000707iSZ@04
0000001oIJX0OfFZ00000080OV6W00<00000081RY`20HZL00P20HZL01@000000PF>W085SY`21HjL0
000000<0PVBX00<000000<Q;400000000P000000101X00000000035Kc@00000305Ede@030000001/
Q=T0K8CI00@0K8CI00<0000007b?f`1lSm/0101lSm/2000000L0QiOL0P00000;08nLg0030000002Y
XLh0ZJ7>00D0ZJ7>00<000000:ZTd@2ZY=401P2ZY=400`000000[:OC0:bWd`060:bWd`800000202]
Z]@00`000000[JcF0:f/eP060:f/eP030000002^[]L0[ZkG00L0[ZkG00D000000:j_f@2^[mT0[ZoI
000000040;ZgeP030000002j^=L0^[SG00@0^[SG00<000000;Vhf@2i^=T01@2i^=T00`000000^;WJ
0;RifP050;RifP030000002g^M/0]kWK00D0]kWK00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000>@3oool003l0oooo
00<000000?ooo`3oool0=03oool00`000000[K_S0:fkh`030:fkh`030000002^^n<0[[_S00<0[[_S
00<000000:nlh`2__><0102__><00`000000/;cS0;2lh`030;2lh`030000002a_N<0/KgS00<0/KgS
00<000000;:nh`2b_^<0102b_^<00`000000/koS0;>oh`030;>oh`030000002f`N<0]/7S00<0]/7S
00<000000;S3hP2h`n801P0000040;K?k@030000002he>h0^=C^0080^=C^00<000000;_Jl02kf_00
0`2kf_000`000000_^;a0;kRl@030;kRl@0300000031k?40`Nca0080`Nca100000000`3Eg=`00000
0=kSf0030=kSf0050000003Wk=40incA0>O/d@0000000`3_l/<01@000000l_B]0?;d[@000000ilFc
0080000000<0JU^_0000001ZFZh00P1ZFZh200000080JUZ]00D0000006]I[01[FJ`0JeV/00000007
07EO[0040000001dGZ/0M5j[000000X0Nf:[00<0000007eRZ@0000001`1nHjT3000000<0OV6W00D0
0000081RY`20HZL0P6:W00000003085SY`0300000022I:P0PVBX0080PVBX00D000000<Q;40000000
ZQd000000003035Kc@050000001EM=D0EGCE05Ede@0000001P1/Q=T00`000000O8oK07b?f`0507b?
f`0300000027Um`0QiOL00H0QiOL00<0000008nLg02?W=`01`2?W=`00`000000Yig<000000070:VQ
cP030000002ZY=40ZZCA00H0ZZCA00<000000:bWd`2/Ym<01`2/Ym<00`000000[J[D0:fZe0060:fZ
e0030000002][=H0[JcF00H0[JcF00<000000:j^e`2^[]L01`2^[]L00`000000[ZoI000000050;Zg
eP030000002j^=L0^[SG00D0^[SG00<000000;Vhf@2i^=T01@2i^=T00`000000^;WJ0;RifP050;Ri
fP030000002g^M/0]kWK00@0]kWK00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000>@3oool003h0oooo00<000000?oo
o`3oool0=03oool00`000000[K_S0:fkh`040:fkh`030000002^^n<0[[_S00<0[[_S00<000000:nl
h`2__><0102__><00`000000/;cS0;2lh`030;2lh`030000002a_N<0/KgS00<0/KgS00<000000;:n
h`2b_^<00`2b_^<00`000000/koS0;>oh`040;>oh`030000002f`N<0]/7S0080]/7S00<000000;S3
hP2h`n80102h`n800`000000^lGR0;_5hP0K000000<0eMcL00<000000=kSf03NhmP00`3NhmP01@00
0000incA0>O/d@3Wk=40000000<0ko;300D000000?;d[@3bm:d000000>O5/`03000000@0JUZ^0P00
000206YJ[@050000001[FJ`0JeV/06]I[00000001@1eGj`2000000<0M5j[00<0000007]RZ`1kHZ/0
201kHZ/00`000000OF:Y07eRZ@02000000L0OV>Y00D0000007iQY`1nHJL0OV6W00000004081RY`05
00000021HjL0PF>W085SY`0000001022I:P300000003000d^@0aFld0<E_=0080<E_=00D0000005Ed
e@1EM=D0EGCE0000000606b4f@030000001lSm/0O8oK00D0O8oK00<0000008NGg027Um`01P27Um`2
000000L0SicL00@000000:NMc02WWL`000001`2YXLh00`000000ZZCA0:ZTd@060:ZTd@030000002/
Ym<0[:OC00L0[:OC00<000000:fZe02]Z]@01P2]Z]@00`000000[JcF0:f/eP060:f/eP800000202^
[]L00`000000^[OF0;ZgeP050;ZgeP030000002j^=L0^[SG00@0^[SG00<000000;Vhf@2i^=T01P2i
^=T00`000000^;WJ0;RifP040;RifP030000002g^M/0]kWK00D0]kWK00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000
>@3oool003d0oooo00<000000?ooo`3oool0=@3oool00`000000[K_S0:fkh`030:fkh`030000002^
^n<0[[_S00@0[[_S00<000000:nlh`2__><00`2__><00`000000/;cS0;2lh`030;2lh`030000002a
_N<0/KgS00@0/KgS00<000000;:nh`2b_^<00`2b_^<00`000000/koS0;>oh`030;>oh`030000002f
`N<0]/7S00<0]/7S00<000000;S3hP2h`n800`2h`n800`000000^lGR0;_5hP040;_5hP030000002n
b>80_/SR0080_/SR00<000000<;;h@32bn400`32bn400`000000am3P0<O@h0030<O@h0030000003>
eMl0c]GO0080c]GO00<000000=GLg03Eg=`00P3Eg=`00`000000g^?H0=kSf0020=kSf0050000003W
k=40incA0>O/d@000000103_l/<00`000000l_B]000000020>O5/`030000001JCj`0000000<0JUZ^
00D0000006YJ[@000000JUZ]0000000306]I[0030000001[F:/0000000<0MEn/00<0000007ANZ`1d
GZ/00`1dGZ/00`000000Nf:[07]RZ`0807]RZ`030000001mHZT0OF:Y0080OF:Y00<0000007iSZ@1n
HjT0101nHjT2000000<0OV6W00<00000081RY`20HZL00P20HZL01@000000PF>W085SY`21HjL00000
00<0PVBX00D000000000S@0008d003Bi00000003035Kc@030000001EM=D0EGCE0080EGCE00<00000
06b4f@1/Q=T0101/Q=T00`000000O8oK07b?f`0507b?f`8000002027Um`00`000000SicL08nLg003
08nLg0030000002WWL`0Yig<0080Yig<00<000000:VQcP2YXLh01@2YXLh00`000000ZZCA0:ZTd@06
0:ZTd@030000002/Ym<0[:OC00L0[:OC00<000000:fZe02]Z]@01P2]Z]@00`000000[JcF0:f/eP07
0:f/eP030000002^[]L0[ZkG00@0[ZkG00<000000;^fe00000001P2j]mH00`000000^[SG0;Zhe`05
0;Zhe`030000002i^=T0^KSI00D0^KSI00<000000;RifP2h^MX01@2h^MX00`000000]kWK0;Nif`04
0;Nif`030000003oool0oooo02/0oooo0P00000_0?ooo`030000003oool0oooo00H0oooo00@00000
0?ooo`3oool00000>@3oool003`0oooo00<000000?ooo`3oool0=P3oool00`000000[K_S0:fkh`03
0:fkh`030000002^^n<0[[_S00<0[[_S00<000000:nlh`2__><0102__><00`000000/;cS0;2lh`03
0;2lh`030000002a_N<0/KgS00<0/KgS00<000000;:nh`2b_^<0102b_^<00`000000/koS0;>oh`03
0;>oh`030000002f`N<0]/7S00<0]/7S00<000000;S3hP2h`n800`2h`n800`000000^lGR0;_5hP03
0;_5hP030000002nb>80_/SR0080_/SR00<000000<;;h@32bn400`32bn400`000000am3P0<O@h003
0<O@h0030000003>eMl0c]GO0080c]GO00<000000=GLg03Eg=`00`3Eg=`00`000000g^?H0=kSf002
0=kSf0050000003Wk=40incA0>O/d@0000000`3_l/<00`000000l_B]000000030>O5/`040000001J
Cj`0000000000080JUZ^00D0000006YJ[@000000JUZ]0000000306]I[0030000001[F:/000000080
MEn/00<0000007ANZ`1dGZ/01@1dGZ/00`000000Nf:[07]RZ`0807]RZ`030000001mHZT0OF:Y0080
OF:Y0P00000407iSZ@800000101nHJL00`000000P6:W081RY`02081RY`0500000021HjL0PF>W085S
Y`0000000P22I:P2000000040000S@00000003Bi000000<0<E_=00<0000005Ede@1EM=D00P1EM=D0
0`000000K8CI06b4f@0406b4f@8000001`1lSm/00`000000QiOL08NGg00608NGg0050000002?W=`0
SicL08nLg00000001P2WWL`00`000000ZJ7>0:VQcP050:VQcP030000002ZY=40ZZCA00H0ZZCA00<0
00000:bWd`2/Ym<01`2/Ym<00`000000[J[D0:fZe0060:fZe0030000002][=H0[JcF00L0[JcF00@0
00000:j^e`2^[]L0[ZkG0P0000020;^fe0030000002j]mH0^[OF00D0^[OF00<000000;Zhe`2j^=L0
1@2j^=L00`000000^KSI0;Vhf@050;Vhf@030000002h^MX0^;WJ00@0^;WJ00<000000;Nif`2g^M/0
1@2g^M/00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
1P3oool010000000oooo0?ooo`00000i0?ooo`00>`3oool00`000000oooo0?ooo`0f0?ooo`030000
002]^n<0[K_S00@0[K_S00<000000:jkh`2^^n<00`2^^n<00`000000[kcS0:nlh`040:nlh`030000
002`_><0/;cS00<0/;cS00<000000;6mh`2a_N<00`2a_N<00`000000/[kS0;:nh`040;:nh`030000
002c_n<0/koS00<0/koS00<000000;K1h`2f`N<00P2f`N<00`000000^<?R0;S3hP040;S3hP030000
002kaN80^lGR00<0^lGR00<000000;k8hP2nb>800P2nb>800`000000`/_Q0<;;h@030<;;h@030000
0037d>00am3P00<0am3P00<000000<kEg`3>eMl00P3>eMl00`000000eMcL0=GLg0020=GLg0030000
003NhmP0g^?H00<0g^?H00D000000>O/d@3Wk=40incA000000030>ob``800000103WaK<010000000
FTn/00000000000206YJ[P8000000P1ZFZd01@000000JeV/06]I[01[FJ`000000080JeR[0P000008
07ANZ``000001P1mHZT200000080OV>Y00<0000007ePYP000000101nHJL00`000000P6:W081RY`02
081RY`0800000021HjL0PF>W00000022I:P00000081OX`0000020000S@0300000000=;T0000000<0
<E_=00<0000005Ede@1EM=D00P1EM=D00`000000K8CI06b4f@0506b4f@030000001lSm/0O8oK00D0
O8oK00<0000008NGg027Um`01P27Um`20000000308nLg0000000Yig<00D0Yig<00<000000:VQcP2Y
XLh01P2YXLh00`000000ZZCA0:ZTd@060:ZTd@030000002/Ym<0[:OC00L0[:OC00<000000:fZe02]
Z]@01P2]Z]@00`000000[JcF0:f/eP070:f/eP030000002^[]L0000000D0^kKD00<000000;ZgeP2j
]mH01@2j]mH00`000000^[SG0;Zhe`040;Zhe`030000002i^=T0^KSI00D0^KSI00<000000;RifP2h
^MX01@2h^MX00`000000]kWK0;Nif`050;Nif`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`060?ooo`800000>P3oool003X0oooo00<000000?ooo`3oool0
=`3oool00`000000[K_S0:fkh`030:fkh`030000002^^n<0[[_S00@0[[_S00<000000:nlh`2__><0
0`2__><00`000000/;cS0;2lh`030;2lh`030000002a_N<0/KgS00@0/KgS00<000000;:nh`2b_^<0
0`2b_^<00`000000/koS0;>oh`030;>oh`030000002f`N<0]/7S00<0]/7S00<000000;S3hP2h`n80
0`2h`n800`000000^lGR0;_5hP040;_5hP030000002nb>80_/SR0080_/SR00<000000<;;h@32bn40
0`32bn400`000000am3P0<O@h0030<O@h0030000003>eMl0c]GO0080c]GO00<000000=GLg03Eg=`0
0P3Eg=`00`000000g^?H0=kSf0020=kSf0050000003Wk=40incA0>O/d@000000103_l/<2000000@0
ilFc00@0000005Y?[0000000Fdn[0P0000001@1ZFZd0000006YJ[@1ZFZd0000000<0JeV/00@00000
06]HZ`1[F:/00000201dGZ/2000000X0NF6Z0P00000707eRZ@060000001nHjT0OV>Y0000001mH:H0
00000`1nHJL00`000000P6:W081RY`02081RY`0400000021HjL0PF>W085SY`8000000P20Gj<00`00
0000002=00000002000d^@050000000aFld0<E_=035Kc@000000101EM=D00`000000K8CI06b4f@05
06b4f@030000001lSm/0O8oK00D0O8oK0P00000808NGg0030000002WWL`0Yig<00H0Yig<00<00000
0:VQcP2YXLh01P2YXLh00`000000ZZCA0:ZTd@060:ZTd@030000002/Ym<0[:OC00L0[:OC00<00000
0:fZe02]Z]@01P2]Z]@2000000P0[JcF00<000000;^fe02k]]@0102k]]@00`000000^[OF0;ZgeP05
0;ZgeP030000002j^=L0^[SG00D0^[SG00<000000;Vhf@2i^=T01@2i^=T00`000000^;WJ0;RifP05
0;RifP030000002g^M/0]kWK00@0]kWK00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo0480oooo000i0?ooo`030000003oool0oooo03P0oooo00<000000:fk
h`2]^n<00`2]^n<00`000000[[_S0:jkh`030:jkh`030000002__><0[kcS00@0[kcS00<000000;2l
h`2`_><00`2`_><00`000000/KgS0;6mh`030;6mh`030000002b_^<0/[kS00@0/[kS00<000000;>o
h`2c_n<00`2c_n<00`000000]/7S0;K1h`030;K1h`030000002h`n80^<?R00<0^<?R00<000000;_5
hP2kaN800`2kaN800`000000_/SR0;k8hP020;k8hP0300000032bn40`/_Q00<0`/_Q00<000000<O@
h037d>000`37d>000`000000c]GO0<kEg`020<kEg`030000003Eg=`0eMcL00<0eMcL00<000000=kS
f03NhmP00P3NhmP01@000000incA0>O/d@3Wk=40000000<0ko;30P0000050>O5/`030000001JCj`0
00000080Fdn[00D0000006YJ[@000000JUZ]0000000306]I[0050000001[F:/0JeR[06]HZ`000000
1`1dGZ/010000000M5fZ07AMZP00000907UQZP040000001kHJP00000000000H0OF:Y0`00000207eP
YP050000001nHJL0OV6W07iQY`0000001020HZL01@000000PF>W085SY`21HjL000000080P5nS00H0
00000000S@0008d00000000d^@000004035Kc@030000001EM=D0EGCE0080EGCE00<0000006b4f@1/
Q=T01@1/Q=T00`000000O8oK07b?f`0607b?f`0300000027Um`0QiOL00@0QiOL00<000000:BHb@00
0000202WWL`00`000000ZJ7>0:VQcP060:VQcP030000002ZY=40ZZCA00H0ZZCA00<000000:bWd`2/
Ym<01`2/Ym<00`000000[J[D0:fZe0070:fZe0030000002][=H0[JcF00@0[JcF00<000000;bddP00
00001P2k]]@00`000000^[OF0;ZgeP050;ZgeP030000002j^=L0^[SG00@0^[SG00<000000;Vhf@2i
^=T01P2i^=T00`000000^;WJ0;RifP040;RifP030000002g^M/0]kWK00D0]kWK00<000000?ooo`3o
ool08`3oool2000003D0oooo00<000000?ooo`3oool0@P3oool003T0oooo00<000000?ooo`3oool0
>03oool00`000000[K_S0:fkh`030:fkh`030000002^^n<0[[_S00<0[[_S00<000000:nlh`2__><0
102__><00`000000/;cS0;2lh`030;2lh`030000002a_N<0/KgS00<0/KgS00<000000;:nh`2b_^<0
102b_^<00`000000/koS0;>oh`030;>oh`030000002f`N<0]/7S00<0]/7S00<000000;S3hP2h`n80
0`2h`n800`000000^lGR0;_5hP030;_5hP030000002nb>80_/SR0080_/SR00<000000<;;h@32bn40
0`32bn400`000000am3P0<O@h0030<O@h0030000003>eMl0c]GO0080c]GO00<000000=GLg03Eg=`0
0P3Eg=`00`000000g^?H0=kSf0030=kSf0050000003Wk=40incA0>O/d@0000000`3_l/<00`000000
ilFc0>O5/`040>O5/`030000001JCj`000000080Fdn[0`0000000`1ZFZd0000006]I[00206]I[006
0000001[F:/0JeR[0000001[EjX000001@1dGZ/01@000000M5fZ07AMZP1dGJX0000000T0NF6Z00D0
000007]QZ01kHJP0Nf6X0000000707eRZ@040000001mH:H0OF2V000000@0OV6W00<00000081RY`20
HZL00P20HZL010000000PF>W085SY`000003081OX`030000000008d00000008003Bi00<00000035K
c@0aFld00P0aFld00`000000EGCE05Ede@0205Ede@030000001/Q=T0K8CI00D0K8CI00<0000007b?
f`1lSm/01P1lSm/00`000000QiOL08NGg00308NGg0040000002TV<T0Y9S9000000P0Yig<00<00000
0:VQcP2YXLh01P2YXLh00`000000ZZCA0:ZTd@060:ZTd@030000002/Ym<0[:OC00L0[:OC00<00000
0:fZe02]Z]@01`2]Z]@010000000[JcF0:f/eP2][=H200000080_;CB00<000000;^fe02k]]@0102k
]]@00`000000^[OF0;ZgeP050;ZgeP030000002j^=L0^[SG00D0^[SG00<000000;Vhf@2i^=T01@2i
^=T00`000000^;WJ0;RifP050;RifP030000002g^M/0]kWK00@0]kWK00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0480oooo000h0?ooo`030000003oool0
oooo03P0oooo00<000000:fkh`2]^n<0102]^n<00`000000[[_S0:jkh`030:jkh`030000002__><0
[kcS00<0[kcS00<000000;2lh`2`_><0102`_><00`000000/KgS0;6mh`030;6mh`030000002b_^<0
/[kS00<0/[kS00<000000;>oh`2c_n<00`2c_n<00`000000]/7S0;K1h`030;K1h`030000002h`n80
^<?R00<0^<?R00<000000;_5hP2kaN80102kaN800`000000_/SR0;k8hP020;k8hP0300000032bn40
`/_Q00<0`/_Q00<000000<O@h037d>000`37d>000`000000c]GO0<kEg`020<kEg`030000003Eg=`0
eMcL0080eMcL00<000000=kSf03NhmP00P3NhmP00`000000incA0>O/d@020>O/d@030000003_l/<0
ko;3008000001P3WaK<00`000000FTn/0000000205]?Z`<0000000<0JUZ]0000001[FJ`00P1[FJ`0
1P000000JeR[06]HZ`000000JeNZ000000@0M5j[00<0000007AMZP1dGJX00P1dGJX00`000000NF6Z
07UQZP0807UQZP050000001kHJP0Nf6X07]QZ00000001P1mHZT200000080OF2V00D0000007iQY`1n
HJL0OV6W00000005081RY`0400000021HjL0000000000080P5nS00@000000000S@0008d000000P00
=;T00`000000<E_=035Kc@02035Kc@030000001EM=D0EGCE0080EGCE0P00000606b4f@030000001l
Sm/0O8oK00H0O8oK0P00000208NGg0030000002TV<T0Y9S90080Y9S900<000000:NMc02WWL`01P2W
WL`00`000000ZJ7>0:VQcP060:VQcP030000002ZY=40ZZCA00H0ZZCA00<000000:bWd`2/Ym<01`2/
Ym<00`000000[J[D0:fZe0070:fZe0030000002][=H0000000D0_;CB00<000000;^fe02k]]@0102k
]]@00`000000^[OF0;ZgeP050;ZgeP030000002j^=L0^[SG00D0^[SG00<000000;Vhf@2i^=T01@2i
^=T00`000000^;WJ0;RifP040;RifP030000002g^M/0]kWK00D0]kWK00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0480oooo000g0?ooo`030000003oool0
oooo03T0oooo00<000000:fkh`2]^n<00`2]^n<00`000000[[_S0:jkh`040:jkh`030000002__><0
[kcS00<0[kcS00<000000;2lh`2`_><00`2`_><00`000000/KgS0;6mh`030;6mh`030000002b_^<0
/[kS00@0/[kS00<000000;>oh`2c_n<00`2c_n<00`000000]/7S0;K1h`030;K1h`030000002h`n80
^<?R00<0^<?R00<000000;_5hP2kaN800`2kaN800`000000_/SR0;k8hP030;k8hP0300000032bn40
`/_Q0080`/_Q00<000000<O@h037d>000`37d>000`000000c]GO0<kEg`020<kEg`030000003Eg=`0
eMcL00<0eMcL00<000000=kSf03NhmP00P3NhmP01@000000incA0>O/d@3Wk=4000000080ko;300<0
00000=k2_00000001P3WaK<00`000000FTn/0000000205]?Z`050000001MCjX0000006YJ[@000000
0`1[FJ`010000000JeR[06]HZ`00000206]GZP040000001dGZ/0M5j[000000H0M5fZ00<0000007UQ
ZP1iHJX01`1iHJX00`000000Nf6X07]QZ00207]QZ0800000101mHZT2000000<0OF2V00D0000007iQ
Y`1nHJL0OV6W00000004081RY`0400000021HjL00000000000<0P5nS00H000000000S@0008d00000
000d^@000004035Kc@030000001EM=D0EGCE00@0EGCE00<0000006b4f@1/Q=T0101/Q=T00`000000
O8oK07b?f`0707b?f`0300000027Um`0000000@0Y9S900<000000:NMc02WWL`01`2WWL`00`000000
ZJ7>0:VQcP050:VQcP030000002ZY=40ZZCA00L0ZZCA00<000000:bWd`2/Ym<01`2/Ym<00`000000
[J[D0:fZe0070:fZe0030000002l]=80_;CB00@0_;CB00<000000;^fe02k]]@01@2k]]@00`000000
^[OF0;ZgeP050;ZgeP030000002j^=L0^[SG00@0^[SG00<000000;Vhf@2i^=T01@2i^=T00`000000
^;WJ0;RifP050;RifP030000002g^M/0]kWK00D0]kWK00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo0480oooo000f0?ooo`030000003oool0oooo03X0oooo
00<000000:fkh`2]^n<00`2]^n<00`000000[[_S0:jkh`030:jkh`030000002__><0[kcS00@0[kcS
00<000000;2lh`2`_><00`2`_><00`000000/KgS0;6mh`030;6mh`030000002b_^<0/[kS00@0/[kS
00<000000;>oh`2c_n<00`2c_n<00`000000]/7S0;K1h`030;K1h`030000002h`n80^<?R00<0^<?R
00<000000;_5hP2kaN800`2kaN800`000000_/SR0;k8hP020;k8hP0300000032bn40`/_Q00<0`/_Q
00<000000<O@h037d>000`37d>000`000000c]GO0<kEg`020<kEg`030000003Eg=`0eMcL00<0eMcL
00D000000=kSf03NhmP0g^?H000000040>O/d@030000003_l/<000000080g/:l00<000000>O5/`3W
aK<0103WaK<00`000000FTn/0000000205]?Z`040000001MCjX00000000000<0JeV/00D0000006]H
Z`1[F:/0JeR[0000000206]GZP030000001dGZ/0000000L0M5fZ1@00000507UQZP030000001kHJP0
Nf6X00@0Nf6X00L0000007eRZ@1mHZT0OF:Y0000001lGjH000000080OF2V00<0000007iQY`1nHJL0
0P1nHJL00`000000P6:W081RY`02081RY`80000000D0OejS00000020Gj<0P5nS000000020000S@04
00000000=;T003Bi000000@0<E_=00<0000005Ede@1EM=D0101EM=D00`000000K8CI06b4f@0406b4
f@030000001lSm/0O8oK00L0O8oK00<000000:BHb@2TV<T0102TV<T00`000000Yig<0:NMc0070:NM
c0030000002YXLh0ZJ7>00D0ZJ7>00<000000:ZTd@2ZY=401`2ZY=400`000000[:OC0:bWd`070:bW
d`030000002]Z]@0[J[D00D0[J[D00<000000;fcd00000001P2l]=800`000000^kKD0;^fe0040;^f
e0030000002j]mH0^[OF00D0^[OF00<000000;Zhe`2j^=L01@2j^=L00`000000^KSI0;Vhf@050;Vh
f@030000002h^MX0^;WJ00D0^;WJ00<000000;Nif`2g^M/0102g^M/00`000000oooo0?ooo`0L0?oo
o`800000>@3oool00`000000oooo000000130?ooo`00=@3oool00`000000oooo0?ooo`0j0?ooo`03
0000002]^n<0[K_S00@0[K_S00<000000:jkh`2^^n<00`2^^n<00`000000[kcS0:nlh`030:nlh`03
0000002`_><0/;cS00@0/;cS00<000000;6mh`2a_N<00`2a_N<00`000000/[kS0;:nh`030;:nh`03
0000002c_n<0/koS00<0/koS00<000000;K1h`2f`N<00`2f`N<00`000000^<?R0;S3hP030;S3hP03
0000002kaN80^lGR00@0^lGR00<000000;k8hP2nb>800P2nb>800`000000`/_Q0<;;h@030<;;h@03
00000037d>00am3P00<0am3P00<000000<kEg`3>eMl00P3>eMl00`000000eMcL0=GLg0020=GLg003
0000003NhmP0g^?H0080g^?H00<000000>O/d@3Wk=400P3Wk=42000000<0g/:l00<000000>O5/`3W
aK<0103WaK<00`000000FTn/0000000205]?Z`040000001MCjX00000000000<0JeV/00@0000006]H
Z`1[F:/00000101[EjX00`000000M5fZ07AMZP0507AMZP800000101hGjT6000000L0Nf6X00@00000
07eRZ@1mHZT000000P1lGjH010000000OF2V07ePYP00000407iQY`0300000020HZL0P6:W0080P6:W
00<0000007mNX`0000000P20Gj<01@000000002=0000S@0008d00000008003Bi00<00000035Kc@0a
Fld00P0aFld00`000000EGCE05Ede@0405Ede@030000001/Q=T0K8CI00@0K8CI0P00000607b?f`03
0000002PT/D0000000H0Y9S900<000000:NMc02WWL`01`2WWL`00`000000ZJ7>0:VQcP050:VQcP03
0000002ZY=40ZZCA00L0ZZCA00<000000:bWd`2/Ym<01`2/Ym<00`000000[J[D0:fZe0030:fZe004
0000002m/m00_K?@000000H0_;CB00<000000;^fe02k]]@01@2k]]@00`000000^[OF0;ZgeP050;Zg
eP030000002j^=L0^[SG00@0^[SG00<000000;Vhf@2i^=T01P2i^=T00`000000^;WJ0;RifP040;Ri
fP030000002g^M/0]kWK00D0]kWK00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0h0?oo
o`040000003oool0oooo000004<0oooo000d0?ooo`030000003oool0oooo03/0oooo00<000000:fk
h`2]^n<00`2]^n<00`000000[[_S0:jkh`040:jkh`030000002__><0[kcS00<0[kcS00<000000;2l
h`2`_><00`2`_><00`000000/KgS0;6mh`040;6mh`030000002b_^<0/[kS00<0/[kS00<000000;>o
h`2c_n<00`2c_n<00`000000]/7S0;K1h`030;K1h`030000002h`n80^<?R00<0^<?R00<000000;_5
hP2kaN800`2kaN800`000000_/SR0;k8hP030;k8hP0300000032bn40`/_Q0080`/_Q00<000000<O@
h037d>000`37d>000`000000c]GO0<kEg`030<kEg`030000003Eg=`0eMcL0080eMcL00<000000=kS
f03NhmP00P3NhmP00`000000incA0>O/d@020>O/d@030000003N`[`0g/:l0080g/:l00<000000>O5
/`3WaK<0103WaK<00`000000FTn/0000000205]?Z`030000001MCjX00000008000000P1[FJ`01000
0000JeR[06]HZ`00000406]GZP030000001dGJX0M5fZ00@0M5fZ00@0000007=LZ@1cG:T00000201h
GjT2000000L0Nf6X0`00000207aOYP050000001mH:H0OF2V07ePYP0000000`1nHJL00`000000P6:W
081RY`02081RY`040000001oGZ<0OejS00000080P5nS00@000000000S@0008d000000`00=;T00`00
0000<E_=035Kc@02035Kc@030000001EM=D0EGCE00@0EGCE00<0000006b4f@1/Q=T01@1/Q=T00`00
0000O8oK07b?f`0207b?f`050000002PT/D0X9;50:2Ba@0000001P2TV<T00`000000Yig<0:NMc007
0:NMc0030000002YXLh0ZJ7>00D0ZJ7>00<000000:ZTd@2ZY=401`2ZY=400`000000[:OC0:bWd`07
0:bWd`050000002]Z]@0[J[D0:fZe0000000102m/m000`000000_;CB0;bddP040;bddP030000002k
]]@0^kKD00@0^kKD00<000000;ZgeP2j]mH01@2j]mH00`000000^[SG0;Zhe`050;Zhe`030000002i
^=T0^KSI00D0^KSI00<000000;RifP2h^MX01@2h^MX00`000000]kWK0;Nif`050;Nif`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0>03oool01@000000oooo0?ooo`3oool0000004<0oooo
000c0?ooo`030000003oool0oooo03`0oooo00<000000:fkh`2]^n<00`2]^n<00`000000[[_S0:jk
h`030:jkh`030000002__><0[kcS00@0[kcS00<000000;2lh`2`_><00`2`_><00`000000/KgS0;6m
h`030;6mh`030000002b_^<0/[kS00@0/[kS00<000000;>oh`2c_n<00`2c_n<00`000000]/7S0;K1
h`030;K1h`030000002h`n80^<?R00<0^<?R00<000000;_5hP2kaN800`2kaN800`000000_/SR0;k8
hP020;k8hP0300000032bn40`/_Q00<0`/_Q00<000000<O@h037d>000`37d>000`000000c]GO0<kE
g`020<kEg`030000003Eg=`0eMcL00<0eMcL00D000000=kSf03NhmP0g^?H000000040>O/d@030000
003N`[`0g/:l00<0g/:l00<000000>O5/`3WaK<0103WaK<00`000000FTn/0000000205]?Z`030000
001MCjX00000008000000P1[FJ`010000000JeR[06]HZ`00000306]GZP030000001[EjT0000000<0
M5fZ0P00000307=LZ@030000001hGjT0N5nY00H0N5nY00@0000007YOZ000000000001`1kHJP01@00
0000O5nV07aOYP1lGjH0000000<0OF2V00D0000007iQY`1nHJL0OV6W00000003081RY`80000000D0
OejS00000020Gj<0P5nS000000030000S@0400000000=;T003Bi000000D0<E_=00<0000005Ede@1E
M=D0101EM=D00`000000K8CI06b4f@0506b4f@050000001lSm/0O8oK07b?f`0000000`2PT/D00`00
0000Y9S90:BHb@050:BHb@030000002WWL`0Yig<00L0Yig<00<000000:VQcP2YXLh01@2YXLh00`00
0000ZZCA0:ZTd@070:ZTd@030000002/Ym<0[:OC00L0[:OC00<000000:fZe00000001@2m/m000`00
0000_;CB0;bddP040;bddP030000002k]]@0^kKD00D0^kKD00<000000;ZgeP2j]mH01@2j]mH00`00
0000^[SG0;Zhe`050;Zhe`030000002i^=T0^KSI00D0^KSI00<000000;RifP2h^MX0102h^MX00`00
0000]kWK0;Nif`050;Nif`030000003oool0oooo01L0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`110?ooo`00<`3oool00`000000oooo0?ooo`0k0?ooo`030000002]^n<0[K_S00@0
[K_S00<000000:jkh`2^^n<00`2^^n<00`000000[kcS0:nlh`030:nlh`030000002`_><0/;cS00@0
/;cS00<000000;6mh`2a_N<00`2a_N<00`000000/[kS0;:nh`030;:nh`030000002c_n<0/koS00@0
/koS00<000000;K1h`2f`N<00P2f`N<00`000000^<?R0;S3hP040;S3hP030000002kaN80^lGR00<0
^lGR00<000000;k8hP2nb>800P2nb>800`000000`/_Q0<;;h@030<;;h@0300000037d>00am3P00<0
am3P00<000000<kEg`3>eMl00P3>eMl00`000000eMcL0=GLg0020=GLg0030000003NhmP0g^?H0080
g^?H00<000000>O/d@3Wk=400`0000050=k2_0030000003WaK<0ilFc00@0ilFc00<0000005Y?[000
00000P1KCj/01@000000GDnZ000000000000GU2Y008000000`1[F:/01`000000JeNZ06]GZP1[EjX0
000006]GZ@0000000P1dGJX00`000000LebY07=LZ@0307=LZ@030000001hGjT0N5nY00H0N5nY00D0
000007YOZ01jGjP0NUnX0000000607]QZ08000000`1lGjH010000000OF2V07ePYP00000407iQY`03
00000020HZL0P6:W008000000P1oGZ<010000000P5nS081OX`0000020000S@0500000000=;T003Bi
000d^@0000001@0aFld00`000000EGCE05Ede@0405Ede@030000001/Q=T0K8CI00D0K8CI00<00000
07b?f`0000001@2PT/D00`000000Y9S90:BHb@050:BHb@030000002WWL`0Yig<00H0Yig<00<00000
0:VQcP2YXLh01P2YXLh00`000000ZZCA0:ZTd@070:ZTd@030000002/Ym<0[:OC00L0[:OC00<00000
0;fcd02m/m001@2m/m000`000000_;CB0;bddP040;bddP030000002k]]@0^kKD00D0^kKD00<00000
0;ZgeP2j]mH0102j]mH00`000000^[SG0;Zhe`050;Zhe`030000002i^=T0^KSI00D0^KSI00<00000
0;RifP2h^MX01@2h^MX00`000000]kWK0;Nif`050;Nif`030000003oool0oooo01@0oooo0P000010
0?ooo`030000003oool0oooo0440oooo000b0?ooo`030000003oool0oooo03`0oooo00<000000:fk
h`2]^n<00`2]^n<00`000000[[_S0:jkh`040:jkh`030000002__><0[kcS00<0[kcS00<000000;2l
h`2`_><0102`_><00`000000/KgS0;6mh`030;6mh`030000002b_^<0/[kS00<0/[kS00<000000;>o
h`2c_n<00`2c_n<00`000000]/7S0;K1h`030;K1h`030000002h`n80^<?R00<0^<?R00<000000;_5
hP2kaN800`2kaN800`000000_/SR0;k8hP030;k8hP0300000032bn40`/_Q00<0`/_Q00<000000<O@
h037d>000P37d>000`000000c]GO0<kEg`030<kEg`030000003Eg=`0eMcL0080eMcL00<000000=kS
f03NhmP00P3NhmP00`000000incA000000020=Jo``030000003N`[`0g/:l00<0g/:l00<000000>O5
/`3WaK<0103WaK<01`000000FTn/05Y?[0000000Fdn[0000001MCjX00P00000205i@Z@040000001[
F:/0JeR[000000@0JeNZ00<0000006]GZ@1[EjT00P00000707=LZ@030000001hGjT0N5nY00H0N5nY
00D0000007YOZ01jGjP0NUnX0000000507]QZ0800000101lGjH010000000OF2V07ePYP00000407iQ
Y`8000000P1nGZ<00`000000OejS00000002081OX`050000000008d0002=0000S@0000000`00=;T0
0`000000<E_=035Kc@03035Kc@030000001EM=D0EGCE00@0EGCE00<0000006b4f@1/Q=T01@1/Q=T0
0`000000X9;50:2Ba@050:2Ba@030000002TV<T0Y9S900D0Y9S900<000000:NMc02WWL`01P2WWL`0
0`000000ZJ7>0:VQcP060:VQcP030000002ZY=40ZZCA00L0ZZCA00<000000:bWd`2/Ym<01@2/Ym<0
0`000000_[7=000000060;fcd0030000002l]=80_;CB00D0_;CB00<000000;^fe02k]]@0102k]]@0
0`000000^[OF0;ZgeP050;ZgeP030000002j^=L0^[SG00D0^[SG00<000000;Vhf@2i^=T01@2i^=T0
0`000000^;WJ0;RifP050;RifP030000002g^M/0]kWK00@0]kWK00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0400oooo000a0?ooo`030000003oool0oooo
03d0oooo00<000000:fkh`2]^n<00`2]^n<00`000000[[_S0:jkh`030:jkh`030000002__><0[kcS
00@0[kcS00<000000;2lh`2`_><00`2`_><00`000000/KgS0;6mh`030;6mh`030000002b_^<0/[kS
00@0/[kS00<000000;>oh`2c_n<00`2c_n<00`000000]/7S0;K1h`030;K1h`030000002h`n80^<?R
00<0^<?R00<000000;_5hP2kaN800`2kaN800`000000_/SR0;k8hP020;k8hP0300000032bn40`/_Q
00<0`/_Q00<000000<O@h037d>000`37d>000`000000c]GO0<kEg`020<kEg`030000003Eg=`0eMcL
00<0eMcL00<000000=kSf03NhmP00P3NhmP2000000<0e[o300<000000=k2_03N`[`00`3N`[`00`00
0000ilFc0>O5/`040>O5/`070000001JCj`0FTn/0000001KCj/0000005e?ZP0200000080GU2Y00@0
000006]HZ`1[F:/00000101[EjX010000000JeNY06]GZ@00000807=LZ@D00000101hGjT00`000000
NUnX07YOZ00207YOZ0030000001kHJP0Nf6X0080Nf6X00<0000007]NY@0000000`1lGjH01@000000
OF2V07ePYP1mH:H0000000<0OV6W0P00000207iNX`040000001oGZ<0OejS00000080P5nS00D00000
0000S@0008d0002=00000002000d^@030000000aFld0<E_=00<0<E_=00<0000005Ede@1EM=D01@1E
M=D00`000000K8CI06b4f@0306b4f@030000002KRl40000000L0X9;500<000000:BHb@2TV<T01@2T
V<T00`000000Yig<0:NMc0060:NMc0030000002YXLh0ZJ7>00H0ZJ7>00<000000:ZTd@2ZY=401`2Z
Y=400`000000[:OC0:bWd`030:bWd`040000002n/Ld0_[7=000000L0_K?@00<000000;bddP2l]=80
102l]=800`000000^kKD0;^fe0050;^fe0030000002j]mH0^[OF00D0^[OF00<000000;Zhe`2j^=L0
1@2j^=L00`000000^KSI0;Vhf@050;Vhf@030000002h^MX0^;WJ00@0^;WJ00<000000;Nif`2g^M/0
1@2g^M/00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
@03oool00300oooo0P00000n0?ooo`030000002]^n<0[K_S00@0[K_S00<000000:jkh`2^^n<00`2^
^n<00`000000[kcS0:nlh`030:nlh`030000002`_><0/;cS00@0/;cS00<000000;6mh`2a_N<00`2a
_N<00`000000/[kS0;:nh`030;:nh`030000002c_n<0/koS00@0/koS00<000000;K1h`2f`N<00P2f
`N<00`000000^<?R0;S3hP040;S3hP030000002kaN80^lGR0080^lGR00<000000;k8hP2nb>800`2n
b>800`000000`/_Q0<;;h@030<;;h@0300000037d>00am3P00<0am3P00<000000<kEg`3>eMl00P3>
eMl00`000000eMcL0=GLg0020=GLg0030000003NhmP0g^?H0080g^?H00<000000=Jo``3F_l<00`3F
_l<00`000000g/:l0=k2_0030=k2_0030000003WaK<0ilFc00@0ilFc00L0000005Y?[01JCj`00000
05]?Z`000000GDnZ008000000P1ND:T20000000306]HZ`000000JeNZ0080JeNZ00D0000006]GZ@1[
EjT0JeNY0000000707=LZ@800000101gGJP5000000D0NUnX00D0000007]QZ01kHJP0Nf6X00000002
07]NY@050000001lGjH0O5nV07aOYP0000000P1mH:H00`000000OV6W07iQY`0207iQY`070000001n
GZ<0OUjS07iNX`000000OejS00000002081OX`050000000008d0002=0000S@0000000`00=;T00`00
0000<E_=035Kc@03035Kc@030000001EM=D0EGCE00D0EGCE00<0000006b4f@1/Q=T00P1/Q=T00`00
0000Vh_1000000070:2Ba@030000002TV<T0Y9S900D0Y9S900<000000:NMc02WWL`01`2WWL`00`00
0000ZJ7>0:VQcP060:VQcP030000002ZY=40ZZCA00L0ZZCA00D000000:bWd`2/Ym<0[:OC00000004
0;jac@030000002m/m00_K?@00@0_K?@00<000000;bddP2l]=801@2l]=800`000000^kKD0;^fe004
0;^fe0030000002j]mH0^[OF00D0^[OF00<000000;Zhe`2j^=L01@2j^=L00`000000^KSI0;Vhf@05
0;Vhf@030000002h^MX0^;WJ00D0^;WJ00<000000;Nif`2g^M/01@2g^M/00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0@03oool00300oooo00@000000?oo
o`0000000000?03oool00`000000[K_S0:fkh`030:fkh`030000002^^n<0[[_S00@0[[_S00<00000
0:nlh`2__><00`2__><00`000000/;cS0;2lh`040;2lh`030000002a_N<0/KgS00<0/KgS00<00000
0;:nh`2b_^<00`2b_^<00`000000/koS0;>oh`030;>oh`030000002f`N<0]/7S00<0]/7S00<00000
0;S3hP2h`n800`2h`n800`000000^lGR0;_5hP030;_5hP030000002nb>80_/SR00<0_/SR00<00000
0<;;h@32bn400`32bn400`000000am3P0<O@h0020<O@h0030000003>eMl0c]GO00<0c]GO00<00000
0=GLg03Eg=`00P3Eg=`00`000000g^?H0=kSf003000000D0e[o300<000000=k2_03N`[`00`3N`[`0
0`000000ilFc0>O5/`040>O5/`070000001JCj`0FTn/0000001KCj/0000005e?ZP0200000080GU2Y
0P0000000`1[F:/0000006]GZP0206]GZP060000001[EjT0JeNY06]GZ@1[EZP000001@1cG:T01000
0000LU^X079KZ000000707MMZ08000001@1jGjP20000000507]QZ0000000NejU07]NY@000000101l
GjH010000000OF2V07ePYP00000307iQY`050000001nGZ<0OUjS07iNX`0000000P1oGZ<010000000
P5nS081OX`0000030000S@0500000000=;T003Bi000d^@0000001@0aFld00`000000EGCE05Ede@05
05Ede@040000001/Q=T0K8CI000000<0Vh_100<000000:2Ba@2PT/D01@2PT/D00`000000Y9S90:BH
b@050:BHb@030000002WWL`0Yig<00L0Yig<00<000000:VQcP2YXLh01P2YXLh00`000000ZZCA0:ZT
d@070:ZTd@030000002/Ym<0000000D0_[7=00<000000;fcd02m/m001@2m/m000`000000_;CB0;bd
dP040;bddP030000002k]]@0^kKD00D0^kKD00<000000;ZgeP2j]mH01@2j]mH00`000000^[SG0;Zh
e`050;Zhe`030000002i^=T0^KSI00D0^KSI00<000000;RifP2h^MX0102h^MX00`000000]kWK0;Ni
f`050;Nif`030000003oool0oooo00d0oooo0P0000160?ooo`030000003oool0oooo0400oooo000`
0?ooo`040000003oool0oooo0?ooo`800000>P3oool00`000000[K_S0:fkh`030:fkh`030000002^
^n<0[[_S00<0[[_S00<000000:nlh`2__><0102__><00`000000/;cS0;2lh`030;2lh`030000002a
_N<0/KgS00<0/KgS00<000000;:nh`2b_^<0102b_^<00`000000/koS0;>oh`030;>oh`030000002f
`N<0]/7S00<0]/7S00<000000;S3hP2h`n800`2h`n800`000000^lGR0;_5hP030;_5hP030000002n
b>80_/SR0080_/SR00<000000<;;h@32bn400`32bn400`000000am3P0<O@h0030<O@h0030000003>
eMl0c]GO0080c]GO00<000000=GLg03Eg=`00`3Eg=`00`000000g^?H000000020<nmb@030000003F
_l<0e[o300<0e[o300<000000=k2_03N`[`00`3N`[`00`000000ilFc0>O5/`040>O5/`070000001J
Cj`0FTn/0000001KCj/0000005e?ZP0200000080GU2Y00<0000005m@Z@000000101[EjX01P000000
JeNY06]GZ@000000JeJX000000@0LebY00D00000079KZ01bFjP0LU^X0000000707MMZ0030000001i
GZL0000000H0NUnX0P00000307]NY@050000001lGjH0O5nV07aOYP0000000`1mH:H00`000000OV6W
07iQY`0200000080OUjS00@0000007mNX`1oGZ<000000P20Gj<01@000000002=0000S@0008d00000
00<003Bi00<00000035Kc@0aFld0100aFld00`000000EGCE05Ede@0505Ede@030000001/Q=T00000
00@0Vh_100<000000:2Ba@2PT/D01@2PT/D00`000000Y9S90:BHb@050:BHb@030000002WWL`0Yig<
00L0Yig<00<000000:VQcP2YXLh01P2YXLh00`000000ZZCA0:ZTd@070:ZTd@030000002n/Ld0_[7=
00D0_[7=00<000000;fcd02m/m001@2m/m000`000000_;CB0;bddP040;bddP030000002k]]@0^kKD
00@0^kKD00<000000;ZgeP2j]mH01@2j]mH00`000000^[SG0;Zhe`050;Zhe`030000002i^=T0^KSI
00D0^KSI00<000000;RifP2h^MX01@2h^MX00`000000]kWK0;Nif`050;Nif`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`100?ooo`00<03oool00`000000
oooo0?ooo`030?ooo`800000>03oool00`000000[K_S0:fkh`030:fkh`030000002^^n<0[[_S00<0
[[_S00<000000:nlh`2__><00`2__><00`000000/;cS0;2lh`040;2lh`030000002a_N<0/KgS00<0
/KgS00<000000;:nh`2b_^<0102b_^<00`000000/koS0;>oh`030;>oh`030000002f`N<0]/7S0080
]/7S00<000000;S3hP2h`n80102h`n800`000000^lGR0;_5hP020;_5hP030000002nb>80_/SR00<0
_/SR00<000000<;;h@32bn400`32bn400`000000am3P0<O@h0030<O@h0030000003>eMl0c]GO0080
c]GO00<000000=GLg03Eg=`00`3Eg=`2000000<0ckg900<000000=Jo``3F_l<00`3F_l<00`000000
g/:l0=k2_0040=k2_0030000003WaK<0ilFc00<0ilFc00L0000005Y?[01JCj`0000005]?Z`000000
GDnZ008000000P1ND:T00`000000Ge2Y0000000306]GZP050000001[EjT0JeNY06]GZ@0000000P1[
EZP010000000LebY07=LZ@000004079KZ0030000001gGJP0MefX00D0MefX00@0000007UNY`1iGZL0
00001P1jGjP00`000000NejU07]NY@0207]NY@050000001lGjH0O5nV07aOYP0000000`1mH:H20000
000307eMX`000000OUjS0080OUjS00@0000007mNX`1oGZ<000000P20Gj<01@000000002=0000S@00
08d0000000<003Bi00<00000035Kc@0aFld0100aFld00`000000EGCE05Ede@0505Ede@030000002K
Rl40Vh_100<0Vh_100<000000:2Ba@2PT/D01P2PT/D00`000000Y9S90:BHb@050:BHb@030000002W
WL`0Yig<00L0Yig<00<000000:VQcP2YXLh01P2YXLh00`000000ZZCA0:ZTd@050:ZTd@030000002o
[lX0000000H0_[7=00<000000;fcd02m/m001@2m/m000`000000_;CB0;bddP040;bddP030000002k
]]@0^kKD00D0^kKD00<000000;ZgeP2j]mH01@2j]mH00`000000^[SG0;Zhe`050;Zhe`030000002i
^=T0^KSI00D0^KSI00<000000;RifP2h^MX01@2h^MX00`000000]kWK0;Nif`040;Nif`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`100?ooo`00;`3oool0
0`000000oooo0?ooo`060?ooo`800000=@3oool00`000000[K_S0:fkh`040:fkh`030000002^^n<0
[[_S00<0[[_S00<000000:nlh`2__><00`2__><00`000000/;cS0;2lh`040;2lh`030000002a_N<0
/KgS00<0/KgS00<000000;:nh`2b_^<00`2b_^<00`000000/koS0;>oh`030;>oh`030000002f`N<0
]/7S00<0]/7S00<000000;S3hP2h`n800`2h`n800`000000^lGR0;_5hP030;_5hP030000002nb>80
_/SR00<0_/SR00<000000<;;h@32bn400`32bn400`000000am3P0<O@h0020<O@h0030000003>eMl0
c]GO00<0c]GO00@000000=GLg03Eg=`0eMcL0P0000050<nmb@030000003F_l<0e[o300<0e[o300<0
00000=k2_03N`[`0103N`[`00`000000ilFc0>O5/`030>O5/`070000001JCj`0FTn/0000001KCj/0
000005e?ZP0200000080GU2Y00@0000005m@Z@00000000000P1[EjX01@000000JeNY06]GZ@1[EjT0
00000080JeJX00<0000007=LZ@0000001@1bFjP00`000000MefX07MMZ00607MMZ0040000001iGZL0
NEjW000000D0NUnX0P00000307]NY@030000001lGjH0O5nV0080O5nV00D0000007ePYP1mH:H0OF2V
0000000207eMX`040000001nGZ<0OUjS00000080OejS00@00000081OX`20Gj<000000`0008d00`00
000003Bi000d^@02000d^@030000000aFld0<E_=00@0<E_=00<0000005Ede@1EM=D0101EM=D00`00
0000Vh_109^;`@0409^;`@030000002PT/D0X9;500H0X9;500<000000:BHb@2TV<T01@2TV<T00`00
0000Yig<0:NMc0070:NMc0030000002YXLh0ZJ7>00H0ZJ7>00<000000:ZTd@2ZY=400`2ZY=401000
0000_jo:0;n_bP0000070;jac@030000002m/m00_K?@00D0_K?@00<000000;bddP2l]=80102l]=80
0`000000^kKD0;^fe0050;^fe0030000002j]mH0^[OF00@0^[OF00<000000;Zhe`2j^=L01P2j^=L0
0`000000^KSI0;Vhf@040;Vhf@030000002h^MX0^;WJ00D0^;WJ00<000000;Nif`2g^M/0102g^M/2
000000X0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0o0?ooo`00;`3oool00`00
0000oooo0?ooo`080?ooo`800000<`3oool00`000000[K_S0:fkh`030:fkh`030000002^^n<0[[_S
00<0[[_S00<000000:nlh`2__><0102__><00`000000/;cS0;2lh`030;2lh`030000002a_N<0/KgS
00@0/KgS00<000000;:nh`2b_^<00`2b_^<00`000000/koS0;>oh`030;>oh`030000002f`N<0]/7S
00<0]/7S00<000000;S3hP2h`n800`2h`n800`000000^lGR0;_5hP030;_5hP030000002nb>80_/SR
00<0_/SR00<000000<;;h@32bn400P32bn400`000000am3P0<O@h0030<O@h0030000003>eMl0c]GO
00<0c]GO00H0eMcL00000000000000000<RkcP0000050<nmb@030000003F_l<0e[o300<0e[o300<0
00000=k2_03N`[`0103N`[`00`000000ilFc0>O5/`030>O5/`070000001JCj`0FTn/0000001KCj/0
000005e?ZP0200000080GU2Y00@0000005m@Z@00000000000P1[EjX01@000000JeNY06]GZ@1[EjT0
000000<0JeJX00<00000079KZ01bFjP01@1bFjP00`000000MefX07MMZ00507MMZ0040000001iGZL0
NEjW07UNY`8000000`1jGjP2000000@0NejU00D0000007aOYP1lGjH0O5nV0000000307ePYP040000
001mGJ<0OEfS000000<0OUjS00H0000007mNX`1oGZ<00000081OX`0000040000S@0300000000=;T0
03Bi008003Bi00<00000035Kc@0aFld0100aFld00`000000EGCE05Ede@0205Ede@030000002EP[`0
000000H0Vh_100<000000:2Ba@2PT/D01@2PT/D00`000000Y9S90:BHb@060:BHb@030000002WWL`0
Yig<00L0Yig<00<000000:VQcP2YXLh01P2YXLh01@000000ZZCA0:ZTd@2ZY=40000000@0_jo:00<0
00000;jac@2n/Ld0102n/Ld00`000000_K?@0;fcd0050;fcd0030000002l]=80_;CB00@0_;CB00<0
00000;^fe02k]]@01@2k]]@00`000000^[OF0;ZgeP050;ZgeP030000002j^=L0^[SG00D0^[SG00<0
00000;Vhf@2i^=T01@2i^=T00`000000^;WJ0;RifP050;RifP040000002g^M/0]kWK0;Nif`800000
00<0_lCN0000003oool01`3oool2000004`0oooo00<000000?ooo`3oool0?`3oool002l0oooo00<0
00000?ooo`3oool02P3oool200000340oooo00<000000:fkh`2]^n<00`2]^n<00`000000[[_S0:jk
h`030:jkh`030000002__><0[kcS00<0[kcS00<000000;2lh`2`_><0102`_><00`000000/KgS0;6m
h`030;6mh`030000002b_^<0/[kS00@0/[kS00<000000;>oh`2c_n<00`2c_n<00`000000]/7S0;K1
h`030;K1h`030000002h`n80^<?R00<0^<?R00<000000;_5hP2kaN800P2kaN800`000000_/SR0;k8
hP030;k8hP0300000032bn40`/_Q00<0`/_Q00<000000<O@h037d>000`37d>0010000000c]GO0<kE
g`3>eMl3000000@0b;_>00<000000<nmb@3?_LT00`3?_LT00`000000e[o30=Jo``030=Jo``030000
003N`[`0g/:l00@0g/:l00<000000>O5/`3WaK<00`3WaK<01`000000FTn/05Y?[0000000Fdn[0000
001MCjX00P00000205i@Z@070000001OD:T00000061@Z0000000JeNZ0000000206]GZ@030000001[
EZP0JeJX0080JeJX00<00000079KZ01bFjP01@1bFjP4000000@0MefX00<0000007UNY`1iGZL00`1i
GZL01P000000NUnX07YOZ0000000NUfU000000@0NejU00D0000007aOYP1lGjH0O5nV0000000207eP
YP050000001mGJ<0OEfS07eMX`0000000P1nGZ<010000000OejS07mNX`000002081OX`0300000000
08d0002=0080002=00D00000000d^@00=;T003Bi00000006035Kc@030000001EM=D0EGCE0080EGCE
00@0000009F2_02EP[`000001P2KRl400`000000X9;50:2Ba@050:2Ba@030000002TV<T0Y9S900H0
Y9S900<000000:NMc02WWL`01`2WWL`00`000000ZJ7>0:VQcP060:VQcP030000002ZY=40000000D0
_jo:00<000000;jac@2n/Ld01@2n/Ld00`000000_K?@0;fcd0050;fcd0030000002l]=80_;CB00@0
_;CB00<000000;^fe02k]]@01@2k]]@00`000000^[OF0;ZgeP050;ZgeP030000002j^=L0^[SG00D0
^[SG00<000000;Vhf@2i^=T01@2i^=T00`000000^;WJ0;RifP040;RifP040000002g^M/000000000
00<0_lCN00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
03l0oooo000_0?ooo`030000003oool0oooo00`0oooo0`00000]0?ooo`030000002]^n<0[K_S00@0
[K_S00<000000:jkh`2^^n<00`2^^n<00`000000[kcS0:nlh`030:nlh`030000002`_><0/;cS00@0
/;cS00<000000;6mh`2a_N<00`2a_N<00`000000/[kS0;:nh`030;:nh`030000002c_n<0/koS00<0
/koS00<000000;K1h`2f`N<00`2f`N<00`000000^<?R0;S3hP030;S3hP030000002kaN80^lGR00<0
^lGR00<000000;k8hP2nb>800`2nb>800`000000`/_Q0<;;h@030<;;h@0300000037d>00am3P00<0
am3P00H0c]GO00000000000000000<>jd@0000050<RkcP030000003?_LT0ckg900<0ckg900<00000
0=Jo``3F_l<00`3F_l<00`000000g/:l0=k2_0040=k2_0030000003WaK<0ilFc0080ilFc0`000000
1@1JCj`0000005]?Z`000000GDnZ008000000P1ND:T010000000Ge2Y0000001PD:P2000000<0JeNY
00<0000006]FZ01[EZP00P1[EZP00`1[EZL00000079KZ004079KZ08000000`1fG:L5000000H0NEjW
00<0000007YOZ00000000P1jGJD00`000000NejU07]NY@0207]NY@060000001lGjH0O5nV07aOYP00
0000OF2V0P00000207eMX`050000001nGZ<0OUjS07iNX`0000000P1oGZ<00`000000P5nS00000004
0000S@0300000000=;T003Bi008003Bi00<00000035Kc@0aFld0100aFld010000000EGCE05Ede@00
000309F2_0030000002KRl40Vh_100@0Vh_100<000000:2Ba@2PT/D01P2PT/D00`000000Y9S90:BH
b@050:BHb@030000002WWL`0Yig<00L0Yig<00<000000:VQcP2YXLh01`2YXLh00`000000_jo:0;n_
bP050;n_bP030000002n/Ld0_[7=00@0_[7=00<000000;fcd02m/m001@2m/m000`000000_;CB0;bd
dP050;bddP030000002k]]@0^kKD00@0^kKD00<000000;ZgeP2j]mH01@2j]mH00`000000^[SG0;Zh
e`050;Zhe`030000002i^=T0^KSI00D0^KSI00<000000;RifP2h^MX0102h^MX2000000D0_lCN00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo03l0oooo000_
0?ooo`030000003oool0oooo00l0oooo0P00000[0?ooo`<00000102]^n<60:jkh`H0[kcS00<00000
0;2lh`2`_><0102`_><00`000000/KgS0;6mh`030;6mh`030000002b_^<0/[kS00<0/[kS00<00000
0;>oh`2c_n<00`2c_n<00`000000]/7S0;K1h`030;K1h`030000002h`n80^<?R00<0^<?R00<00000
0;_5hP2kaN800`2kaN800`000000_/SR0;k8hP030;k8hP0300000032bn40`/_Q00<0`/_Q0P37d>05
000000@0`k[A00<000000<RkcP38^lh00`38^lh00`000000ckg90<nmb@030<nmb@030000003F_l<0
e[o300<0e[o300<000000=k2_03N`[`0103N`[`00`000000ilFc0>O5/`020>O5/`<0000000D0FTn/
0000001KCj/0000005e?ZP0200000080GU2Y00<0000005m@Z@0000000P1PD:P01@000000JeNY06]G
Z@1[EjT0000000<0JeJX00<0000006]FY`0000000`1bFjP200000080LEVW00<0000007ILY`1fG:L0
101fG:L2000000H0NEjW0P00000207YMY@030000001kGZD0NejU0080NejU00<0000007aOYP1lGjH0
0P1lGjH3000000<0OEfS00@0000007iNX`1nGZ<000000P1oGZ<010000000P5nS081OX`0000040000
S@0300000000=;T003Bi008003Bi00<00000035Kc@0aFld0100aFld00`000000EGCE0000000409F2
_0030000002KRl40Vh_100@0Vh_100<000000:2Ba@2PT/D01P2PT/D00`000000Y9S90:BHb@050:BH
b@030000002WWL`0Yig<00L0Yig<00<000000:VQcP2YXLh01@2YXLh2000000L0_jo:00<000000;ja
c@2n/Ld01@2n/Ld00`000000_K?@0;fcd0050;fcd0030000002l]=80_;CB00@0_;CB00<000000;^f
e02k]]@01@2k]]@00`000000^[OF0;ZgeP050;ZgeP030000002j^=L0^[SG00D0^[SG00<000000;Vh
f@2i^=T01@2i^=T010000000^;WJ0;RifP2h^MX2000000030<75g@000000_lCN00@0_lCN00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`1=0?ooo`800000@@3oool002l0oooo00<000000?oo
o`3oool04@3oool2000002T0oooo00<000000:^ghP2[]n80300000040:nlh`L0/;cS1P2a_N<60;:n
h`030000002c_n<0/koS00<0/koS00<000000;K1h`2f`N<00`2f`N<00`000000^<?R0;S3hP030;S3
hP030000002kaN80^lGR00<0^lGR1P2nb>820<;;h@H000000`2n^M@00`000000`k[A0<>jd@030<>j
d@0300000038^lh0b;_>00<0b;_>00<000000<nmb@3?_LT00`3?_LT00`000000e[o30=Jo``040=Jo
``030000003N`[`0g/:l00<0g/:l00D000000>O5/`3WaK<0ilFc000000020;nH[`<0000000<0Fdn[
0000001MCjX00P00000205i@Z@030000001OD:T000000080H52X0P00000206]GZ@070000001[EZP0
JeJX06]FZ0000000JeJW00000002079KZ0030000001aFJL0LEVW0080LEVW00<0000007ILY`1fG:L0
1@1fG:L3000000D0NEjW00D0000007YMY@1jGJD0NUfU0000000407]NY@040000001lGjH0O5nV07aO
YP80000000D0O5bS0000001mGJ<0OEfS0000000207iNX`040000001oGZ<0OejS00000080P5nS00<0
00000000S@0008d00P0008d00`00000003Bi000d^@02000d^@030000000aFld0<E_=00D0<E_=00<0
000009F2_02EP[`0102EP[`00`000000Vh_109^;`@0409^;`@030000002PT/D0X9;500D0X9;500<0
00000:BHb@2TV<T01P2TV<T00`000000Yig<0:NMc0070:NMc0030000002YXLh0ZJ7>00<0ZJ7>00@0
00000;n]a`2o[LL000001`2o[lX00`000000_[7=0;jac@050;jac@030000002m/m00_K?@00@0_K?@
00<000000;bddP2l]=801@2l]=800`000000^kKD0;^fe0050;^fe0030000002j]mH0^[OF00@0^[OF
00<000000;Zhe`2j^=L01P2j^=L00`000000^KSI0;Vhf@040;Vhf@040000002h^MX00000000000<0
`LGM00<000000;o4gP2oa=h0102oa=h00`000000oooo0?ooo`02000004l0oooo00@000000?ooo`3o
ool00000@03oool002h0oooo00<000000?ooo`3oool0503oool2000002L0oooo00<000000:^ghP2[
]n800`2[]n800`000000ZkKQ0:^fh@030:^fh@030000002/]^40[;KQ01<00000102b_^<60;>oh`H0
]/7S1P2h`n820;_5hP`000000`2j^=L00`000000_[WD0;jie0030;jie00300000033^]40`k[A00<0
`k[A00<000000<RkcP38^lh00`38^lh00`000000ckg90<nmb@030<nmb@030000003F_l<0e[o300@0
e[o300<000000=k2_03N`[`00`3N`[`010000000ilFc0>O5/`0000030;nH[`060000001?AZL00000
05]?Z`000000GDnZ0P00000205i@Z@030000001OD:T000000080H52X0P0000000`1[EjT0000006]F
Z00306]FZ0030000001[EZL0JeJW008000001@1aFJL00`000000MUbW07ILY`0507ILY`040000001h
G:H0N5bV000000@0NEjW0P00000307YMY@030000001kGZD0NejU0080NejU00L0000007aOYP1lGjH0
O5nV0000001lG:<000000080OEfS00D0000007iNX`1nGZ<0OUjS0000000207mNX`0400000020Gj<0
P5nS000000@0002=00<00000000d^@00=;T00P00=;T00`000000<E_=035Kc@03035Kc@030000002=
N;L0UH:l00D0UH:l00<0000009^;`@2KRl40102KRl400`000000X9;50:2Ba@060:2Ba@030000002T
V<T0Y9S900H0Y9S900<000000:NMc02WWL`01`2WWL`01@000000ZJ7>0:VQcP2YXLh0000000<0_jg7
00<000000;n_bP2o[lX01@2o[lX00`000000_[7=0;jac@050;jac@030000002m/m00_K?@00D0_K?@
00<000000;bddP2l]=80102l]=800`000000^kKD0;^fe0050;^fe0030000002j]mH0^[OF00D0^[OF
00<000000;Zhe`2j^=L01@2j^=L00`000000^KSI0;Vhf@040;Vhf@8000001@31aMd00`000000_lCN
0;o4gP040;o4gP030000003oool0000005@0oooo00<000000?ooo`3oool0?P3oool002h0oooo00<0
00000?ooo`3oool05P3oool2000002H0oooo1@2[]n800`000000ZkKQ0:^fh@030:^fh@030000002/
]^40[;KQ00<0[;KQ00<000000:bfh02/]^00102/]^000`000000[KKP0:ffh0030:ffh0030000002^
]]l0[[KO01P000000`2d]m/00`000000]kOI0;Ngf@030;Ngf@030000002j^=L0^[SG00<0^[SG00<0
00000;jie02n^M@00`2n^M@00`000000`k[A0<>jd@030<>jd@0300000038^lh0b;_>00<0b;_>00<0
00000<nmb@3?_LT00`3?_LT00`000000e[o30=Jo``040=Jo``030000003N`[`0g/:l00<0g/:l00@0
00000>O5/`3WaK<000000`2oV:l00`000000CdJW000000020000000305e?ZP00000000000080GU2Y
00<0000005m@Z@0000000P1PD:P010000000HE2W00000000000406]FZ0040000001[EZL0JeJW0000
00L0LEVW00<0000007ILY`1fG:L0101fG:L01@000000N5bV07QLYP1hG:H0000000<0NEjW0P000003
07YMY@030000001kGZD0NejU0080NejU00D0000007aOYP1lGjH0O5nV0000000207aLX`040000001m
GJ<0OEfS00000080OUjS00@0000007mNX`1oGZ<000000P20Gj<00`000000002=0000S@020000S@03
00000000=;T003Bi00<003Bi00D00000035Kc@0aFld0<E_=0000000208eh]`030000002EP[`0UH:l
00@0UH:l00<0000009^;`@2KRl40102KRl400`000000X9;50:2Ba@060:2Ba@030000002TV<T0Y9S9
00H0Y9S900<000000:NMc02WWL`01`2WWL`00`000000ZJ7>000000050;n]a`030000002o[lX0_jo:
00D0_jo:00<000000;jac@2n/Ld01@2n/Ld00`000000_K?@0;fcd0050;fcd0030000002l]=80_;CB
00@0_;CB00<000000;^fe02k]]@01@2k]]@00`000000^[OF0;ZgeP050;ZgeP030000002j^=L0^[SG
00D0^[SG00@000000;Vhf@2i^=T0^KSI0P0000000`33aM`000000<75g@040<75g@030000002oa=h0
_lCN00@0_lCN0P00001E0?ooo`030000003oool0oooo03h0oooo000^0?ooo`030000003oool0oooo
01P0oooo0P00000T0?ooo`030000002[]n80ZkOR00<0ZkOR1@2[]^400`000000[;KQ0:bfh@030:bf
h@030000002/]^00[;KP00@0[;KP00<000000:ffh02]]^000`2]]^000`000000[[KO0:jfg`030:jf
g`030000002_]]h0[kKN00<0[kKN00<000000;6fg@2a]]d00`2a]]d00`000000/[KL0;:fg0030;:f
g0030000002d]m/0];OK00<0];OK00<000000;Ngf@2g]mT00`2g]mT00`000000^[SG0;Zhe`030;Zh
e`030000002n^M@0_[WD00<0_[WD00<000000<>jd@33^]400`33^]400`000000b;_>0<RkcP030<Rk
cP030000003?_LT0ckg900<0ckg900<000000=Jo``3F_l<0103F_l<00`000000g/:l0=k2_0030=k2
_0030000003WaK<0000000@0_iR_00<0000004m6Y`0000000P0000000`1MCjX000000000000205i@
Z@030000001OD:T000000080H52X00@00000065@Y`1QD:L000000`1[EZP01@000000JeJW06]FY`1[
EZL0000000L0LEVW0P00000507ILY`030000001hG:H0N5bV0080N5bV00H0000007UNY`1iGZL00000
07QLY@00000307YMY@030000001kGZD0NejU0080NejU00<0000007aOYP1lGjH00P0000001@1lG:<0
000007eMX`1mGJ<0000000<0OUjS00@0000007mNX`1oGZ<000000P20Gj<00`000000002=0000S@02
0000S@0300000000=;T003Bi00<003Bi00@00000035Kc@0aFld000000`2=N;L00`000000UH:l09F2
_00309F2_0030000002KRl40Vh_100D0Vh_100<000000:2Ba@2PT/D01P2PT/D00`000000Y9S90:BH
b@060:BHb@030000002WWL`0Yig<00L0Yig<00<000000;n]a`2o[LL0102o[LL00`000000_jo:0;n_
bP050;n_bP030000002n/Ld0_[7=00D0_[7=00<000000;fcd02m/m001@2m/m000`000000_;CB0;bd
dP040;bddP030000002k]]@0^kKD00D0^kKD00<000000;ZgeP2j]mH01@2j]mH00`000000^[SG0;Zh
e`050;Zhe`040000002i^=T00000000000<0`lGL00<000000<75g@31aMd01031aMd00`000000_lCN
0;o4gP030;o4gP030000003oool0oooo05@0oooo00<000000?ooo`3oool0?P3oool002h0oooo00<0
00000?ooo`3oool06P3oool200000280oooo00<000000:^ghP2[]n800`2[]n800`000000ZkKQ0:^f
h@030:^fh@030000002/]^40[;KQ0080[;KQ00<000000:bfh02/]^00102/]^000`000000[KKP0:ff
h0030:ffh0030000002^]]l0[[KO00<0[[KO00<000000:nfgP2_]]h00`2_]]h00`000000/KKM0;6f
g@030;6fg@030000002b]]`0/[KL00<0/[KL00<000000;Bgf`2d]m/00`2d]m/00`000000]kOI0;Ng
f@030;Ngf@030000002j^=L0^[SG00<0^[SG00<000000;jie02n^M@00`2n^M@00`000000`k[A0<>j
d@040<>jd@0300000038^lh0b;_>0080b;_>00<000000<nmb@3?_LT00`3?_LT00`000000e[o30=Jo
``040=Jo``030000003N`[`0g/:l00<0g/:l0P0000050;nH[`060000001?AZL000000557Y`000000
GDnZ0P00000205i@Z@030000001OD:T000000080H52X00<00000065@Y`1QD:L00P00000206]FZ006
0000001[EZL0JeJW06]FY`1[EJL000001@1aFJL20000000307EKY`0000000000008000000P1fG:L0
0`000000N5bV07QLYP0207QLYP80000000@0NEjW0000001hG:D000000`1jGJD00`000000NejU07]N
Y@0207]NY@80000000D0Ne^R0000001lG:<0O5bS0000000207eMX`040000001nGZ<0OUjS00000080
OejS00@00000081OX`20Gj<000001@0008d00`00000003Bi000d^@02000d^@030000000aFld00000
00@0SGRg00<0000009F2_02EP[`0102EP[`00`000000Vh_109^;`@0409^;`@030000002PT/D0X9;5
00H0X9;500<000000:BHb@2TV<T01`2TV<T00`000000Yig<0:NMc0050:NMc08000001`2o[LL00`00
0000_jo:0;n_bP050;n_bP030000002n/Ld0_[7=00D0_[7=00<000000;fcd02m/m001@2m/m000`00
0000_;CB0;bddP040;bddP030000002k]]@0^kKD00D0^kKD00<000000;ZgeP2j]mH01@2j]mH00`00
0000^[SG0;Zhe`050;Zhe`0300000033aM`0`lGL00<0`lGL00<000000<75g@31aMd01031aMd00`00
0000_lCN0;o4gP030;o4gP030000003oool0oooo05@0oooo00<000000?ooo`3oool0?P3oool002h0
oooo00<000000?ooo`3oool0703oool3000001l0oooo00<000000:^ghP2[]n800`2[]n800`000000
ZkKQ0:^fh@030:^fh@030000002/]^40[;KQ00<0[;KQ00<000000:bfh02/]^00102/]^000`000000
[KKP0:ffh0020:ffh0030000002^]]l0[[KO00<0[[KO00<000000:nfgP2_]]h00`2_]]h00`000000
/KKM0;6fg@030;6fg@030000002b]]`0/[KL00<0/[KL00<000000;Bgf`2d]m/00`2d]m/00`000000
]kOI0;Ngf@030;Ngf@030000002j^=L0^[SG00<0^[SG00<000000;jie02n^M@00`2n^M@00`000000
`k[A0<>jd@040<>jd@0300000038^lh0b;_>0080b;_>00<000000<nmb@3?_LT0103?_LT00`000000
e[o30=Jo``030=Jo``030000003N`[`0g/:l00<0g/:l0P0000050;nH[`030000001?AZL0CdJW00D0
00000P1ND:T01P000000Ge2Y05m@Z@000000H52X00000080HE2W0P00000206]FZ0060000001[EZL0
JeJW0000001[EJL00000101aFJL010000000LERW075HY`00000407EKY`<000001P1hG:H200000080
N5bU00@0000007YMY@1jGJD00000101kGZD200000080Ne^R00<0000007aLX`0000000P1mGJ<01@00
0000OUjS07iNX`1nGZ<000000080OejS00<00000081OX`0000001@0008d00`00000003Bi000d^@03
000d^@030000002=N;L0SGRg00@0SGRg00<0000009F2_02EP[`0102EP[`00`000000Vh_109^;`@04
09^;`@030000002PT/D0X9;500H0X9;500<000000:BHb@2TV<T01`2TV<T00`000000Yig<0:NMc003
0:NMc00400000030ZL<0`:W3000000H0_jg700<000000;n_bP2o[lX01@2o[lX00`000000_[7=0;ja
c@050;jac@030000002m/m00_K?@00D0_K?@00<000000;bddP2l]=80102l]=800`000000^kKD0;^f
e0050;^fe0030000002j]mH0^[OF00D0^[OF00<000000;Zhe`2j^=L00`2j^=L3000000D0`lGL00<0
00000<75g@31aMd01031aMd00`000000_lCN0;o4gP030;o4gP030000003oool0oooo05@0oooo00<0
00000?ooo`3oool0?P3oool002h0oooo00<000000?ooo`3oool07`3oool2000001d0oooo00<00000
0:^ghP2[]n800`2[]n800`000000ZkKQ0:^fh@030:^fh@030000002/]^40[;KQ00<0[;KQ00<00000
0:bfh02/]^00102/]^000`000000[KKP0:ffh0030:ffh0030000002^]]l0[[KO0080[[KO00<00000
0:nfgP2_]]h00`2_]]h00`000000/KKM0;6fg@030;6fg@030000002b]]`0/[KL00<0/[KL00<00000
0;Bgf`2d]m/00`2d]m/00`000000]kOI0;Ngf@030;Ngf@030000002j^=L0^[SG00<0^[SG00<00000
0;jie02n^M@0102n^M@00`000000`k[A0<>jd@030<>jd@0300000038^lh0b;_>0080b;_>00<00000
0<nmb@3?_LT0103?_LT00`000000e[o30=Jo``030=Jo``030000003N`[`0g/:l00<0g/:l00<00000
0;nH[`2oV:l01@2oV:l00`000000CdJW000000020000000505e?ZP000000GU2Y05i@Z@0000000P1O
D:T00`000000H52X00000002065@Y`050000001RD:L0000006]FZ00000000P1[EZL010000000JeFW
06]EY`000002075IY`050000001aF:L0LERW075HY`0000001P1eFjL2000000H0N5bV00@0000007QL
Y@1hG:D000000`1jGJD00`000000NejU07]NY@0207]NY@040000001kFj80Ne^R00000080O5bS00@0
000007eMX`1mGJ<000000P1nGZ<010000000OejS07mNX`000002081OX`030000000008d0002=00<0
002=00@00000000d^@00=;T003Bi0P00000608eh]`030000002EP[`0UH:l00@0UH:l00<0000009^;
`@2KRl401@2KRl400`000000X9;50:2Ba@060:2Ba@030000002TV<T0Y9S900H0Y9S900<000000:NM
c02WWL`00`2WWL`010000000`:W30<2Y``0000070;n]a`030000002o[lX0_jo:00D0_jo:00<00000
0;jac@2n/Ld01@2n/Ld00`000000_K?@0;fcd0050;fcd0030000002l]=80_;CB00@0_;CB00<00000
0;^fe02k]]@01@2k]]@00`000000^[OF0;ZgeP050;ZgeP050000002j^=L0^[SG0;Zhe`0000000P35
aMX00`000000`lGL0<?5g0040<?5g00300000031aMd0`LGM00<0`LGM00<000000;o4gP2oa=h00`2o
a=h00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo03d0oooo000]0?ooo`030000003oool0
oooo0280oooo0P00000K0?ooo`030000002[]n80ZkOR00<0ZkOR00<000000:^fh@2[]^400`2[]^40
0`000000[;KQ0:bfh@030:bfh@030000002/]^00[;KP00@0[;KP00<000000:ffh02]]^000`2]]^00
0`000000[[KO0:jfg`030:jfg`030000002_]]h0[kKN00<0[kKN00<000000;6fg@2a]]d00P2a]]d0
0`000000/[KL0;:fg0030;:fg0030000002d]m/0];OK00@0];OK00<000000;Ngf@2g]mT00P2g]mT0
0`000000^[SG0;Zhe`030;Zhe`030000002n^M@0_[WD00@0_[WD00<000000<>jd@33^]400`33^]40
0`000000b;_>0<RkcP020<RkcP030000003?_LT0ckg900@0ckg900<000000=Jo``3F_l<00`3F_l<0
0`000000g/:l0=k2_0020=k2_08000001`2oV:l010000000CdJW0000001AAjL300000080GU2Y00H0
000005m@Z@1OD:T00000061@Z0000002065@Y`040000001RD:L00000000000<0JeJW00H0000006]E
Y`1[EJL00000075IY`000004075HY`030000001eFjL0ME^W00@0ME^W00<0000007IKYP0000001@1h
G:H200000080N5bU00D0000007YMY@1jGJD0NUfU0000000307]NY@070000001kFj80Ne^R07]KXP00
0000O5bS0000000207eMX`050000001nGZ<0OUjS07iNX`0000000P1oGZ<00`000000P5nS00000005
0000S@0700000000=;T003Bi000d^@000000PVba0000000608eh]`030000002EP[`0UH:l00@0UH:l
00<0000009^;`@2KRl401@2KRl400`000000X9;50:2Ba@060:2Ba@030000002TV<T0Y9S900H0Y9S9
00D000000:NMc02WWL`0Yig<000000040<2Y``030000002o[LL0_jg700@0_jg700<000000;n_bP2o
[lX01@2o[lX00`000000_[7=0;jac@050;jac@030000002m/m00_K?@00D0_K?@00<000000;bddP2l
]=801@2l]=800`000000^kKD0;^fe0050;^fe0030000002j]mH0^[OF00@0^[OF00@000000;Zhe`00
000000000`35aMX00`000000`lGL0<?5g0040<?5g00300000031aMd0`LGM00<0`LGM00<000000;o4
gP2oa=h00`2oa=h00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo03d0oooo000]0?ooo`03
0000003oool0oooo02@0oooo0P00000J0?ooo`030000002[]n80ZkOR0080ZkOR00<000000:^fh@2[
]^400`2[]^400`000000[;KQ0:bfh@030:bfh@030000002/]^00[;KP00@0[;KP00<000000:ffh02]
]^000`2]]^000`000000[[KO0:jfg`030:jfg`030000002_]]h0[kKN00<0[kKN00<000000;6fg@2a
]]d00`2a]]d00`000000/[KL0;:fg0030;:fg0030000002d]m/0];OK00<0];OK00<000000;Ngf@2g
]mT00P2g]mT00`000000^[SG0;Zhe`040;Zhe`030000002n^M@0_[WD00<0_[WD00<000000<>jd@33
^]400`33^]400`000000b;_>0<RkcP020<RkcP030000003?_LT0ckg900@0ckg900<000000=Jo``3F
_l<00`3F_l<01`000000g/:l0=k2_03N`[`000000;ZI]`0000001`2oV:l01`000000CdJW0000001A
AjL0000005=7YP0000000P1ND:T01P000000Ge2Y05m@Z@000000H52X00000080HE2W00@00000069@
Y`1RD:L000000`1[EZL01@000000JeFW06]EY`1[EJL0000000D0LERW00<0000007EKY`1eFjL0101e
FjL010000000MU^V07IKYP00000407QLYP8000000`1hG:D010000000NUfU07YMY@00000307]NY@80
00000P1kFj800`000000O5bS0000000207eMX`050000001nGZ<0OUjS07iNX`0000000P1oGZ<01000
0000P5nS081OX`0000050000S@0300000000=;T000000080PVba00<0000008eh]`2=N;L0102=N;L0
0`000000UH:l09F2_00409F2_0030000002KRl40Vh_100D0Vh_100<000000:2Ba@2PT/D01`2PT/D0
0`000000Y9S90:BHb@060:BHb@030000002WWL`0000000D0`:W300<000000;n]a`2o[LL01@2o[LL0
0`000000_jo:0;n_bP050;n_bP030000002n/Ld0_[7=00D0_[7=00<000000;fcd02m/m001@2m/m00
0`000000_;CB0;bddP040;bddP030000002k]]@0^kKD00D0^kKD00<000000;ZgeP2j]mH0102j]mH2
000000H0aLGJ00<000000<?5g033aM`00`33aM`00`000000`LGM0<75g@030<75g@030000002oa=h0
_lCN00@0_lCN00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0m0?ooo`00;@3oool00`00
0000oooo0?ooo`0V0?ooo`800000603oool00`000000ZkOR0:^ghP030:^ghP030000002[]^40ZkKQ
0080ZkKQ00<000000:bfh@2/]^400`2/]^400`000000[;KP0:bfh0040:bfh0030000002]]^00[KKP
00<0[KKP00<000000:jfg`2^]]l00`2^]]l00`000000[kKN0:nfgP030:nfgP030000002a]]d0/KKM
00<0/KKM00<000000;:fg02b]]`00`2b]]`00`000000];OK0;Bgf`030;Bgf`030000002g]mT0]kOI
00<0]kOI00<000000;Zhe`2j^=L00`2j^=L00`000000_[WD0;jie0030;jie00300000033^]40`k[A
00<0`k[A00<000000<RkcP38^lh00`38^lh00`000000ckg90<nmb@030<nmb@030000003F_l<0e[o3
00<0e[o300@000000=k2_03N`[`000000`2jVKL00`000000_iR_0;nH[`040;nH[`060000001?AZL0
00000557Y`000000DdNV0P0000001`1ND:T0000005m@Z@1OD:T00000061@Z00000000P1QD:L00`00
0000HU2W069@Y`0200000080JeJW00D0000006]EY`1[EJL0JeFW00000006075HY`030000001eFjL0
ME^W00@0ME^W00<0000007IKYP1fFjH00P00000207QLYP030000001gFj@000000080N5bU00D00000
07YMY@1jGJD0NUfU0000000207]NY@8000000P1kFj8010000000O5bS07aLX`00000207eMX`040000
001nGZ<0OUjS000000<0OejS00<00000081OX`0000001@0008d00`00000003Bi00000003089//@03
0000002=N;L0SGRg00@0SGRg00<0000009F2_02EP[`0102EP[`00`000000Vh_109^;`@0509^;`@03
0000002PT/D0X9;500H0X9;500<000000:BHb@2TV<T01`2TV<T00`000000`:W30<2Y``050<2Y``03
0000002o[LL0_jg700@0_jg700<000000;n_bP2o[lX01@2o[lX00`000000_[7=0;jac@050;jac@03
0000002m/m00_K?@00D0_K?@00<000000;bddP2l]=801@2l]=800`000000^kKD0;^fe0050;^fe004
0000002j]mH0^[OF0;ZgeP80000000<0alKI00000035aMX01@35aMX00`000000`lGL0<?5g0030<?5
g00300000031aMd0`LGM00<0`LGM00<000000;o4gP2oa=h0102oa=h00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo03d0oooo000]0?ooo`030000003oool0oooo02P0oooo0P00000F0?ooo`03
0000002[]n80ZkOR00<0ZkOR00<000000:^fh@2[]^400`2[]^400`000000[;KQ0:bfh@020:bfh@03
0000002/]^00[;KP00@0[;KP00<000000:ffh02]]^000`2]]^000`000000[[KO0:jfg`030:jfg`03
0000002_]]h0[kKN00<0[kKN00<000000;6fg@2a]]d00`2a]]d00`000000/[KL0;:fg0030;:fg003
0000002d]m/0];OK00<0];OK00<000000;Ngf@2g]mT00`2g]mT00`000000^[SG0;Zhe`030;Zhe`03
0000002n^M@0_[WD00<0_[WD00<000000<>jd@33^]400`33^]400`000000b;_>0<RkcP030<RkcP03
0000003?_LT0ckg900<0ckg900<000000=Jo``3F_l<00`3F_l<00`000000g/:l000000040;ZI]`03
0000002oV:l0_iR_00@0_iR_00P0000004m6Y`000000DDNW0000001CAjH0000005I8YP8000000P1O
D:T00`000000H52X00000002065@Y`030000001RD:L0HU2W008000000P1[EZL01P000000JeFW06]E
Y`000000JeBV000000D0LERW0P00000507EKY`030000001fFjH0MU^V0080MU^V00D0000007QLYP00
0000Me^T0000000307QLY@040000001jGJD0NUfU07YMY@8000000P1jFj801P000000Ne^R07]KXP00
0000O5bS00000080OEfS00D0000007iNX`1nGZ<0OUjS0000000207mNX`0400000020Gj<0P5nS0000
00D0002=00<00000089//@22K;400P22K;400`000000SGRg08eh]`0408eh]`030000002EP[`0UH:l
00D0UH:l00<0000009^;`@2KRl401@2KRl400`000000X9;50:2Ba@060:2Ba@030000002TV<T0Y9S9
00D0Y9S90P0000070<2Y``030000002o[LL0_jg700D0_jg700<000000;n_bP2o[lX01@2o[lX00`00
0000_[7=0;jac@050;jac@030000002m/m00_K?@00D0_K?@00<000000;bddP2l]=80102l]=800`00
0000^kKD0;^fe0050;^fe0040000002j]mH00000000000<0alKI00<000000<G5fP35aMX01035aMX0
0`000000`lGL0<?5g0030<?5g00300000031aMd0`LGM00<0`LGM00<000000;o4gP2oa=h0102oa=h0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo03d0oooo000]0?ooo`030000003oool0oooo
02X0oooo0`00000C0?ooo`030000002[]n80ZkOR00<0ZkOR00<000000:^fh@2[]^400`2[]^400`00
0000[;KQ0:bfh@030:bfh@030000002/]^00[;KP00<0[;KP00<000000:ffh02]]^000`2]]^000`00
0000[[KO0:jfg`030:jfg`030000002_]]h0[kKN00<0[kKN00<000000;6fg@2a]]d00`2a]]d00`00
0000/[KL0;:fg0030;:fg0030000002d]m/0];OK00<0];OK00<000000;Ngf@2g]mT00`2g]mT00`00
0000^[SG0;Zhe`030;Zhe`030000002n^M@0_[WD00<0_[WD00<000000<>jd@33^]400`33^]400`00
0000b;_>0<RkcP030<RkcP030000003?_LT0ckg900<0ckg900<000000=Jo``3F_l<00`3F_l<20000
00D0^YVg00<000000;nH[`2oV:l0102oV:l00`000000CdJW04m6Y`020000000505=7YP000000ETRV
05I8YP0000000P1OD:T00`000000H52X00000002065@Y`050000001RD:L0HU2W0000001SD:H00P00
000306]EY`030000001[E:H0000000@0LERW0P0000000`1cFZH00000000000020000000307EKY`00
0000MU^V00@0MU^V0P00000207MKY0050000001hG:D0N5bU07QLY@0000000P1jGJD200000080NU^R
00@0000007]KXP1kFj8000000P1lG:<010000000OEfS07eMX`00000207iNX`070000001oGZ<0OejS
07mNX`000000P5nS000000040000S@8000001@22K;400`000000SGRg08eh]`0408eh]`030000002E
P[`0UH:l00@0UH:l00<0000009^;`@2KRl401@2KRl400`000000X9;50:2Ba@070:2Ba@030000002T
V<T0Y9S900<0Y9S900@000000<2V_`30Y[l000001`30ZL<00`000000_jg70;n]a`040;n]a`030000
002o[lX0_jo:00H0_jo:00<000000;jac@2n/Ld0102n/Ld00`000000_K?@0;fcd0060;fcd0030000
002l]=80_;CB00@0_;CB00<000000;^fe02k]]@01@2k]]@00`000000alKI0<O6f@030<O6f@030000
0035aMX0aLGJ00@0aLGJ00<000000<?5g033aM`00`33aM`00`000000`LGM0<75g@040<75g@030000
002oa=h0_lCN00<0_lCN00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0l0?ooo`00;@3o
ool00`000000oooo0?ooo`0]0?ooo`8000004@3oool00`000000ZkOR0:^ghP030:^ghP030000002[
]^40ZkKQ00<0ZkKQ00<000000:bfh@2/]^400`2/]^400`000000[;KP0:bfh0040:bfh0030000002]
]^00[KKP0080[KKP00<000000:jfg`2^]]l00`2^]]l00`000000[kKN0:nfgP030:nfgP030000002a
]]d0/KKM00<0/KKM00<000000;:fg02b]]`00`2b]]`00`000000];OK0;Bgf`030;Bgf`030000002g
]mT0]kOI00<0]kOI00<000000;Zhe`2j^=L00`2j^=L00`000000_[WD0;jie0030;jie00300000033
^]40`k[A00<0`k[A00<000000<RkcP38^lh00`38^lh00`000000ckg90<nmb@030<nmb@030000003F
_l<0e[o300<0e[o300<000000;ZI]`2jVKL0102jVKL00`000000_iR_0;nH[`050;nH[`040000001?
AZL0000000000080DdNV00P0000005I8YP000000000005m@Z@000000H52X00000080HE2W00D00000
069@Y`1RD:L0000006=@YP02000000<0JeFW00@0000006]DYP1[E:H000000P1aF:L010000000L5NV
071GYP00000407=JYP8000001P1fFjH01@000000Me^T07MKY01gFj@000000080N5bU00D0000007YM
Y@1jGJD0NUfU0000000207YKXP070000001kFj80Ne^R07]KXP000000O5bS0000000207eMX`050000
001nGZ<0OUjS07iNX`0000000P1oGZ<010000000P5nS081OX`0000020000S@040000001cG:T0LebY
000000@0PVba00<0000008eh]`2=N;L0102=N;L00`000000UH:l09F2_00509F2_0030000002KRl40
Vh_100D0Vh_100<000000:2Ba@2PT/D01`2PT/D00`000000Y9S90:BHb@020:BHb@0400000030Y[l0
`:Jo000000L0`:W300<000000;n]a`2o[LL01@2o[LL00`000000_jo:0;n_bP050;n_bP030000002n
/Ld0_[7=00D0_[7=00<000000;fcd02m/m001@2m/m000`000000_;CB0;bddP040;bddP030000002k
]]@0^kKD00<0^kKD0`0000060<O6f@0300000035aMX0aLGJ00<0aLGJ00<000000<?5g033aM`00`33
aM`00`000000`LGM0<75g@040<75g@030000002oa=h0_lCN00<0_lCN00<000000?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0l0?ooo`00;03oool00`000000oooo0?ooo`0`0?ooo`8000003`3oool0
0`000000ZkOR0:^ghP030:^ghP030000002[]^40ZkKQ00<0ZkKQ00<000000:bfh@2/]^400`2/]^40
0`000000[;KP0:bfh0040:bfh0030000002]]^00[KKP0080[KKP00<000000:jfg`2^]]l00`2^]]l0
0`000000[kKN0:nfgP030:nfgP030000002a]]d0/KKM00<0/KKM00<000000;:fg02b]]`00`2b]]`0
0`000000];OK0;Bgf`030;Bgf`030000002g]mT0]kOI00<0]kOI00<000000;Zhe`2j^=L00`2j^=L0
0`000000_[WD0;jie0030;jie00300000033^]40`k[A00<0`k[A00<000000<RkcP38^lh00`38^lh0
0`000000ckg90<nmb@030<nmb@030000003F_l<0e[o30080e[o30P0000070;ZI]`030000002oV:l0
_iR_00@0_iR_00<0000004m6Y`0000000P0000000`1CAjH0000005I8YP020000000405m@Z@000000
H52X00000080HE2W00@00000069@Y`1RD:L000000P1SD:H01@000000JeFW06]EY`1[EJL000000080
JeBV00@00000075HY`1aF:L000000P1`EjH00`000000LeZV07=JYP0307=JYP8000001@1fFjH20000
0080Me^T00D0000007QLY@1hG:D0N5bU0000000207YMY@050000001jFj80NU^R07YKXP0000000P1k
Fj8010000000O5bS07aLX`00000207eMX`040000001nGZ<0OUjS000000<0OejS00<00000081OX`00
00000P0008d010000000LebY07=LZ@000005089//@030000002=N;L0SGRg00@0SGRg00<0000009F2
_02EP[`0102EP[`00`000000Vh_109^;`@0609^;`@030000002PT/D0X9;500H0X9;500D000000:BH
b@2TV<T0Y9S9000000040<2V_`0300000030ZL<0`:W300D0`:W300<000000;n]a`2o[LL0102o[LL0
0`000000_jo:0;n_bP060;n_bP030000002n/Ld0_[7=00D0_[7=00<000000;fcd02m/m001@2m/m00
0`000000_;CB0;bddP040;bddP050000002k]]@0^kKD0;^fe00000000P39a]L00`000000alKI0<O6
f@040<O6f@0300000035aMX0aLGJ00<0aLGJ00<000000<?5g033aM`00`33aM`00`000000`LGM0<75
g@040<75g@030000002oa=h0_lCN00<0_lCN00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0l0?ooo`00;03oool00`000000oooo0?ooo`0b0?ooo`8000003P3oool00`000000ZkOR0:^ghP03
0:^ghP030000002[]^40ZkKQ0080ZkKQ00<000000:bfh@2/]^400`2/]^400`000000[;KP0:bfh004
0:bfh0030000002]]^00[KKP0080[KKP00<000000:jfg`2^]]l00`2^]]l00`000000[kKN0:nfgP03
0:nfgP030000002a]]d0/KKM00<0/KKM00<000000;:fg02b]]`00`2b]]`00`000000];OK0;Bgf`03
0;Bgf`030000002g]mT0]kOI00<0]kOI00<000000;Zhe`2j^=L00`2j^=L00`000000_[WD0;jie003
0;jie00300000033^]40`k[A00<0`k[A00<000000<RkcP38^lh00`38^lh00`000000ckg90<nmb@03
0<nmb@030000003F_l<0e[o3008000000P2dVkd00`000000^YVg0;ZI]`040;ZI]`030000002oV:l0
_iR_00@0_iR_00<0000004m6Y`0000000P0000001@1CAjH0000005I8YP000000EdVV0080000000D0
H52X0000001QD:L0HE2W00000002069@Y`040000001SD:H0He2V00000080JeFW00<0000006]DYP1[
E:H00P1[E:H2000000<0L5NV00<0000007=JYP1cFZH00`1cFZH00`000000MEZU0000000407IKYP80
00000`1gFj@01P000000N5bU07QLY@1hG:D0000007YMY@8000000P1jFj8010000000Ne^R07]KXP00
000207aLX`040000001mGJ<0OEfS000000<0OUjS00@0000007mNX`1oGZ<000000P20Gj<2000000<0
LebY00<00000089//@22K;400`22K;400`000000SGRg08eh]`0408eh]`030000002EP[`0UH:l00D0
UH:l00<0000009^;`@2KRl401@2KRl400`000000X9;50:2Ba@070:2Ba@030000002TV<T0000000D0
`:Jo00<000000<2Y``30ZL<01@30ZL<00`000000_jg70;n]a`050;n]a`030000002o[lX0_jo:00D0
_jo:00<000000;jac@2n/Ld01@2n/Ld00`000000_K?@0;fcd0050;fcd0030000002l]=80_;CB00@0
_;CB00@000000;^fe000000000000`39a]L00`000000alKI0<O6f@040<O6f@0300000035aMX0aLGJ
00<0aLGJ00<000000<?5g033aM`01033aM`00`000000`LGM0<75g@030<75g@030000002oa=h0_lCN
00<0_lCN00<000000?ooo`3oool0E03oool2000003h0oooo000/0?ooo`030000003oool0oooo03@0
oooo0P00000<0?ooo`030000002[]n80ZkOR00<0ZkOR00<000000:^fh@2[]^400P2[]^400`000000
[;KQ0:bfh@030:bfh@030000002/]^00[;KP00@0[;KP00<000000:ffh02]]^000`2]]^000`000000
[[KO0:jfg`030:jfg`030000002_]]h0[kKN00<0[kKN00<000000;6fg@2a]]d00P2a]]d00`000000
/[KL0;:fg0030;:fg0030000002d]m/0];OK00<0];OK00<000000;Ngf@2g]mT00`2g]mT00`000000
^[SG0;Zhe`030;Zhe`030000002n^M@0_[WD00<0_[WD00<000000<>jd@33^]400`33^]400`000000
b;_>0<RkcP030<RkcP030000003?_LT0ckg900<0ckg900<000000=Jo``000000102dVkd00`000000
^YVg0;ZI]`040;ZI]`030000002oV:l0_iR_00@0_iR_00<0000004m6Y`0000000P0000002@1CAjH0
000005I8YP1FB:H0000005M9YP000000H52X00000002065@Y`040000001RD:L0HU2W00000080He2V
0P0000000`1[EJL0000006]DYP0306]DYP030000001`EjH0L5NV0080L5NV00<0000007=JYP1cFZH0
0`1cFZH010000000MEZU07EJY@00000307IKYP030000001fFZ@0000000<0Me^T00@0000007QLY@1h
G:D0N5bU0`00000307YKXP040000001kFj80Ne^R00000080O5bS00@0000007eMX`1mGJ<000000P1n
GZ<01`000000OejS07mNX`1oGZ<00000081OX`0000001@1cG:T00`000000PVba089//@03089//@03
0000002=N;L0SGRg00@0SGRg00<0000009F2_02EP[`01@2EP[`00`000000Vh_109^;`@0509^;`@03
0000002PT/D0X9;500L0X9;500<000000<2V_`30Y[l01@30Y[l00`000000`:W30<2Y``050<2Y``03
0000002o[LL0_jg700@0_jg700<000000;n_bP2o[lX01P2o[lX00`000000_[7=0;jac@050;jac@03
0000002m/m00_K?@00D0_K?@00<000000;bddP2l]=80102l]=800`000000bLKG0<W6e`040<W6e`03
00000037a]T0alKI00<0alKI00<000000<G5fP35aMX00`35aMX00`000000`lGL0<?5g0040<?5g003
00000031aMd0`LGM00<0`LGM00<000000;o4gP2oa=h00`2oa=h00`000000oooo0?ooo`1C0?ooo`03
0000003oool0000003h0oooo000/0?ooo`030000003oool0oooo03H0oooo0P00000:0?ooo`030000
002[]n80ZkOR00<0ZkOR00<000000:^fh@2[]^400`2[]^400`000000[;KQ0:bfh@020:bfh@030000
002/]^00[;KP00@0[;KP00<000000:ffh02]]^000`2]]^000`000000[[KO0:jfg`030:jfg`030000
002_]]h0[kKN00<0[kKN00<000000;6fg@2a]]d00P2a]]d00`000000/[KL0;:fg0030;:fg0030000
002d]m/0];OK00<0];OK00<000000;Ngf@2g]mT00`2g]mT00`000000^[SG0;Zhe`030;Zhe`030000
002n^M@0_[WD00<0_[WD00<000000<>jd@33^]400`33^]400`000000b;_>0<RkcP030<RkcP030000
003?_LT0ckg900<0ckg90P0000050;BK_@030000002jVKL0^YVg00@0^YVg00<000000;nH[`2oV:l0
102oV:l00`000000CdJW000000020000000905=7YP000000ETRV05I8YP000000EdVV0000001PD:P0
00000080HE2W00@00000069@Y`1RD:L000000P1SD:H20000000306]EY`000000JeBV00<0JeBV00<0
0000071GYP1`EjH00`1`EjH00`000000LeZV07=JYP0307=JYP040000001eFZD0MEZU00000080MU^V
00<0000007IJY00000000`1gFj@010000000N5bU07QLY@1hG:D20000000507UJXP000000NU^R07YK
XP0000000P1kFj8010000000O5bS07aLX`00000207eMX`040000001nGZ<0OUjS000000<0OejS00<0
0000081OX`0000001@1cG:T00`000000PVba089//@03089//@030000002=N;L0SGRg00@0SGRg00<0
000009F2_02EP[`01@2EP[`00`000000Vh_109^;`@0609^;`@030000002PT/D0X9;500D0X9;50P00
00070<2V_`0300000030ZL<0`:W300D0`:W300<000000;n]a`2o[LL01@2o[LL00`000000_jo:0;n_
bP050;n_bP030000002n/Ld0_[7=00D0_[7=00<000000;fcd02m/m001@2m/m000`000000_;CB0;bd
dP030;bddP8000001P39a]L00`000000alKI0<O6f@030<O6f@0300000035aMX0aLGJ00@0aLGJ00<0
00000<?5g033aM`00`33aM`00`000000`LGM0<75g@030<75g@030000002oa=h0_lCN00<0_lCN00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`0l0?ooo`00;03oool00`000000oooo0?ooo`0h
0?ooo`800000203oool00`000000ZkOR0:^ghP030:^ghP030000002[]^40ZkKQ00<0ZkKQ00<00000
0:bfh@2/]^400`2/]^400`000000[;KP0:bfh0030:bfh0030000002]]^00[KKP00<0[KKP00<00000
0:jfg`2^]]l00`2^]]l00`000000[kKN0:nfgP030:nfgP030000002a]]d0/KKM0080/KKM00<00000
0;:fg02b]]`00`2b]]`00`000000];OK0;Bgf`040;Bgf`030000002g]mT0]kOI0080]kOI00<00000
0;Zhe`2j^=L00`2j^=L00`000000_[WD0;jie0030;jie00300000033^]40`k[A00<0`k[A00<00000
0<RkcP38^lh00`38^lh00`000000ckg90<nmb@030<nmb@030000002dVkd0]9^m00@0]9^m00<00000
0;ZI]`2jVKL0102jVKL00`000000_iR_0;nH[`050;nH[`@0000000H0DdNV0000001FB:H0ETRV0000
001GBJH300000080HE2W00@00000069@Y`1RD:L000000P1SD:H20000000306]EY`000000JeBV0080
JeBV00<0000006]DY@000000101`EjH2000000@0LeZV00L0000007EJY@1eFZD0MEZU0000001fFjH0
00000080MUZT00D0000007MKY01gFj@0Me^T0000000307QLY@030000001iFZ80000000<0NU^R00@0
000007]KXP1kFj8000000P1lG:<00`000000OEfS0000000307iNX`060000001oGZ<0OejS07mNX`00
0000OU^O1P1cG:T00`000000PVba089//@02089//@030000002=N;L0SGRg00D0SGRg00<0000009F2
_02EP[`01@2EP[`00`000000Vh_109^;`@0609^;`@030000002PT/D0X9;500@0X9;500<000000<2R
^P0000001`30Y[l00`000000`:W30<2Y``050<2Y``030000002o[LL0_jg700@0_jg700<000000;n_
bP2o[lX01P2o[lX00`000000_[7=0;jac@050;jac@030000002m/m00_K?@00D0_K?@00<000000;bd
dP2l]=800P0000000`3<a]@000000<W6e`050<W6e`0300000037a]T0alKI00<0alKI00<000000<G5
fP35aMX01035aMX00`000000`lGL0<?5g0030<?5g00300000031aMd0`LGM00<0`LGM00<000000;o4
gP2oa=h0102oa=h00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo03/0oooo000/0?ooo`03
0000003oool0oooo03X0oooo0`0000050?ooo`030000002[]n80ZkOR00<0ZkOR00<000000:^fh@2[
]^400`2[]^400`000000[;KQ0:bfh@030:bfh@030000002/]^00[;KP00<0[;KP00<000000:ffh02]
]^000`2]]^000`000000[[KO0:jfg`030:jfg`030000002_]]h0[kKN00<0[kKN00<000000;6fg@2a
]]d00`2a]]d00`000000/[KL0;:fg0030;:fg0030000002d]m/0];OK00<0];OK00<000000;Ngf@2g
]mT00P2g]mT00`000000^[SG0;Zhe`030;Zhe`030000002n^M@0_[WD00<0_[WD00<000000<>jd@33
^]401033^]400`000000b;_>0<RkcP020<RkcP040000003?_LT0ckg90<nmb@<000001`2dVkd00`00
0000^YVg0;ZI]`040;ZI]`030000002oV:l0_iR_00@0_iR_00X0000004m6Y`000000DDNW0000001C
AjH0000005I8YP000000EdVV0`000002065@Y`040000001RD:L0HU2W00000080He2V00<0000006A@
YP000000101[E:H00`000000JeBU00000003071GYP80000000H0LURU000000000000000007=JYP00
000407EJY@8000000`1fFZ@010000000Me^T07MKY000000307QLY@040000001iFZ80NEZR00000080
NU^R00@0000007]KXP1kFj8000000P1lG:<010000000OEfS07eMX`00000207iNX`070000001oGZ<0
OejS07mNX`000000OU^O0000000507=LZ@0300000022K;40PVba00<0PVba00<0000008eh]`2=N;L0
102=N;L00`000000UH:l09F2_00509F2_0030000002KRl40Vh_100H0Vh_100<000000:2Ba@2PT/D0
0`2PT/D010000000`::j0<2R^P0000070<2V_`0300000030ZL<0`:W300D0`:W300<000000;n]a`2o
[LL01@2o[LL00`000000_jo:0;n_bP050;n_bP030000002n/Ld0_[7=00D0_[7=00<000000;fcd02m
/m001@2m/m000`000000_;CB000000030<c6e00300000039a]L0bLKG00@0bLKG00<000000<O6f@37
a]T00`37a]T00`000000aLGJ0<G5fP040<G5fP0300000033aM`0`lGL00<0`lGL00<000000<75g@31
aMd00`31aMd00`000000_lCN0;o4gP040;o4gP030000003oool0oooo05D0oooo00<000000?ooo`3o
ool0>`3oool002/0oooo00<000000?ooo`3oool0?P3oool2000000<0oooo00<000000:^ghP2[]n80
0`2[]n800`000000ZkKQ0:^fh@030:^fh@030000002/]^40[;KQ00<0[;KQ00<000000:bfh02/]^00
102/]^000`000000[KKP0:ffh0020:ffh0030000002^]]l0[[KO00<0[[KO00<000000:nfgP2_]]h0
0`2_]]h00`000000/KKM0;6fg@030;6fg@030000002b]]`0/[KL00<0/[KL00<000000;Bgf`2d]m/0
0`2d]m/00`000000]kOI0;Ngf@020;Ngf@030000002j^=L0^[SG00<0^[SG00<000000;jie02n^M@0
0`2n^M@00`000000`k[A0<>jd@040<>jd@0300000038^lh0b;_>0080b;_>00@000000<nmb@3?_LT0
00000`2`WL<00`000000]9^m0;BK_@040;BK_@030000002jVKL0^YVg00@0^YVg00<000000;nH[`2o
V:l0102oV:l02@000000CdJW0000001AAjL0000005=7YP000000ETRV0000000205M9YP8000000P1Q
D:L010000000HU2W069@Y`00000206=@YP030000001TD:H0000000@0JeBV00<0000006]DY@000000
0P1`EjH010000000KeJU06mFY@000003079HY@8000001@1eFZD01@000000MUZT07IJY01fFZ@00000
00<0Me^T00<0000007QLY@1hG:D00P0000001@1iFZ80000007YKXP1jFj80000000<0Ne^R00<00000
07aLX`0000000P1mGJ<01@000000OUjS07iNX`1nGZ<000000080OejS00<0000007iKW`0000001@1c
G:T00`000000PVba089//@03089//@030000002=N;L0SGRg00D0SGRg00<0000009F2_02EP[`01@2E
P[`00`000000Vh_109^;`@0609^;`@050000002PT/D0X9;50:2Ba@0000001030X[X00`000000`:Jo
0<2V_`050<2V_`0300000030ZL<0`:W300D0`:W300<000000;n]a`2o[LL0102o[LL00`000000_jo:
0;n_bP060;n_bP030000002n/Ld0_[7=00D0_[7=00<000000;fcd02m/m001@2m/m000`000000c<KD
0<c6e0030<c6e00300000039a]L0bLKG00<0bLKG00<000000<O6f@37a]T00`37a]T00`000000aLGJ
0<G5fP040<G5fP0300000033aM`0`lGL00<0`lGL00<000000<75g@31aMd01031aMd00`000000_lCN
0;o4gP030;o4gP030000003oool0oooo05D0oooo00<000000?ooo`3oool0>`3oool002/0oooo00<0
00000?ooo`3oool0@03oool200000080oooo00<000000:^ghP2[]n800`2[]n800`000000ZkKQ0:^f
h@020:^fh@030000002/]^40[;KQ00<0[;KQ00<000000:bfh02/]^00102/]^000`000000[KKP0:ff
h0020:ffh0030000002^]]l0[[KO00<0[[KO00<000000:nfgP2_]]h00`2_]]h00`000000/KKM0;6f
g@030;6fg@030000002b]]`0/[KL00<0/[KL00<000000;Bgf`2d]m/00`2d]m/00`000000]kOI0;Ng
f@020;Ngf@030000002j^=L0^[SG00<0^[SG00<000000;jie02n^M@0102n^M@00`000000`k[A0<>j
d@030<>jd@0300000038^lh0b;_>0080b;_>0`0000040;2M``030000002dVkd0]9^m00@0]9^m00<0
00000;ZI]`2jVKL0102jVKL00`000000_iR_0;nH[`040;nH[`090000001?AZL000000557Y`000000
DdNV0000001FB:H000000080EdVV0`0000001@1QD:L00000069@Y`1RD:L000000080He2V00@00000
06A@YP00000000000P1[E:H010000000JeBU06]DY@1[E:D2000000<0KeJU00<00000079HY@1bF:D0
0P1bF:D2000000@0MEZU0P00000307IJY0040000001gFj@0Me^T07MKY080000000D0N5VR0000001i
FZ80NEZR0000000207YKXP040000001kFj80Ne^R00000080O5bS00@0000007eMX`1mGJ<000000P1n
GZ<01P000000OejS0000001mFYl0OU^O000000H0LebY00<00000089//@22K;400`22K;400`000000
SGRg08eh]`0408eh]`030000002EP[`0UH:l00H0UH:l00<0000009^;`@2KRl401P2KRl400`000000
X9;5000000050<2R^P0300000030Y[l0`:Jo00D0`:Jo00<000000<2Y``30ZL<01@30ZL<00`000000
_jg70;n]a`050;n]a`030000002o[lX0_jo:00D0_jo:00<000000;jac@2n/Ld01@2n/Ld00`000000
_K?@0;fcd0030;fcd0<000001@3<a]@00`000000bLKG0<W6e`030<W6e`0300000037a]T0alKI00@0
alKI00<000000<G5fP35aMX00`35aMX00`000000`lGL0<?5g0030<?5g00300000031aMd0`LGM00@0
`LGM00<000000;o4gP2oa=h00`2oa=h00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo03/0
oooo000[0?ooo`030000003oool0oooo0480oooo0`0000050:^ghP030000002[]^40ZkKQ0080ZkKQ
00<000000:bfh@2/]^400`2/]^400`000000[;KP0:bfh0040:bfh0030000002]]^00[KKP0080[KKP
00<000000:jfg`2^]]l00`2^]]l00`000000[kKN0:nfgP030:nfgP030000002a]]d0/KKM00<0/KKM
00<000000;:fg02b]]`00`2b]]`00`000000];OK0;Bgf`030;Bgf`030000002g]mT0]kOI0080]kOI
00<000000;Zhe`2j^=L00`2j^=L00`000000_[WD0;jie0040;jie00300000033^]40`k[A00<0`k[A
00<000000<RkcP38^lh00P38^lh00`000000/9g30;2M``040;2M``030000002dVkd0]9^m00@0]9^m
00<000000;ZI]`2jVKL0102jVKL00`000000_iR_0;nH[`040;nH[`070000001?AZL000000557Y`00
0000DdNV0000000205I8YP050000001GBJH000000000001KBZD00P000002069@Y`050000001SD:H0
He2V0000001TD:H00P00000206]DYP050000001[E:D0JeBU06]DY@000000101_EZD00`000000LURU
079HY@02079HY@030000001dFJ@0000000<0MEZU0P00000307IJY0040000001gFj@0Me^T07MKY080
00000P1hFJ800`000000NEZR0000000207YKXP040000001kFj80Ne^R00000080O5bS00@0000007eM
X`1mGJ<000000`1nGZ<20000000407eJW`1nFil0OU^O000000D0LebY00<00000089//@22K;400`22
K;400`000000SGRg08eh]`0508eh]`030000002EP[`0UH:l00D0UH:l00<0000009^;`@2KRl401P2K
Rl400`000000X9;5000000050<2R^P0300000030Y[l0`:Jo00D0`:Jo00<000000<2Y``30ZL<01P30
ZL<00`000000_jg70;n]a`040;n]a`030000002o[lX0_jo:00H0_jo:00<000000;jac@2n/Ld01@2n
/Ld01@000000_K?@0;fcd02m/m0000000080clKB00<000000<c6e03<a]@00`3<a]@00`000000bLKG
0<W6e`030<W6e`0300000037a]T0alKI00@0alKI00<000000<G5fP35aMX00`35aMX00`000000`lGL
0<?5g0030<?5g00300000031aMd0`LGM00@0`LGM00<000000;o4gP2oa=h00`2oa=h00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo03/0oooo000[0?ooo`030000003oool0oooo04@0oooo00<0
00000:^ghP2[]n800`2[]n800`000000ZkKQ0:^fh@020:^fh@030000002/]^40[;KQ00<0[;KQ00<0
00000:bfh02/]^00102/]^000`000000[KKP0:ffh0020:ffh0030000002^]]l0[[KO00<0[[KO00<0
00000:nfgP2_]]h00`2_]]h00`000000/KKM0;6fg@030;6fg@030000002b]]`0/[KL00<0/[KL00<0
00000;Bgf`2d]m/00`2d]m/00`000000]kOI0;Ngf@020;Ngf@030000002j^=L0^[SG00@0^[SG00<0
00000;jie02n^M@00`2n^M@00`000000`k[A0<>jd@030<>jd@0300000038^lh0b;_>00<000001P2`
WL<00`000000]9^m0;BK_@050;BK_@030000002jVKL0^YVg00<0^YVg00<000000;nH[`2oV:l0102o
V:l01`000000CdJW0000001AAjL0000005=7YP0000000P1FB:H01`000000EdVV0000001IBZD00000
05]:Y@0000000P1RD:L02P000000He2V06=@YP000000I52V0000001UD:D0000006]DYP00000306]D
Y@030000001_EZD0KeJU0080KeJU00<00000079HY@1bF:D00P1bF:D00`000000M5VT07AIY0020000
000407EJY@000000MEVT000000<0MUZT00D0000007MKY01gFj@0Me^T0000000207QIXP030000001i
FZ80000000<0NU^R00@0000007]KXP1kFj8000000P1lG:<010000000OEfS07eMX`00000207iNX`06
0000001mFYl0OEZO0000001nFil000001@1cG:T00`000000PVba089//@04089//@030000002=N;L0
SGRg00@0SGRg00<0000009F2_02EP[`01P2EP[`00`000000Vh_109^;`@0609^;`@0300000030X[X0
`::j00D0`::j00<000000<2V_`30Y[l01@30Y[l00`000000`:W30<2Y``050<2Y``030000002o[LL0
_jg700D0_jg700<000000;n_bP2o[lX01@2o[lX00`000000_[7=0;jac@050;jac@040000002m/m00
0000000000<0clKB00<000000<c6e03<a]@00`3<a]@00`000000bLKG0<W6e`030<W6e`0300000037
a]T0alKI00@0alKI00<000000<G5fP35aMX00`35aMX00`000000`lGL0<?5g0040<?5g00300000031
aMd0`LGM00<0`LGM00<000000;o4gP2oa=h00`2oa=h00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo03X0oooo000[0?ooo`030000003oool0oooo04@0oooo00<000000:^ghP2[]n800`2[]n80
0`000000ZkKQ0:^fh@030:^fh@030000002/]^40[;KQ00<0[;KQ00<000000:bfh02/]^000`2/]^00
0`000000[KKP0:ffh0030:ffh0030000002^]]l0[[KO00<0[[KO00<000000:nfgP2_]]h00`2_]]h0
0`000000/KKM0;6fg@020;6fg@030000002b]]`0/[KL00<0/[KL00<000000;Bgf`2d]m/00`2d]m/0
0`000000]kOI0;Ngf@030;Ngf@030000002j^=L0^[SG00<0^[SG00<000000;jie02n^M@00`2n^M@0
0`000000`k[A0<>jd@030<>jd@<000000`2]WlT00`000000/9g30;2M``040;2M``030000002dVkd0
]9^m00@0]9^m00<000000;ZI]`2jVKL0102jVKL00`000000_iR_0;nH[`040;nH[`8000000P1AAjL2
00000080ETRV00H0000005M9YP000000FDZU0000001KBZD200000008069@Y`000000He2V06=@YP00
0000I52V0000001UD:D2000000@0JeBU0P00000406mFY@030000001bF:D0LURU0080LURU00H00000
07AIY01dFJ@0M5VT0000001eFZD2000000@0MUZT00@0000007MKY01gFj@000000P1hFJ8010000000
NEZR07UJXP00000207YKXP040000001kFj80Ne^R00000080O5bS00D0000007eMX`1mGJ<0000007iN
X`0200000080OEZO00<0000007iKW`0000001P1cG:T00`000000PVba089//@03089//@030000002=
N;L0SGRg00D0SGRg00<0000009F2_02EP[`01@2EP[`00`000000Vh_109^;`@0509^;`@8000001`30
X[X00`000000`:Jo0<2V_`050<2V_`0300000030ZL<0`:W300H0`:W300<000000;n]a`2o[LL0102o
[LL00`000000_jo:0;n_bP060;n_bP030000002n/Ld0_[7=00D0_[7=00<000000<o6dP3?a]80103?
a]800`000000c<KD0<c6e0020<c6e00300000039a]L0bLKG00@0bLKG00<000000<O6f@37a]T00`37
a]T00`000000aLGJ0<G5fP030<G5fP0300000033aM`0`lGL00@0`lGL00<000000<75g@31aMd00`31
aMd00`000000_lCN0;o4gP030;o4gP030000003oool0oooo05H0oooo00<000000?ooo`3oool0>P3o
ool002/0oooo00<000000?ooo`3oool0A03oool00`000000ZkOR0:^ghP030:^ghP030000002[]^40
ZkKQ00<0ZkKQ00<000000:bfh@2/]^400`2/]^400`000000[;KP0:bfh0030:bfh0030000002]]^00
[KKP00<0[KKP00<000000:jfg`2^]]l00`2^]]l00`000000[kKN0:nfgP030:nfgP030000002a]]d0
/KKM0080/KKM00<000000;:fg02b]]`00`2b]]`00`000000];OK0;Bgf`030;Bgf`030000002g]mT0
]kOI00<0]kOI00<000000;Zhe`2j^=L00`2j^=L00`000000_[WD0;jie0030;jie00300000033^]40
`k[A0080`k[A0P0000050:fOb@030000002`WL<0/9g300@0/9g300<000000;BK_@2dVkd0102dVkd0
0`000000^YVg0;ZI]`040;ZI]`030000002oV:l0_iR_00@0_iR_0P0000020557Y`0:0000001CAjH0
000005I8YP000000EdVV0000001IBZD0000005]:Y@80000000L0HU2W0000001SD:H0He2V0000001T
D:H000000080IE2U00L0000006]DY@1[E:D0JeBU0000001[DjD0000000@0KeJU0P000003079HY@03
0000001dFJ@0M5VT0080M5VT0P0000000`1eFJ@0000007IJY00207IJY0030000001gFj@0Me^T0080
00000P1hFJ800`000000NEZR0000000207YKXP050000001kFj80Ne^R07]KXP0000000P1lG:<00`00
0000OEfS07eMX`020000000407aJW`1mFYl0OEZO07eJW`80OU^O00<0000007=LZ@1cG:T00`1cG:T0
0`000000PVba089//@04089//@030000002=N;L0SGRg00@0SGRg00<0000009F2_02EP[`01P2EP[`0
0`000000Vh_109^;`@0409^;`@0300000030WKD0000000L0`::j00<000000<2V_`30Y[l01@30Y[l0
0`000000`:W30<2Y``050<2Y``030000002o[LL0_jg700D0_jg700<000000;n_bP2o[lX01@2o[lX0
0`000000_[7=0;jac@030;jac@<000001P3?a]800`000000c<KD0<c6e0020<c6e00300000039a]L0
bLKG00@0bLKG00<000000<O6f@37a]T00`37a]T00`000000aLGJ0<G5fP040<G5fP0300000033aM`0
`lGL00<0`lGL00<000000<75g@31aMd00`31aMd00`000000_lCN0;o4gP030;o4gP030000003oool0
oooo05H0oooo00<000000?ooo`3oool0>P3oool002X0oooo00<000000?ooo`3oool0AP3oool00`00
0000ZkOR0:^ghP030:^ghP030000002[]^40ZkKQ0080ZkKQ00<000000:bfh@2/]^400`2/]^400`00
0000[;KP0:bfh0030:bfh0030000002]]^00[KKP00<0[KKP00<000000:jfg`2^]]l00`2^]]l00`00
0000[kKN0:nfgP030:nfgP030000002a]]d0/KKM0080/KKM00<000000;:fg02b]]`00`2b]]`00`00
0000];OK0;Bgf`030;Bgf`030000002g]mT0]kOI00<0]kOI00<000000;Zhe`2j^=L00`2j^=L00`00
0000_[WD0;jie0030;jie00300000033^]4000000080000000<0Zj7=0000002]WlT0102]WlT00`00
0000/9g30;2M``040;2M``030000002dVkd0]9^m00@0]9^m00<000000;ZI]`2jVKL0102jVKL00`00
0000_iR_0;nH[`040;nH[`<0000000d0DDNW0000001CAjH0000005I8YP000000EdVV0000001IBZD0
000005]:Y@000000G4^U008000000P1SD:H00`000000I52V0000000206E@Y@8000000P1[E:D01000
0000Je>U06]CY@00000206mFY@80000000D0LENT000000000000LURU0000000507AIY0040000001e
FJ@0MEVT000000<0MUZT0P0000001@1gF:80000007QIXP1hFJ8000000080NEZR00@0000007YKXP1j
Fj8000000P1kFj8010000000O5bS07aLX`00000207eMX`030000001lFYl0O5ZO00<0OEZO00<00000
07iKW`0000001@1cG:T00`000000PVba089//@04089//@030000002=N;L0SGRg00D0SGRg00<00000
09F2_02EP[`01P2EP[`00`000000Vh_109^;`@0209^;`@0400000030WKD0`9fe000000L0`::j00<0
00000<2V_`30Y[l01@30Y[l00`000000`:W30<2Y``060<2Y``030000002o[LL0_jg700@0_jg700<0
00000;n_bP2o[lX01P2o[lX01@000000_[7=0;jac@2n/Ld000000080d/K?00<000000<o6dP3?a]80
103?a]800`000000c<KD0<c6e0030<c6e00300000039a]L0bLKG00<0bLKG00<000000<O6f@37a]T0
0`37a]T00`000000aLGJ0<G5fP040<G5fP0300000033aM`0`lGL00<0`lGL00<000000<75g@31aMd0
0`31aMd00`000000_lCN0;o4gP030;o4gP030000003oool0oooo05H0oooo00<000000?ooo`3oool0
>P3oool002X0oooo00<000000?ooo`3oool0AP3oool00`000000ZkOR0:^ghP030:^ghP030000002[
]^40ZkKQ0080ZkKQ00<000000:bfh@2/]^400`2/]^400`000000[;KP0:bfh0040:bfh0030000002]
]^00[KKP0080[KKP00<000000:jfg`2^]]l00`2^]]l00`000000[kKN0:nfgP030:nfgP030000002a
]]d0/KKM0080/KKM00<000000;:fg02b]]`00`2b]]`00`000000];OK0;Bgf`030;Bgf`030000002g
]mT0]kOI00<0]kOI00<000000;Zhe`2j^=L00`2j^=L00`000000_[WD0;jie0020;jie0<000001@2[
XLd00`000000[Io90:fOb@030:fOb@030000002`WL<0/9g300@0/9g300<000000;BK_@2dVkd0102d
Vkd00`000000^YVg0;ZI]`030;ZI]`030000002oV:l0_iR_00@0_iR_0`0000001P1AAjL0000005=7
YP000000ETRV00000080EdVV0P00000205]:Y@030000001LBjD000000080He2V00<0000006A@YP00
00000P1UD:D200000080JeBU00@0000006]CY@1[DjD000000P1_EZD2000000<0LENT0P00000507AI
Y080000000<0MEVT0000001fFZ@00P1fFZ@200000080MeRR00H0000007QIXP1hFJ80000007UJXP00
000207YKXP040000001kFj80Ne^R000000<0O5bS00<0000007eMX`0000000P1lFYl01P000000OEZO
07eJW`000000OU^O000000H0LebY00<00000089//@22K;400`22K;400`000000SGRg08eh]`0508eh
]`030000002EP[`0UH:l00H0UH:l00D0000009^;`@2KRl40Vh_1000000040<2M]@0300000030X[X0
`::j00D0`::j00<000000<2V_`30Y[l01@30Y[l00`000000`:W30<2Y``050<2Y``030000002o[LL0
_jg700D0_jg700<000000;n_bP2o[lX01@2o[lX010000000_[7=0000000000030=;6c`030000003?
a]80clKB00@0clKB00<000000<c6e03<a]@00`3<a]@00`000000bLKG0<W6e`030<W6e`0300000037
a]T0alKI00<0alKI00<000000<G5fP35aMX01035aMX00`000000`lGL0<?5g0030<?5g00300000031
aMd0`LGM00<0`LGM00<000000;o4gP2oa=h0102oa=h00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo03X0oooo000Z0?ooo`030000003oool0oooo04H0oooo00<000000:^ghP2[]n800`2[]n80
0`000000ZkKQ0:^fh@020:^fh@030000002/]^40[;KQ00<0[;KQ00<000000:bfh02/]^00102/]^00
0`000000[KKP0:ffh0020:ffh0030000002^]]l0[[KO00<0[[KO00<000000:nfgP2_]]h00`2_]]h0
0`000000/KKM0;6fg@020;6fg@030000002b]]`0/[KL00<0/[KL00<000000;Bgf`2d]m/0102d]m/0
0`000000]kOI0;Ngf@020;Ngf@030000002j^=L0^[SG00<0^[SG00<000000;jie00000000P000000
0`2XXm4000000:^Qc@050:^Qc@030000002]WlT0[Io900<0[Io900<000000;2M``2`WL<0102`WL<0
0`000000]9^m0;BK_@040;BK_@030000002jVKL0^YVg00@0^YVg00<000000;nH[`2oV:l00`2oV:l3
000000040557Y`000000DdNV00000080ETRV00P0000005M9YP000000FDZU0000001KBZD0000005a;
Y@80000000/0He2V0000001TD:H0I52V0000001UD:D0000006I@Y@000000JeBU0000000306]CY@80
00000P1_EJ@010000000LENT075GY01aEj@2000000@0M5VT0P00000207EIY0050000001fFZ@0MUZT
07IJY00000000P1gF:8010000000N5VR07QIXP00000207UJXP040000001jFj80NU^R00000080Ne^R
00H0000007aLX`1lG:<0000007eMX`00000207aJW`060000001mFYl0OEZO0000001nFil000001P1c
G:T00`000000PVba089//@04089//@030000002=N;L0SGRg00D0SGRg00<0000009F2_02EP[`01P2E
P[`00`000000Vh_1000000050<2M]@0300000030X[X0`::j00D0`::j00<000000<2V_`30Y[l01@30
Y[l00`000000`:W30<2Y``060<2Y``030000002o[LL0_jg700@0_jg700<000000;n_bP2o[lX01P2o
[lX00`000000d/K?0=;6c`040=;6c`030000003?a]80clKB00<0clKB00<000000<c6e03<a]@00`3<
a]@00`000000bLKG0<W6e`030<W6e`0300000037a]T0alKI00<0alKI00<000000<G5fP35aMX01035
aMX00`000000`lGL0<?5g0030<?5g00300000031aMd0`LGM00@0`LGM00<000000;o4gP2oa=h00`2o
a=h00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo03X0oooo000Z0?ooo`030000003oool0
oooo04H0oooo00<000000:^ghP2[]n800`2[]n800`000000ZkKQ0:^fh@020:^fh@030000002/]^40
[;KQ00<0[;KQ00<000000:bfh02/]^00102/]^000`000000[KKP0:ffh0020:ffh0030000002^]]l0
[[KO00<0[[KO00<000000:nfgP2_]]h00`2_]]h00`000000/KKM0;6fg@030;6fg@030000002b]]`0
/[KL00<0/[KL00<000000;Bgf`2d]m/00`2d]m/00`000000]kOI0;Ngf@020;Ngf@030000002j^=L0
^[SG00D000001@2XXm400`000000Zj7=0:^Qc@030:^Qc@030000002]WlT0[Io900<0[Io900<00000
0;2M``2`WL<0102`WL<00`000000]9^m0;BK_@040;BK_@030000002jVKL0^YVg00@0^YVg00<00000
0;nH[`2oV:l00`2oV:l3000000040557Y`000000DdNV00000080ETRV00P0000005M9YP000000FDZU
0000001KBZD0000005a;Y@80000000P0He2V0000001TD:H0I52V0000001UD:D0000006I@Y@800000
101[DjD01@000000KeFT06mEY01_EJ@0000000@0LENT0P00000307AIY0030000001dF:<000000080
MEVT00@0000007IJY01fFZ@000000P1gF:8010000000N5VR07QIXP00000207UJXP040000001jFj80
NU^R00000080Ne^R00L0000007aLX`1lG:<0O5bS0000001kFIl000000080O5ZO0`1mFYl00`000000
OU^O0000000607=LZ@0300000022K;40PVba00<0PVba00<0000008eh]`2=N;L01@2=N;L00`000000
UH:l09F2_00609F2_0030000002KRl40000000D0`9fe00<000000<2R^P30X[X01@30X[X00`000000
`:Jo0<2V_`060<2V_`0300000030ZL<0`:W300D0`:W300<000000;n]a`2o[LL01@2o[LL00`000000
_jo:0;n_bP040;n_bP8000001P3Ba/l00`000000clKB0<o6dP030<o6dP030000003<a]@0c<KD00<0
c<KD00<000000<W6e`39a]L00`39a]L00`000000alKI0<O6f@040<O6f@0300000035aMX0aLGJ00<0
aLGJ00<000000<?5g033aM`00`33aM`00`000000`LGM0<75g@040<75g@030000002oa=h0_lCN00<0
_lCN00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0i0?ooo`00:P3oool00`000000oooo
0?ooo`160?ooo`030000002[]n80ZkOR00<0ZkOR00<000000:^fh@2[]^400`2[]^400`000000[;KQ
0:bfh@030:bfh@030000002/]^00[;KP00<0[;KP00<000000:ffh02]]^000P2]]^000`000000[[KO
0:jfg`030:jfg`030000002_]]h0[kKN00<0[kKN00<000000;6fg@2a]]d00`2a]]d00`000000/[KL
0;:fg0030;:fg0030000002d]m/0];OK00<0];OK00@000000;Ngf@2g]mT0]kOI100000030:NUe003
0000002XXm40Z:?A00@0Z:?A00<000000:^Qc@2[XLd0102[XLd00`000000[Io90:fOb@030:fOb@03
0000002`WL<0/9g300@0/9g300<000000;BK_@2dVkd00`2dVkd00`000000^YVg0;ZI]`040;ZI]`03
0000002oV:l0_iR_00@0_iR_0P0000020557Y`8000000P1FB:H02P000000EdVV0000001IBZD00000
05]:Y@000000G4^U0000001NC:@200000080I52V00<0000006E@Y@0000000P1VD:D00`000000Je>U
06]CY@0206]CY@050000001_EJ@0KeFT06mEY0000000101aEj@00`000000LeNT0000000207AIY003
0000001dF:<000000080MEVT00<0000007IJY01fFZ@00P00000207MHXP040000001hFJ80N5VR0000
0080NEZR00@0000007YKXP1jFj8000000P1kFj801P000000O5bS07aLX`000000NeVO00000080O5ZO
00H0000007eJW`1mFYl0000007iKW`00000607=LZ@0300000022K;40PVba00@0PVba00<0000008eh
]`2=N;L01@2=N;L00`000000UH:l09F2_00609F2_00300000030WKD0`9fe00D0`9fe00<000000<2R
^P30X[X01@30X[X00`000000`:Jo0<2V_`050<2V_`0300000030ZL<0`:W300H0`:W300<000000;n]
a`2o[LL0102o[LL00`000000_jo:0;n_bP020;n_bP80000000<0eLK;0000003Ba/l01@3Ba/l00`00
0000clKB0<o6dP030<o6dP030000003<a]@0c<KD00<0c<KD00<000000<W6e`39a]L00`39a]L00`00
0000alKI0<O6f@040<O6f@0300000035aMX0aLGJ00<0aLGJ00<000000<?5g033aM`00`33aM`00`00
0000`LGM0<75g@040<75g@030000002oa=h0_lCN00<0_lCN00<000000?ooo`3oool0E@3oool20000
03/0oooo000Z0?ooo`030000003oool0oooo04H0oooo00<000000:^ghP2[]n80102[]n800`000000
ZkKQ0:^fh@020:^fh@030000002/]^40[;KQ00<0[;KQ00<000000:bfh02/]^000`2/]^000`000000
[KKP0:ffh0020:ffh0030000002^]]l0[[KO00<0[[KO00<000000:nfgP2_]]h00`2_]]h00`000000
/KKM0;6fg@030;6fg@030000002b]]`0/[KL00<0/[KL00<000000;Bgf`2d]m/00`2d]m/01P000000
]kOI000000000000YZOG000000H0YjGD00<000000:RSd@2XXm40102XXm400`000000Zj7=0:^Qc@03
0:^Qc@030000002]WlT0[Io900<0[Io900<000000;2M``2`WL<0102`WL<00`000000]9^m0;BK_@04
0;BK_@030000002jVKL0^YVg00<0^YVg00<000000;nH[`2oV:l0102oV:l200000080DDNW00/00000
05=7YP000000ETRV0000001GBJH0000005U:Y@000000FdZU0000000205a;Y@030000001NC:@00000
0080I52V00<0000006E@Y@0000000P1VD:D01`000000Je>U06]CY@1[DjD0000006]CY00000000P1_
EJ@00`000000LENT075GY002075GY0060000001cEj@0LeNT0000001dFJ@000000P1dF:<00`000000
MEVT07EIY0020000000507IHXP000000MeRR07MHXP0000000P1hFJ8010000000NEZR07UJXP000002
07YKXP050000001kFj80Ne^R0000001lG:<00P0000001@1kFIl0000007aJW`1lFYl000000080OEZO
00<0000007iKW`0000001P1cG:T00`000000PVba089//@04089//@030000002=N;L0SGRg00D0SGRg
00<0000009F2_02EP[`01@2EP[`2000000L0`9fe00<000000<2R^P30X[X01@30X[X00`000000`:Jo
0<2V_`060<2V_`0300000030ZL<0`:W300D0`:W300<000000;n]a`2o[LL01@2o[LL010000000_jo:
0;n_bP0000030=G6b`030000003Ba/l0d/K?00@0d/K?00<000000<o6dP3?a]80103?a]800`000000
c<KD0<c6e0020<c6e00300000039a]L0bLKG00@0bLKG00<000000<O6f@37a]T00`37a]T00`000000
aLGJ0<G5fP030<G5fP0300000033aM`0`lGL00@0`lGL00<000000<75g@31aMd00`31aMd00`000000
_lCN0;o4gP030;o4gP030000003oool0oooo05@0oooo00<000000?ooo`000000>`3oool002T0oooo
00<000000?ooo`3oool0B03oool00`000000ZkOR0:^ghP030:^ghP030000002[]^40ZkKQ0080ZkKQ
00<000000:bfh@2/]^400`2/]^400`000000[;KP0:bfh0030:bfh0030000002]]^00[KKP0080[KKP
00<000000:jfg`2^]]l0102^]]l00`000000[kKN0:nfgP030:nfgP030000002a]]d0/KKM0080/KKM
00<000000;:fg02b]]`00`2b]]`00`000000];OK0;Bgf`05000000@0YZOG00<000000:NUe02WYM@0
0`2WYM@00`000000Z:?A0:RSd@040:RSd@030000002[XLd0Zj7=00<0Zj7=00<000000:fOb@2]WlT0
0`2]WlT00`000000/9g30;2M``040;2M``030000002dVkd0]9^m00@0]9^m00<000000;ZI]`2jVKL0
0`2jVKL00`000000_iR_0;nH[`040;nH[`0?0000001?AZL000000557Y`000000DdNV0000001FB:H0
000005M9YP000000FDZU0000001KBZD000000080G4^U00P0000005i<Y0000000000006A@YP000000
IE2U00000080IU2U0P00000206]CY@030000001[Dj@0000000<0KeFT00D00000075GY01aEj@0LENT
0000000307=GY08000000P1dF:<00`000000MEVT07EIY00200000080MURR00@0000007MHXP1gF:80
00000P1hFJ800`000000NEZR0000000207YKXP040000001kFj80Ne^R07]KXP8000000`1kFIl00`00
0000O5ZO07aJW`0207eJW`040000001nFil0OU^O000000H0LebY00<00000089//@22K;401022K;40
0`000000SGRg08eh]`0508eh]`030000002EP[`0UH:l00@0UH:l00<000000;nH/00000001`30WKD0
0`000000`::j0<2R^P050<2R^P0300000030Y[l0`:Jo00D0`:Jo00<000000<2Y``30ZL<01P30ZL<0
0`000000_jg70;n]a`040;n]a`030000002o[lX0000000D0eLK;00<000000=;6c`3Ba/l00`3Ba/l0
0`000000clKB0<o6dP040<o6dP030000003<a]@0c<KD00<0c<KD00<000000<W6e`39a]L00`39a]L0
0`000000alKI0<O6f@030<O6f@0300000035aMX0aLGJ00<0aLGJ00<000000<?5g033aM`01033aM`0
0`000000`LGM0<75g@030<75g@030000002oa=h0_lCN00<0_lCN00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0i0?ooo`00:@3oool00`000000oooo0?ooo`180?ooo`030000002[]n80ZkOR
00<0ZkOR00<000000:^fh@2[]^400P2[]^400`000000[;KQ0:bfh@030:bfh@030000002/]^00[;KP
00<0[;KP00<000000:ffh02]]^000`2]]^000`000000[[KO0:jfg`030:jfg`030000002_]]h0[kKN
00<0[kKN00<000000;6fg@2a]]d00P2a]]d00`000000/[KL0;:fg006000000<0YJWI00<000000:JW
e`2VYmL00`2VYmL00`000000YjGD0:NUe0040:NUe0030000002XXm40Z:?A00<0Z:?A00<000000:^Q
c@2[XLd0102[XLd00`000000[Io90:fOb@030:fOb@030000002`WL<0/9g300<0/9g300<000000;BK
_@2dVkd0102dVkd00`000000^YVg0;ZI]`040;ZI]`030000002oV:l0_iR_0080_iR_100000002P1A
AjL0000005=7YP000000ETRV0000001GBJH0000005U:Y@00000205]:Y@040000001LBjD0000005i<
Y080000000@0I52V0000001UD:D000000P1VD:D200000080Je>U00<0000006]CY00000000`1_EJ@3
00000080LENT00D0000007=GY01cEj@0LeNT0000000307AHX`040000001eFJ@0MEVT00000080MURR
00@0000007MHXP1gF:8000000P1hFJ8010000000NEZR07UJXP00000207YKXP040000001kFj80Ne^R
000000@0NeVO00@0000007aJW`1lFYl000000P1mFYl00`000000OU^O0000000607=LZ@0300000022
K;40PVba00@0PVba00<0000008eh]`2=N;L01@2=N;L00`000000UH:l09F2_00309F2_0040000002o
V;00_iR`000000L0`9fe00<000000<2R^P30X[X01@30X[X00`000000`:Jo0<2V_`060<2V_`030000
0030ZL<0`:W300D0`:W300<000000;n]a`2o[LL01@2o[LL00`000000eLK;0=G6b`040=G6b`030000
003Ba/l0d/K?00<0d/K?00<000000<o6dP3?a]80103?a]800`000000c<KD0<c6e0030<c6e0030000
0039a]L0bLKG00<0bLKG00<000000<O6f@37a]T00`37a]T00`000000aLGJ0<G5fP040<G5fP030000
0033aM`0`lGL00<0`lGL00<000000<75g@31aMd00`31aMd00`000000_lCN0;o4gP030;o4gP030000
003oool0oooo05H0oooo00<000000?ooo`3oool0>@3oool002T0oooo00<000000?ooo`3oool0B03o
ool00`000000ZkOR0:^ghP030:^ghP030000002[]^40ZkKQ0080ZkKQ00<000000:bfh@2/]^400`2/
]^400`000000[;KP0:bfh0040:bfh0030000002]]^00[KKP0080[KKP00<000000:jfg`2^]]l00`2^
]]l00`000000[kKN0:nfgP030:nfgP030000002a]]d0/KKM00D000000`2TZ]/00`000000YJWI0:FY
f@040:FYf@030000002VYmL0YZOG00<0YZOG00<000000:NUe02WYM@00`2WYM@00`000000Z:?A0:RS
d@040:RSd@030000002[XLd0Zj7=00<0Zj7=00<000000:fOb@2]WlT00`2]WlT00`000000/9g30;2M
``040;2M``030000002dVkd0]9^m00<0]9^m00<000000;ZI]`2jVKL0102jVKL00`000000_iR_0;nH
[`020;nH[`@0000000@0DDNW0000001CAjH000000P1FB:H030000000EdVV0000001IBZD0000005]:
Y@000000G4^U0000001NC:@0000005m<Y080000000T0IE2U0000001VD:D0IU2U0000001VD:@00000
06]CY@0000000P1[Dj@400000080L5JT0`00000307=GY08000000`1dF:<00`000000MEVT00000003
07IHXP030000001gF:8000000080N5VR00@0000007UJXP1iFZ8000000P1jFj8010000000Ne^R0000
0000000207]IW`030000001kFIl000000080O5ZO00H0000007eJW`1mFYl0000007iKW`00000607=L
Z@0300000022K;40PVba00D0PVba00<0000008eh]`2=N;L01@2=N;L00`000000UH:l09F2_00209F2
_0040000002oV;00_iR`000000L0`9fe00<000000<2R^P30X[X01@30X[X00`000000`:Jo0<2V_`06
0<2V_`0300000030ZL<0`:W300H0`:W300<000000;n]a`2o[LL00`2o[LL2000000H0eLK;00<00000
0=;6c`3Ba/l00`3Ba/l00`000000clKB0<o6dP040<o6dP030000003<a]@0c<KD00<0c<KD00<00000
0<W6e`39a]L00`39a]L00`000000alKI0<O6f@030<O6f@0300000035aMX0aLGJ00@0aLGJ00<00000
0<?5g033aM`00`33aM`00`000000`LGM0<75g@030<75g@030000002oa=h0_lCN00<0_lCN00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0h0?ooo`00:@3oool00`000000oooo0?ooo`180?oo
o`030000002[]n80ZkOR00<0ZkOR00<000000:^fh@2[]^400P2[]^400`000000[;KQ0:bfh@030:bf
h@030000002/]^00[;KP00@0[;KP00<000000:ffh02]]^000P2]]^000`000000[[KO0:jfg`030:jf
g`030000002_]]h0[kKN00H000000`2T[=d60:BZf`030000002UZMT0YJWI00<0YJWI00<000000:JW
e`2VYmL00`2VYmL00`000000YjGD0:NUe0030:NUe0030000002XXm40Z:?A00@0Z:?A00<000000:^Q
c@2[XLd0102[XLd00`000000[Io90:fOb@020:fOb@030000002`WL<0/9g300@0/9g300<000000;BK
_@2dVkd0102dVkd00`000000^YVg0;ZI]`030;ZI]`040000002oV:l0_iR_0;nH[`80000000<0MF:_
0000000000000P1AAjL200000080ETRV00T0000005M9YP000000FDZU0000001KBZD0000005a;Y@00
00000P1NC:@01@000000GdbT0000001UD:D000000080IU2U00@0000006I@Y000000000000`1[Dj@0
1@000000KUBT06iDY01^E:@0000000<0L5JT0P00000207=GY08000000`1dF:<010000000MEVT0000
0000000207IHXP040000001gF:80MeRR00000080N5VR00@0000007UJXP1iFZ8000000P1jFj820000
000407YIW`1kFIl0NeVO00000080NeVO00<0000007aJW`0000000P1mFYl010000000OU^O07iKW`00
000607=LZ@0300000022K;40PVba00@0PVba00<0000008eh]`2=N;L01@2=N;L01@000000UH:l09F2
_02EP[`0000000@0_iR`00<000000<2M]@30WKD01@30WKD00`000000`::j0<2R^P050<2R^P030000
0030Y[l0`:Jo00D0`:Jo00<000000<2Y``30ZL<01P30ZL<00`000000_jg70;n]a`020;n]a`030000
003HaLL0000000H0eLK;00<000000=;6c`3Ba/l0103Ba/l00`000000clKB0<o6dP030<o6dP030000
003<a]@0c<KD00<0c<KD00<000000<W6e`39a]L00`39a]L00`000000alKI0<O6f@030<O6f@030000
0035aMX0aLGJ00@0aLGJ00<000000<?5g033aM`00`33aM`00`000000`LGM0<75g@030<75g@030000
002oa=h0_lCN00@0_lCN00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`060?ooo`@00000
;P3oool002T0oooo00<000000?ooo`3oool0B03oool00`000000ZkOR0:^ghP030:^ghP030000002[
]^40ZkKQ00<0ZkKQ00<000000:bfh@2/]^400`2/]^400`000000[;KP0:bfh0030:bfh0030000002]
]^00[KKP0080[KKP00<000000:jfg`2^]]l01P0000040:B]gPD0Y:cM00<000000:BZf`2TZ]/00`2T
Z]/00`000000YJWI0:FYf@040:FYf@030000002VYmL0YZOG00<0YZOG00<000000:NUe02WYM@00`2W
YM@00`000000Z:?A0:RSd@030:RSd@030000002[XLd0Zj7=00@0Zj7=00<000000:fOb@2]WlT00`2]
WlT00`000000/9g30;2M``030;2M``030000002dVkd0]9^m00@0]9^m00<000000;ZI]`2jVKL00`2j
VKL01`000000_iR_0;nH[`000000MF:_0000001eHZl01P00000205I8YP090000001GBJH0000005U:
Y@000000FdZU0000001LBjD000000080GTbT00D0000005m<Y0000000IE2U0000000206I@Y@040000
001VD:@0IU2T000000<0Je>T00D0000006iDY01^E:@0KUBT00000003071FY0070000001aEZ<00000
07=GY0000000LUNS0000000307AHX`<000000P1fF:8010000000MeRR07MHXP00000207QIXP040000
001iFZ80NEZR00000080NU^R00@0000007YIW`1jFIl00000101kFIl010000000O5ZO07aJW`000002
07eJW`030000001nFil0000000H0LebY00<00000089//@22K;401@22K;400`000000SGRg08eh]`05
08eh]`030000002EP[`0000000D0_iR`00<000000<2M]@30WKD01@30WKD00`000000`::j0<2R^P05
0<2R^P0300000030Y[l0`:Jo00H0`:Jo00<000000<2Y``30ZL<01P30ZL<01`000000_jg70;n]a`2o
[LL000000=S5a`0000001P3Ea//00`000000d/K?0=;6c`040=;6c`030000003?a]80clKB00<0clKB
00<000000<c6e03<a]@00`3<a]@00`000000bLKG0<W6e`030<W6e`0300000037a]T0alKI00@0alKI
00<000000<G5fP35aMX00`35aMX00`000000`lGL0<?5g0030<?5g00300000031aMd0`LGM00@0`LGM
00<000000;o4gP2oa=h00`2oa=h00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0;`3oool002T0oooo00<000000?ooo`3oool0B03oool00`000000ZkOR0:^g
hP040:^ghP030000002[]^40ZkKQ0080ZkKQ00<000000:bfh@2/]^400`2/]^400`000000[;KP0:bf
h00;000000@0XjkO1P2T[Mh00`000000Y:cM0:B/g@030:B/g@030000002TZ]/0Y:[K00<0Y:[K00<0
00000:FYf@2UZMT00`2UZMT00`000000YZOG0:JWe`030:JWe`030000002WYM@0YjGD00<0YjGD00<0
00000:RSd@2XXm40102XXm400`000000Zj7=0:^Qc@030:^Qc@030000002]WlT0[Io900<0[Io900<0
00000;2M``2`WL<0102`WL<00`000000]9^m0;BK_@030;BK_@030000002jVKL0^YVg00@0^YVg0P00
000207ER[`0C0000001eHZl0000004i1X`000000D4:S0000001CAjH0000005I8YP000000EdVV0000
001IBZD0000005]:Y@000000G4^U0000000205i<Y0030000001OC:@00000008000000P1VD:D01000
0000IU2T06I@Y000000306]CY08000000P1^E:@02`000000L5JT071FY01`EZ@00000075FX`000000
LeNT0000001bEj<0000000<0M5RS0P0000001`1dEj80000007IHXP1fF:80000007MHXP0000000`1h
FJ801P000000NEZR07UJXP000000NU^R00000080NUVO00H0000007]IW`1kFIl0000007]IW`000002
07aJW`060000001mFYl0OEZO0000001nFil000001P1cG:T00`000000PVba089//@05089//@030000
002=N;L0SGRg00D0SGRg00<0000009F2_00000001@2oV;000`000000`9fe0<2M]@060<2M]@030000
0030X[X0`::j00D0`::j00<000000<2V_`30Y[l01@30Y[l00`000000`:W30<2Y``060<2Y``040000
002o[LL0_jg7000000<0f<G700<000000=G6b`3Ea//00`3Ea//00`000000d/K?0=;6c`040=;6c`03
0000003?a]80clKB00<0clKB00<000000<c6e03<a]@00`3<a]@00`000000bLKG0<W6e`030<W6e`03
00000037a]T0alKI00@0alKI00<000000<G5fP35aMX00`35aMX00`000000`lGL0<?5g0030<?5g003
00000031aMd0`LGM00@0`LGM00<000000;o4gP2oa=h00`2oa=h00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0;P3oool002P0oooo00<000000?ooo`3oool0
BP3oool00`000000ZkOR0:^ghP030:^ghP030000002[]^40ZkKQ0080ZkKQ00<000000:bfh@2/]^40
1P0000040:>`h@D0XjoP1P2S[]l00`000000Y:gN0:B]gP040:B]gP030000002T[=d0Y:cM0080Y:cM
00<000000:BZf`2TZ]/00`2TZ]/00`000000YJWI0:FYf@040:FYf@030000002VYmL0YZOG00<0YZOG
00<000000:NUe02WYM@00`2WYM@00`000000Z:?A0:RSd@030:RSd@030000002[XLd0Zj7=00@0Zj7=
00<000000:fOb@2]WlT00`2]WlT00`000000/9g30;2M``030;2M``030000002dVkd0]9^m00<0]9^m
00<000000;ZI]`2jVKL0102jVKL200000080MF:_00H0000007ER[`000000CT6S0000001@@Z<30000
000:05I8YP000000EdVV0000001IBZD0000005]:Y@000000G4^U00000080GTbT00<0000005m<Y000
00000P00000206I@Y@030000001VD:@0IU2T008000000P1[Dj@200000080KUBT00<00000071FY01`
EZ@00P1`EZ@010000000LEJS000000000002079GX`070000001dF:<0M5RS07AHX`000000M5NR0000
000207IHXP040000001gF:80MeRR00000080N5VR00H0000007UJXP1iFZ80000007YKXP00000207YI
W`060000001kFIl0NeVO0000001kFIl000000P1lFYl01P000000OEZO07eJW`000000OU^O000000L0
LebY00<00000089//@22K;401022K;400`000000SGRg08eh]`0608eh]`030000002oV;00_iR`00D0
_iR`00<000000<2M]@30WKD01@30WKD00`000000`::j0<2R^P050<2R^P0300000030Y[l0`:Jo00H0
`:Jo00<000000<2Y``30ZL<01P30ZL<2000000@0f<G700<000000=G6b`3Ea//00`3Ea//00`000000
d/K?0=;6c`040=;6c`030000003?a]80clKB00@0clKB00<000000<c6e03<a]@00`3<a]@00`000000
bLKG0<W6e`030<W6e`0300000037a]T0alKI00<0alKI00<000000<G5fP35aMX00`35aMX00`000000
`lGL0<?5g0030<?5g00300000031aMd0`LGM00@0`LGM00<000000;o4gP2oa=h00`2oa=h00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0;@3oool002P0oooo
00<000000?ooo`3oool0BP3oool00`000000ZkOR0:^ghP0;000000@0Y;7R1P2S/>400`000000XjoP
0:>_h0020:>_h0030000002S[]l0XjkO00@0XjkO00<000000:B]gP2T[Mh00`2T[Mh00`000000Y:cM
0:B/g@030:B/g@030000002TZ]/0Y:[K00<0Y:[K00<000000:FYf@2UZMT00`2UZMT00`000000YZOG
0:JWe`030:JWe`030000002WYM@0YjGD00<0YjGD00<000000:RSd@2XXm40102XXm400`000000Zj7=
0:^Qc@030:^Qc@030000002]WlT0[Io900<0[Io900<000000;2M``2`WL<00`2`WL<00`000000]9^m
0;BK_@040;BK_@030000002jVKL0^YVg00<0^YVg00D0000007ER[`1eHZl0MF:_0000000207ER[`80
000000P0D4:S0000001B@j<0000005I8YP000000EdVV00000080FDZU00/0000005]:Y@000000G4^U
0000001NC:@0000005m<Y0000000HDfT0000000206I@Y@030000001VD:@0IU2T0080000000D0Je>T
0000001[DZ<0Je:S0000000206iDY0050000001`EZ@0L5JT071FY00000000P1aEZ<01@000000LUNS
079GX`1bEj<000000080M5RS00@0000007AGXP1dEj8000000P1fF:800`000000MeRR0000000207QI
XP070000001iFZ80NEZR07UJXP000000NERO0000000207YIW`030000001kFIl0NeVO0080NeVO00H0
000007aJW`1lFYl0000007eJW`00000207iKW`030000001cG:T0LebY00@0LebY00<00000089//@22
K;401@22K;400`000000SGRg08eh]`0508eh]`030000002oV;00_iR`00D0_iR`00<000000<2M]@30
WKD01@30WKD00`000000`::j0<2R^P060<2R^P0300000030Y[l0`:Jo00D0`:Jo00<000000<2Y``30
ZL<01P30ZL<00`000000f<G70=S5a`030=S5a`030000003Ea//0eLK;00@0eLK;00<000000=;6c`3B
a/l00`3Ba/l00`000000clKB0<o6dP040<o6dP030000003<a]@0c<KD00<0c<KD00<000000<W6e`39
a]L00`39a]L00`000000alKI0<O6f@030<O6f@0300000035aMX0aLGJ00<0aLGJ00<000000<?5g033
aM`01033aM`00`000000`LGM0<75g@030<75g@030000002oa=h0_lCN00@00000F03oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo02`0oooo000X0?ooo`030000003oool0oooo04X0oooo
0`0000040:Bbh`D0Y;;R1P2T/N800`000000Xk3Q0:>`h@040:>`h@030000002S[n00XjoP0080XjoP
00<000000:>^g`2S[]l00`2S[]l00`000000Y:gN0:B]gP040:B]gP030000002T[=d0Y:cM0080Y:cM
00<000000:BZf`2TZ]/00`2TZ]/00`000000YJWI0:FYf@040:FYf@030000002VYmL0YZOG0080YZOG
00<000000:NUe02WYM@0102WYM@00`000000Z:?A0:RSd@030:RSd@030000002[XLd0Zj7=00<0Zj7=
00<000000:fOb@2]WlT00`2]WlT00`000000/9g30;2M``040;2M``030000002dVkd0]9^m00<0]9^m
00<000000;ZI]`2jVKL00P2jVKL2000000<0MF:_00<0000007ER[`1eHZl00P0000020512X`<00000
00<0ETRV0000000000000P1IBZD01`000000FdZU0000001LBjD0000005i<Y00000000P1OC:@30000
000606I@Y@000000IU2T06I@Y0000000Ie2S0P00000206]BX`030000001^E:@0KUBT008000000P1`
EZ@00`000000LEJS075FX`0200000080LUNS00<0000007AHX`1dF:<00P0000001@1dEj80000007IH
XP1fF:8000000080MeRR00@0000007QIXP1hFJ8000000P1iFZ800`000000NERO0000000207YIW`06
0000001kFIl0NeVO0000001kFIl000000P1lFYl01P000000OEZO07eJW`000000OU^O000000H0LebY
00<00000089//@22K;401@22K;400`000000SGRg08eh]`0408eh]`030000002mTZX0000000H0_iR`
00<000000<2M]@30WKD01P30WKD00`000000`::j0<2R^P050<2R^P0300000030Y[l0`:Jo00H0`:Jo
00<000000<2Y``30ZL<01030ZL<2000000D0f<G700<000000=G6b`3Ea//0103Ea//00`000000d/K?
0=;6c`030=;6c`030000003?a]80clKB00@0clKB00<000000<c6e03<a]@00`3<a]@00`000000bLKG
0<W6e`030<W6e`0300000037a]T0alKI00<0alKI00<000000<G5fP35aMX00`35aMX00`000000`lGL
0<?5g0040<?5g00300000031aMd0`LGM0080`LGM100000030<CDiP030000003oool0oooo05L0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`00000^0?ooo`00:03oool00`000000oooo
0?ooo`1;0?ooo`H0Y;;S00<000000:BbhP2T/^800P2T/^800`000000Y;7R0:BahP040:BahP030000
002S/>40Xk3Q00<0Xk3Q00<000000:>_h02S[n000P2S[n000`000000XjkO0:>^g`040:>^g`030000
002T[Mh0Y:gN00<0Y:gN00<000000:B/g@2T[=d00`2T[=d00`000000Y:[K0:BZf`030:BZf`030000
002UZMT0YJWI00<0YJWI00<000000:JWe`2VYmL00`2VYmL00`000000YjGD0:NUe0030:NUe0030000
002XXm40Z:?A00<0Z:?A00<000000:^Qc@2[XLd0102[XLd00`000000[Io90:fOb@030:fOb@030000
002`WL<0/9g300<0/9g300<000000;BK_@2dVkd00`2dVkd01@000000^YVg0;ZI]`2jVKL000000080
LfRh00@0000007ER[`1eHZl000000P1eHZl010000000CT6S0000001@@Z<20000000=05A4X`000000
000005M9YP000000FDZU0000001KBZD0000005a;Y@000000GTbT0000000205m<Y0<0000000H0IU2U
0000001VD:@0IU2T0000001WD:<2000000<0Je:S00@0KUBT000000000000KeFS0`000002075FX`80
00000`1bEj<20000000407=FXP000000M5NR000000<0MURR00<0000007MHXP0000000P1hFJ801P00
0000NEZR000000000000NERO00000080NUVO00H0000007]IW`1kFIl0000007]IW`00000207aJW`06
0000001mFYl0OEZO0000001nFil000001`1cG:T00`000000PVba089//@05089//@030000002=N;L0
SGRg00<0SGRg00<000000;fBZP0000001`2oV;000`000000`9fe0<2M]@050<2M]@0300000030X[X0
`::j00D0`::j00<000000<2V_`30Y[l01P30Y[l00`000000`:W30<2Y``030<2Y``030000003Ka<<0
000000D0f<G700<000000=G6b`3Ea//0103Ea//00`000000d/K?0=;6c`030=;6c`030000003?a]80
clKB00@0clKB00<000000<c6e03<a]@00`3<a]@00`000000bLKG0<W6e`030<W6e`0300000037a]T0
alKI00<0alKI00<000000<G5fP35aMX01035aMX00`000000`lGL0<?5g0030<?5g00300000031aMd0
00000080000000<0amKU00000034e>H00`34e>H00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo00H0oooo0P00000_0?ooo`00:03oool00`000000oooo0?ooo`1;0?ooo`030000002T/^<0Y;;S
00@0Y;;S00<000000:BbhP2T/^800P2T/^800`000000Y;7R0:BahP030:BahP030000002S/>40Xk3Q
00@0Xk3Q00<000000:>_h02S[n000P2S[n000`000000XjkO0:>^g`030:>^g`030000002T[Mh0Y:gN
00@0Y:gN00<000000:B/g@2T[=d00P2T[=d00`000000Y:[K0:BZf`030:BZf`030000002UZMT0YJWI
00<0YJWI00<000000:JWe`2VYmL00`2VYmL00`000000YjGD0:NUe0030:NUe0030000002XXm40Z:?A
00@0Z:?A00<000000:^Qc@2[XLd00`2[XLd00`000000[Io90:fOb@030:fOb@030000002`WL<0/9g3
00<0/9g300<000000;BK_@2dVkd00`2dVkd010000000^YVg0;ZI]`00000307=X^0040000001eHZl0
MF:_00000080MF:_0140000004i1X`000000D4:S0000001B@j<0000005A4X`000000EdVV0000001I
BZD0000005]:Y@000000G4^U0000000205i<Y0050000001OC:@000000000001RCJ<00P00000206I@
Y0040000001WD:<0Ie2S000000<0Je:S00@0000006iCX`1^Dj<000000P1_EJ<200000004075FX`00
0000LEJS00000080LUNS0P0000001@1cEZ80000007AGXP1dEj8000000080MURR00<0000007MHXP00
00000`1hFJ820000000607QHX01iF9l0NERO0000001jFIl000000P1kFIl01P000000NeVO07]IW`00
0000O5ZO00000080OEZO00@0000007iKW`1nFil000001P1cG:T00`000000PVba089//@05089//@03
0000002=N;L0SGRg0080SGRg00@000000;fBZP2mTZX000001`2oV;000`000000`9fe0<2M]@060<2M
]@0300000030X[X0`::j00D0`::j00<000000<2V_`30Y[l01P30Y[l01@000000`:W30<2Y``30ZL<0
00000080flC300<000000=S5a`3HaLL00`3HaLL00`000000eLK;0=G6b`040=G6b`030000003Ba/l0
d/K?00@0d/K?00<000000<o6dP3?a]800`3?a]800`000000c<KD0<c6e0030<c6e00300000039a]L0
bLKG00<0bLKG00<000000<O6f@37a]T00`37a]T00`000000aLGJ0<G5fP040<G5fP0300000033aM`0
`lGL0080`lGL0`0000030<OFi@0300000034e>H0a=CV00<0a=CV00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0g0?ooo`00:03oool00`000000oooo0?ooo`1<0?ooo`030000002T/^<0Y;;S
00<0Y;;S00<000000:BbhP2T/^800`2T/^800`000000Y;7R0:BahP030:BahP030000002S/>40Xk3Q
00<0Xk3Q00<000000:>_h02S[n000`2S[n000`000000XjkO0:>^g`030:>^g`030000002T[Mh0Y:gN
00<0Y:gN00<000000:B/g@2T[=d00`2T[=d00`000000Y:[K0:BZf`030:BZf`030000002UZMT0YJWI
00<0YJWI00<000000:JWe`2VYmL00`2VYmL00`000000YjGD0:NUe0030:NUe0030000002XXm40Z:?A
00<0Z:?A00<000000:^Qc@2[XLd00`2[XLd00`000000[Io90:fOb@030:fOb@030000002`WL<0/9g3
00<0/9g300<000000;BK_@2dVkd0102dVkd2000000@0LfRh00@0000007ER[`1eHZl000000`1eHZl2
000000050512X`000000DT>S0000001DA:<00`0000001P1IBZD0000005]:Y@000000G4^U00000080
GTbT00L0000005m<Y0000000HDfT0000001RCJ<000000080IU2T00@0000006M@X`1WD:<000000`1[
DZ<010000000KU>S06iCX`00000206mEX`040000001`EJ<00000075FX`8000000`1bEj<01P000000
LeJR07=FXP000000M5NR00000080MURR00@0000007MHXP1gF:8000000P1hFJ801P000000N5RP07QH
X0000000NERO00000080NUVO00H0000007]IW`1kFIl0000007]IW`00000207aJW`030000001mFYl0
00000080OU^O00<0000007=LZ@1cG:T01@1cG:T00`000000PVba089//@05089//@050000002=N;L0
SGRg08eh]`0000000`2mTZX00`000000_iR`0;nH/0050;nH/00300000030WKD0`9fe00D0`9fe00<0
00000<2R^P30X[X01@30X[X00`000000`:Jo0<2V_`060<2V_`0400000030ZL<0`:W3000000@0flC3
00<000000=S5a`3HaLL00P3HaLL00`000000eLK;0=G6b`040=G6b`030000003Ba/l0d/K?00@0d/K?
00<000000<o6dP3?a]800`3?a]800`000000c<KD0<c6e0030<c6e00300000039a]L0bLKG00<0bLKG
00<000000<O6f@37a]T00`37a]T00`000000aLGJ0<G5fP040<G5fP0300000033aM`0000000800000
00<0bMST00000037e^D00`37e^D00`000000a=CV0<CDiP030<CDiP030000003oool0oooo05P0oooo
00<000000?ooo`3oool0<03oool2000000D0oooo000W0?ooo`030000003oool0oooo04h0oooo00<0
00000:Bbh`2T/^<00`2T/^<00`000000Y;;R0:BbhP020:BbhP030000002T/N80Y;7R00@0Y;7R00<0
00000:>`h@2S/>400`2S/>400`000000XjoP0:>_h0020:>_h0030000002S[]l0XjkO00<0XjkO00<0
00000:B]gP2T[Mh0102T[Mh00`000000Y:cM0:B/g@020:B/g@030000002TZ]/0Y:[K00<0Y:[K00<0
00000:FYf@2UZMT00`2UZMT00`000000YZOG0:JWe`030:JWe`030000002WYM@0YjGD00<0YjGD00<0
00000:RSd@2XXm400`2XXm400`000000Zj7=0:^Qc@040:^Qc@030000002]WlT0[Io900<0[Io900<0
00000;2M``2`WL<00`2`WL<00`000000]9^m0;BK_@030;BK_@030000001cJ;P0LfRh00@0LfRh00<0
000007ER[`0000000`1eHZl200000080D4:S0P000000101DA:<0000005I5X`00000205U:Y@800000
00X0G4^U0000001NC:@0GTbT0000001OC:@00000065=Y0000000HTfS0P000000101VD:@0000006M@
X`1WD:<200000080Je:S0P0000002`1^Dj<0000006mEX`1_EJ<00000071EX`000000LEJS0000001a
EZ<000000080LUNS00@0000007=FXP1cEZ8000000P1dEj801`000000MURR07IHXP000000MeRR0000
001hFJ800P00000207QHX0030000001iF9l000000080NUVO00H0000007]IW`1kFIl0000007]IW`00
000207aJW`060000001mFYl0OEZO0000001nFil000001`1cG:T00`000000PVba089//@05089//@05
0000002=N;L0SGRg08eh]`0000000`2mTZX00`000000_iR`0;nH/0050;nH/00300000030WKD0`9fe
00H0`9fe00<000000<2R^P30X[X01@30X[X00`000000`:Jo0<2V_`060<2V_`8000001@3Ka<<00`00
0000f<G70=S5a`030=S5a`030000003Ea//0eLK;00<0eLK;00<000000=;6c`3Ba/l0103Ba/l00`00
0000clKB0<o6dP030<o6dP030000003<a]@0c<KD00@0c<KD00<000000<W6e`39a]L00P39a]L00`00
0000alKI0<O6f@040<O6f@0300000035aMX0aLGJ0080aLGJ0`0000030<WHi00300000037e^D0amKU
00<0amKU00<000000<CDiP34e>H00P34e>H00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo
02l0oooo00@000000?ooo`3oool00000103oool002L0oooo00<000000?ooo`3oool0CP3oool00`00
0000Y;;S0:Bbh`040:Bbh`030000002T/^80Y;;R0080Y;;R00<000000:BahP2T/N800`2T/N800`00
0000Xk3Q0:>`h@040:>`h@030000002S[n00XjoP0080XjoP00<000000:>^g`2S[]l00`2S[]l00`00
0000Y:gN0:B]gP030:B]gP030000002T[=d0Y:cM00<0Y:cM00<000000:BZf`2TZ]/00`2TZ]/00`00
0000YJWI0:FYf@030:FYf@030000002VYmL0YZOG00<0YZOG00<000000:NUe02WYM@00`2WYM@00`00
0000Z:?A0:RSd@030:RSd@030000002[XLd0Zj7=00<0Zj7=00<000000:fOb@2]WlT00`2]WlT00`00
0000/9g30;2M``030;2M``030000002dVkd0]9^m0080]9^m0P00000607=X^0030000001eHZl00000
00<0MF:_00@0000004i1X`000000D4:S0P00000205A4X`D0000000<0FdZU0000000000000P1NC:@0
1P000000GdbT0000001QCJ@00000069=X`80000000@0IU2T0000001WD:<0Ie2S0P00000206]BX`80
00000P1^Dj<00`000000KeFS00000002071EX`80000000@0LEJS0000001bEj<0LUNS0P0000001@1c
EZ80000007AGXP1dEj8000000080MURR00<0000007MHXP1gF:800P000000101gEj00N5RP07QHX000
000207UHW`030000001jFIl000000080NeVO00<0000007]IW`0000000P1lFYl01P000000OEZO07eJ
W`000000OU^O000000L0LebY00<00000089//@22K;401P22K;400`000000SGRg000000040;fBZP03
0000002oV;00_iR`00D0_iR`00<000000<2M]@30WKD01P30WKD00`000000`::j0<2R^P050<2R^P03
00000030Y[l0`:Jo00H0`:Jo00<000000=_4``3Ka<<0103Ka<<00`000000f<G70=S5a`030=S5a`03
0000003Ea//0eLK;00<0eLK;00<000000=;6c`3Ba/l0103Ba/l00`000000clKB0<o6dP040<o6dP03
0000003<a]@0c<KD00<0c<KD00<000000<W6e`39a]L00P39a]L00`000000alKI0<O6f@040<O6f@03
00000035aMX0aLGJ0080000000<0cM[S00000039f>@00`39f>@00`000000amKU0<OFi@020<OFi@03
00000034e>H0a=CV00<0a=CV00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo00D0oooo000W0?ooo`030000003oool0oooo04l0oooo00<000000:Bbh`2T/^<0
0`2T/^<00`000000Y;;R0:BbhP030:BbhP030000002T/N80Y;7R00<0Y;7R00<000000:>`h@2S/>40
0`2S/>400`000000XjoP0:>_h0020:>_h0030000002S[]l0XjkO00<0XjkO00<000000:B]gP2T[Mh0
102T[Mh00`000000Y:cM0:B/g@020:B/g@030000002TZ]/0Y:[K00<0Y:[K00<000000:FYf@2UZMT0
0`2UZMT00`000000YZOG0:JWe`030:JWe`030000002WYM@0YjGD00<0YjGD00<000000:RSd@2XXm40
0`2XXm400`000000Zj7=0:^Qc@030:^Qc@030000002]WlT0[Io900<0[Io900<000000;2M``2`WL<0
0`2`WL<00`000000]9^m0;BK_@0200000080Lfo000<0000007=X^01cJ;P00`1cJ;P00`000000MF:_
0000000307ER[`080000001>@J<000000512X`000000DT>S0000001DA:<200000080F4JR00@00000
05]:Y@00000000000P1NC:@01@000000GdbT0000001QCJ@000000080HTfS0`00000206M@X`060000
001XD:<000000000001[DZ<000000P1^Dj<010000000KeFS06mEX`000002071EX`030000001aEZ<0
LEJS0080000000L0LUFR0000001cEZ80LeJR0000001dEj80000000<0MURR00<0000007MHXP000000
0P1gEj001P000000N5RP07QHX0000000NERO00000080NUVO00<0000007]IW`0000000P1kFIl01P00
0000O5ZO07aJW`000000OEZO00000080OU^O00<0000007=LZ@1cG:T01@1cG:T00`000000PVba089/
/@05089//@030000002=N;L0000000D0_I:Z00<000000;nH/02oV;001@2oV;000`000000`9fe0<2M
]@050<2M]@0300000030X[X0`::j00D0`::j00<000000<2V_`30Y[l01@30Y[l2000000H0flC300<0
00000=S5a`3HaLL00`3HaLL00`000000eLK;0=G6b`040=G6b`030000003Ba/l0d/K?00<0d/K?00<0
00000<o6dP3?a]80103?a]800`000000c<KD0<c6e0030<c6e00300000039a]L0bLKG00<0bLKG00<0
00000<O6f@37a]T00`37a]T300000080cM[S00<000000<WHi039f>@00`39f>@00`000000amKU0<OF
i@020<OFi@0300000034e>H0a=CV0080a=CV00<000000?ooo`3oool0FP3oool200000300oooo00@0
00000?ooo`3oool00000103oool002L0oooo00<000000?ooo`3oool0C`3oool00`000000Y;;S0:Bb
h`040:Bbh`030000002T/^80Y;;R0080Y;;R00<000000:BahP2T/N800`2T/N800`000000Xk3Q0:>`
h@040:>`h@030000002S[n00XjoP0080XjoP00<000000:>^g`2S[]l00`2S[]l00`000000Y:gN0:B]
gP030:B]gP030000002T[=d0Y:cM00<0Y:cM00<000000:BZf`2TZ]/00`2TZ]/00`000000YJWI0:FY
f@030:FYf@030000002VYmL0YZOG00<0YZOG00<000000:NUe02WYM@00P2WYM@00`000000Z:?A0:RS
d@040:RSd@030000002[XLd0Zj7=00<0Zj7=00<000000:fOb@2]WlT00`2]WlT00`000000/9g30;2M
``030;2M``800000101cKl000`000000LfRh07=X^00307=X^0030000001eHZl0000000@0MF:_0P00
00002@1@@Z<000000593X`000000E4BS0000001FAJ<0000005Q6XP030000000805a;Y@000000GTbT
0000001OC:@00000065=Y0000002069=X`030000001TCZ<000000080Ie2S00@0000006Q@X`000000
00000P1[DZ<01P000000KU>S06iCX`000000KeFS00000080L5FS0P0000000`1aEZ<0000000000002
079EXP030000001cEZ8000000080M5NR00H0000007IHXP1fF:80000007MHXP00000207MGX0060000
001hF:00N5RP0000001iF9l000000P1jFIl01P000000NeVO07]IW`000000NeVO00000080O5ZO00H0
000007eJW`1mFYl0000007iKW`00000707=LZ@0300000022K;40PVba00H0PVba00<000000;fBZP2m
TZX0102mTZX00`000000_iR`0;nH/0050;nH/00300000030WKD0`9fe00H0`9fe00<000000<2R^P30
X[X01@30X[X00`000000`:Jo0<2V_`030<2V_`030000003N`kd0000000H0flC300<000000=S5a`3H
aLL00`3HaLL00`000000eLK;0=G6b`040=G6b`030000003Ba/l0d/K?00<0d/K?00<000000<o6dP3?
a]80103?a]800`000000c<KD0<c6e0030<c6e00300000039a]L0bLKG00<0bLKG00<000000<O6f@37
a]T00P37a]T2000000@0cM[S00<000000<WHi039f>@00P39f>@00`000000amKU0<OFi@030<OFi@03
00000034e>H0a=CV0080a=CV00<000000?ooo`3oool0F03oool2000000030?ooo`000000oooo0300
oooo0P0000050?ooo`009`3oool00`000000oooo0?ooo`1@0?ooo`030000002T/^<0Y;;S00<0Y;;S
00<000000:BbhP2T/^800`2T/^800`000000Y;7R0:BahP030:BahP030000002S/>40Xk3Q00<0Xk3Q
00<000000:>_h02S[n000`2S[n000`000000XjkO0:>^g`030:>^g`030000002T[Mh0Y:gN00<0Y:gN
00<000000:B/g@2T[=d00P2T[=d00`000000Y:[K0:BZf`030:BZf`030000002UZMT0YJWI00<0YJWI
00<000000:JWe`2VYmL00`2VYmL00`000000YjGD0:NUe0030:NUe0030000002XXm40Z:?A00<0Z:?A
00<000000:^Qc@2[XLd00`2[XLd00`000000[Io90:fOb@030:fOb@030000002`WL<0/9g300<0/9g3
00<0000007=_`01cKl000`1cKl000`000000LfRh07=X^00407=X^0800000101eHZl200000080D4:S
0P000000401DA:<0000005I5X`000000F4JR0000001IAj80000005a;Y@000000GTbT0000001OC:@0
0000065=Y0000002069=X`060000001TCZ<000000000001WD:<000000P1XD:<010000000Je:S06]B
X`00000206iCX`030000001_EJ<000000080L5FS0P000002075FX`040000001bEJ80LUFR00000080
LeJR00<0000007AGXP0000000`1fF:801@000000MUJP07MGX01gEj0000000080N5RP00<0000007UH
W`0000000P1jFIl01P000000NeVO07]IW`000000NeVO00000080O5ZO00H0000007eJW`1mFYl00000
07iKW`00000707=LZ@0300000022K;40PVba00H0PVba00<000000;fBZP2mTZX0102mTZX00`000000
_iR`0;nH/0050;nH/00300000030WKD0`9fe00H0`9fe00<000000<2R^P30X[X01@30X[X00`000000
`:Jo0<2V_`020<2V_`040000003N`kd0g/>m000000H0flC300<000000=S5a`3HaLL00`3HaLL00`00
0000eLK;0=G6b`040=G6b`030000003Ba/l0d/K?00<0d/K?00<000000<o6dP3?a]80103?a]800`00
0000c<KD0<c6e0030<c6e00300000039a]L0bLKG00<0bLKG00<000000<O6f@0000000P0000000`3@
gN8000000<gJh`030<gJh`0300000039f>@0bMST0080bMST00<000000<OFi@37e^D00P37e^D00`00
0000a=CV0<CDiP030<CDiP030000003oool0oooo05L0oooo00D000000?ooo`3oool0oooo0000000h
0?ooo`009`3oool00`000000oooo0?ooo`1A0?ooo`030000002T/^<0Y;;S00<0Y;;S00<000000:Bb
hP2T/^800P2T/^800`000000Y;7R0:BahP030:BahP030000002S/>40Xk3Q00@0Xk3Q00<000000:>_
h02S[n000P2S[n000`000000XjkO0:>^g`030:>^g`030000002T[Mh0Y:gN00<0Y:gN00<000000:B/
g@2T[=d00`2T[=d00`000000Y:[K0:BZf`030:BZf`030000002UZMT0YJWI00<0YJWI00<000000:JW
e`2VYmL00`2VYmL00`000000YjGD0:NUe0020:NUe0030000002XXm40Z:?A00<0Z:?A00<000000:^Q
c@2[XLd0102[XLd00`000000[Io90:fOb@020:fOb@040000002`WL<0/9g30;2M``<000001P1cKl00
0`000000LfRh07=X^00307=X^0800000101eHZl010000000CT6S0000001@@Z<200000080E4BS0P00
000205Q6XP@000000P1NC:@200000080HDfT00@00000069=X`000000I4jS0P000000101WD:<00000
06Q@X`1XD:<200000080Je:S00<0KU>S0000000000000P000002071EX`050000001`E:800000075F
X`0000000`1bEJ800`000000LeJR0000000207AGXP060000001fF:80MURR0000001fEZ0000000P1g
Ej000`000000N5RP0000000207UHW`030000001jFIl000000080NeVO00<0000007]IW`0000000P1l
FYl010000000OEZO07eJW`00000207iKW`030000001cG:T0LebY00D0LebY00<00000089//@22K;40
1@22K;400`000000_I:Z0;fBZP050;fBZP030000002oV;00_iR`00D0_iR`00<000000<2M]@30WKD0
1P30WKD00`000000`::j0<2R^P050<2R^P0500000030Y[l0`:Jo0<2V_`0000000`3N`kd00`000000
flC30=_4``030=_4``030000003HaLL0f<G700<0f<G700<000000=G6b`3Ea//0103Ea//00`000000
d/K?0=;6c`040=;6c`030000003?a]80clKB00<0clKB00<000000<c6e03<a]@00`3<a]@00`000000
bLKG0<W6e`030<W6e`8000000`3@gN800`000000cM[S0<gJh`020<gJh`0300000039f>@0bMST00<0
bMST00<000000<OFi@37e^D00P37e^D00`000000a=CV0<CDiP020<CDiP030000003oool0oooo05`0
oooo00<000000?ooo`3oool0=P3oool002H0oooo00<000000?ooo`3oool0DP3oool00`000000Y;;S
0:Bbh`040:Bbh`030000002T/^80Y;;R0080Y;;R00<000000:BahP2T/N800`2T/N800`000000Xk3Q
0:>`h@030:>`h@030000002S[n00XjoP00<0XjoP00<000000:>^g`2S[]l00`2S[]l00`000000Y:gN
0:B]gP030:B]gP030000002T[=d0Y:cM00<0Y:cM00<000000:BZf`2TZ]/00P2TZ]/00`000000YJWI
0:FYf@030:FYf@030000002VYmL0YZOG00<0YZOG00<000000:NUe02WYM@00`2WYM@00`000000Z:?A
0:RSd@030:RSd@030000002[XLd0Zj7=00<0Zj7=00<000000:fOb@2]WlT00`2]WlT3000000<0M7O8
00<0000007=_`01cKl000`1cKl000`000000LfRh07=X^00307=X^0800000101eHZl020000000CT6S
0000001@@Z<000000593X`000000E4BS0P00000205Q6XP80000000h0FdRR0000001NC:@0GTbT0000
001OC:@00000065=Y0000000HTfS0000001TCZ<0000006E>X`8000000P1XD:<200000080Je:S00@0
000006eCXP000000KUBR0P0000001@1`EJ<00000071DXP000000LEJS008000000P1bEJ800`000000
LeJR0000000207AGXP060000001fF:8000000000001fEZ0000000P1gEj001P000000N5RP07QHX000
0000NERO00000080NUVO00H0000007]IW`1kFIl0000007]IW`00000207aJW`030000001mFYl00000
0080OU^O00<0000007=LZ@1cG:T01@1cG:T00`000000PVba089//@04089//@030000002kS:@00000
00H0_I:Z00<000000;nH/02oV;001@2oV;000`000000`9fe0<2M]@060<2M]@0300000030X[X0`::j
00D0`::j00@000000<2V_`30Y[l00000103N`kd00`000000flC30=_4``040=_4``030000003HaLL0
f<G70080f<G700<000000=G6b`3Ea//0103Ea//00`000000d/K?0=;6c`040=;6c`030000003?a]80
clKB00<0clKB00<000000<c6e03<a]@0103<a]@00`000000bLKG0<W6e`03000000@0d=gR00<00000
0<gJh`3=f^<00P3=f^<00`000000bMST0<WHi0020<WHi00300000037e^D0amKU00<0amKU00<00000
0<CDiP34e>H00P34e>H00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo03H0oooo000V0?oo
o`030000003oool0oooo05<0oooo00<000000:Bbh`2T/^<00`2T/^<00`000000Y;;R0:BbhP030:Bb
hP030000002T/N80Y;7R00<0Y;7R00<000000:>`h@2S/>400`2S/>400`000000XjoP0:>_h0020:>_
h0030000002S[]l0XjkO00<0XjkO00<000000:B]gP2T[Mh00`2T[Mh00`000000Y:cM0:B/g@030:B/
g@030000002TZ]/0Y:[K00<0Y:[K00<000000:FYf@2UZMT00`2UZMT00`000000YZOG0:JWe`020:JW
e`030000002WYM@0YjGD00<0YjGD00<000000:RSd@2XXm400`2XXm400`000000Zj7=0:^Qc@030:^Q
c@030000002]WlT0[Io90080[Io90P00000507Agb0030000001cKl00Lfo000@0Lfo000<0000007=X
^01cJ;P00`1cJ;P00`000000MF:_07ER[`0307ER[`80000000/0D4:S0000001B@j<0000005A4X`00
0000ETFS0000001HAZ80000005U7XP050000000605m<Y0000000HDfT0000001RCJ<000000P1TCZ<0
0`000000IDjS0000000206Q@X`050000001YD:80000006]BX`0000000P1]Dj820000000306mDXP00
000000000080L5BR0`000002079EXP040000001cEZ80LeJR00000080M5NR0P0000000`1eEZ00MUJP
0000000207MGX0060000001hF:00N5RP0000001iF9l000000P1jFIl01P000000NeVO07]IW`000000
NeVO00000080O5ZO00H0000007eJW`1mFYl0000007iKW`00000707=LZ@0300000022K;40PVba00@0
PVba00<000000;^<Y00000001P2mTZX00`000000_iR`0;nH/0050;nH/00300000030WKD0`9fe00H0
`9fe00<000000<2R^P30X[X01P30X[X2000000D0g/>m00<000000=_4``3Ka<<0103Ka<<00`000000
f<G70=S5a`030=S5a`030000003Ea//0eLK;00<0eLK;00<000000=;6c`3Ba/l0103Ba/l00`000000
clKB0<o6dP030<o6dP030000003<a]@0c<KD00@0c<KD0`0000000`3Dgn0000000=3MhP040=3MhP03
0000003=f^<0cM[S0080cM[S00<000000<WHi039f>@00P39f>@00`000000amKU0<OFi@020<OFi@03
00000034e>H0a=CV00<0a=CV00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0e0?ooo`00
9P3oool00`000000oooo0?ooo`1D0?ooo`030000002T/^<0Y;;S00<0Y;;S00<000000:BbhP2T/^80
0P2T/^800`000000Y;7R0:BahP030:BahP030000002S/>40Xk3Q00@0Xk3Q00<000000:>_h02S[n00
0P2S[n000`000000XjkO0:>^g`030:>^g`030000002T[Mh0Y:gN00<0Y:gN00<000000:B/g@2T[=d0
0`2T[=d00`000000Y:[K0:BZf`020:BZf`030000002UZMT0YJWI00<0YJWI00<000000:JWe`2VYmL0
0`2VYmL00`000000YjGD0:NUe0030:NUe0030000002XXm40Z:?A0080Z:?A00<000000:^Qc@2[XLd0
102[XLd010000000[Io900000000000207MocPH0M7O800<0000007=_`01cKl000`1cKl000`000000
LfRh07=X^00307=X^0030000001eHZl0MF:_00<0MF:_00@0000004i1X`000000D4:S0P0000001`1D
A:<0000005I5X`000000F4JR0000001IAj800P00000205e9XP050000001OC:@00000065=Y0000000
0P1RCJ<010000000I4jS0000001UCZ<20000000306Q@X`000000JE2R0080000000<0Je6R0000001]
Dj800P00000206mDXP030000001`E:80L5BR0080000000L0LEBQ0000001bEJ80LUFR0000001cEZ80
00000080M5NR00H0000007EFX01eEZ00000007IFX000000207MGX0030000001hF:0000000080NERO
00<0000007YIW`0000000P1kFIl00`000000NeVO0000000207aJW`060000001mFYl0OEZO0000001n
Fil00000201cG:T00`000000PVba089//@02089//@040000002kS:@0^hbT000000L0_I:Z00<00000
0;nH/02oV;001@2oV;000`000000`9fe0<2M]@060<2M]@0300000030X[X0`::j00D0`::j00<00000
0=k3_@3N`kd0103N`kd00`000000flC30=_4``040=_4``030000003HaLL0f<G700<0f<G700<00000
0=G6b`3Ea//00`3Ea//00`000000d/K?0=;6c`040=;6c`030000003?a]80clKB00@0clKB00<00000
0<c6e03<a]@00P3<a]@2000000<0e=oP00<000000=3MhP3@gN800P3@gN800`000000cM[S0<gJh`02
0<gJh`0300000039f>@0bMST00<0bMST00<000000<OFi@37e^D00P37e^D00`000000a=CV0<CDiP02
0<CDiP030000003oool0oooo05h0oooo00<000000?ooo`3oool0=@3oool002H0oooo00<000000?oo
o`3oool0E03oool00`000000Y;;S0:Bbh`040:Bbh`030000002T/^80Y;;R0080Y;;R00<000000:Ba
hP2T/N800`2T/N800`000000Xk3Q0:>`h@030:>`h@030000002S[n00XjoP0080XjoP00<000000:>^
g`2S[]l00`2S[]l00`000000Y:gN0:B]gP030:B]gP030000002T[=d0Y:cM00<0Y:cM00<000000:BZ
f`2TZ]/00`2TZ]/00`000000YJWI0:FYf@020:FYf@030000002VYmL0YZOG00<0YZOG00<000000:NU
e02WYM@00`2WYM@00`000000Z:?A0:RSd@030:RSd@030000002[XLd0Zj7=00<0Zj7=0P00000407Mo
cP030000001dMlP0M7O800<0M7O800<0000007=_`01cKl000`1cKl000`000000LfRh07=X^00307=X
^0030000001eHZl0MF:_00<0MF:_00@0000004i1X`000000D4:S0P00000205A4X`8000000P1HAZ82
0000000305]8XP000000GDVR00<0000000P0HDfT0000001RCJ<0HTfS0000001TCZ<0000006E>X`80
000000P0J52S0000001YD:80JE2R0000001[DJ80000006eCXP8000000P1_E:801`000000L5BR071D
XP1`E:800000075DX@0000000P1bEJ8010000000LeJR0000001dEj8200000080MEJP00<0000007IF
X00000000P1gEj000`000000N5RP0000000207UHW`030000001jFIl000000080NeVO00@0000007]I
W`1kFIl000000P1lFYl00`000000OEZO0000000207iKW`030000001cG:T0LebY00D0LebY00<00000
089//@22K;400P22K;4010000000^hbT0;^<Y00000070;fBZP030000002oV;00_iR`00D0_iR`00<0
00000<2M]@30WKD01P30WKD00`000000`::j0<2R^P040<2R^P8000001P3N`kd00`000000flC30=_4
``040=_4``030000003HaLL0f<G700<0f<G700<000000=G6b`3Ea//0103Ea//00`000000d/K?0=;6
c`030=;6c`030000003?a]80clKB00@0clKB00<000000<c6e03<a]@00P0000000`3Hhmh000000=CO
h0020=COh0030000003@gN80d=gR0080d=gR00<000000<gJh`3=f^<00P3=f^<00`000000bMST0<WH
i0020<WHi00300000037e^D0amKU00<0amKU00<000000<CDiP34e>H00P34e>H00`000000oooo0?oo
o`1N0?ooo`030000003oool0oooo03D0oooo000V0?ooo`030000003oool0oooo05D0oooo00<00000
0:Bbh`2T/^<00`2T/^<00`000000Y;;R0:BbhP030:BbhP030000002T/N80Y;7R0080Y;7R00<00000
0:>`h@2S/>40102S/>400`000000XjoP0:>_h0020:>_h0030000002S[]l0XjkO00<0XjkO00<00000
0:B]gP2T[Mh00`2T[Mh00`000000Y:cM0:B/g@030:B/g@030000002TZ]/0Y:[K0080Y:[K00<00000
0:FYf@2UZMT00`2UZMT00`000000YZOG0:JWe`030:JWe`030000002WYM@0YjGD0080YjGD00<00000
0:RSd@2XXm400`2XXm4010000000Zj7=0:^Qc@2[XLd20000000307Z6e01gOlh0Mgo>00@0Mgo>00<0
000007Agb01dMlP00`1dMlP00`000000Lfo007=_`00307=_`0030000001cJ;P0LfRh0080LfRh0P00
000407ER[`080000001>@J<000000512X`000000DT>S0000001DA:<200000080F4JR0P000000201K
B:80000005e9XP000000GTZR0000001QCJ@000000P1RCJ<01P000000I4jS0000001UCZ<0000006I?
XP8000000P1YD:8020000000Je6R0000001]Dj80000006iDXP000000KeBR0P000002071DXP030000
001aE:40000000<0LUFR00D0000007=FXP000000000007AEX00207EFX0030000001fEZ0000000080
MeNP00H0000007QHX01hF:00000007UHW`00000207YIW`060000001kFIl0NeVO0000001kFIl00000
0P1lFYl00`000000OEZO0000000207iKW`030000001cG:T0LebY00H0LebY00@00000089//@22K;40
0000102kS:@00`000000_I:Z0;fBZP040;fBZP030000002oV;00_iR`00D0_iR`00<000000<2M]@30
WKD01`30WKD00`000000`::j0<2R^P030<2R^P8000001P3N`kd00`000000flC30=_4``040=_4``03
0000003HaLL0f<G700<0f<G700<000000=G6b`3Ea//0103Ea//00`000000d/K?0=;6c`030=;6c`03
0000003?a]80clKB00@0clKB0`0000020=SSgP030000003Dgn00e=oP0080e=oP00<000000=3MhP3@
gN800P3@gN800`000000cM[S0<gJh`020<gJh`0300000039f>@0bMST0080bMST00<000000<OFi@37
e^D00P37e^D00`000000a=CV0<CDiP020<CDiP030000003oool0oooo05l0oooo00<000000?ooo`3o
ool0=@3oool002H0oooo00<000000?ooo`3oool0EP3oool00`000000Y;;S0:Bbh`030:Bbh`030000
002T/^80Y;;R0080Y;;R00<000000:BahP2T/N800`2T/N800`000000Xk3Q0:>`h@030:>`h@030000
002S[n00XjoP00<0XjoP00<000000:>^g`2S[]l00P2S[]l00`000000Y:gN0:B]gP030:B]gP030000
002T[=d0Y:cM00<0Y:cM00<000000:BZf`2TZ]/00`2TZ]/00`000000YJWI0:FYf@020:FYf@030000
002VYmL0YZOG00<0YZOG00<000000:NUe02WYM@00`2WYM@00`000000Z:?A0:RSd@030:RSd@<00000
0`1jQ]@00`000000Mgo>07MocP0307MocP030000001dMlP0M7O800<0M7O800<0000007=_`01cKl00
0`1cKl000`000000LfRh07=X^00207=X^08000001@1eHZl20000000;0512X`000000DT>S0000001D
A:<0000005I5X`000000F4JR0000001IAj800P00000205e9XP<0000000H0HDfT0000001RCJ<00000
06A>X`00000206E>X`030000001VCj8000000080JE2R0`00000206eCXP0306iDXP000000KeBR0080
00000P1`E:8200000007075DX@000000LUFR079EXP000000LeJR0000000207AEX0080000001eEZ00
MEJP0000001fEZ00000007MGX000000207QHX0030000001iF9l000000080NUVO00H0000007]IW`1k
FIl0000007]IW`00000207aJW`060000001mFYl0OEZO0000001nFil00000201cG:T010000000PVba
089//@0000040;^<Y0030000002mTZX0_I:Z00D0_I:Z00<000000;nH/02oV;001@2oV;000`000000
`9fe0<2M]@060<2M]@0300000030X[X0`::j0080`::j00<000000>71]`0000001P3N`kd00`000000
flC30=_4``040=_4``030000003HaLL0f<G700<0f<G700<000000=G6b`3Ea//0103Ea//00`000000
d/K?0=;6c`030=;6c`030000003?a]80clKB00@0clKB00<000000=SSgP3Hhmh00P3Hhmh01@000000
e=oP0=COh03Dgn00000000@0d=gR00<000000<gJh`3=f^<00P3=f^<00`000000bMST0<WHi0030<WH
i00300000037e^D0amKU0080amKU00<000000<CDiP34e>H00P34e>H00`000000oooo0?ooo`1O0?oo
o`030000003oool0oooo03D0oooo000U0?ooo`030000003oool0oooo05L0oooo00<000000:Bbh`2T
/^<00`2T/^<00`000000Y;;R0:BbhP030:BbhP030000002T/N80Y;7R00<0Y;7R00<000000:>`h@2S
/>400`2S/>400`000000XjoP0:>_h0020:>_h0030000002S[]l0XjkO00<0XjkO00<000000:B]gP2T
[Mh00`2T[Mh00`000000Y:cM0:B/g@030:B/g@030000002TZ]/0Y:[K0080Y:[K00<000000:FYf@2U
ZMT00`2UZMT00`000000YZOG0:JWe`030:JWe`030000002WYM@0YjGD0080YjGD00<000000:RSd@2X
Xm400P2XXm42000000H0NXKD00<0000007MocP1gOlh00`1gOlh00`000000M7O807Agb00307Agb003
0000001cKl00Lfo00080Lfo000<0000007=X^01cJ;P00P1cJ;P2000000D0MF:_00@0000004i1X`00
0000D4:S0P0000001`1DA:<0000005I5X`000000F4JR0000001IAj800P00000205e9XP030000001N
BZ8000000080000000@0HTfS0000001TCZ<000000P1UCZ<01@000000ITnR000000000000JE2R0080
000000<0Je6R06eCXP0000000P0000000`1_E:80000006mDXP0200000004071DX@000000LEBQ0000
00<0LUFR0P00000207AEX0060000001eEZ00MEJP0000001fEZ0000000P1gEj000`000000N5RP0000
000207UHW`030000001jFIl000000080NeVO00<0000007]IW`0000000P1lFYl010000000OEZO07eJ
W`00000207iKW`030000001cG:T0LebY00D0LebY00<00000089//@0000001@2kS:@00`000000_I:Z
0;fBZP050;fBZP030000002oV;00_iR`00D0_iR`00<000000<2M]@30WKD01P30WKD00`000000`::j
0<2R^P020<2R^P040000003Q`KL0hL6g000000H0g/>m00<000000=_4``3Ka<<00`3Ka<<00`000000
f<G70=S5a`030=S5a`030000003Ea//0eLK;00@0eLK;00<000000=;6c`3Ba/l0103Ba/l010000000
clKB0<o6dP3?a]83000000@0f>?N00D000000=COh03Dgn00e=oP000000040=3MhP030000003=f^<0
cM[S0080cM[S00<000000<WHi039f>@00P39f>@00`000000amKU0<OFi@030<OFi@0300000034e>H0
a=CV0080a=CV00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0d0?ooo`009@3oool00`00
0000oooo0?ooo`1H0?ooo`030000002T/^<0Y;;S00<0Y;;S00<000000:BbhP2T/^800`2T/^800`00
0000Y;7R0:BahP020:BahP030000002S/>40Xk3Q00@0Xk3Q00<000000:>_h02S[n000P2S[n000`00
0000XjkO0:>^g`030:>^g`030000002T[Mh0Y:gN0080Y:gN00<000000:B/g@2T[=d00`2T[=d00`00
0000Y:[K0:BZf`030:BZf`030000002UZMT0YJWI0080YJWI00<000000:JWe`2VYmL00`2VYmL00`00
0000YjGD0:NUe0030:NUe0040000002XXm40000000000080OXgH1P1jQ]@00`000000Mgo>07MocP03
07MocP030000001dMlP0M7O800<0M7O800<0000007=_`01cKl000`1cKl001`000000LfRh07=X^01c
J;P0000007=X^0000000101eHZl010000000CT6S0000001@@Z<20000000@05A4X`000000ETFS0000
001HAZ80000005U7XP000000FdRR0000001MBJ80000005i:XP000000H4^R00000080HTfS0P000002
06E>X`070000001VCj8000000000001YD:80000006U@XP020000000606aBXP000000000006mDXP00
0000KeBR0P0000001@1`E:400000075DX@1aE:4000000080LUFR00D0000007=EX01dEJ00M5FP0000
000207EFX0030000001fEZ0000000080MeNP00<0000007QHX00000000P1iF9l010000000NUVO07YI
W`00000207]IW`030000001kFIl000000080O5ZO00<0000007eJW`0000000P1nFil00`000000LebY
07=LZ@0607=LZ@8000001@2kS:@00`000000_I:Z0;fBZP050;fBZP030000002oV;00_iR`00D0_iR`
00<000000<2M]@30WKD01`30WKD010000000`::j0<2R^P0000030>71]`030000003N`kd0g/>m00@0
g/>m00<000000=_4``3Ka<<0103Ka<<00`000000f<G70=S5a`020=S5a`030000003Ea//0eLK;00@0
eLK;00<000000=;6c`3Ba/l0103Ba/l01P000000clKB0<o6dP000000gNKK000000@0f>?N00<00000
0=COh03Dgn000P3Dgn000`000000d=gR0=3MhP020=3MhP030000003=f^<0cM[S0080cM[S00<00000
0<WHi039f>@00P39f>@00`000000amKU0<OFi@020<OFi@0300000034e>H0a=CV0080a=CV00<00000
0?ooo`3oool0H@3oool00`000000oooo0?ooo`0d0?ooo`009@3oool00`000000oooo0?ooo`1H0?oo
o`030000002T/^<0Y;;S00@0Y;;S00<000000:BbhP2T/^800P2T/^800`000000Y;7R0:BahP030:Ba
hP030000002S/>40Xk3Q00<0Xk3Q00<000000:>_h02S[n000P2S[n000`000000XjkO0:>^g`030:>^
g`030000002T[Mh0Y:gN00<0Y:gN00<000000:B/g@2T[=d00`2T[=d00`000000Y:[K0:BZf`020:BZ
f`030000002UZMT0YJWI00<0YJWI00<000000:JWe`2VYmL00`2VYmL00`000000YjGD0:NUe0040000
00@0OXgH00<0000007Z6e01jQ]@0101jQ]@00`000000Mgo>07MocP0307MocP030000001dMlP0M7O8
00<0M7O800<0000007=_`01cKl000P1cKl001`000000LfRh07=X^01cJ;P0000007=X^0000000101e
HZl010000000CT6S0000001@@Z<200000080E4BS0P00000205Q6XP80000000L0FdRR0000001MBJ80
000005i:XP000000H4^R00@0000000L0I4jS0000001UCZ<0000006I?XP000000IdnR0080000000@0
JE2R000000000000K5:R1000000206mDXP030000001`E:4000000080LEBQ00H00000079EXP000000
000007=EX000000207AEX0030000001eEZ00MEJP008000000P1gEj001P000000N5RP07QHX0000000
NERO00000080NUVO00H0000007]IW`1kFIl0000007]IW`00000207aJW`030000001mFYl000000080
OU^O00<0000007=LZ@1cG:T01P1cG:T00`000000^hbT0;^<Y0050;^<Y0030000002mTZX0_I:Z00D0
_I:Z00<000000;nH/02oV;001@2oV;000`000000`9fe0<2M]@060<2M]@0300000030X[X0000000@0
hL6g00<000000=k3_@3N`kd0103N`kd00`000000flC30=_4``040=_4``030000003HaLL0f<G700<0
f<G700<000000=G6b`3Ea//00`3Ea//00`000000d/K?0=;6c`040=;6c`<000000P3Mi]/00`000000
f>?N0=SSgP020=SSgP050000003Dgn00e=oP0=COh0000000103@gN800`000000cM[S0<gJh`020<gJ
h`0300000039f>@0bMST00<0bMST00<000000<OFi@37e^D00P37e^D00`000000a=CV0<CDiP020<CD
iP030000003oool0oooo0640oooo00<000000?ooo`3oool0=03oool002D0oooo00<000000?ooo`3o
ool0F@3oool00`000000Y;;S0:Bbh`030:Bbh`030000002T/^80Y;;R00<0Y;;R00<000000:BahP2T
/N800P2T/N800`000000Xk3Q0:>`h@040:>`h@030000002S[n00XjoP0080XjoP00<000000:>^g`2S
[]l00`2S[]l00`000000Y:gN0:B]gP020:B]gP030000002T[=d0Y:cM00<0Y:cM00<000000:BZf`2T
Z]/00`2TZ]/00`000000YJWI0:FYf@020:FYf@030000002VYmL0YZOG0080YZOG10000003086Cg0H0
OXgH00<0000007Z6e01jQ]@00`1jQ]@00`000000Mgo>07MocP0307MocP030000001dMlP0M7O800<0
M7O800<0000007=_`01cKl000`1cKl001P000000LfRh07=X^0000000LfRh000000D0MF:_0P000000
2`1@@Z<000000593X`000000E4BS0000001FAJ<0000005Q6XP000000FDNR008000000P1MBJ820000
000;061;XP000000HTbR069<XP000000I4jS0000001UCZ<0000006I?XP0000000P1WCj800`000000
JE2R06U@XP020000000406aBXP000000000000000080KeBR00@00000071DX@1`E:4000000P1aE:43
0000000507=EX0000000M5FP07AEX00000000P1eEZ000`000000MUJP0000000207MGX0030000001h
F:0000000080NERO00<0000007YIW`0000000P1kFIl00`000000NeVO0000000207aJW`040000001m
FYl0OEZO00000080OU^O00<0000007=LZ@1cG:T01@1cG:T00`000000^hbT0;^<Y0050;^<Y0030000
002mTZX0_I:Z00D0_I:Z00<000000;nH/02oV;001@2oV;000`000000`9fe0<2M]@070<2M]@800000
103Q`KL00`000000g/>m0=k3_@040=k3_@030000003Ka<<0flC300@0flC300<000000=S5a`3HaLL0
0`3HaLL00`000000eLK;0=G6b`030=G6b`030000003Ba/l0d/K?00@0d/K?00<000000=gVf`3Mi]/0
0P3Mi]/00`000000f>?N0=SSgP020=SSgP050000003Dgn00e=oP0=COh0000000103@gN800`000000
cM[S0<gJh`020<gJh`0300000039f>@0bMST0080bMST00<000000<OFi@37e^D00`37e^D00`000000
a=CV0<CDiP020<CDiP030000003oool0oooo0640oooo00<000000?ooo`3oool0=03oool002D0oooo
00<000000?ooo`3oool0FP3oool00`000000Y;;S0:Bbh`030:Bbh`030000002T/^80Y;;R00<0Y;;R
00<000000:BahP2T/N800P2T/N800`000000Xk3Q0:>`h@030:>`h@030000002S[n00XjoP00<0XjoP
00<000000:>^g`2S[]l00P2S[]l00`000000Y:gN0:B]gP030:B]gP030000002T[=d0Y:cM00<0Y:cM
00<000000:BZf`2TZ]/00P2TZ]/00`000000YJWI0:FYf@030:FYf@040000002VYmL0000000000080
Q9SN1@21Tm`00`000000OXgH07j=f00407j=f0030000001jQ]@0NXKD00<0NXKD00<0000007MocP1g
Olh00`1gOlh00`000000M7O807Agb00307Agb0030000001cKl00Lfo00080Lfo000H0000007=X^01c
J;P0000007=X^000000507ER[`040000001>@J<000000512X`80000000L0E4BS0000001FAJ<00000
05Q6XP000000FDNR008000000P1MBJ801P000000GTZR0000001PBj800000069<XP<0000000@0IDjS
0000001VCj8000000P1WCj820000000406U@XP000000000006aBXP<000000P1_E:8200000005071D
X@000000LEBQ075DX@0000000P1bE:001@000000LeFP0000001dEJ0000000080MEJP00<0000007IF
X00000000P1gEj000`000000N5RP0000000207UHW`030000001jFIl000000080NeVO00@0000007]I
W`1kFIl000000P1lFYl00`000000OEZO0000000207iKW`030000001cG:T0LebY00@0LebY0P000007
0;^<Y0030000002mTZX0_I:Z00D0_I:Z00<000000;nH/02oV;001@2oV;000`000000`9fe0<2M]@07
0<2M]@030000003Q`KL0hL6g00<0hL6g00<000000=k3_@3N`kd0103N`kd00`000000flC30=_4``04
0=_4``030000003HaLL0f<G700<0f<G700<000000=G6b`3Ea//0103Ea//010000000d/K?0=;6c`3B
a/l3000000@0gNKK00<000000=SSgP3Hhmh00P3Hhmh01@000000e=oP0=COh03Dgn00000000@0d=gR
00<000000<gJh`3=f^<00P3=f^<00`000000bMST0<WHi0020<WHi00300000037e^D0amKU0080amKU
00<000000<CDiP34e>H00P34e>H00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo03@0oooo
000U0?ooo`030000003oool0oooo05X0oooo00<000000:Bbh`2T/^<00`2T/^<00`000000Y;;R0:Bb
hP030:BbhP030000002T/N80Y;7R00<0Y;7R00<000000:>`h@2S/>400`2S/>400`000000XjoP0:>_
h0020:>_h0030000002S[]l0XjkO00<0XjkO00<000000:B]gP2T[Mh00P2T[Mh00`000000Y:cM0:B/
g@030:B/g@030000002TZ]/0Y:[K00<0Y:[K00@000000:FYf@2UZMT0YJWI0`00000508BHgPD0PI?L
00<0000007j=f01nSMP00`1nSMP00`000000NXKD07Z6e00407Z6e0030000001gOlh0Mgo>0080Mgo>
00<0000007Agb01dMlP00`1dMlP00`000000Lfo007=_`00207=_`0040000001cJ;P0LfRh00000080
LfRh00<0000007ER[`1eHZl00P1eHZl010000000CT6S0000001@@Z<20000000D05A4X`000000ETFS
0000001HAZ80000005U7XP000000FdRR0000001MBJ80000005i:XP000000H4^R0000001RC:800000
06=<XP00000206E>X`040000001VCj80000006M?XP80000000@0JE2R000000000000K5:R1@000000
1@1_Dj400000071DX@000000LEBQ008000000P1bE:001@000000LeFP0000001dEJ0000000080MEJP
00<0000007IFX00000000P1gEj001P000000N5RP07QHX0000000NERO00000080NUVO00H0000007]I
W`1kFIl0000007]IW`00000207aJW`030000001mFYl000000080OU^O00<0000007=LZ@1cG:T0101c
G:T00`000000^8FN000000060;^<Y0030000002mTZX0_I:Z00D0_I:Z00<000000;nH/02oV;001P2o
V;000`000000`9fe0<2M]@050<2M]@8000001@3Q`KL00`000000g/>m0=k3_@040=k3_@030000003K
a<<0flC300@0flC300<000000=S5a`3HaLL00`3HaLL00`000000eLK;0=G6b`040=G6b`060000003B
a/l0d/K?0000003RjML00000103Mi]/00`000000f>?N0=SSgP020=SSgP050000003Dgn00e=oP0=CO
h0000000103@gN800`000000cM[S0<gJh`020<gJh`0300000039f>@0bMST00<0bMST00<000000<OF
i@37e^D00P37e^D00`000000a=CV0<CDiP020<CDiP030000003oool0oooo0680oooo00<000000?oo
o`3oool0=03oool002@0oooo00<000000?ooo`3oool0G03oool00`000000Y;;S0:Bbh`030:Bbh`03
0000002T/^80Y;;R00<0Y;;R00<000000:BahP2T/N800P2T/N800`000000Xk3Q0:>`h@030:>`h@03
0000002S[n00XjoP00<0XjoP00<000000:>^g`2S[]l00P2S[]l00`000000Y:gN0:B]gP030:B]gP03
0000002T[=d0Y:cM00<0Y:cM00<000000:BZf`2TZ]/00P2TZ]/010000000YJWI00000000000208RL
h@0300000024V=h0Q9SN00<0Q9SN00<00000086Cg021Tm`00`21Tm`00`000000OXgH07j=f00307j=
f0030000001jQ]@0NXKD00<0NXKD00<0000007MocP1gOlh00`1gOlh00`000000M7O807Agb00307Ag
b0030000001cKl00Lfo00080Lfo000<0000007=X^00000000P1cJ;P00`000000MF:_07ER[`0207ER
[`040000001>@J<000000512X`8000000P1DA:<20000000<05Q6XP000000FDNR0000001KB:800000
05e9XP000000GTZR0000001PBj8000000P1RC:850000000506I?XP000000IdnR0000001YD:802@00
000206mCX@050000001`E:4000000000001aDj000P1bE:000`000000LeFP0000000207AEX0060000
001eEZ00MEJP0000001fEZ0000000P1gEj000`000000N5RP0000000207UHW`030000001jFIl00000
0080NeVO00<0000007]IW`0000000P1lFYl01P000000OEZO07eJW`000000OU^O000000D0LebY00@0
00000;R5WP2hQIh000001`2kS:@00`000000_I:Z0;fBZP050;fBZP030000002oV;00_iR`00D0_iR`
00<000000<2M]@30WKD01@30WKD2000000D0hL6g00<000000=k3_@3N`kd0103N`kd00`000000flC3
0=_4``040=_4``030000003HaLL0f<G700<0f<G700<000000=G6b`3Ea//0103Ea//300000080h^WG
00<000000=gVf`3Mi]/00P3Mi]/00`000000f>?N0=SSgP020=SSgP050000003Dgn00e=oP0=COh000
0000103@gN800`000000cM[S0<gJh`020<gJh`0300000039f>@0bMST00<0bMST00D000000<OFi@37
e^D0amKU000000050<CDiP030000003oool0oooo0640oooo0`00000e0?ooo`00903oool00`000000
oooo0?ooo`1M0?ooo`030000002T/^<0Y;;S00<0Y;;S00<000000:BbhP2T/^800`2T/^800`000000
Y;7R0:BahP020:BahP030000002S/>40Xk3Q00<0Xk3Q00<000000:>_h02S[n000P2S[n000`000000
XjkO0:>^g`030:>^g`030000002T[Mh0Y:gN0080Y:gN00<000000:B/g@2T[=d00`2T[=d010000000
Y:[K0:BZf`2TZ]/3000000D0R9cQ00<0000008BHgP24V=h00`24V=h00`000000PI?L086Cg003086C
g0030000001nSMP0OXgH00<0OXgH00<0000007Z6e01jQ]@00`1jQ]@00`000000Mgo>07MocP0207Mo
cP030000001dMlP0M7O800<0M7O800<0000007=_`01cKl000P1cKl02000000<0LfRh00<0000007ER
[`1eHZl00`1eHZl01`000000CT6S000000000000DT>S0000001DA:<00P00000205Q6XP80000000@0
FdRR0000001MBJ80GDVR0P0000003P1PBj800000069<XP1RC:80000006=<XP000000I4fR0000001V
Cj80000006M?XP000000JE2R0P0000001@1ZD:80000006aBXP1^DZ80KU>R008000000P1_Dj400`00
0000L5BQ00000002075CX0030000001bE:0000000080LeFP00<0000007AEX00000000P1eEZ000`00
0000MUJP0000000207MGX0030000001hF:0000000080NERO00<0000007YIW`0000000P1kFIl00`00
0000NeVO0000000207aJW`040000001mFYl0OEZO00000080OU^O00<0000007=LZ@1cG:T00P1cG:T0
10000000^8FN0;R5WP0000070;^<Y0030000002mTZX0_I:Z00D0_I:Z00<000000;nH/02oV;001P2o
V;000`000000`9fe0<2M]@030<2M]@030000003T_[00000000H0hL6g00<000000=k3_@3N`kd0103N
`kd00`000000flC30=_4``030=_4``030000003HaLL0f<G700<0f<G700<000000=G6b`3Ea//0103E
a//00`000000h^WG0>;Ye`020>;Ye`030000003Mi]/0gNKK0080gNKK00<000000=SSgP3Hhmh00P3H
hmh01@000000e=oP0=COh03Dgn00000000@0d=gR00<000000<gJh`3=f^<00P3=f^<00`000000bMST
0<WHi0020<WHi00300000037e^D0amKU0080amKU00<000000<CDiP34e>H00P34e>H00`000000oooo
0?ooo`1Q0?ooo`040000003oool0oooo000003D0oooo000T0?ooo`030000003oool0oooo05d0oooo
00<000000:Bbh`2T/^<00`2T/^<00`000000Y;;R0:BbhP030:BbhP030000002T/N80Y;7R0080Y;7R
00<000000:>`h@2S/>40102S/>400`000000XjoP0:>_h0020:>_h0030000002S[]l0XjkO0080XjkO
00<000000:B]gP2T[Mh00`2T[Mh00`000000Y:cM0:B/g@020:B/g@@000000`2;X>800`000000R9cQ
08RLh@0308RLh@0300000024V=h0Q9SN00<0Q9SN00<00000086Cg021Tm`00P21Tm`00`000000OXgH
07j=f00307j=f0030000001jQ]@0NXKD00<0NXKD00<0000007MocP1gOlh00`1gOlh00`000000M7O8
07Agb00207Agb0030000001cKl00Lfo00080Lfo00P00000407=X^0030000001eHZl0MF:_0080MF:_
00@0000004i1X`000000D4:S0P0000001`1DA:<0000005I5X`000000F4JR0000001IAj800P000002
05e9XP0:0000001NBZ800000061;XP000000HTbR0000001SC:80000006A=XP<000000P1WCj801P00
0000JE2R0000001ZD:80000006aBXP@000000`1_Dj4200000080LE>P00P00000079DX01bE:000000
07=EX0000000M5FP00000080MEJP00<0000007IFX00000000P1gEj000`000000N5RP0000000207UH
W`060000001jFIl0NUVO0000001kFIl000000P1kFIl01P000000O5ZO07aJW`000000OEZO00000080
OU^O00<0000007=LZ@1cG:T00P1cG:T010000000^8FN0;R5WP0000070;^<Y0030000002mTZX0_I:Z
00D0_I:Z00<000000;nH/02oV;001P2oV;000`000000`9fe0<2M]@030<2M]@040000003T_[00i;j`
000000D0hL6g00<000000=k3_@3N`kd0103N`kd00`000000flC30=_4``040=_4``030000003HaLL0
f<G70080f<G700<000000=G6b`3Ea//00`3Ea//2000000@0h^WG00D000000=gVf`3Mi]/0gNKK0000
00040=SSgP030000003Dgn00e=oP0080e=oP00<000000=3MhP3@gN800P3@gN801@000000cM[S0<gJ
h`3=f^<0000000D0bMST00<000000<OFi@37e^D00P37e^D00`000000a=CV0<CDiP020<CDiP030000
003oool0oooo06@0oooo00<000000?ooo`3oool0<`3oool002@0oooo00<000000?ooo`3oool0GP3o
ool00`000000Y;;S0:Bbh`030:Bbh`030000002T/^80Y;;R00<0Y;;R00<000000:BahP2T/N800P2T
/N800`000000Xk3Q0:>`h@030:>`h@030000002S[n00XjoP00<0XjoP00<000000:>^g`2S[]l00P2S
[]l00`000000Y:gN0:B]gP020:B]gP030000002T[=d0Y:cM008000000P2=Y>@00`000000Rj3R08^P
hP0308^PhP0300000028W>40R9cQ0080R9cQ00<0000008BHgP24V=h01024V=h00`000000PI?L086C
g002086Cg0030000001nSMP0OXgH00<0OXgH00<0000007Z6e01jQ]@00`1jQ]@00`000000Mgo>07Mo
cP0207MocP030000001dMlP0M7O800<0M7O800<0000007=_`01cKl000P1cKl000`000000LfRh07=X
^00207=X^0030000001eHZl0MF:_0080MF:_00@0000004i1X`000000D4:S0P000000601DA:<00000
05I5X`000000F4JR0000001IAj80000005]8XP000000GDVR0000001NBZ800000061;XP000000HTbR
0000001SC:80000006A=XP000000ITjR00000080IdnR00<0000006U@XP0000002000000206mCX@05
0000001`Dj000000075CX00000000P1bE:000`000000LeFP0000000207AEX0050000001eEZ000000
07IFX00000000P1gEj001P000000N5RP07QHX0000000NERO00000080NUVO00H0000007]IW`1kFIl0
000007]IW`00000207aJW`030000001mFYl000000080OU^O00D0000007=LZ@1cG:T0LebY00000004
0;R5WP030000002kS:@0^hbT00@0^hbT00<000000;fBZP2mTZX01P2mTZX00`000000_iR`0;nH/005
0;nH/00300000030WKD0`9fe0080`9fe00D000000>Bn/03T_[00i;j`000000050>71]`030000003N
`kd0g/>m00@0g/>m00<000000=_4``3Ka<<0103Ka<<00`000000f<G70=S5a`030=S5a`030000003E
a//0eLK;00<00000103RjML00`000000gNKK0=gVf`020=gVf`030000003Hhmh0f>?N0080f>?N00D0
00000=COh03Dgn00e=oP000000040=3MhP030000003=f^<0cM[S0080cM[S00<000000<WHi039f>@0
0`39f>@01@000000amKU0<OFi@37e^D0000000@0a=CV00<000000?ooo`3oool0I@3oool00`000000
oooo0?ooo`0c0?ooo`00903oool00`000000oooo0?ooo`1O0?ooo`030000002T/^<0Y;;S0080Y;;S
00<000000:BbhP2T/^800`2T/^800`000000Y;7R0:BahP020:BahP030000002S/>40Xk3Q00@0Xk3Q
00<000000:>_h02S[n000P2S[n000`000000XjkO0:>^g`020:>^g`040000002T[Mh0Y:gN0:B]gP@0
00001@2=Y>@00`000000Rj3R08^PhP0308^PhP0300000028W>40R9cQ0080R9cQ00<0000008BHgP24
V=h00`24V=h00`000000PI?L086Cg003086Cg0030000001nSMP0OXgH00<0OXgH00<0000007Z6e01j
Q]@00P1jQ]@00`000000Mgo>07MocP0307MocP030000001dMlP0M7O80080M7O800<0000007=_`01c
Kl000P1cKl000`000000LfRh07=X^00207=X^0030000001eHZl0MF:_0080MF:_00@0000004i1X`00
0000D4:S0P000000401DA:<0000005I5X`000000F4JR0000001IAj80000005]8XP000000GDVR0000
001NBZ800000061;XP000002069<XP8000000P1TCJ850000000406U@XP000000000006Y@XPH00000
00D0Ke>Q000000000000L5>P00000002075CX0050000001bE:00000007=EX00000000P1dEJ001P00
0000MEJP07EFX0000000MUJP00000080MeNP00<0000007QHX00000000P1iF9l00`000000NUVO0000
000207]IW`030000001kFIl000000080O5ZO00@0000007eJW`1mFYl000000P1nFil010000000LebY
07=LZ@0000040;R5WP030000002kS:@0^hbT00D0^hbT00<000000;fBZP2mTZX01@2mTZX00`000000
_iR`0;nH/0060;nH/00400000030WKD0`9fe000000@0i;j`00<000000>71]`3Q`KL00`3Q`KL00`00
0000g/>m0=k3_@040=k3_@030000003Ka<<0flC300@0flC300<000000=S5a`3HaLL00`3HaLL00`00
0000eLK;000000020>O/dP030000003RjML0h^WG0080h^WG00<000000=gVf`3Mi]/00P3Mi]/00`00
0000f>?N0=SSgP020=SSgP050000003Dgn00e=oP0=COh0000000103@gN800`000000cM[S0<gJh`02
0<gJh`0300000039f>@0bMST0080bMST00<000000<OFi@37e^D00P37e^D00`000000a=CV0<CDiP02
0<CDiP030000003oool0oooo06D0oooo00<000000?ooo`3oool0<`3oool002@0oooo00<000000?oo
o`3oool0G`3oool00`000000Y;;S0:Bbh`030:Bbh`030000002T/^80Y;;R00<0Y;;R00<000000:Ba
hP2T/N800P2T/N800`000000Xk3Q0:>`h@030:>`h@030000002S[n00XjoP00<0XjoP00@000000:>^
g`2S[]l0XjkO10000003092Vi@030000002=Y>@0SJCT00@0SJCT00<0000008^PhP2;X>800`2;X>80
0`000000R9cQ08RLh@0208RLh@0300000024V=h0Q9SN00<0Q9SN00<00000086Cg021Tm`00`21Tm`0
0`000000OXgH07j=f00207j=f0030000001jQ]@0NXKD00<0NXKD00<0000007MocP1gOlh00P1gOlh0
0`000000M7O807Agb00307Agb0040000001cKl00Lfo007=_`0800000101cJ;P00`000000MF:_07ER
[`0207ER[`070000001>@J<000000000001B@j<0000005A4X`0200000080F4JR0P000000101KB:80
000005e9XP1MBJ820000000=061;XP000000HTbR069<XP000000HdbR0000001TCJ80000006I>XP00
0000IdjQ0000000206U@XPL0000000H0KU:Q0000000000000000071CX0000002075CX0030000001b
E:0000000080LeFP00<0000007AEX00000000P1eEZ000`000000MUJP0000000207MGX0030000001h
F:0000000080NERO00<0000007YIW`0000000P1kFIl010000000NeVO07]IW`00000207aJW`030000
001mFYl000000080OU^O00@0000007=LZ@1cG:T00000102hQIh00`000000^hbT0;^<Y0050;^<Y003
0000002mTZX0_I:Z00D0_I:Z00<000000;nH/02oV;001P2oV;0010000000`9fe0<2M]@0000040>Bn
/0030000003Q`KL0hL6g00<0hL6g00<000000=k3_@3N`kd0103N`kd00`000000flC30=_4``040=_4
``030000003HaLL0f<G700<0f<G70P0000030>O/dP030000003RjML0h^WG0080h^WG00<000000=gV
f`3Mi]/00P3Mi]/01@000000f>?N0=SSgP3Hhmh0000000@0e=oP00<000000=3MhP3@gN800P3@gN80
1@000000cM[S0<gJh`3=f^<0000000D0bMST00<000000<OFi@37e^D00P37e^D00`000000a=CV0<CD
iP020<CDiP030000003oool0oooo06H0oooo00<000000?ooo`3oool0<P3oool002<0oooo00<00000
0?ooo`3oool0H@3oool00`000000Y;;S0:Bbh`030:Bbh`030000002T/^80Y;;R00<0Y;;R00<00000
0:BahP2T/N800P2T/N800`000000Xk3Q0:>`h@030:>`h@030000002S[n00XjoP0080XjoP00@00000
0:>^g`00000000000P2BZND00`000000T:KU092Vi@03092Vi@030000002=Y>@0SJCT00@0SJCT00<0
000008^PhP2;X>800P2;X>800`000000R9cQ08RLh@0308RLh@0300000024V=h0Q9SN00<0Q9SN00<0
0000086Cg021Tm`00P21Tm`00`000000OXgH07j=f00307j=f0030000001jQ]@0NXKD0080NXKD00<0
000007MocP1gOlh00`1gOlh00`000000M7O807Agb00207Agb0040000001cKl00Lfo007=_`0800000
101cJ;P00`000000MF:_07ER[`0207ER[`040000001>@J<000000512X`80000000L0E4BS0000001F
AJ<0000005Q6XP000000FDNR008000000P1MBJ803P000000GTZR0000001PBj800000069<XP000000
HdbR0000001TCJ80000006I>XP000000IdjQ100000000`1ZD:400000000000030000000906iBX@00
0000Ke:Q06mBX@000000L5>P0000001aDj0000000080LUBP00D0000007=EX0000000M5FP00000002
07EFX0030000001fEZ0000000080MeNP00<0000007QHX00000000P1iF9l010000000NUVO07YIW`00
000207]IW`030000001kFIl000000080O5ZO00<0000007eJW`0000000P1nFil00`000000LebY0000
00050;R5WP030000002kS:@0^hbT00D0^hbT00<000000;fBZP2mTZX01P2mTZX00`000000_iR`0;nH
/0050;nH/00300000030WKD0000000D0i;j`00<000000>71]`3Q`KL00`3Q`KL00`000000g/>m0=k3
_@040=k3_@030000003Ka<<0flC300@0flC300<000000=S5a`3HaLL00`3HaLL00`000000incB0>O/
dP020>O/dP050000003RjML0h^WG0>;Ye`000000103Mi]/00`000000f>?N0=SSgP020=SSgP050000
003Dgn00e=oP0=COh0000000103@gN800`000000cM[S0<gJh`020<gJh`0300000039f>@0bMST00<0
bMST00D000000<OFi@37e^D0amKU000000040<CDiP030000003oool0oooo06L0oooo00<000000?oo
o`3oool0<P3oool002<0oooo00<000000?ooo`3oool0HP3oool00`000000Y;;S0:Bbh`020:Bbh`03
0000002T/^80Y;;R00<0Y;;R00<000000:BahP2T/N800P2T/N800`000000Xk3Q0:>`h@030:>`h@04
0000002S[n00XjoP0:>_h0<000001@2BZND00`000000T:KU092Vi@03092Vi@030000002=Y>@0SJCT
00@0SJCT00<0000008^PhP2;X>800P2;X>800`000000R9cQ08RLh@0308RLh@0300000024V=h0Q9SN
00<0Q9SN00<00000086Cg021Tm`00P21Tm`00`000000OXgH07j=f00307j=f0030000001jQ]@0NXKD
0080NXKD00<0000007MocP1gOlh00P1gOlh00`000000M7O807Agb00307Agb0030000001cKl00Lfo0
00800000101cJ;P00`000000MF:_07ER[`0207ER[`040000001>@J<000000512X`80000001X0E4BS
0000001FAJ<0000005Q6XP000000FDNR0000001KB:80000005e9XP000000GTZR0000001PBj800000
069<XP000000HdbR0000001TCJ80000006I>XP000000IdjQ00000080J4nQ00<0000006Y@X@000000
100000001`1^DZ40000006mBX@1_DZ400000071CX00000000P1aDj001@000000LUBP0000001cEJ00
00000080M5FP00H0000007EFX01eEZ00000007IFX000000207MGX0030000001hF:0000000080NERO
00<0000007YIW`0000000P1kFIl00`000000NeVO0000000207aJW`030000001mFYl000000080OU^O
00<0000007=LZ@0000001@2hQIh00`000000^hbT0;^<Y0050;^<Y0030000002mTZX0_I:Z00H0_I:Z
00<000000;nH/02oV;001P2oV;02000000D0i;j`00<000000>71]`3Q`KL00`3Q`KL00`000000g/>m
0=k3_@040=k3_@030000003Ka<<0flC300@0flC300<000000=S5a`3HaLL00P3HaLL2000000<0incB
00<000000>;Ye`3RjML00P3RjML00`000000gNKK0=gVf`020=gVf`030000003Hhmh0f>?N0080f>?N
00D000000=COh03Dgn00e=oP000000040=3MhP030000003=f^<0cM[S0080cM[S00<000000<WHi039
f>@00P39f>@00`000000amKU0<OFi@020<OFi@0300000034e>H0a=CV0080a=CV00<000000?ooo`3o
ool0I`3oool00`000000oooo0?ooo`0b0?ooo`008`3oool00`000000oooo0?ooo`1R0?ooo`030000
002T/^<0Y;;S00<0Y;;S00<000000:BbhP2T/^800`2T/^800`000000Y;7R0:BahP020:BahP030000
002S/>40Xk3Q0080Xk3Q1000000309B[iP030000002BZND0TZWU00<0TZWU00<00000092Vi@2@Y^D0
0`2@Y^D00`000000SJCT08fTi00408fTi0030000002;X>80Rj3R0080Rj3R00<0000008RLh@28W>40
0`28W>400`000000Q9SN08BHgP0308BHgP0300000021Tm`0PI?L0080PI?L00<0000007j=f01nSMP0
0P1nSMP00`000000NXKD07Z6e00307Z6e0030000001gOlh0Mgo>0080Mgo>00<0000007Agb01dMlP0
0P1dMlP01P000000Lfo007=_`0000000Lfo0000000@0LfRh00P0000007ER[`1eHZl0MF:_0000001>
@J<000000512X`80000001@0E4BS0000001FAJ<0000005Q6XP000000FDNR0000001KB:80000005e9
XP000000GTZR0000001PBj800000069<XP000000HdbR00000080I4fR0P00000206M>X@030000001X
Cj40000000L0000000@0KE6Q0000001_DZ4000000P1`Dj001@000000LE>P0000001bE:0000000080
LeFP00<0000007AEX00000000P1eEZ000`000000MUJP0000000207MGX0030000001hF:0000000080
NERO00<0000007YIW`0000000P1kFIl00`000000NeVO0000000207aJW`040000001mFYl0OEZO0000
0080OU^O00<000000;R5WP2hQIh01@2hQIh00`000000^hbT0;^<Y0050;^<Y0030000002mTZX0_I:Z
00D0_I:Z00<000000;nH/02oV;001P2oV;000`000000i;j`0>Bn/0040>Bn/0030000003Q`KL0hL6g
00<0hL6g00<000000=k3_@3N`kd01@3N`kd00`000000flC30=_4``030=_4``070000003HaLL0f<G7
0=S5a`000000k>k;000000030>O/dP030000003RjML0h^WG0080h^WG00<000000=gVf`3Mi]/00P3M
i]/00`000000f>?N0=SSgP020=SSgP050000003Dgn00e=oP0=COh0000000103@gN801@000000cM[S
0<gJh`3=f^<0000000D0bMST00<000000<OFi@37e^D00P37e^D00`000000a=CV0<CDiP020<CDiP03
0000003oool0oooo06L0oooo00<000000?ooo`3oool0<P3oool002<0oooo00<000000?ooo`3oool0
H`3oool00`000000Y;;S0:Bbh`030:Bbh`030000002T/^80Y;;R00<0Y;;R00D000000:BahP2T/N80
Y;7R000000020:>`h@8000000P2F[NL00`000000U:_V09B[iP0309B[iP030000002BZND0TZWU00<0
TZWU00<00000092Vi@2@Y^D00`2@Y^D00`000000SJCT08fTi00308fTi0030000002;X>80Rj3R00<0
Rj3R00<0000008RLh@28W>400`28W>400`000000Q9SN08BHgP0208BHgP0300000021Tm`0PI?L00<0
PI?L00<0000007j=f01nSMP00P1nSMP00`000000NXKD07Z6e00207Z6e0030000001gOlh0Mgo>0080
Mgo>00<0000007Agb01dMlP00`1dMlP01@000000Lfo00000001cKl00000000@0LfRh00<0000007ER
[`1eHZl00P1eHZl01`000000CT6S000000000000DT>S0000001DA:<00P0000001P1HAZ80000005U7
XP000000FdRR00000080GDVR0P000000401PBj800000069<XP1RC:80000006=<XP000000I4fR0000
001VCZ80000006M>X@000000J4nQ0000001ZD:460000000406eAX@000000Ke:Q00000080L5>P00D0
0000075CX0000000LUBP0000000207=EX0030000001dEJ0000000080MEJP00<0000007IFX0000000
0P1gEj000`000000N5RP0000000207UHW`030000001jFIl000000080NeVO00@0000007]IW`1kFIl0
00000P1lFYl6000000L0^8FN00<000000;^<Y02kS:@01@2kS:@00`000000_I:Z0;fBZP060;fBZP03
0000002oV;00_iR`00D0_iR`00<000000>Bn/03T_[00103T_[000`000000hL6g0>71]`040>71]`03
0000003N`kd0g/>m00@0g/>m00<000000=_4``3Ka<<0103Ka<<00`000000f<G70=S5a`02000000@0
incB00<000000>;Ye`3RjML00P3RjML00`000000gNKK0=gVf`020=gVf`050000003Hhmh0f>?N0=SS
gP000000103Dgn001@000000d=gR0=3MhP3@gN80000000@0cM[S00<000000<WHi039f>@00`39f>@0
1@000000amKU0<OFi@37e^D0000000@0a=CV00<000000?ooo`3oool0J03oool00`000000oooo0?oo
o`0b0?ooo`008`3oool00`000000oooo0?ooo`1S0?ooo`030000002T/^<0Y;;S00<0Y;;S00<00000
0:BbhP2T/^800`2T/^800`000000Y;7R0:BahP04000000D0UZgW00<0000009B[iP2DZnH00`2DZnH0
0`000000TZWU09:Yi@0309:Yi@030000002@Y^D0T:KU00<0T:KU00<0000008fTi02=Y>@00`2=Y>@0
0`000000Rj3R08^PhP0308^PhP0300000028W>40R9cQ0080R9cQ00<0000008BHgP24V=h00`24V=h0
0`000000PI?L086Cg002086Cg0030000001nSMP0OXgH00<0OXgH00<0000007Z6e01jQ]@00P1jQ]@0
0`000000Mgo>07MocP0207MocP030000001dMlP0M7O80080M7O800D0000007=_`0000000Lfo00000
000407=X^0030000001eHZl0MF:_0080MF:_00@0000004i1X`000000D4:S0P0000001`1DA:<00000
05I5X`000000F4JR0000001IAj800P00000205e9XP0?0000001NBZ800000061;XP000000HTbR0000
001SC:80000006A=XP000000ITjR0000001WCZ4000000080J4nQ00<0000006Y@X@0000000P000000
2`1/DJ40000006eAX@1]DJ40000006mBX@000000L5>P0000001aDj0000000080LUBP00D0000007=E
X0000000M5FP0000000207EFX0030000001fEZ0000000080MeNP00<0000007QHX00000000P1iF9l0
10000000NUVO07YIW`00000207]IW`H0000000D0NeNL0000001lEi`0O5NL000000070;R5WP030000
002kS:@0^hbT00D0^hbT00<000000;fBZP2mTZX01P2mTZX00`000000_iR`0;nH/0040;nH/0800000
1`3T_[000`000000hL6g0>71]`030>71]`030000003N`kd0g/>m00@0g/>m00<000000=_4``3Ka<<0
103Ka<<01@000000f<G70000003/k//0000000@0incB00D000000>;Ye`3RjML0h^WG000000040=gV
f`030000003Hhmh0f>?N0080f>?N00D000000=COh03Dgn00e=oP000000040=3MhP030000003=f^<0
cM[S0080cM[S00<000000<WHi039f>@00P39f>@00`000000amKU0<OFi@020<OFi@0300000034e>H0
a=CV0080a=CV00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0b0?ooo`008`3oool00`00
0000oooo0?ooo`1T0?ooo`030000002T/^<0Y;;S00<0Y;;S00<000000:BbhP2T/^800P2T/^830000
00<0UjkW00<0000009J]i`2F[NL0102F[NL00`000000U:_V09B[iP0309B[iP030000002BZND0TZWU
00<0TZWU00<00000092Vi@2@Y^D00`2@Y^D00`000000SJCT08fTi00308fTi0030000002;X>80Rj3R
00<0Rj3R00<0000008RLh@28W>400P28W>400`000000Q9SN08BHgP0308BHgP0300000021Tm`0PI?L
0080PI?L00<0000007j=f01nSMP00`1nSMP01@000000NXKD07Z6e01jQ]@0000000@0Mgo>00<00000
07Agb01dMlP00`1dMlP200000080Lfo000D0000007=X^01cJ;P0LfRh0000000407ER[`040000001>
@J<000000512X`80000001X0E4BS0000001FAJ<0000005Q6XP000000FDNR0000001KB:80000005e9
XP000000GTZR0000001PBj800000069<XP000000HdbR0000001TCJ80000006I>XP000000IdjQ0000
0080J4nQ0`0000000`1[D:400000000000040000000906mBX@000000L5>P071CX0000000LE>P0000
001bE:0000000080LeFP00<0000007AEX00000000P1eEZ000`000000MUJP0000000207MGX0030000
001hF:0000000080NERO1P0000001`1jEid0000007YGW@1jEid0000007]GW00000000P1lEi`00`00
0000^8FN0;R5WP050;R5WP030000002kS:@0^hbT00D0^hbT00<000000;fBZP2mTZX01P2mTZX00`00
0000_iR`0;nH/0040;nH/08000001`3T_[000`000000hL6g0>71]`030>71]`030000003N`kd0g/>m
00@0g/>m00<000000=_4``3Ka<<0103Ka<<200000080k>k;00D000000>O/dP3Wk=80incB00000004
0>;Ye`030000003Mi]/0gNKK0080gNKK00<000000=SSgP3Hhmh00P3Hhmh01@000000e=oP0=COh03D
gn00000000@0d=gR00D000000<gJh`3=f^<0cM[S000000050<WHi00300000037e^D0amKU0080amKU
00D000000<CDiP34e>H0a=CV0000001/0?ooo`030000003oool0oooo0340oooo000R0?ooo`030000
003oool0oooo06H0oooo00<000000:Bbh`2T/^<00P2T/^<00`000000Y;;R0:BbhP0200000080V:oW
00<0000009N^i`2G[^L00P2G[^L00`000000UZgW09J]i`0409J]i`030000002DZnH0U:_V00<0U:_V
00<0000009:Yi@2BZND00`2BZND00`000000T:KU092Vi@03092Vi@030000002=Y>@0SJCT00<0SJCT
00<0000008^PhP2;X>800`2;X>800`000000R9cQ08RLh@0208RLh@0300000024V=h0Q9SN00<0Q9SN
00<00000086Cg021Tm`00P21Tm`00`000000OXgH07j=f00207j=f0030000001jQ]@0NXKD0080NXKD
00<0000007MocP1gOlh00P1gOlh00`000000M7O807Agb00207Agb08000000P1cKl000`000000LfRh
07=X^00207=X^0030000001eHZl0MF:_0080MF:_00<0CT6S0000001@@Z<00P000000501DA:<00000
05I5X`000000F4JR0000001IAj80000005]8XP000000GDVR0000001NBZ800000061;XP000000HTbR
0000001SC:8000000P1TCJ8010000000ITjR0000001WCZ430000000306Y?X@000000Je2Q00<00000
0P1]DJ0L0000000707QFW@000000NEJM07UFW@000000NUNM0000000207YGW@030000001kEi`0NeNL
00<0O5NL00<000000;R5WP2hQIh0102hQIh00`000000^hbT0;^<Y0060;^<Y0030000002mTZX0_I:Z
00H0_I:Z00<000000;nH/02oV;000P2oV;0010000000i[^Y0>JkZ@0000060>Bn/0030000003Q`KL0
hL6g00<0hL6g00<000000=k3_@3N`kd0103N`kd00`000000flC30=_4``040=_4``050000003/k//0
k>k;0>c^b`0000000`3Wk=800`000000h^WG0>;Ye`020>;Ye`030000003Mi]/0gNKK0080gNKK00D0
00000=SSgP3Hhmh0f>?N000000040=COh0050000003@gN80d=gR0=3MhP000000103=f^<00`000000
bMST0<WHi0030<WHi00500000037e^D0amKU0<OFi@0000001034e>H00`000000oooo0?ooo`1Z0?oo
o`030000003oool0oooo0340oooo000R0?ooo`030000003oool0oooo06H0oooo00@000000:Bbh`2T
/^<0Y;;S1000000509R_i`030000002G[^L0UjkW0080UjkW00<0000009J]i`2F[NL0102F[NL20000
00@0U:_V00<0000009:Yi@2BZND00`2BZND00`000000T:KU092Vi@03092Vi@030000002=Y>@0SJCT
00<0SJCT00<0000008^PhP2;X>800`2;X>800`000000R9cQ08RLh@0208RLh@0300000024V=h0Q9SN
00<0Q9SN00<00000086Cg021Tm`00P21Tm`00`000000OXgH07j=f00207j=f0050000001jQ]@0NXKD
07Z6e0000000101gOlh00`000000M7O807Agb00307Agb0050000001cKl00Lfo007=_`00000000`1c
J;P00`000000MF:_07ER[`0207ER[`070000001>@J<000000000001B@j<0000005A4X`0200000006
05Q6XP000000FDNR0000001KB:8000000P1MBJ8200000008061;XP000000HTbR069<XP000000HdbR
0000001TCJ850000000406Q?X@000000JTnQ06Y?X@<0000000H0K56P0000001]DJ00000006iBX000
000206mBX0050000001`Dil00000075CW`0000000P1bDil00`000000LeBO0000000207ADWP030000
001eE9h000000080MUFN00<0000007MEWP0000000P1hEYd00`000000N5JM0000000207UFW@030000
001jEid0NUNM00<0NUNM0P1kEi`307aGW0030000002hQIh0^8FN00D0^8FN00<000000;^<Y02kS:@0
1@2kS:@00`000000_I:Z0;fBZP060;fBZP030000002oV;00_iR`0080_iR`00@000000>JkZ@3V^jT0
00001P3T_[000`000000hL6g0>71]`030>71]`030000003N`kd0g/>m00@0g/>m00<000000=_4``3K
a<<00`3Ka<<200000080k>k;00<000000>O/dP3Wk=800P3Wk=801@000000h^WG0>;Ye`3RjML00000
00@0gNKK00<000000=SSgP3Hhmh00P3Hhmh01@000000e=oP0=COh03Dgn00000000@0d=gR00<00000
0<gJh`3=f^<00P3=f^<00`000000bMST0<WHi0020<WHi00300000037e^D0amKU0080amKU00<00000
0<CDiP34e>H00P34e>H00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0340oooo000R0?oo
o`030000003oool0oooo06L0oooo0`00000309Zai`030000002H[nL0V:oW00@0V:oW00<0000009N^
i`2G[^L00P2G[^L2000000H0UZgW00<0000009B[iP2DZnH00P2DZnH00`000000TZWU09:Yi@0309:Y
i@030000002@Y^D0T:KU00<0T:KU00<0000008fTi02=Y>@00`2=Y>@00`000000Rj3R08^PhP0308^P
hP0300000028W>40R9cQ0080R9cQ00<0000008BHgP24V=h00P24V=h00`000000PI?L086Cg002086C
g0030000001nSMP0OXgH00<0OXgH00D0000007Z6e01jQ]@0NXKD0000000407MocP030000001dMlP0
M7O80080M7O800D0000007=_`01cKl00Lfo00000000307=X^0040000001eHZl0MF:_07ER[`@00000
00X0D4:S000000000000E4BS0000001FAJ<0000005Q6XP000000FDNR0P00000205e9XP060000001N
BZ800000061;XP000000HTbR1@000000101VCJ00000006M>X@00000206Q?X@030000001ZCj400000
00H0000000T0KU:P0000001_DZ00Ke:P0000001`Dil00000075CW`0000000P1bDil00`000000LeBO
0000000207ADWP030000001eE9h000000080MUFN00<0000007MEWP0000000P1hEYd00`000000N5JM
07QFW@0207UFW@030000001jEid0NUNM00<0NUNM0P1kEi`010000000O5NL07aGW00000070;R5WP03
0000002kS:@0^hbT00D0^hbT00<000000;fBZP2mTZX01P2mTZX01@000000_iR`0;nH/02oV;000000
00<0i[^Y00<000000>Bn/03T_[00103T_[000`000000hL6g0>71]`030>71]`030000003N`kd0g/>m
00@0g/>m00<000000=_4``3Ka<<00P3Ka<<00`000000lO32000000020>c^b`030000003Wk=80incB
0080incB00D000000>;Ye`3RjML0h^WG000000040=gVf`030000003Hhmh0f>?N0080f>?N00D00000
0=COh03Dgn00e=oP000000040=3MhP050000003=f^<0cM[S0<gJh`0000001@39f>@00`000000amKU
0<OFi@020<OFi@0500000034e>H0a=CV0<CDiP000000K@3oool00`000000oooo0?ooo`0a0?ooo`00
8P3oool00`000000oooo0?ooo`1X0?ooo`030000002J/NL0V[7W00<0V[7W00<0000009R_i`2H[nL0
102H[nL2000000@0UjkW00<0000009J]i`2F[NL0102F[NL00`000000U:_V09B[iP0209B[iP030000
002BZND0TZWU00<0TZWU00<00000092Vi@2@Y^D00`2@Y^D00`000000SJCT08fTi00308fTi0030000
002;X>80Rj3R0080Rj3R00<0000008RLh@28W>400`28W>400`000000Q9SN08BHgP0208BHgP030000
0021Tm`0PI?L0080PI?L00<0000007j=f01nSMP00P1nSMP00`000000NXKD07Z6e00207Z6e0050000
001gOlh0Mgo>07MocP000000101dMlP200000080Lfo000<0000007=X^01cJ;P00P1cJ;P300000003
0;]R00000000DT2N00H0000000L0ETFS0000001HAZ80000005U7XP000000FdRR00T0000000@0Hd^P
0000001UC:0000000P1VCJ0200000080J4nQ00<0000006Y?X@0000001@000000101]DJ00000006iB
X000000206mBX0040000001`Dil0LE>O075CW`<0LU>O0P1cE9l307ADWP80MEBN0`1fEIh207MEWPD0
N5JM0`1iEYd207YGW@060000001jEid0NUNM0000001kEi`000000P1lEi`00`000000^8FN0;R5WP05
0;R5WP030000002kS:@0^hbT00D0^hbT00<000000;fBZP2mTZX01`2mTZX010000000_iR`0;nH/000
00030>JkZ@030000003T_[00i;j`00@0i;j`00<000000>71]`3Q`KL00`3Q`KL00`000000g/>m0=k3
_@050=k3_@060000003Ka<<0flC30000003al<8000000`3/k//01@000000incB0>O/dP3Wk=800000
00@0h^WG00<000000=gVf`3Mi]/00P3Mi]/01@000000f>?N0=SSgP3Hhmh0000000@0e=oP00D00000
0=3MhP3@gN80d=gR000000040<gJh`0300000039f>@0bMST00<0bMST00D000000<OFi@37e^D0amKU
000000020<CDiP<00000K@3oool00`000000oooo0?ooo`0a0?ooo`008P3oool00`000000oooo0?oo
o`1Y0?ooo`030000002J/NL0V[7W00<0V[7W0P00000609R_i`030000002G[^L0UjkW0080UjkW00<0
000009J]i`2F[NL0102F[NL00`000000U:_V09B[iP0209B[iP030000002BZND0TZWU00<0TZWU00<0
0000092Vi@2@Y^D00`2@Y^D00`000000SJCT08fTi00308fTi0030000002;X>80Rj3R0080Rj3R00<0
000008RLh@28W>400P28W>400`000000Q9SN08BHgP0308BHgP0300000021Tm`0PI?L0080PI?L00<0
000007j=f01nSMP00P1nSMP01@000000NXKD07Z6e01jQ]@0000000@0Mgo>00D0000007Agb01dMlP0
000007Agb0030000000307=_`0000000LfRh00<00000102kHP000`000000DT2N0000000200000003
05M3W`000000000000L0000000P0GTRP0000001OBJ0000000659X0000000HT^P00000080Hd^P00L0
000006E<X0000000ITfP0000001WCZ4000000080J4nQ00<0000006U?X00000000`0000001@1]DJ00
00000000001^DZ0000000080Ke:P00D00000071CW`000000LE>O00000002079CW`030000001cE9l0
00000080M5BN00<0000007EDWP0000000P1fEIh207MEWPD0N5JM00H0000007UFW@1iEYd0000007YG
W@00000207YGW@030000001kEi`000000080O5NL00<000000;R5WP2hQIh01@2hQIh00`000000^hbT
0;^<Y0060;^<Y0030000002mTZX0_I:Z00H0_I:Z00<000000;nH/0000000103V^jT00`000000i;j`
0>Bn/0040>Bn/0030000003Q`KL0hL6g00@0hL6g00<000000=k3_@3N`kd0103N`kd00`000000flC3
000000020?7``P050000003/k//0k>k;0>c^b`0000000`3Wk=801@000000h^WG0>;Ye`3RjML00000
00D0gNKK00D000000=SSgP3Hhmh0f>?N000000030=COh0030000003@gN80d=gR0080d=gR00<00000
0<gJh`3=f^<00P3=f^<00`000000bMST0<WHi0020<WHi00300000037e^D0amKU00D0000000<0_n?a
0000003oool0K@3oool200000380oooo000R0?ooo`030000003oool0oooo06X0oooo0P00000509Za
i`030000002H[nL0V:oW00@0V:oW00<0000009N^i`2G[^L00P2G[^L00`000000UZgW09J]i`0409J]
i`030000002DZnH0U:_V0080U:_V00<0000009:Yi@2BZND00`2BZND00`000000T:KU092Vi@03092V
i@030000002=Y>@0SJCT00<0SJCT00<0000008^PhP2;X>800P2;X>800`000000R9cQ08RLh@0208RL
h@0300000024V=h0Q9SN00<0Q9SN00<00000086Cg021Tm`00P21Tm`00`000000OXgH07j=f00207j=
f0050000001jQ]@0NXKD07Z6e00000000`1gOlh00`000000M7O80000000307Agb0030000001cKl00
000000<0000000<0Z4P00000002kHP000`2kHP0010000000DT2N0000001C@Il20000000905M3W`00
0000000005Y5W`000000FdJO0000001LAil000000080GTRP00l0000005m9X0000000HDVP0000001R
Bj00000006=;X0000000IDbP0000001VCJ00000006M>X@0000000P1XCj400`000000JDnP00000003
00000080KE6P00<0000006iBX00000000P1_DZ001@000000L5>O0000001aDil000000080LU>O00<0
000007=DW`0000000P1dE9h00`000000MEBN0000000207IEWP030000001gEIh000000080N5JM00<0
000007QFW@0000000P1iEYd00`000000NUNM0000000207YGW@030000001kEi`000000080O5NL00<0
00000;R5WP2hQIh01P2hQIh00`000000^hbT0;^<Y0050;^<Y0030000002mTZX0_I:Z00H0_I:Z00<0
00000;nH/0000000103V^jT00`000000i;j`0>Bn/0050>Bn/0030000003Q`KL0hL6g00<0hL6g00<0
00000=k3_@3N`kd0103N`kd2000000<0lO3200@000000>c^b`3/k//00000103Wk=801@000000h^WG
0>;Ye`3RjML0000000@0gNKK00<000000=SSgP3Hhmh00P3Hhmh01@000000e=oP0=COh03Dgn000000
00@0d=gR00D000000<gJh`3=f^<0cM[S000000020<WHi0H0000000<0`NOa0000002oho400P2oho40
0`000000oooo0?ooo`1/0?ooo`030000003oool000000380oooo000Q0?ooo`030000003oool0oooo
06d0oooo00<0000009Zai`2J/NL00`2J/NL00`000000V:oW09R_i`0409R_i`030000002G[^L0UjkW
0080UjkW00<0000009J]i`2F[NL0102F[NL00`000000U:_V09B[iP0209B[iP030000002BZND0TZWU
00<0TZWU00<00000092Vi@2@Y^D00`2@Y^D00`000000SJCT08fTi00308fTi0030000002;X>80Rj3R
0080Rj3R00<0000008RLh@28W>400P28W>400`000000Q9SN08BHgP0208BHgP0300000021Tm`0PI?L
0080PI?L00<0000007j=f01nSMP00P1nSMP01@000000NXKD07Z6e01jQ]@0000000@0Mgo>00@00000
07Agb01dMlP0M7O80`000000100006P000000000000000020:Q800@0^f8000@000000590WP000000
Dd6O0P0000006P1G@il0000005Q4W`000000FTFO0000001KAYl0000005a7W`000000GTRP0000001O
BJ0000000659X0000000HT^P0000001SBj00000006E<X0000000ITfP0000001WCZ4000000P1XCj40
0`000000JDnP000000040000000406eAX0000000000000000080Ke:P00D00000071CW`000000LE>O
00000002079CW`030000001cE9l000000080M5BN00<0000007EDWP0000000P1fEIh00`000000MeFN
0000000207QFW@030000001hEYd000000080NEJM00<0000007YGW@1jEid00P1jEid00`000000NeNL
07]GW00307aGW0030000002hQIh0^8FN00D0^8FN00<000000;^<Y02kS:@01@2kS:@00`000000_I:Z
0;fBZP070;fBZP030000003V^jT0i[^Y00<0i[^Y00<000000>Bn/03T_[001@3T_[000`000000hL6g
0>71]`030>71]`030000003N`kd0g/>m00@0g/>m00<000000?7``P3al<800P3al<8010000000k>k;
0>c^b`0000040>O/dP050000003RjML0h^WG0>;Ye`000000103Mi]/00`000000f>?N0=SSgP020=SS
gP050000003Dgn00e=oP0=COh00000000`3@gN800`000000cM[S0<gJh`0500000080`n_`00D00000
0<7Wl@31io40`NOa000000030;oSl@030000003oool0oooo06`0oooo00@000000?ooo`3oool00000
<P3oool00240oooo00<000000?ooo`3oool0KP3oool00`000000V[7W09Zai`0309Zai`030000002H
[nL0V:oW00@0V:oW00<0000009N^i`2G[^L00P2G[^L00`000000UZgW09J]i`0409J]i`030000002D
ZnH0U:_V0080U:_V00<0000009:Yi@2BZND00`2BZND00`000000T:KU092Vi@03092Vi@030000002=
Y>@0SJCT00<0SJCT00<0000008^PhP2;X>800P2;X>800`000000R9cQ08RLh@0208RLh@0300000024
V=h0Q9SN0080Q9SN00<00000086Cg021Tm`00P21Tm`00`000000OXgH07j=f00207j=f0060000001j
Q]@0NXKD07Z6e0000000Mgo>0`0000000`1dMlP00000000000020000R@030000000006P0001X0080
Z4P00`0000030;]R00040000001B@9h0000005=1W`8000000180Ed>O0000001HA9l0000005Y5W`00
0000FdJO0000001LAil0000005i8X0000000GdVP0000001QBJ000000069;X000000206=;X0040000
001UC:00000006I=X080000000@0J4nQ000000000000JDnP1@0000000`1]DJ00000006iAW`020000
000406mBX0000000L5>O00000080LE>O00D00000079CW`000000LeBO0000000207ADWP030000001e
E9h000000080MUFN00<0000007MEWP0000000P1hEYd00`000000N5JM0000000207UFW@040000001j
Eid0NUNM00000080NUNM0P1kEi`010000000O5NL07aGW00000070;R5WP030000002kS:@0^hbT00D0
^hbT00<000000;fBZP2mTZX01`2mTZX00`000000i[^Y0>JkZ@030>JkZ@030000003T_[00i;j`00D0
i;j`00<000000>71]`3Q`KL00`3Q`KL00`000000g/>m0=k3_@030=k3_@8000000`3al<801@000000
k>k;0>c^b`3/k//0000000<0incB00<000000>;Ye`3RjML00P3RjML00`000000gNKK0=gVf`020=gV
f`050000003Hhmh0f>?N0=SSgP000000103Dgn000`000000d=gR0=3MhP04000000030<C_l0000000
`n_`00<0`n_`00D000000<7Wl@31io40`NOa000000030;oSl@030000003oool0oooo0700oooo00<0
00000?ooo`3oool0<03oool00240oooo00<000000?ooo`3oool0K`3oool00`000000V[7W09Zai`03
09Zai`030000002H[nL0V:oW00@0V:oW00<0000009N^i`2G[^L00P2G[^L00`000000UZgW09J]i`04
09J]i`030000002DZnH0U:_V0080U:_V00<0000009:Yi@2BZND00`2BZND00`000000T:KU092Vi@03
092Vi@030000002=Y>@0SJCT00<0SJCT00<0000008^PhP2;X>800P2;X>800`000000R9cQ08RLh@02
08RLh@0300000024V=h0Q9SN0080Q9SN00<00000086Cg021Tm`00P21Tm`00`000000OXgH07j=f002
07j=f0030000001jQ]@0NXKD0080000000@0Mgo>0000000000000000100008T010000000001X0000
J00000030:Q8008000000`2kHP000`000000DT2N000000020000000>05M3W`000000F4BO0000001J
AIl0000005]6W`000000G4NO0000001NB:00000005m9X00000020659X00:0000001RBj00000006=;
X0000000IDbP0000001VCJ00000006M>X@80000000<0J4jP0000001YCZ000P000000101/D:000000
00000000000206iAW`030000001_DZ0000000080L5>O00<00000075CW`0000000P1bDil01@000000
LeBO0000001dE9h000000080MEBN00<0000007IEWP0000000P1gEIh207QFW@060000001hEYd0N5JM
0000001iEYd000000P1jEid01P000000NUNM07YGW@000000NeNL00000080O5NL00<000000;R5WP2h
QIh01@2hQIh00`000000^hbT0;^<Y0060;^<Y0030000002mTZX0_I:Z00H0_I:Z00<000000>JkZ@3V
^jT0103V^jT00`000000i;j`0>Bn/0040>Bn/0030000003Q`KL0hL6g00<0hL6g00<000000=k3_@3N
`kd00`3N`kd2000000<0lO3200D000000>c^b`3/k//0k>k;000000030>O/dP050000003RjML0h^WG
0>;Ye`000000103Mi]/00`000000f>?N0=SSgP020=SSgP060000003Dgn00e=oP0=COh0000000d=gR
0`0000030<C_l00300000033jo00`n_`0080`n_`00D000000<7Wl@31io40`NOa000000030;oSl@03
0000003oool0oooo0740oooo00<000000?ooo`3oool0<03oool00240oooo00<000000?ooo`3oool0
L03oool00`000000V[7W09Zai`0309Zai`030000002H[nL0V:oW00@0V:oW00<0000009N^i`2G[^L0
0P2G[^L2000000D0UZgW00<0000009B[iP2DZnH00P2DZnH2000000@0TZWU00<00000092Vi@2@Y^D0
0`2@Y^D00`000000SJCT08fTi00308fTi0030000002;X>80Rj3R0080Rj3R00<0000008RLh@28W>40
0P28W>400`000000Q9SN08BHgP0208BHgP0300000021Tm`0PI?L0080PI?L00D0000007j=f01nSMP0
OXgH0000000207Z6e0<000000`007:L00`00000000290000R@020000R@030000000006P0001X00@0
Z4P000P0^f80000000000000^f800000001B@9h0000005=1W`80000001X0Ed>O0000001HA9l00000
05Y5W`000000FdJO0000001LAil0000005i8X0000000GdVP0000001QBJ000000069;X0000000Hd^P
0000001UC:00000006I=X0000000IdjQ00000080J4jP00<0000006U>X00000001@00000206iAW`80
000000H0Ke:P0000001`Dil00000075CW`000002079CW`030000001cE9l000000080M5BN00<00000
07EDWP0000000P1fEIh00`000000MeFN0000000207QFW@030000001hEYd000000080NEJM00<00000
07YGW@0000000P1jEid00`000000NeNL0000000207aGW0030000002hQIh0^8FN00D0^8FN00<00000
0;^<Y02kS:@01P2kS:@00`000000_I:Z0;fBZP050;fBZP8000001P3V^jT00`000000i;j`0>Bn/004
0>Bn/0030000003Q`KL0hL6g00<0hL6g00<000000=k3_@3N`kd00P3N`kd2000000@0lO3200D00000
0>c^b`3/k//0k>k;000000030>O/dP050000003RjML0h^WG0>;Ye`000000103Mi]/00`000000f>?N
0=SSgP020=SSgP030000003Dgn00e=oP00<0000000<0a_C^00000034ko000P34ko000`000000`n_`
0<?[l0020<?[l00500000031io40`NOa0<7Wl@0000000`2oho400`000000oooo0?ooo`1b0?ooo`03
0000003oool0oooo0300oooo000Q0?ooo`030000003oool0oooo0740oooo0P00000409Zai`800000
1@2H[nL2000000@0UjkW00<0000009J]i`2F[NL00`2F[NL2000000@0U:_V00<0000009:Yi@2BZND0
0P2BZND00`000000T:KU092Vi@03092Vi@030000002=Y>@0SJCT00<0SJCT00<0000008^PhP2;X>80
0P2;X>800`000000R9cQ08RLh@0208RLh@0300000024V=h0Q9SN0080Q9SN00D00000086Cg021Tm`0
PI?L0000000207j=f0@000000P00?L001@00000001bW000LY`007:L0000000@0002900@000000000
J00006P000000`2XB0000`000000^f800;]R00040000000M05=1W`000000000005M3W`000000F4BO
0000001JAIl0000005]6W`000000G4NO0000001NB:00000005m9X0000000HDVP0000001RBj000000
06=;X0000000IDbP0000001VCJ00000006M>X@0000000P1XCZ000`000000JDjP06U>X00200000003
06a@X000000000000080KU6O00P0000006mAW`0000000000071CW`000000LE>O00000080LU>O00<0
000007=DW`0000000P1dE9h00`000000MEBN0000000207IEWP030000001gEIh000000080N5JM00<0
000007QFW@0000000P1iEYd00`000000NUNM0000000207YGW@030000001kEi`000000080O5NL00<0
00000;R5WP2hQIh01P2hQIh00`000000^hbT0;^<Y0050;^<Y0030000002mTZX0_I:Z00D0_I:Z0P00
00060>JkZ@030000003T_[00i;j`00@0i;j`00<000000>71]`3Q`KL00`3Q`KL01`000000g/>m0=k3
_@3N`kd000000?G`]P000000103al<8010000000k>k;0>c^b`0000040>O/dP050000003RjML0h^WG
0>;Ye`000000103Mi]/01P000000f>?N0=SSgP3Hhmh000000=COh0<000000P36m>h01@000000a>o`
0<C_l034ko00000000@0`n_`00D000000<7Wl@31io40`NOa000000030;oSl@030000003oool0oooo
07@0oooo00<000000?ooo`3oool0;`3oool00240oooo00<000000?ooo`3oool0L`3oool00`000000
V[7W09Zai`0309Zai`030000002H[nL0V:oW00@0V:oW00<0000009N^i`2G[^L00P2G[^L00`000000
UZgW09J]i`0409J]i`030000002DZnH0U:_V0080U:_V00<0000009:Yi@2BZND00P2BZND00`000000
T:KU092Vi@03092Vi@030000002=Y>@0SJCT0080SJCT00<0000008^PhP2;X>800`2;X>801@000000
R9cQ08RLh@28W>40000000@0Q9SN00<00000086Cg021Tm`00P21Tm`20000008005WC0P000003000m
`005000000007:L001bW000LY`000000100008T00`000000001X0000J0040:Q800@0^f801@000000
3P1G@il0000005Q4W`000000FTFO0000001KAYl0000005a7W`000000GTRP0000001OBJ0000000P1Q
BJ0030000000HT^P0000001SBj00000006E<X0000000ITfP0000001WCIl0000006Q>X080000000@0
JDjP000000000000K52P0`0000002@1^DIl0000006mAW`1_DIl00000071CW`000000LE>O00000002
079CW`030000001cE9l000000080M5BN00<0000007EDWP0000000P1fEIh00`000000MeFN00000002
07QFW@030000001hEYd000000080NEJM00<0000007YGW@0000000P1jEid01P000000NeNL07]GW000
0000O5NL000000P0^8FN00<000000;^<Y02kS:@01@2kS:@00`000000_I:Z0;fBZP040;fBZP030000
003X]j40000000H0i[^Y00<000000>Bn/03T_[00103T_[000`000000hL6g0>71]`040>71]`030000
003N`kd000000080mO2f00D000000?7``P3al<80lO32000000030>c^b`050000003Wk=80incB0>O/
dP0000000`3RjML00`000000gNKK0=gVf`030=gVf`030000003Hhmh0f>?N00<0000000D0aoWZ0000
0036m>h0a_C^000000040<C_l00500000033jo00`n_`0<?[l00000000`31io400`000000_n?a0;oS
l@020;oSl@030000003oool0oooo07@0oooo00<000000?ooo`3oool0;`3oool00200oooo00<00000
0?ooo`3oool0M@3oool00`000000V[7W09Zai`0309Zai`030000002H[nL0V:oW00@0V:oW00<00000
09N^i`2G[^L00P2G[^L00`000000UZgW09J]i`0409J]i`030000002DZnH0U:_V0080U:_V00<00000
09:Yi@2BZND00P2BZND00`000000T:KU092Vi@03092Vi@030000002=Y>@0SJCT0080SJCT00<00000
08^PhP2;X>800P2;X>800`000000R9cQ08RLh@0208RLh@0300000024V=h0Q9SN0080Q9SN00P00000
086Cg0000000000001Y_g`00000005WC0000008005WC00D00000000m`000?L0003g000000003000L
Y`030000000008T000290080002900<000000000J00000000`2XB0001P000000^f800;]R002kHP00
00000590WP@0000000D0Ed>O0000001HA9l0000005Y5W`020000000K05a7W`000000GTRP05i8X000
0000GdVP0000001QBJ000000069;X0000000Hd^P0000001UC:00000006I=X0000000IdfO0000001X
CZ00000006Q=W`000000JDnP06Y?X0000000K52P0080000000@0KU6O0000001_DIl0Ke6O0P000000
201`Dil00000075CW`000000LU>O0000001cE9l000000P1dE9h00`000000MEBN0000000207IEWP03
0000001gEIh000000080N5JM00<0000007QFW@0000000P1iEYd01P000000NUNM07YGW@000000NUNM
00000080NeNL00@0000007aGW01lEi`000001`2hQIh00`000000^hbT0;^<Y0060;^<Y0030000002m
TZX0_I:Z00<0_I:Z00<000000>RgX@0000001P3V^jT00`000000i;j`0>Bn/0050>Bn/0030000003Q
`KL0hL6g00<0hL6g00<000000=k3_@0000000P3el;H01@000000lO320?7``P3al<80000000<0k>k;
00D000000>O/dP3Wk=80incB000000030>;Ye`030000003Mi]/0gNKK0080gNKK00<000000=SSgP00
00000P0000020<OijP0500000036m>h0a_C^0<KdkP0000000`34ko001@000000`n_`0<?[l033jo00
000000@0`NOa00D000000;oSl@2oho40_n?a0000001g0?ooo`030000003oool0oooo02l0oooo000P
0?ooo`030000003oool0oooo07H0oooo00<0000009Zai`2J/NL00`2J/NL00`000000V:oW09R_i`04
09R_i`030000002G[^L0UjkW0080UjkW00<0000009J]i`2F[NL0102F[NL00`000000U:_V09B[iP02
09B[iP030000002BZND0TZWU0080TZWU00<00000092Vi@2@Y^D00`2@Y^D00`000000SJCT08fTi002
08fTi0030000002;X>80Rj3R0080Rj3R00<0000008RLh@28W>400P28W>400`000000Q9SN08BHgP03
000000@06VoO00<00000001Id`00FM<00P00FM<01000000003g0000m`0000004000LY`0500000000
08T000290000R@0000000P0006P40:Q800<0^f8000@000000590WP000000Dd6O100000005P1HA9l0
000005Y5W`000000FdJO0000001LAil0000005i8X0000000GdVP0000001QBJ000000069;X0000000
Hd^P0000001UC:00000006I=X000000206M=W`8000000P1XCIl01P000000JTnP0000001/D:000000
06e@W`8000000P1_DIl020000000Ke6O000000000000LE>O0000001bDil000000P1cE9l00`000000
M5BN0000000207EDWP050000001fEIh0000007MEWP0000000P1hEYd00`000000N5JM0000000207UF
W@040000001jEid0NUNM00000080NUNM00<0000007]GW00000000P1lEi`00`000000^8FN0;R5WP05
0;R5WP030000002kS:@0^hbT00H0^hbT00<000000;fBZP2mTZX00P2mTZX01@000000j;NQ0>RgX@3X
]j40000000D0i[^Y00<000000>Bn/03T_[001@3T_[000`000000hL6g0>71]`030>71]`8000000`3e
l;H01@000000lO320?7``P3al<80000000<0k>k;00D000000>O/dP3Wk=80incB000000030>;Ye`04
0000003Mi]/0gNKK0=gVf`<0000000D0aogT00000037nNX0aoWZ000000030<KdkP0500000034ko00
a>o`0<C_l00000001033jo001@000000`NOa0<7Wl@31io40000000<0_n?a00<000000?ooo`3oool0
MP3oool00`000000oooo0?ooo`0_0?ooo`00803oool00`000000oooo0?ooo`1g0?ooo`030000002J
/NL0V[7W00<0V[7W00<0000009R_i`2H[nL0102H[nL00`000000UjkW09N^i`0209N^i`030000002F
[NL0UZgW00@0UZgW00<0000009B[iP2DZnH00P2DZnH00`000000TZWU09:Yi@0209:Yi@030000002@
Y^D0T:KU00<0T:KU00<0000008fTi02=Y>@00P2=Y>@00`000000Rj3R08^PhP0208^PhP0300000028
W>40R9cQ0080R9cQ0P00000303:0j0060000000JKml06VoO0000000JKml000001000FM<010000000
03g0000m`0000003000LY`030000000008T000290080002900<000000000J00000000`2XB0030;]R
00040000001B@9h0000005=1W`8000000180Ed>O000000000000000005Y5W`000000FdJO0000001L
Ail0000005i8X0000000GdVP0000001QBJ000000069;X000000206=;X0060000001UC:00000006I<
W`000000IdfO0P00000206Q=W`060000001ZCj00JTnP06a@X0000000KE2O0P00000206mAW`060000
001_DIl0Ke6O0000001aDil000000P1bDil00`000000LeBO0000000207ADWP050000001eE9h00000
07IEWP0000000P1gEIh00`000000N5JM0000000207QFW@030000001iEYd000000080NUNM00H00000
07YGW@1jEid0000007]GW000000207aGW0030000002hQIh0^8FN00H0^8FN00<000000;^<Y02kS:@0
1@2kS:@00`000000_I:Z0;fBZP020;fBZP050000003X]j40j;NQ0>RgX@0000001@3V^jT00`000000
i;j`0>Bn/0050>Bn/0030000003Q`KL0hL6g00<0hL6g00D000000?G`]P3el;H0mO2f000000040?7`
`P040000003/k//0k>k;000000@0incB00H000000>;Ye`3RjML0h^WG0000003Mi]/300000080aogT
00@000000<OijP37nNX000000`36m>h01@000000a>o`0<C_l034ko00000000@0`n_`00D000000<7W
l@31io40`NOa000000030;oSl@030000003oool0oooo07L0oooo00<000000?ooo`3oool0;`3oool0
0200oooo00<000000?ooo`3oool0N03oool2000000@0V[7W00<0000009R_i`2H[nL0102H[nL00`00
0000UjkW09N^i`0209N^i`030000002F[NL0UZgW00@0UZgW00<0000009B[iP2DZnH00P2DZnH00`00
0000TZWU09:Yi@0209:Yi@030000002@Y^D0T:KU00<0T:KU00<0000008fTi02=Y>@00P2=Y>@00`00
0000Rj3R08^PhP0208^PhP0600000028W>40000000000016SNd00000100bP>P2000000<06VoO00<0
0000001Id`00FM<00P00FM<01000000003g0000m`0000003000LY`050000000008T000290000R@00
00000P0006P30:Q800060000002kHP00^f800;]R00000000DT2N0P0000000`1E@Yl0000005M3W`04
0000000405]6W`000000G4NO00000080GTRP0P0000020659X0090000001RBj00000006=;X0000000
IDbP0000001VC9l000000080IdfO00<0000006Q=W`1XCIl010000000101[Cil0000006e@W`000002
06mAW`030000001_DIl0Ke6O00<000000P1bDil00`000000LeBO0000000207ADWP030000001eE9h0
00000080MUFN00<0000007MEWP0000000P1hEYd00`000000N5JM0000000207UFW@030000001jEid0
00000080NUNM00<0000007]GW00000000P1lEi`00`000000^8FN0;R5WP060;R5WP030000002kS:@0
^hbT00D0^hbT00<000000;fBZP2mTZX00P2mTZX01@000000j;NQ0>RgX@3X]j40000000D0i[^Y00<0
00000>Bn/03T_[001@3T_[000`000000hL6g0>71]`020>71]`8000000`3el;H00`000000lO320?7`
`P020?7``P040000003/k//0k>k;000000<0incB00@000000>;Ye`3RjML0h^WG0`0000001@35o]X0
00000<Omi037oN@000000080aoWZ00D000000<KdkP36m>h0a_C^000000030<C_l00300000033jo00
`n_`0080`n_`00D000000<7Wl@31io40`NOa000000030;oSl@030000003oool0oooo07T0oooo00<0
00000?ooo`3oool0;P3oool00200oooo00<000000?ooo`3oool0NP3oool00`000000V[7W09Zai`02
09Zai`8000001@2H[nL00`000000UjkW09N^i`0209N^i`8000001@2F[NL00`000000U:_V09B[iP02
09B[iP030000002BZND0TZWU0080TZWU00<00000092Vi@2@Y^D00`2@Y^D00`000000SJCT08fTi002
08fTi0030000002;X>80Rj3R00<000001016SNd010000000<X3X03:0j000000203:0j0@06VoO00<0
0000001Id`00FM<00P00FM<01000000003g0000m`0000003000LY`070000000008T000290000R@00
0000001X000000030:Q800<0^f8000@000000590WP000000Dd6O0P0000000`1G@il0000005Q4W`03
0000000@05]6W`000000G4NO0000001NB:00000005m9X0000000HDVP0000001RBj00000006=;X000
0000IDbP00000080ITbO00<0000006M=W`0000000P1XCIl20000000606U>W`000000JdnO0000001]
D9l000000P1_DIl00`000000Ke6O06mAW`0200000006075CW`000000LU>O0000001cE9l000000P1d
E9h00`000000MEBN0000000207IEWP030000001gEIh000000080N5JM00<0000007QFW@0000000P1i
EYd00`000000NUNM0000000207YGW@030000001kEi`000000080O5NL00<000000;R5WP2hQIh01P2h
QIh00`000000^hbT0;^<Y0060;^<Y0040000002mTZX0_I:Z000000@0j;NQ00<000000>JkZ@3V^jT0
103V^jT00`000000i;j`0>Bn/0040>Bn/0030000003Q`KL0hL6g0080hL6g0P0000030?G`]P050000
003al<80lO320?7``P0000000`3/k//01@000000incB0>O/dP3Wk=80000000<0h^WG00@000000<Gn
fP35o]X000000`37oN@010000000aoWZ0<OijP0000020<KdkP0500000034ko00a>o`0<C_l0000000
1033jo001@000000`NOa0<7Wl@31io40000000<0_n?a00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`0^0?ooo`00803oool00`000000oooo0?ooo`1k0?ooo`030000002J/NL0V[7W00<0V[7W
00<0000009R_i`2H[nL00`2H[nL2000000@0UjkW00<0000009J]i`2F[NL00`2F[NL00`000000U:_V
09B[iP0209B[iP030000002BZND0TZWU0080TZWU00<00000092Vi@2@Y^D00`2@Y^D00`000000SJCT
08fTi00208fTi08000000`1EUo000`000000AXg]04J=k@0304J=k@030000000bP>P0<X3X0080<X3X
00D0000001Y_g`0JKml06VoO00000004001Id`0400000000?L0003g0000000<001bW00@000000000
R@0008T000000P0006P30:Q800<0^f8000@000000590WP000000Dd6O0P0000001@1G@il0000005Q4
W`000000FTFO00<0000000X0G4NO0000001NB:00000005m9X0000000HDVP0000001RBj0000000P1S
Bj001P000000ID^O0000001VC9l0000006M=W`80000000P0J4fO000000000000JDjO0000001[Cil0
000006e@W`80000000H0Ke6O0000001_DIl0Ke6O0000001`DYh200000009079CW`000000LeBO07=D
W`000000M5BN0000001eE9h000000080MUFN00<0000007MEWP0000000P1hEYd00`000000N5JM0000
000207UFW@060000001jEid0NUNM0000001jEid000000P1kEi`00`000000O5NL000000080;R5WP03
0000002kS:@0^hbT00H0^hbT00@000000;fBZP2mTZX00000103X]j400`000000i[^Y0>JkZ@040>Jk
Z@030000003T_[00i;j`00@0i;j`00@000000>71]`3Q`KL0hL6g0P0000040?G`]P050000003al<80
lO320?7``P0000000`3/k//01@000000incB0>O/dP3Wk=8000000080h^WG00@000000<GnfP35o]X0
00000`37oN@010000000aoWZ0<OijP0000020<KdkP0500000034ko00a>o`0<C_l00000001033jo00
1@000000`NOa0<7Wl@31io40000000<0_n?a00<000000?ooo`3oool0N`3oool00`000000oooo0?oo
o`0^0?ooo`007`3oool00`000000oooo0?ooo`1m0?ooo`030000002J/NL0V[7W00<0V[7W00<00000
09R_i`2H[nL0102H[nL00`000000UjkW09N^i`0209N^i`030000002F[NL0UZgW00<0UZgW00<00000
09B[iP2DZnH00P2DZnH00`000000TZWU09:Yi@0209:Yi@030000002@Y^D0T:KU00<0T:KU00H00000
08fTi0000000000006:Nl@00000505FGl00600000016SNd0AXg]00000016SNd00000100bP>P00`00
00006VoO01Y_g`0201Y_g`0500000000FM<005WC001Id`0000000P00?L001000000001bW000LY`00
00030000R@030000000006P0000000<0Z4P00`2kHP000`000000DT2N000000020000000405M3W`00
0000F4BO05Q4W`80000000<0FdJO0000000000000`0000003P1OBJ0000000659X01QBJ000000069;
X0000000Hd^P0000001UBil0000006I<W`000000IdfO0P0000001`1XCIl0000006Q>W`000000JDjO
0000001[Cil00`0000001@1_DIl0000006mAW`1_DIl000000080L5:N00<00000079CW`0000000P1c
E9l01@000000M5BN0000001eE9h000000080MUFN00<0000007MEWP0000000P1hEYd00`000000N5JM
0000000207UFW@040000001jEid0NUNM00000080NUNM00<0000007]GW00000000P1lEi`00`000000
^8FN0;R5WP050;R5WP030000002kS:@0^hbT00H0^hbT00<000000;fBZP0000001@3X]j400`000000
i[^Y0>JkZ@040>JkZ@030000003T_[00i;j`00@0i;j`00@000000>71]`3Q`KL0hL6g0P0000040?G`
]P050000003al<80lO320?7``P0000000P3/k//00`000000incB0>O/dP020>O/dP<000000`35o]X0
10000000aogT0<Omi00000020<OijP0400000036m>h0a_C^000000<0a>o`00<000000<?[l033jo00
0P33jo001@000000`NOa0<7Wl@31io40000000<0_n?a00<000000?ooo`3oool0O03oool00`000000
oooo0?ooo`0^0?ooo`007`3oool00`000000oooo0?ooo`1n0?ooo`030000002J/NL0V[7W00<0V[7W
00<0000009R_i`2H[nL0102H[nL00`000000UjkW09N^i`0209N^i`030000002F[NL0UZgW00<0UZgW
0P00000309B[iP030000002BZND0TZWU0080TZWU00<00000092Vi@2@Y^D00P2@Y^D2000000D0HYka
00<0000005FGl01EUo000P1EUo02000000<0AXg]0P00000303:0j0030000000JKml06VoO00806VoO
00D00000001Id`00FM<005WC00000002000m`004000000007:L001bW000000<0002900<000000000
J02XB0000P2XB0030;]R00040000001B@9h0000005=1W`80000000T0Ed>O0000001HA9l0000005Y5
W`000000FdJO0000001LAil0100000020659X0050000001RBj00000006=;X00000000P1UBil01@00
0000ITbO000000000000IdfO0080000000D0J4jO0000001YCYl0000006]?W`020000000306e@W`00
000000000080Ke6O00<00000071BWP1`DYh00P000000101bDil0000007=DW`00000207ADWP050000
001eE9h0000007IEWP0000000P1gEIh00`000000N5JM0000000207QFW@030000001iEYd000000080
NUNM00H0000007YGW@1jEid0000007]GW000000207aGW0030000002hQIh0^8FN00H0^8FN00<00000
0;^<Y02kS:@01P2kS:@00`2mTZX000000>RgX@040>RgX@030000003V^jT0i[^Y00@0i[^Y00<00000
0>Bn/03T_[00103T_[001P000000hL6g0>71]`000000n>jX000000<0mO2f00<000000?7``P3al<80
0P3al<8010000000k>k;0>c^b`0000030>O/dP80000000D0_og;00000035o]X0aOkJ000000020<Om
i00400000037nNX0aoWZ00000080a_C^00D000000<C_l034ko00a>o`000000040<?[l00500000031
io40`NOa0<7Wl@0000000`2oho400`000000oooo0?ooo`1m0?ooo`030000003oool0oooo02h0oooo
000O0?ooo`030000003oool0oooo07l0oooo0P00000409Zai`030000002H[nL0V:oW00@0V:oW00<0
000009N^i`2G[^L00P2G[^L00`000000UZgW09J]i`0409J]i`050000002DZnH0U:_V09B[iP000000
102BZND010000000T:KU00000000000206bTlP030000001RW_40HYka00<0HYka00@0000005FGl01E
Uo00EIO`0`00000404J=k@040000000bP>P0<X3X03:0j08000000`0JKml01`00000005WC001Id`00
FM<00000000m`00000000`007:L01P00000000290000R@000000001X00000080Z4P000L000000;]R
002kHP0000000590WP000000Dd6O0080000000/0Ed>O0000001HA9l0000005Y5W`000000FdJO0000
001LAil0000005i8X003000000050659X0000000HT^P0000001SBj000P0000000`1UBil0000006I<
W`020000000706M=W`000000000006Q>W`000000JDjO0000000206]?W`040000001]D9l000000000
0080Ke6O00D00000071BWP1`DYh00000075BWP020000000707=DW`000000M5BN07ADWP000000MEBN
0000000207IEWP050000001gEIh0000007QFW@0000000P1hEYd00`000000NEJM0000000207YGW@06
0000001jEid0NUNM0000001kEi`000000P1lEi`00`000000^8FN0;R5WP060;R5WP030000002kS:@0
^hbT00H0^hbT00<000000>RgX@3X]j40103X]j400`000000i[^Y0>JkZ@040>JkZ@030000003T_[00
i;j`00D0i;j`00D000000>71]`000000n>jX000000030?G`]P050000003al<80lO320?7``P000000
0`3/k//01`000000incB0>O/dP3Wk=8000000;omb`0000000P35o]X010000000aogT0<Omi0000002
0<OijP0400000036m>h0a_C^000000@0a>o`00D000000<?[l033jo00`n_`000000030<7Wl@050000
002oho40_n?a0;oSl@000000P03oool00`000000oooo0?ooo`0^0?ooo`007`3oool00`000000oooo
0?ooo`210?ooo`030000002J/NL0V[7W0080V[7W0P00000509R_i`030000002G[^L0UjkW0080UjkW
00<0000009J]i`2F[NL0102F[NL01@000000U:_V09B[iP2DZnH0000000@0TZWU00<0000006bTlP1/
Y?80101/Y?800`000000HYka06:Nl@0306:Nl@8000000`1EUo000`000000AXg]04J=k@0204J=k@03
0000000bP>P0<X3X0080<X3X00D0000001Y_g`0JKml06VoO00000003001Id`0300000000?L000000
00<001bW00D000000000R@0008T000000000J0030:Q80080^f8000@000000590WP000000Dd6O0P00
0000101G@il0000005Q4W`1HA9l20000000705]6W`000000G4NO0000001NB:00000005m9X0040000
0006069;X0000000I4ZO0000001UBil000000P1VC9l020000000IdfO06M=W`000000J4jO0000001Y
CYl000000P1[Cil010000000KE2O06e@W`00000306mAW`030000001`DYh000000080LE:N00<00000
07=DW`0000000P1dE9h00`000000MEBN0000000207IEWP030000001gEIh000000080N5JM00<00000
07QFW@0000000P1iEYd00`000000NUNM0000000207YGW@030000001kEi`000000080O5NL00<00000
0;R5WP2hQIh01P2hQIh00`000000^hbT0;^<Y0060;^<Y0030000003X]j40j;NQ00@0j;NQ00<00000
0>JkZ@3V^jT0103V^jT00`000000i;j`0>Bn/0050>Bn/08000000P3hkZP01@000000mO2f0?G`]P3e
l;H0000000<0lO3200D000000>c^b`3/k//0k>k;000000020>O/dP030000002ooL/000000080aOkJ
00@000000<Omi037oN@000000P37nNX01@000000a_C^0<KdkP36m>h0000000<0a>o`00D000000<?[
l033jo00`n_`000000030<7Wl@050000002oho40_n?a0;oSl@000000PP3oool00`000000oooo0?oo
o`0]0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`030000002J/NL0V[7W00<0V[7W00<00000
09R_i`2H[nL00`2H[nL00`000000UjkW09N^i`0209N^i`030000002F[NL0UZgW00@0UZgW00H00000
09B[iP2DZnH0U:_V0000002BZND20000000307BXlP000000K:Cb00H0K:Cb00@0000006:Nl@1RW_40
HYka0`00000305FGl08000000`16SNd2000000<0<X3X00D0000001Y_g`0JKml06VoO00000003001I
d`0300000000?L000000008001bW00H000000000R@0008T000000000J00000020:Q800<0^f800140
00000590WP000000000005E2W`000000Ed>O0000001HA9l0000005Y5W`000000FdJO0000001LAil0
000005i8X00200000080HDVP0`00000206A:W`050000001UBil0000006I<W`0000000P1WCIl20000
000406Q>W`1YCYl0JDjO06]?W`8000000P1]D9l200000080Ke6O00<00000071BWP0000000P1aDYh2
0000000607=DW`000000M5BN0000001eE9h000000P1fEIh00`000000MeFN0000000207QFW@030000
001hEYd000000080NEJM00H0000007YGW@1jEid0000007YGW@00000207]GW0030000001lEi`00000
00P0^8FN00<000000;^<Y02kS:@01P2kS:@00`000000j;NQ0>RgX@040>RgX@030000003V^jT0i[^Y
00@0i[^Y00<000000>Bn/03T_[001@3T_[02000000030?S^Z0000000000000<0mO2f00D000000?7`
`P3al<80lO32000000020>c^b`060000003Wk=8000000000002ooL/000000P35o]X010000000aogT
0<Omi00000020<OijP0500000036m>h0a_C^0<KdkP0000000`34ko001@000000`n_`0<?[l033jo00
000000<0`NOa00D000000;oSl@2oho40_n?a000000210?ooo`<00000;`3oool001l0oooo00<00000
0?ooo`3oool0P`3oool00`000000V[7W09Zai`0309Zai`030000002H[nL0V:oW00<0V:oW00<00000
09N^i`2G[^L00P2G[^L2000000D0UZgW00<0000009B[iP2DZnH00P00000507BXlP030000001/Y?80
K:Cb00@0K:Cb0`00000306:Nl@030000001EUo00EIO`0080EIO`00<0000004J=k@16SNd00P16SNd0
1@000000<X3X03:0j00bP>P0000000<06VoO00@00000001Id`00FM<000000P00?L001000000001bW
000LY`0000020000R@050000000006P0Z4P00:Q8000000000P2kHP0010000000DT2N0000001C@Il2
0000000A05M3W`000000F4BO0000001JAIl0000005]6W`000000G4NO0000001NB:00000005m9X000
0000HDVP0000001RBj000P0000001@1TBYl0000006E;W`000000ITbO0080000000@0IdfO0000001W
CIh000000P1YCYl01@1[Cil0000006]?W`000000KE2O008000000P1_DIl00`000000L5:N00000002
075BWP080000001aDYh000000000001dE9h0000007EDWP00000207IEWP030000001gEIh000000080
N5JM00<0000007QFW@0000000P1iEYd01P000000NUNM07YGW@000000NUNM00000080NeNL00<00000
07aGW00000002@2hQIh00`000000^hbT0;^<Y0040;^<Y08000001`3X]j400`000000i[^Y0>JkZ@03
0>JkZ@030000003T_[00i;j`00D0i;j`00@000000?S^Z03hkZP00000103el;H01@000000lO320?7`
`P3al<8000000080k>k;0P0000000`2dmK<00000000000020<GnfP0400000037oN@0aogT00000080
aoWZ00D000000<KdkP36m>h0a_C^000000030<C_l00500000033jo00`n_`0<?[l00000000`31io40
1@000000_n?a0;oSl@2oho4000000840oooo00@000000?ooo`3oool00000;`3oool001h0oooo00<0
00000?ooo`3oool0Q@3oool00`000000V[7W09Zai`0309Zai`030000002H[nL0V:oW00<0V:oW0P00
000409N^i`030000002F[NL0UZgW0080UZgW0`00000207^[lP8000001@1dZ?800`000000K:Cb06bT
lP0206bTlP030000001/Y?80000000@0HYka0P00000305FGl00300000016SNd0AXg]0080AXg]00D0
000003:0j00bP>P0<X3X0000000301Y_g`0400000000FM<005WC0000008003g000@00000000LY`00
7:L000000P0008T200000080Z4P00P2kHP0010000000DT2N0000001C@Il20000000>05M3W`000000
F4BO0000001JAIl0000005]6W`000000G4NO0000001NB:00000005m9X00000020659X0030000001S
BIh00000008000000P1UBil30000000406M=W`000000IdfN06M=WP<000000P1[Cil02@000000KE2O
0000001^D9h0000006mAW`000000L5:N00000002075BWP060000001aDYh0LE:N0000001dE9h00000
0P1eE9h00`000000MUFN0000000207MEWP050000001hEYd0000007QFW@0000000P1iEYd010000000
NUNM07YGW@00000207YGW@030000001kEi`000000080O5NL00<000000;R5WP2hQIh01P2hQIh00`00
0000^hbT0;^<Y0040;^<Y08000001`3X]j400`000000i[^Y0>JkZ@040>JkZ@030000003T_[00i;j`
00@0i;j`00@000000?S^Z03hkZP000000`3el;H01@000000lO320?7``P3al<80000000<0k>k;00@0
00000;Ce/`00000000000P35o]X01`000000aogT0<Omi037oN@000000<OijP0000000`36m>h01@00
0000a>o`0<C_l034ko00000000<0`n_`00D000000<7Wl@31io40`NOa000000030;oSl@030000003o
ool0oooo08<0oooo00<000000?ooo`3oool0;@3oool001h0oooo00<000000?ooo`3oool0QP3oool2
000000@0V[7W00<0000009R_i`2H[nL0102H[nL00`000000UjkW09N^i`0209N^i`040000002F[NL0
000000000080PJkb00<0000007^[lP1kZo800P1kZo82000000@0M:Sb0P0000000`1/Y?80000006bT
lP0206bTlP800000101RW_4010000000EIO`05FGl01EUo02000000<0AXg]00@0000003:0j00bP>P0
<X3X0P00000201Y_g`0400000000FM<005WC0000008003g000<00000000LY`0000000P0008T01000
0000001X0:Q8002XB0030;]R00030000001B@9h000000080000000`0Ed>O0000001HA9l0F4BO0000
001JAIl0000005]6W`000000G4NO0000001NB:0200000080HDVP00<0000006=9WP0000000P1TBYl4
0000000306I<WP00000000000080IdfN00<0000006U=WP0000000P1[Cil00`000000KE2O00000002
06i@WP80000000D0L5:N0000001aDYh0LE:N00000002075BWP80000000H0M5BN0000001eE9h00000
07IEWP00000207MEWP030000001hEYd000000080N5JM00<0000007UFW@0000000P1jEid01P000000
NUNM07YGW@000000NeNL00000080O5NL00<000000;R5WP2hQIh01P2hQIh00`000000^hbT0;^<Y004
0;^<Y08000001`3X]j400`000000i[^Y0>JkZ@040>JkZ@030000003T_[00i;j`00<0i;j`0P000002
0?S^Z0050000003el;H0mO2f0?G`]P0000000`3al<802P000000k>k;0>c^b`000000]?Fc0000002o
oL/000000<GnfP0000030<Omi00300000037nNX0000000<0a_C^00D000000<C_l034ko00a>o`0000
00030<?[l00500000031io40`NOa0<7Wl@0000000`2oho400`000000oooo0?ooo`240?ooo`030000
003oool0oooo02d0oooo000N0?ooo`030000003oool0oooo08P0oooo00<0000009Zai`2J/NL00P2J
/NL00`000000V:oW09R_i`0409R_i`030000002G[^L0UjkW0080UjkW00<00000086^lP21[_801021
[_800`000000Nj_b07^[lP0207^[lP800000101dZ?82000000D0K:Cb0P00000306:Nl@8000000`1E
Uo0010000000AXg]04J=k@16SNd2000000<0<X3X00@0000001Y_g`0JKml000000P00FM<01P000000
03g0000m`000000001bW0000008000290P0000020:Q80080^f80014000000590WP000000000005E2
W`000000Ed>O0000001HA9l0000005Y5W`000000FdJO0000001LAil0000005i8X002000000030659
X000000000000080HdVN00<0000006A:W`0000000P1UBil30000000406M=W`000000IdfN00000080
JDfN00<0000006]?W`1[Cil00P00000206i@WP8000000P1`DYh00`000000LE:N00000002075BWP06
0000001bDYd000000000001eE9h000000P1fEIh01@000000MeFN0000001hEYd000000080N5JM00<0
000007UFW@0000000P1jEid01P000000NUNM07YGW@000000NeNL00000080O5NL00<000000;R5WP2h
QIh01P2hQIh00`000000^hbT0;^<Y0040;^<Y0030000003Y/YX0000000H0j;NQ00<000000>JkZ@3V
^jT0103V^jT00`000000i;j`0>Bn/0030>Bn/0050000003hkZP0n>jX0?S^Z00000000`3el;H02`00
0000lO320?7``P3al<8000000>c^b`000000]?Fc0000002ooL/000000080aOkJ00H000000<Omi037
oN@000000<OijP0000030<KdkP0500000034ko00a>o`0<C_l00000000`33jo001@000000`NOa0<7W
l@31io40000000<0_n?a00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0/0?ooo`007P3o
ool00`000000oooo0?ooo`290?ooo`030000002J/NL0V[7W0080V[7W0P00000509R_i`050000002G
[^L0000000000025/?400P000006086^lP030000001kZo80Nj_b0080Nj_b00@0000007BXlP1dZ?80
00000P1dZ?82000000D0K:Cb00<0000006:Nl@1RW_400P1RW_4010000000EIO`05FGl01EUo020000
00<0AXg]00D0000003:0j00bP>P0<X3X0000000201Y_g`0600000000FM<005WC00000000?L000000
0P007:L01000000000290000000006P20:Q80080^f8000@000000590WP000000Dd6O0P0000003@1G
@il0000005Q4W`000000FTFO0000001KAYl0000005a7W`000000GTRP0000001OBJ000P000000101R
B9h0000006=9WP00000206A:W`040000001UBil0000006I<WP<000000P1WCIh00`000000JDfN0000
000206]?W`8000000`1^D9h01P000000L5:N071BWP000000LE:N00000080LE:N00H00000079BW@1b
DYd0000007EDWP00000207IEWP030000001gEIh000000080N5JM00<0000007QFW@0000000P1iEYd0
0`000000NUNM0000000207YGW@030000001kEi`000000080O5NL00<000000;R5WP2hQIh01P2hQIh0
0`000000^hbT0;^<Y0030;^<Y0040000003Y/YX0jK:J000000H0j;NQ00<000000>JkZ@3V^jT0103V
^jT00`000000i;j`0>Bn/0020>Bn/08000000P3hkZP2000000<0mO2f00H000000?7``P3al<80lO32
0000003/k//2000000050;omb`000000aOkJ0<GnfP0000000P37oN@00`000000aoWZ000000030<Kd
kP0500000034ko00a>o`0<C_l00000001033jo001@000000`NOa0<7Wl@31io40000000<0_n?a00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`0/0?ooo`007P3oool00`000000oooo0?ooo`2:
0?ooo`030000002J/NL0V[7W00<0V[7W00<0000009R_i`2H[nL00P2H[nL2000000D0QK3a0P000006
086^lP040000001kZo80Nj_b07^[lP8000001@1dZ?800`000000K:Cb06bTlP0306bTlP8000000`1R
W_42000000<0EIO`00D0000004J=k@16SNd0AXg]0000000303:0j0040000000JKml06VoO00000080
05WC00<00000000m`00000000P007:L02`0000000029000000000000Z4P00000002kHP0000000590
WP000000Dd6O0080000000H0Ed>O0000001HA9l0F4BO0000001JAIl20000000605a7W`000000GTRP
0000001OBJ0000000P1RB9h00`000000HdVN0000000206A:W`030000001UBil000000080ITbN0`00
0000101WCIh0000006U=WP00000306]?W`050000001^D9h0KU2N06i@WP0000000P1`DYh00`000000
LE:N00000002075BWP030000001bDYd0LU:M00<000000P1fEIh00`000000MeFN0000000207QFW@03
0000001hEYd000000080NEJM00H0000007YGW@1jEid0000007YGW@00000207]GW0030000001lEi`0
000000T0^8FN00<000000;^<Y02kS:@00P2kS:@010000000jK:J0>VbVP0000060>RgX@030000003V
^jT0i[^Y00@0i[^Y00<000000>Bn/03T_[000P3T_[0200000080n>jX0P0000030?G`]P050000003a
l<80lO320000003/k//00P0000001@2ooL/000000<GnfP35o]X000000080aogT00<000000<OijP00
00000`36m>h01@000000a>o`0<C_l034ko00000000@0`n_`00D000000<7Wl@31io40`NOa00000003
0;oSl@030000003oool0oooo08L0oooo00<000000?ooo`3oool0;03oool001h0oooo00<000000?oo
o`3oool0R`3oool00`000000V[7W09Zai`0309Zai`040000002H[nL0000000000080RK;a0P000005
08F`l@8000001P21[_8010000000Nj_b0000001kZo82000000@0M:Sb0P00000506bTlP030000001R
W_40HYka0080HYka00@0000005FGl01EUo00EIO`0P00000204J=k@8000000P0bP>P20000000901Y_
g`00000005WC001Id`00000003g0000000007:L000000080002900<000000:Q8002XB0000P2kHP00
4@000000DT2N000000000000ED:O0000001G@il0000005Q4W`000000FTFO0000001KAYl0000005a7
W`000000GTRP008000000P1RB9h01`000000HdVN06=9WP000000I4ZO0000001UBil00P00000206I<
WP040000001WCIh0000000000080JDfN00@0000006]?W`1[Cil000000`1^D9h200000004071BWP00
0000LE:N00000080LE:N00<00000079BW@1bDYd00P0000001P1eE9h0000007IEWP000000MeFN0000
0080N5JM00<0000007QFW@0000000P1iEYd010000000NUNM07YGW@00000207YGW@050000001kEi`0
000007aGW00000002@2hQIh00`000000^hbT0;^<Y0020;^<Y0040000003Y/YX0jK:J000000H0j;NQ
00<000000>JkZ@3V^jT0103V^jT01`000000i;j`0>Bn/03T_[0000000?WZU`0000000P3hkZP01@00
0000mO2f0?G`]P3el;H0000000<0lO320P0000000`2dmK<00000000000020<GnfP0400000037oN@0
aogT00000080aoWZ00@000000<KdkP36m>h000000`34ko000`000000`n_`0<?[l0020<?[l0050000
0031io40`NOa0<7Wl@0000000`2oho400`000000oooo0?ooo`280?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0803oool001d0oooo00<000000?ooo`3oool0S@3oool2000000@0V[7W
00<0000008Vbl@29/_401029/_42000000D0QK3a0P000005086^lP8000000`1kZo82000000@0M:Sb
0P00000406bTlP8000000`1RW_42000000<0EIO`00D0000004J=k@16SNd0AXg]0000000303:0j00;
0000000JKml0000000000000FM<00000000m`000000001bW0000000008T00P0000001`2XB000^f80
0;]R00000000DT2N0000001C@Il00P0000003P1G@il0000005Q4W`000000FTFO0000001KAYl00000
05a7W`000000GTRP0000001PB9h000000P1RB9h00`000000HdVN0000000206A:W`<000000P1VC9h2
0000000306M=WP0000000000008000000P1[Cil010000000KU2N06i@WP1^D9h200000004071BWP00
0000LE:N00000080LE:N00D00000079BW@1bDYd0000007=BW@020000000707IEWP000000MeFN07ME
WP000000N5JM0000000207QFW@030000001iEYd000000080NUNM00H0000007YGW@1jEid0000007]G
W000000207aGW0030000002hQIh0^8FN00H0^8FN00<000000;^<Y02kS:@00P2kS:@010000000jK:J
0>VbVP0000060>RgX@030000003V^jT0i[^Y00@0i[^Y00L000000>Bn/03T_[00i;j`0000003ijYL0
00000080n>jX00D000000?G`]P3el;H0mO2f000000030?7``P040000002dmK<0000000000080aOkJ
00@000000<Omi037oN@000000P37nNX010000000a_C^0<KdkP0000040<C_l00500000033jo00`n_`
0<?[l00000000`31io401@000000_n?a0;oSl@2oho40000008/0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0P0?ooo`007@3oool00`000000oooo0?ooo`2?0?ooo`040000002J/NL0
000000000080SK?`00<0000008Vbl@29/_401029/_42000000D0QK3a0P000002086^lP0300000021
[_80PJkb008000000`1kZo800`000000M:Sb07BXlP0307BXlP030000001/Y?80K:Cb00<0K:Cb0P00
000306:Nl@050000001EUo00EIO`05FGl00000000`16SNd01@000000<X3X03:0j00bP>P000000080
6VoO00T00000001Id`00000003g0000000007:L000000000R@0000000P2XB0001@2kHP0000000590
WP000000Dd6O0080000000@0Ed>O0000001HA9l0F4BO0P000000201KAYl0000005a7W`000000GTRP
0000001PB9h000000P1RB9h01@000000HdVN06=9WP000000I4ZO0080000000L0ID^N0000001VC9h0
000006M<WP000000IdfN0080JDfN0`0000001P1[CYh0000006i@WP1^D9h0000006i@WP8000000P1a
DYh00`000000LE:N00000002079BW@060000001cDYd0Le:M0000001fEIh000000P1gEIh00`000000
N5JM0000000207QFW@030000001iEYd000000080NUNM00H0000007YGW@1jEid0000007]GW0000002
07aGW0030000002hQIh0^8FN00H0^8FN00D000000;^<Y02kS:@0^hbT000000030>VbVP030000003X
]j40j;NQ00@0j;NQ00<000000>JkZ@3V^jT0103V^jT01@000000i;j`0>Bn/0000000nNZG00800000
0P3hkZP01@000000mO2f0?G`]P3el;H000000080lO3200L000000;Ce/`000000_og;00000035o]X0
00000080aogT00@000000<OijP37nNX000000`36m>h01@000000a>o`0<C_l034ko00000000<0`n_`
00D000000<7Wl@31io40`NOa000000030;oSl@030000003oool0oooo08X0oooo00<000000?ooo`3o
ool01P3oool500000240oooo000M0?ooo`030000003oool0oooo0900oooo00<0000008fcl02=/o00
102=/o000`000000RK;a08Vbl@0408Vbl@8000001@25/?42000000D0PJkb0P00000207^[lP800000
101dZ?82000000D0K:Cb00@0000006:Nl@1RW_40HYka0P00000205FGl08000000P16SNd200000080
<X3X00T0000001Y_g`0JKml00000001Id`00000003g0000000007:L00`0000001@2XB000^f800;]R
00000000DT2N0080000000<0ED:O0000000000000P1HA9l03@000000FTFO0000001KAYl0000005a7
W`000000GdNM0000001PB9h000000698WP0000000P1SBIh020000000I4ZO06A:W`000000ID^N0000
001VC9h000000P1WC9h01@000000JDfN06U=WP1YCIh0JdnO00<000000P1^D9h010000000KU2N0000
00000002075BWP030000001aDYh000000080LU:M00<0000007=BW@1cDYd00P0000001P1fEIh00000
07MEWP000000N5JM00000080N5JM00<0000007UFW@0000000P1jEid01P000000NUNM07YGW@000000
NeNL00000080O5NL00<000000;R5WP2hQIh01P2hQIh01@000000^hbT0;^<Y02kS:@0000000<0jK:J
00<000000>RgX@3X]j40103X]j400`000000i[^Y0>JkZ@050>JkZ@050000003T_[0000000?WZU`00
00000P3hkZP2000000<0mO2f00T000000?7``P000000]?Fc0000002ooL/000000<GnfP0000000P37
oN@010000000aoWZ0<OijP0000030<KdkP0500000034ko00a>o`0<C_l00000000`33jo001@000000
`NOa0<7Wl@31io40000000<0_n?a00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`050?oo
o`040000003oool0oooo00000280oooo000M0?ooo`030000003oool0oooo0980oooo00<0000008fc
l02=/o00102=/o02000000D0RK;a0P00000208F`l@0300000025/?40QK3a008000001@21[_820000
0080Nj_b0P00000407BXlP800000101/Y?82000000<0HYka00D0000005FGl01EUo00EIO`00000003
04J=k@040000000bP>P0<X3X000000806VoO00@00000001Id`00000003g00P0000001`0008T00000
0:Q800000000^f800000001B@9h00P000000401E@Yl0000005M3W`000000F4BO0000001JAIl00000
05]6W`000000G4NO0000001OAid000000618WP0000020698WP060000001SBIh0HdVN0000001TBYl0
00000P1UBih2000000<0IdbN1000000206]>WP<000000`1^D9h01P000000LE:N075BWP000000LE:N
00000080LU:M00D0000007=BW@1cDYd0000007=BW@020000000707MEWP000000N5JM07QFW@000000
N5JM0000000207UFW@080000001jEid0NUNM0000001jEid0000007]GW000000207aGW0030000002h
QIh0^8FN00L0^8FN00@000000;^<Y02kS:@000000`3Y/YX00`000000j;NQ0>RgX@040>RgX@030000
003V^jT0i[^Y00D0i[^Y0P0000020?WZU`030000003hkZP0n>jX008000000`3el;H020000000lO32
000000000000_og;00000035o]X000000`37oN@00`000000aoWZ000000030<KdkP0500000034ko00
a>o`0<C_l00000000`33jo001@000000`NOa0<7Wl@31io40000000<0_n?a00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`060?ooo`030000003oool000000280oooo000M0?ooo`030000003o
ool0oooo09@0oooo00<0000008fcl02=/o00102=/o02000000D0RK;a0P00000508F`l@8000001@21
[_8010000000Nj_b07^[lP1kZo82000000@0M:Sb0P00000406bTlP8000000P1RW_4200000080EIO`
0P00000204J=k@030000000bP>P0<X3X0080000000<06VoO00000000FM<00P0000002P007:L00000
000000000000Z4P00;]R00000000DT2N0000001C@Il20000000405M3W`000000F4BO05Q4W`800000
00@0FdJO0000001LAil000000P1OAid200000080HTRN00H0000006=9WP1SBIh0000006A:W`000002
06E;WP030000001VC9h000000080IdbN00@0000006Q=WP1XCIh000000`1[CYh40000000706i@WP00
0000LE:N075BWP000000LE:N00000003079BW@030000001cDYd000000080Le:M00<0000007MEWP00
00000P1hEYd00`000000N5JM0000000207UFW@060000001jEid0NUNM0000001jEid000000P1kEi`0
0`000000O5NL000000090;R5WP030000002kS:@0000000@0jK:J00<000000>RgX@3X]j401@3X]j40
0`000000i[^Y0>JkZ@040>JkZ@8000000P3ijYL010000000n>jX0?S^Z00000030?G`]P060000003a
l<8000000000002ooL/000000P35o]X01P000000aogT0<Omi0000000aoWZ000000<0a_C^00<00000
0<C_l00000003P00002@0?ooo`030000003oool0oooo00L0oooo0P00000R0?ooo`007@3oool00`00
0000oooo0?ooo`2F0?ooo`8000001@2=/o02000000<0RK;a00@0000008Vbl@00000000001@25/?42
000000@0PJkb0P00000307^[lP800000101dZ?800`000000K:Cb06bTlP0306bTlP050000001RW_40
HYka06:Nl@0000000`1EUo000`000000AXg]04J=k@0200000080<X3X00@0000001Y_g`00000005WC
0P00000010007:L000000000002XB0020;]R0080000000D0Dd6O000000000000Ed>O0000000205Q4
W`0=0000001JAIl0000005]6W`000000GTJM0000001OAid000000618WP000000HTRN0000000206=9
WP040000001TBYl0000000000080ID^N0P00000206M<WP040000001XCIh0J4fN000000<0JdjN0P00
000206i@WP<0000000@0LE:N0000001aDYh000000`1bDYd00`000000Le:M0000000207=BW@800000
00H0MeFN0000001hEYd0000007QFW@00000207UFW@040000001jEid0NUNM00000080NUNM00<00000
07]GW00000000P1lEi`00`000000^8FN0;R5WP060;R5WP030000002kS:@0000000@0jK:J00<00000
0>RgX@3X]j401@3X]j400`000000i[^Y0>JkZ@040>JkZ@050000003ijYL0nNZG0?WZU`0000000P3h
kZP010000000mO2f0?G`]P3el;H2000000030;Ce/`00000000000080aOkJ00<000000<Omi037oN@0
2`0000000`2Qk_P00000000000030:K[nP8000000P2Xj?X200000940oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0P0?ooo`00703oool00`000000oooo0?ooo`2I0?ooo`8000001@2=
/o03000000@0RK;a0P00000508F`l@0300000021[_80PJkb00<0PJkb0P00000307^[lP030000001d
Z?80M:Sb0080M:Sb0P00000406bTlP8000000P1RW_4200000080EIO`00H0000004J=k@16SNd0AXg]
0000000bP>P700000003000LY`00000000000080^f8001@000000590WP000000000005E2W`000000
Ed>O0000001HA9l0000005Y5W`000000FdJO0000001NAYd0000005m7W@000000H4RN00000080HTRN
00<0000006=9WP1SBIh00`00000206E;WP8000000`1WC9h010000000J4fN06Q=WP00000306]>WP04
0000001^D9h0KU2N06i@WP@000000P1aDYh01P000000LU:M079BW@000000Le:M00000080Le:M00H0
000007ACW@000000000007QFW@00000207QFW@030000001iEYd000000080NUNM00H0000007YGW@1j
Eid0000007]GW000000207aGW0030000002hQIh0^8FN00H0^8FN00<000000;^<Y00000001@3Y/YX0
0`000000j;NQ0>RgX@040>RgX@030000003V^jT0i[^Y00@0i[^Y00<000000?WZU`3ijYL00P000002
0?S^Z0060000003el;H0mO2f0?G`]P000000]?Fc0P0000020<GnfP0300000037oN@0aogT00<00000
0P2@k^X20000000409_`l`00000000000:7^n08000000`2VjoX200000080Z>Sj0P00002C0?ooo`03
0000003oool0oooo02/0oooo000L0?ooo`030000003oool0oooo09/0oooo0P00000408fcl0<00000
1@29/_42000000@0QK3a0P000005086^lP8000000P1kZo82000000@0M:Sb0P00000406bTlP050000
001RW_40HYka06:Nl@0000000P1EUo020000000304J=k@00000000000080K@0000@0000009800000
0000[R80100000001P2XB000^f800000001B@9h0000005=1W`80000000@0Ed>O0000001HA9l0F4BO
0P0000002`1KAYl0000005i6W@1NAYd0000005m7W@000000H4RN0000001RB9h000000080HdVN0P00
00001@1TBYd0000006E;WP1UBih0000000<0IdbN00@0000006Q=WP1XCIh000000`1[CYh01P000000
KU2N06i@WP1^D9h0000006i@WP<0000000L0LE:N0000001bDYd0LU:M0000001cDYd000000080Le:M
00H0000007ACW@1dDid0000007QFW@00000207QFW@030000001iEYd000000080NUNM00H0000007YG
W@1jEid0000007]GW000000207aGW0030000002hQIh0^8FN00L0^8FN0P0000050>VbVP030000003X
]j40j;NQ00@0j;NQ00<000000>JkZ@3V^jT00`3V^jT200000080nNZG0P0000000`3hkZP000000000
00030?G`]P050;Ce/`000000_og;00000035o]X01@000002093^jP80000000@0Vo3c000000000000
XNkh0P0000030:K[nP8000000P2Xj?X2000009H0oooo00<000000?ooo`3oool0:P3oool001`0oooo
00<000000?ooo`3oool0W@3oool20000000308fcl0000000SK?`0080SK?`0P00000508Vbl@800000
1025/?42000000D0PJkb0P00000207^[lP800000101dZ?800`000000K:Cb06bTlP0206bTlP800000
0P1RW_420000000605FGl0000000000000000000DJ/000000P1]0002000000030980002^8P000000
00<0000000D0^f800000001B@9h0000005=1W`020000000?05M3W`000000F4BO05Q4W`000000FTFO
0000001MAId0000005i6W@000000GdNM0000001PB9h000000080HTRN00H0000006=9WP1SBIh00000
06A:W@00000206E;WP8000000P1WC9h010000000J4fN06Q=WP00000206]>WP8000000`1^D9h01@00
0000KU2N000000000000LE:N008000000P1bDYd00`000000Le:M0000000207=BW@030000001dDid0
M5>M00<000000P1hEYd00`000000NEJM0000000307YGW@050000001jEid0000007]GW00000000P1l
Ei`00`000000^8FN0;R5WP070;R5WP030000003Y/YX0jK:J00@0jK:J00<000000>RgX@3X]j40103X
]j400`000000i[^Y0>JkZ@030>JkZ@8000000P3ijYL00`000000n>jX0?S^Z00200000080mO2f0P00
00000`2ooL/000000000000400000080T>kZ0P000000102Kl?<000000000002Qk_P2000000<0Y^_j
0P0000020:SXnP800000V03oool00`000000oooo0?ooo`0Z0?ooo`00703oool00`000000oooo0?oo
o`2O0?ooo`<00000102=/o02000000D0RK;a0P00000408F`l@8000001@21[_8200000080Nj_b0P00
000307BXlP800000101/Y?820000000506:Nl@000000000000000000L/`00`000002001AZ`0606d0
00000000TP00098000000000[R800P000000102XB000^f800000001B@9h20000000@05E2W`000000
Ed>O0000001HA9l0000005Y5W`000000GDFM0000001NAYd0000005m7W@000000H4RN00000080HTRN
00@0000006=9WP1SBIh000000P1TBYd01`000000ID^N0000001VBid0000006M<WP0000000P1XCIh0
1P000000JdjN06]>WP000000JdjN00000080KU2N00@0000006i@WP1^D9h000000P1aDYh400000080
Le:M00<0000007=BW@0000000P1dDid20000000407QFW@000000N5JM00000080NEJM00H0000007YG
W@1jEid0000007YGW@00000207]GW0030000001lEi`0000000T0^8FN00<000000>VbVP3Y/YX0103Y
/YX00`000000j;NQ0>RgX@040>RgX@030000003V^jT0i[^Y0080i[^Y0P0000030?WZU`030000003h
kZP0n>jX0080000000@0mO2f000000000000_og;1@000002093^jP80000000@0Vo3c000000000000
XNkh0P0000030:K[nP8000000P2Xj?X2000009T0oooo0P00000/0?ooo`00703oool00`000000oooo
0?ooo`2M0?ooo`8000000`3oool2000000@0SK?`0P00000508Vbl@8000001025/?42000000D0PJkb
00D0000007^[lP1kZo80Nj_b0000000407BXlP800000101/Y?82000000803HcS0P000002001bc009
001AZ`000000056[001AZ`1]00000000098000000000[R800080000000<0^f800000001B@9h00P00
0000101E@Yl0000005M3W`00000205Q4W`80000000/0GDFM0000001NAYd0GTJM0000001OAid00000
0618WP000000HTRN0000000206=9WP060000001TBYd0I4ZM0000001UBih000000P1VBid00`000000
IdbN0000000206Q=WP0706]>WP000000JdjN06]>WP000000KU2N0000000306i@WP040000001aDYh0
LE:N00000080LU:M100000001P1cDYd0000007ACW@1dDid0000007ACW080000000D0N5JM0000001i
EYd0NEJM0000000207YGW@030000001jEid000000080NeNL00<0000007aGW00000002@2hQIh00`00
0000jK:J0>VbVP040>VbVP030000003X]j40j;NQ00@0j;NQ00<000000>JkZ@3V^jT00P3V^jT20000
00<0nNZG00D000000?S^Z03hkZP000000?G`]P02000000030;omb`0000000000008000000P2@k^X2
0000000409_`l`00000000000:7^n08000000`2VjoX200000080Z>Sj0P00002I0?ooo`80000000<0
oooo0000003oool0:`3oool001`0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`05
0?ooo`800000102=/o03000000@0RK;a0P00000408F`l@8000001021[_8200000080Nj_b0P000004
07BXlP80000000@0K:Cb0000000/WO00;9g`0`0000001@0=S><0000000000000000007;<00<00000
00@0056[06d000000000TP00100000000`1B@9h0000005=1W`020000000?05M3W`000000F4BO05Q4
W`000000G4BL0000001MAId0000005i6W@000000GdNM0000001PB9h000000080HTRN00@0000006=9
WP00000000000P1TBYd2000000<0IT^M0P00000206Q=WP0706]>WP000000JdjN06]>WP000000KU2N
0000000306i@WP040000001aDYh0LE:N00000080LU:M00<0000007=BW@1cDYd00`00000207ACW@06
0000001dDi`0M5>L0000001hEYd000000P1iEYd010000000NUNM07YGW@00000207YGW@030000001k
Ei`000000080O5NL00<000000;R5WP2hQIh01@2hQIh2000000H0jK:J00<000000>RgX@3X]j40103X
]j401`000000i[^Y0>JkZ@3V^jT000000?STQ00000000`3ijYL00`000000n>jX0?S^Z00200000003
0;Ce/`0000000000008000000P2@k^X20000000409_`l`00000000000:7^n08000000`2VjoX20000
0080Z>Sj0P00002J0?ooo`050000003oool0oooo0?ooo`000000;03oool001/0oooo00<000000?oo
o`3oool0W03oool00`000000oooo0?ooo`080?ooo`8000001@2=/o02000000@0RK;a0P00000408F`
l@8000001021[_8200000080Nj_b0P00000407BXlP8000001@0/WO02000000803HcS0`0000002@00
L/`0056[00000000DJ/0K@000000002B000000000;]R00020000000305=1W`000000ED:O00800000
00T0F4BO000000000000G4BL0000001MAId0000005i6W@0000000P1OAid200000080HTRN00@00000
06=9WP00000000000P1TBYd00`000000ID^N0000000306I;W@@00000101[CYh2000000<0KU2N0P00
00001@1aDYh00000079BW@1bDYd000000080Le:M00H0000007=BW@000000000007ACW@00000207AC
W080000000@0N5JM0000001iEYd000000P1jEid01P000000NUNM07YGW@000000NeNL00000080O5NL
00<000000;R5WP2hQIh01@2hQIh2000000H0jK:J00<000000>RgX@3X]j40103X]j401`000000i[^Y
0>JkZ@3V^jT000000?STQ00000000P3ijYL2000000030?S^Z0000000000000D0000000@0T>kZ0000
00000000Vo3c0P0000000`2Qk_P00000000000030:K[nP8000000P2Xj?X200000:00oooo00<00000
0?ooo`3oool0:P3oool001/0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0;0?oo
o`8000001@2=/o02000000@0RK;a0P00000408F`l@8000001021[_8200000080Nj_b0P000000101d
Z?80000004BYm`14ZOL3000000@0;9g`0`00000200f<h`80000000T007;<000000000000056[06d0
002B0000^f800000001B@9h00P0000000`1E@Yl0000005M3W`020000000305]3W000000000000080
GDFM00P0000005i6W@000000GdNM0000001PB9h000000698WP8000000P1SBId00`000000I4ZM06A:
W@02000000<0IT^M00@0000006Q<W@1XC9d00000101[CYh2000000<0KU2N0P0000001@1aDYh00000
079BW@1bDYd000000080Le:M00<0000007=BW@1cDYd00`00000207ACW0060000001eDi`000000000
001iEYd000000P1jEid01P000000NUNM07YGW@000000NeNL00000080O5NL00<000000;R5WP2hQIh0
1@2hQIh2000000H0jK:J00<000000>RgX@3X]j40103X]j401`000000i[^Y0>JkZ@3V^jT000000?ST
Q00000000P3ijYL2000000030?S^Z0000000000000<0000000@0T>kZ000000000000Vo3c0P000000
0`2Qk_P00000000000030:K[nP8000000P2Xj?X200000:<0oooo00<000000?ooo`3oool0:@3oool0
01/0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0>0?ooo`8000001@2=/o020000
00@0RK;a0P00000408F`l@8000001021[_820000000307^[lP000000000000H0A:Wg0`00000402bM
l0<0000000<03HcS0000000000000P0000001`00DJ/000000;]R00000000DT2N0000001C@Il00P00
00003`1G@il0000005]3W01K@i`0000005a4W0000000GDFM0000001NAYd0000005m7W@000000H4RN
000000020698WP040000001SBId0HdVM00000080I4ZM0P00000306I;W@050000001XC9d0J4bM06Q<
W@000000101[CYh01P000000KU2N06i@WP1^D9h0000006i@W@8000000P1bDYd010000000Le:M07=B
W@00000207=BW@030000001dDid0M5>M00<000000P1eDi`00`000000NEJM0000000307YGW@050000
001jEid0000007]GW00000000P1lEi`00`000000^8FN0;R5WP050;R5WP8000001P3Y/YX00`000000
j;NQ0>RgX@050>RgX@030000003V^jT000000080n>B400@000000?WZU`3ijYL000000P3hkZP30000
0004093^jP000000000009_`l`80000000<0XNkh0000000000000`2VjoX200000080Z>Sj0P00002U
0?ooo`030000003oool0oooo02T0oooo000K0?ooo`030000003oool0oooo09T0oooo00<000000?oo
o`3oool04@3oool2000000D0SK?`0P00000408Vbl@8000001025/?42000000@0PJkb00@0000005N`
n`1G/?/0Ek3k0P00000604BYm`<00000100/WO02000000803HcS1@0000000`1B@9h0000005=1W`02
0000000905M3W`000000Fd>L05]3W0000000G4BL0000001MAId000000080GTJM00L0000005m7W@00
0000H4RN0000001RB9h0000000<0HdVM00@0000006A:W@1TBYd000000`1VBid01@000000J4bM06Q<
W@1XC9d0000000@0JdjN00H0000006i@WP1^D9h0KU2N0000001^D9d200000080LU:M00@0000007=B
W@1cDYd000000P1cDYd01@000000M5>M07ACW@000000M5>L0080000000D0ME>L000000000000NEJM
0000000207YGW@030000001jEid000000080NeNL00<0000007aGW00000001P2hQIh010000000jJjB
0>V^TP0000060>VbVP030000003X]j40j;NQ00@0j;NQ00@000000>JkZ@000000n>B40P0000020?WZ
U`050000003hkZP0n>jX0000002@k^X00P000000102Kl?<000000000002Qk_P2000000<0Y^_j0P00
00020:SXnP800000Y`3oool00`000000oooo0?ooo`0Y0?ooo`006`3oool00`000000oooo0?ooo`2H
0?ooo`030000003oool0oooo01@0oooo0`00000408fcl08000001029/_42000000@0QK3a0P000000
1021[_80000006Ffo01U]_`2000000@0Ek3k0P00000504BYm`<000000`0/WO03000000803HcS00@0
00000;]R00000000DT2N0P000000101E@Yl0000005Y2W000000205]3W08000000P1MAId02@000000
GTJM0000001OAid000000618WP000000HTRN0000000306=9W@030000001TBYd0I4ZM008000000P1V
Bid01@000000J4bM06Q<W@1XC9d0000000@0JdjN00D0000006i@WP1^D9h0KU2N0000000206i@W@04
0000001bDYd0LU:M00000080Le:M00@0000007=BW@1cDYd000000P1dDid010000000M5>L0000001e
Di`30000000507UFW@000000NUNM07YGW@0000000P1jEid01@000000NeNL0000001lEi`0000000H0
^8FN00@000000>V^TP3Y[Y8000001P3Y/YX00`000000j;NQ0>RgX@040>RgX@8000000P3hi8@01P00
0000nNZG0?WZU`3ijYL000000?S^Z0<0000000@0Vo3c000000000000XNkh0P0000030:K[nP800000
0P2Xj?X200000:T0oooo00<000000?ooo`3oool0:@3oool001/0oooo00<000000?ooo`3oool0U`3o
ool00`000000oooo0?ooo`0H0?ooo`800000102=/o02000000@0RK;a0P00000408F`l@030000001U
]_`0IKKl00@0IKKl0`00000305N`n`<000001014ZOL3000000<0;9g`0`0000000`0=S><000000590
WP020000000405E2W`000000FT:L00000080Fd>L00L0000005a4W0000000GDFM0000001NAYd00000
0080GdNM0P0000000`1RB9h000000000000306=9W@050000001TBYd0000006E:W@0000000P1VBid0
10000000J4bM06Q<W@00000306]>WP030000001[CId000000080KU2N00<0000006i@W@1^D9d00P00
0002079BW@030000001cDYd000000080Le:M00H0000007ACW@1dDid0000007ACW000000207ECW0@0
00000P1jEid01P000000NUNM07YGW@000000NeNL00000080O5NL00<000000;R5WP2hQIh00`2hQIh0
10000000jJjB0>V^TP0000060>VbVP030000003X]j40j;NQ00@0j;NQ0P0000020?STQ0030000003i
jYL0nNZG0080000000<0n>jX0000002Kl?<00P0000000`2Qk_P00000000000030:K[nP8000000P2X
j?X200000:/0oooo00<000000?ooo`3oool0:@3oool001X0oooo00<000000?ooo`3oool0UP3oool2
000001d0oooo0P00000408fcl08000001029/_420000000408F`l@000000L;Wl072io0<000001P1U
]_`3000000<0Ek3k0`00000304BYm`<000000`0/WO02000000030590WP000000Dd6O0080000000T0
FT:L0000001K@i`0Fd>L0000001LA9`0000005e5W@0000000P1NAYd010000000GdNM0000001PB9h3
000000<0HdVM00D0000006A:W@000000IDZM0000000206I;W@050000001XC9d0J4bM06Q<W@000000
0P1[CYh01@000000JdfM0000001^D9h0000000<0KU2M0P000002079BW@030000001cDYd000000080
Le:M00@0000007ACW@1dDid000000P1dDi`207ECW0030000001fDi`0MU>L00@000000P1jEid00`00
0000NeNL0000000207aGW0030000002hQIh0^8FN00<0^8FN00@000000>V^TP3Y[Y8000001P3Y/YX0
0`000000j;NQ0>RgX@040>RgX@050000003hi8@0n>B40?STQ00000000P3ijYL5000000030:7^n000
0000000000<0Y^_j0P0000020:SXnP800000[P3oool00`000000oooo0?ooo`0X0?ooo`006P3oool0
0`000000oooo0?ooo`2E0?ooo`030000003oool0oooo01l0oooo0P00000408fcl08000001029/_40
0`000000L;Wl072io005072io0<000001@1U]_`3000000<0Ek3k1000000204BYm`@0000000T0;9g`
000000000000Dd6O0000001I@I`0000005Y2W00000000P1K@i`200000080GDFM00H0000005i6W@00
0000GdNM0000001PB9h2000000030698W@000000HdVM0080HdVM0P00000206E:W@030000001VBid0
000000<0J4bM00<0000006]>WP0000000P1[CId00`000000KU2N0000000306i@W@070000001_D9d0
0000079BW@000000Le:M0000000207=BW@040000001dDid0M5>M00000080M5>L00<0000007ECW000
00000P1fDi`20000000707YGW@000000000007YGW@000000NeNL0000000207aGW0030000002hQIh0
^8FN0080^8FN00D000000>V^TP3Y[Y80jJjB000000060>VbVP030000003X]j40j;NQ00@0j;NQ00D0
00000?STQ03hi8@0n>B4000000020?WZU`<0000000<0XNkh0000000000000`2VjoX200000080Z>Sj
0P00002`0?ooo`030000003oool0oooo02P0oooo000J0?ooo`030000003oool0oooo09@0oooo00<0
00000?ooo`3oool08P3oool2000000@0SK?`0P00000208Vbl@030000001h^o/00000008000001`1`
^O`3000000@0IKKl1000000305N`n`<000000`14ZOL2000000070590WP000000000005U1W0000000
FT:L0000000205]3W0070000001LA9`0000005e5W@000000GTJM0000000205m7W@050000001PB9h0
00000698W@0000000`1SBId00`000000I4ZM0000000206E:W@8000000`1XC9d00`000000JdjN0000
000306]=W@8000000`1^D9d01`000000Ke2M0000001bDYd0000007=BW@0000000P1cDYd010000000
M5>M07ACW@00000207ACW0030000001eDi`000000080MU>L00<0000007ICV`0000001000000207]G
W0030000001lEi`0000000@0^8FN00D000000>V^TP3Y[Y80jJjB000000060>VbVP030000003X]j40
j;NQ00@0j;NQ00D000000?STQ03hi8@0n>B4000000020?WZU`@000000`2VjoX200000080Z>Sj0P00
002b0?ooo`030000003oool0oooo02P0oooo000J0?ooo`030000003oool0oooo09<0oooo00<00000
0?ooo`3oool09@3oool2000000@0SK?`0P00000607Rkn`@000001P1`^O`3000000@0IKKl0`000003
05N`n`D0000000<0DT2N0000001G@I/00P0000001`1J@Y`0000005]3W01K@i`0000005a4W0000000
0P1MAId01`000000GTJM0000001OAid000000618WP0000000P1RB9d010000000HdVM06=9W@1SBId2
000000<0IDZM0`00000206Q<W@030000001[CId0JdfM0080JdfM0P00000306i@W@030000001_D9d0
Ke2M0080000000D0Le:M0000001cDYd0Le:M0000000207ACW@060000001dDi`0M5>L0000001eDi`0
00000P1fDi`01P000000MU>K07ICV`1fDi/0000007YGW@@0000000<0O5NL0000002hQIh00`2hQIh0
1@000000jJjB0>V^TP3Y[Y80000000H0jK:J00<000000>RgX@3X]j400`3X]j42000000<0n>B400<0
00000?WZU`3ijYL00P0000030:K[nP8000000P2Xj?X200000;@0oooo00<000000?ooo`3oool0:03o
ool001X0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0X0?ooo`8000000P2=/o00
0`000000Okcj07nlnP03000000H0N;_k10000005072io0@000000`1U]_`3000000@0Ek3k00T00000
0590WP000000Ed6K0000001I@I`0000005Y2W00000000P1K@i`200000080GDFM00L0000005i6W@00
0000GdNM0000001PB9h000000080HTRM00@0000006=9W@1SBId0HdVM0P00000306E:W@030000001W
Bid0Id^M00<00000101[CId2000000<0KU2M00<0000006m@W@1_D9d00P0000001@1cDYd0000007=B
W@1cDYd000000080M5>M00@0000007ACW01dDi`000000P1eDi`00`000000MU>L0000000307ICV`80
000000<0NUNM0000001kEi`00`0000030;R5WP030000003Y[Y80jJjB0080jJjB00<000000>VbVP3Y
/YX0103Y/YX00`000000j;NQ0>RgX@030>RgX@8000000P3hi8@2000000030?WZU`00000000000080
Y^_j0P0000020:SXnP800000]P3oool00`000000oooo0?ooo`0X0?ooo`006P3oool00`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo02/0oooo0P00000707nlnP@000001@1h^o/4000000D0L;Wl
1000000206Ffo0@0000000<0Ek3k0000001F?i/00P000000101I@I`0000005Y2W000000205]3W005
0000001LA9`0000005e5W@0000000P1NAYd00`000000GdNM0000000200000080HTRM00D0000006=9
W@1SBId0HdVM0000000306E:W@030000001WBid0Id^M0080Id^M00<0000006]=W@1[CId00`1[CId0
1@000000KU2M06i@W@1^D9d0000000<0Ke2M00H0000007=BW@1cDYd0000007=BW@00000207ACW@04
0000001dDi`0M5>L00000080ME>L00<0000007ICW00000000`1fDi/01`000000Me>K000000000000
NeNL0000001lEi`00P0000020;R5WP030000003Y[Y80jJjB0080jJjB00<000000>VbVP3Y/YX0103Y
/YX00`000000j;NQ0>RgX@030>RgX@8000000P3hi8@2000000030?WZU`0000000000008000000P2X
j?X200000;P0oooo00<000000?ooo`3oool0:03oool001T0oooo00<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`0`0?ooo`8000001`1o_?X4000000D0N;_k10000005072io0@000000P1U]_`2
0000000<05HoV`000000Ed6K0000001I@I`0000005Y2W0000000Fd>L0000001LA9`000000P1MAId0
10000000GTJM0000001OAid300000080HTRM00@0000006=9W@1SBId0HdVM0P00000306E:W@030000
001WBid0Id^M0080Id^M00<0000006]=W@1[CId00P1[CId01@000000KU2M06i@W@1^D9d0000000<0
Ke2M00H0000007=BW@1cDYd0000007=BW@00000207ACW@040000001dDi`0M5>L00000080ME>L00<0
000007ICW01fDi`00`1fDi/01P000000Me>K07MCV`000000NeNL00000080O5NL100000040>V^TP03
0000003Y/YX0jK:J00D0jK:J00<000000>RgX@3X]j400P3X]j4200000080n>B400<000000?WZU`3i
jYL00P0000020:SXnP800000^`3oool00`000000oooo0?ooo`0W0?ooo`006@3oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo03D0oooo0`00000607nlnP@000001@1h^o/4000000D0L;Wl
10000000201F?i/0000005M1V`000000FD6L0000001J@Y`000000P1K@i`200000080GDFM00<00000
05i6W@0000000P1OAid00`000000HDNL000000020698W@030000001SBId0HdVM008000000`1UBYd0
0`000000Id^M06M;W@0206M;W@030000001[CId0JdfM0080JdfM00@0000006i@W@1^D9d00000101_
D9d20000000407=BW@000000Le:M00000080M5>M00@0000007ACW01dDi`000000P1eDi`00`000000
MU>L07ICW00307ICV`030000001gDi/0Me>K00<000000P1lEi`00`000000^8FN0;R5WP03000000<0
jJjB00<000000>VbVP3Y/YX0103Y/YX010000000j;NQ0>RgX@3X]j42000000<0n>B400<000000?WZ
U`3ijYL01000002m0?ooo`030000003oool0oooo02L0oooo000I0?ooo`030000003oool0oooo08h0
oooo0P00000l0?ooo`@000001@1o_?X4000000D0N;_k10000004072io080000000L0ESnK00000000
0000FD6L0000001J@Y`000000080Fd>L00D0000005a4W0000000GDFM0000000205i6W@050000001O
Aid000000657W00000000P1RB9d01P000000HdVM06=9W@000000I4VL00000080IDZM00<0000006M;
W@1WBid00P1WBid02@000000JdfM06]=W@1[CId0000006Y=W@000000KU2M0000000406m@W@800000
00@0Le:M0000001cDYd000000`1dDid00`000000M5>L0000000207ECW0040000001fDi`0MU>L0000
0080MU>K00<0000007MCV`1gDi/00P0000001P1kEi`0000007aGW0000000^8FN000000<0jJjB0P00
00000`3Y[Y8000000>VbVP050>VbVP040000003X]j40j;NQ0>RgX@8000000`3hi8@010000000nNZG
0?WZU`0000300?ooo`030000003oool0oooo02L0oooo000I0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0@03oool4000000D0Okcj1000000507Rkn`@0000000h0L;Wl0000001F?i/0
000005M1V`000000FD6L0000001J@Y`0000005]3W0000000G4BL00000080GDFM00D0000005i6W@00
0000GdNM000000020657W0060000001RB9d0HTRM0000001SBId000000P1TBI`00`000000IDZM0000
000506M;W@080000001[CId0JdfM0000001ZCId0000006i@W@00000406m@W@060000001_Ci`00000
0000001cDYd000000`1dDid00`000000M5>L0000000207ECW0040000001fDi`0MU>L00000080MU>K
00D0000007MCV`1gDi/0000007MCV`020000000407aGW0000000^8FN000000D0jJjB0P0000060>Vb
VP040000003X]j40j;NQ0>RgX@8000000`3hi8@00`000000nNZG000000300?ooo`800000:@3oool0
01T0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`150?ooo`@000001@1o_?X40000
00D0N;_k0P000000201F?i/0000005M1V`000000FD6L0000001J@Y`000000P1K@i`020000000G4BL
0000001MAId0000005i6W@000000GdNM0P0000001`1QAi`000000698W@1RB9d0000006=9W@000000
0`1TBI`2000000D0Id^M00<0000006]=W@0000000P1ZCId00`000000KU2M0000000306m@W@030000
001_Ci`0KdnL0080000000<0Le:M0000001dDid00P1dDid00`000000M5>L0000000207ECW0040000
001fDi`0MU>L00000080MU>K00@0000007MCV`1gDi/000000P1gDi/01@000000O5NL0000002hQIh0
000000H0jJjB0`0000040>VbVP040000003X]j40j;NQ0>RgX@8000000P3hi8@2000000030?WZU`3o
ool0oooo0;h0oooo00<000000?ooo`000000:@3oool001T0oooo00<000000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`1:0?ooo`@000001@1o_?X4000000<0N;_k00@0000005HoV`000000Ed6K0P00
00001`1J@Y`0000005]3W01K@i`0000005a4W00000000P1MAId00`000000GTJM0000000200000080
HDNL00<000000698W@1RB9d00P00000306A9W0030000001UBYd0000000@0Id^M00<0000006]=W@00
00000`1ZCId2000000<0Ke2M00D0000006m?W01_Ci`0KdnL0000000207=BW@060000001dDid0M5>M
0000001dDi`000000P1eDi`010000000MU>L07ICW000000207ICV`040000001gDi/0Me>K00000080
Me>K0P0000000`1lEi`00000000000060>V^TP030000003Y/YX0jK:J008000000P3Y/YX01P000000
j;NQ0>RgX@000000m=]a00000080n>B40`0000330?ooo`030000003oool0oooo02H0oooo000H0?oo
o`030000003oool0oooo08/0oooo00<000000?ooo`3oool0C`3oool4000000D0Okcj10000000301F
?i/0000005M1V`000000FD6L0000001J@Y`0000005]3W0000000G4BL00000080GDFM00P0000005i6
W@00000000000616W0000000HDNL000000<0HTRM00<0000006A9W01TBI`00P1TBI`2000000D0Id^M
00<0000006Y=W@1ZCId00P1ZCId2000000<0Ke2M00D0000006m?W01_Ci`0KdnL0000000207=BW@06
0000001dDid0M5>M0000001dDi`000000P1eDi`010000000MU>L07ICW000000307ICV`030000001g
Di/000000080Me>K00@0000007QCV`00000000001`3Y[Y800`000000jK:J0>VbVP020>VbVP<00000
0P3X]j400`000000m=]a000000020?STQ0<00000``3oool00`000000oooo0?ooo`0V0?ooo`00603o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo05@0oooo1000000407nlnP090000001F
?i/0000005M1V`000000FD6L0000001J@Y`000000080Fd>L00D0000005a4W0000000GDFM00000002
05i6W@030000001PAY`000000080HDNL00@000000698W@1RB9d000001@1TBI`7000000@0JTfM0P00
000306m@W@040000001_Ci`0KdnL06m?W080000000D0Le:M0000001dDid0M5>M0000000207ACW003
0000001eDi`000000080MU>L00D0000007ICV`1fDi/0MU>K0000000407MCV`040000001hDi/0N5>K
000000L0jJjB00<000000>VbVP3Y/YX0103Y/YX2000000040>RgX@000000m=]a00000080n>B400<0
00000?WZU`3oool0``3oool00`000000oooo0?ooo`0V0?ooo`00603oool00`000000oooo0?ooo`29
0?ooo`030000003oool0oooo05T0oooo100000001@1o_?X0000005HoV`000000Ed6K0080000000L0
FT:L0000001K@i`0Fd>L0000001LA9`000000080GDFM00<0000005i6W@0000000P1PAY`00`000000
HDNL000000020698W@800000101TBI`00`000000IdZL06M:W00306M:W0030000001ZCId0JTfM00<0
JTfM00D0000006m@W@1_D9d0Ke2M0000000306m?W080000000D0Le:M0000001dDid0M5>M00000002
07ACW0030000001eDi`000000080MU>L00D0000007ICV`1fDi/0MU>K0000000207MCV`030000001g
Di/000000080N5>K00<000000>V^TP3Y[Y801@3Y[Y800`000000jK:J0>VbVP040>VbVP030000003X
]j40000000<000000P3hi8@200000<@0oooo00<000000?ooo`3oool09P3oool001P0oooo00<00000
0?ooo`3oool0R03oool00`000000oooo0?ooo`1N0?ooo`80000000`0ESnK0000001G@I/0000005U1
W0000000FT:L0000001K@i`0000005a4W000000205e5W@030000001NAYd000000080H4JL00P00000
0657W01QAi`000000698W@000000HdRL000000<0I4VL00<0000006M:W01WBY`00`1WBY`00`000000
JTfM06Y=W@0306Y=W@050000001_D9d0Ke2M06m@W@0000000`1_Ci`010000000KdnL000000000002
07ACW@060000001dDi`0M5>L0000001eDi`000000P1fDi`01@000000MU>K07ICV`1fDi/000000080
Me>K00<0000007MCV`0000000P1hDi/00`000000jJjB0>V^TP050>V^TP030000003Y/YX0jK:J00@0
jK:J00@000000>RgX@000000m=]a0`0000000`3hi8@00000000000340?ooo`030000003oool0oooo
02H0oooo000H0?ooo`030000003oool0oooo08H0oooo0P00001R0?ooo`090000001F?i/0000005M1
V`000000FD6L0000001J@Y`000000080Fd>L00H0000005a4W0000000GDFM0000001NAYd200000080
H4JL00L000000657W0000000HTRM0000001SB9`0000000@0I4VL00<0000006M:W01WBY`00`1WBY`0
0`000000JTfM06Y=W@0206Y=W@050000001_D9d0Ke2M06m@W@0000000`1_Ci`010000000KdnL0000
0000000207ACW@060000001dDi`0M5>L0000001eDi`000000P1fDi`01@000000MU>K07ICV`1fDi/0
00000080Me>K00<0000007MCV`1gDi/00P1hDi/00`000000jJjB0>V^TP050>V^TP030000003Y/YX0
jK:J00D0jK:J0P000000103dfg4000000000003hi8@200000<D0oooo00<000000?ooo`3oool09P3o
ool001P0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`1S0?ooo`060000001F?i/0
000005M1V`000000FD6L0P00000205]3W0030000001LA9`000000080GDFM0`0000020616W0030000
001QAi`0HDNL008000000P1SB9`01@000000I4VL06A9W01TBI`0000000D0IdZL00L0000006Y=W@1Z
CId0JTfM0000001ZC9`000000080Ke2M00@0000006m?W01_Ci`000000`1_Ci`010000000M5>M07AC
W@00000207ACW0030000001eDi`000000080MU>L00D0000007ICV`1fDi/0MU>K0000000207MCV`03
0000001gDi/0Me>K0080N5>K00<000000>V^TP3Y[Y801@3Y[Y800`000000jK:J0>VbVP050>VbVP80
000000@0m=]a0000003hi8@0n>B4100000340?ooo`030000003oool0oooo02D0oooo000H0?ooo`03
0000003oool0oooo08@0oooo00<000000?ooo`3oool0I03oool03@000000ESnK0000001G@I/00000
05U1W0000000FT:L0000001K@i`0000005a4W00000000P1MAId20000000905m5V`000000H4JL0616
W0000000HDNL0000001RB9d000000080HdRL00@0000006A9W01TBI`000001@1WBY`01`000000JTfM
06Y=W@1ZCId0000006Y<W00000000P1_D9d010000000KdnL06m?W000000306m?W0040000001dDid0
M5>M00000080M5>L00@0000007ECW01eDi`000000P1fDi`010000000MU>K07ICV`00000207MCV`03
0000001gDi/0Me>K0080N5>K00<000000>V^TP3Y[Y801P3Y[Y800`000000jK:J0>VbVP040>VbVP80
000000D0m=]a0000003hi8@0n>B4000000030?ooo`800000`P3oool00`000000oooo0?ooo`0U0?oo
o`005`3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo06D0oooo00T0000005HoV`00
0000Ed6K0000001I@I`0000005Y2W00000000P1K@i`00`000000G4BL0000000205e5W@030000001O
AI/000000080H4JL00<000000657W01QAi`00P00000306=8W0030000001TBI`0000000D0IdZL00@0
000006Y=W@1ZCId000000P1ZC9`010000000Ke2M06m@W@00000206m?W0040000001_Ci`0KdnL06m?
W080000000D0M5>M0000001dDi`0M5>L0000000207ECW0040000001fDi`0MU>L00000080MU>K00@0
000007MCV`1gDi/000000P1gDi/00`000000N5>K000000080>V^TP030000003Y/YX0jK:J00@0jK:J
00@000000?CKL@3dfg4000000P3hi8@00`000000oooo0?ooo`030?ooo`800000`03oool00`000000
oooo0?ooo`0U0?ooo`005`3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo06L0oooo
00d0000005HoV`000000Ed6K0000001I@I`0000005Y2W0000000Fd>L0000001LA9`000000080GDFM
00H0000005m5V`1OAI/000000616W00000030657W0030000001SB9`0HdRL0080HdRL0P00000506M:
W0040000001ZCId0JTfM000000<0JTbL0P00000306m?W0040000001_Ci`0KdnL06m?W08000000P1d
Did00`000000M5>L0000000207ECW0040000001fDi`0MU>L00000080MU>K00@0000007MCV`1gDi/0
00000P1gDi/010000000N5>K07QCV`0000070>V^TP030000003Y/YX0jK:J00@0jK:J00@000000?CK
L@3dfg4000000P3hi8@00`000000oooo0?ooo`050?ooo`800000_P3oool00`000000oooo0?ooo`0U
0?ooo`005`3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo06P0oooo00d0000005Ho
V`000000Ed6K0000001I@I`0000005Y2W0000000Fd>L0000001LA9`000000080GDFM00@0000005m5
V`1OAI/000000P1PAY`010000000HDNL0657W000000406=8W0030000001TBI`0000000D0IdZL0P00
000406Y<W08000000`1_Ci`02`000000KdnL06m?W01_Ci`0000006m?W0000000M5>M0000001dDi`0
00000080ME>L00@0000007ICW01fDi`000000P1fDi/010000000Me>K07MCV`00000207MCV`040000
001hDi/0N5>K000000L0jJjB00<000000>VbVP3Y/YX0103Y/YX010000000m=]a0?CKL@0000020?ST
Q0X0oooo0P00002l0?ooo`030000003oool0oooo02D0oooo000G0?ooo`030000003oool0oooo0840
oooo00<000000?ooo`3oool0J@3oool02@000000ESnK0000001G@I/0000005U1W0000000FT:L0000
000205]3W0040000001LA9`0000005e5W@8000000P1OAI/00`000000H4JL000000020657W0800000
101SB9`2000000D0IdZL0P00000406Y<W08000000`1_Ci`02`000000KdnL06m?W01_Ci`0000006m?
W0000000M5>M0000001dDi`000000080ME>L00@0000007ICW01fDi`000000P1fDi/010000000Me>K
07MCV`00000207MCV`040000001hDi/0N5>K000000L0jJjB00<000000>VbVP3Y/YX0103Y/YX01000
0000m=]a0?CKL@0000020?STQ0`0oooo0`00002j0?ooo`030000003oool0oooo02@0oooo000G0?oo
o`030000003oool0oooo0800oooo00<000000?ooo`3oool0J`3oool03P000000ESnK0000001G@I/0
000005U1W0000000FT:L0000001K@i`0000005a4W0000000GDFM0P00000205m5V`080000001PAY`0
H4JL0000001QAi`0000006=7V`00000406=8W0L000001P1ZC9`01@000000KdnL06m?W01_Ci`00000
00<0KdnL00<0000006m?W01_Ci`00P0000001@1dDi`0000007ECW01eDi`000000080MU>L00@00000
07ICV`1fDi/000000P1gDi/010000000Me>K07MCV`00000207QCV`030000003Y[Y80jJjB00D0jJjB
00<000000>VbVP3Y/YX00`3Y/YX2000000050?CKL@00000000000?STQ00000003`3oool200000;P0
oooo00<000000?ooo`3oool0903oool001L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo
0?ooo`1/0?ooo`0<0000001F?i/0000005M1V`000000FD6L0000001J@Y`0000005]3W0000000G4BL
0P00000205i4V`0:0000001OAI/0GdFK0000001PAY`000000657W0000000HdNK000000@0HdRL00<0
000006I9W01VBI`00`1VBI`00`000000JTbL06Y<W00406Y<W0050000001_Ci`0KdnL06m?W0000000
0`1_Ci`00`000000KdnL06m?W0020000000507ACW0000000ME>L07ECW00000000P1fDi`010000000
MU>K07ICV`00000207MCV`040000001gDi/0Me>K00000080N5>K00<000000>V^TP3Y[Y801@3Y[Y80
0`000000jK:J0>VbVP030>VbVP80000000@0m=]a000000000000n>B44P3oool200000;H0oooo00<0
00000?ooo`3oool0903oool001H0oooo00<000000?ooo`3oool0OP3oool2000006l0oooo00T00000
05HoV`000000Ed6K0000001I@I`0000005Y2W00000000P1K@i`00`000000G4BL0000000205i4V`04
0000001OAI/0GdFK00000080H4JL0P00000206=7V`050000001SB9`0HdRL06=8W00000001P1VBI`0
0`000000JTbL06Y<W00306Y<W0050000001_Ci`0KdnL06m?W00000000`1_Ci`01`000000KdnL06m?
W01_Ci`0000007ACW00000000P1eDi`010000000MU>L07ICW000000207ICV`040000001gDi/0Me>K
00000080Me>K00@0000007QCV`1hDi/000001`3Y[Y800`000000jK:J0>VbVP030>VbVP80000000@0
m=]a000000000000n>B4503oool200000;@0oooo00<000000?ooo`3oool0903oool001H0oooo00<0
00000?ooo`3oool0O@3oool00`000000oooo0?ooo`1`0?ooo`0=0000001F?i/0000005M1V`000000
FD6L0000001J@Y`0000005]3W0000000G4BL0000000305i4V`030000001OAI/000000080H4JL00<0
00000657W00000000P1SAi/01@000000HdRL06=8W01SB9`0000000D0ITVL00<0000006Y<W01ZC9`0
0P1ZC9`00`000000JTbL0000000206m?W0050000001_Ci`0KdnL06m?W00000000`1_Ci`01P000000
M5>L07ACW0000000ME>L00000080MU>L00@0000007ICV`1fDi/000000P1gDi/010000000Me>K07MC
V`00000207QCV`030000003Y[Y80jJjB00D0jJjB00<000000>VbVP3Y/YX00`3Y/YX00`000000m=]a
0?CKL@03000001H0oooo0P00002b0?ooo`030000003oool0oooo02@0oooo000F0?ooo`030000003o
ool0oooo07`0oooo00<000000?ooo`3oool0L@3oool03@000000ESnK0000001G@I/0000005U1W000
0000FT:L0000001K@i`0000005a4W00000000`1NA9/010000000GdFK05m5V`0000020616W0800000
0`1SAi/010000000HdRL06=8W000000506I9W0030000001ZC9`0JTbL0080JTbL00<0000006Y<W000
00000P1_Ci`01@000000KdnL06m?W01_Ci`0000000<0KdnL0P000000101dDi`0000007ECW0000002
07ICW0040000001fDi/0MU>K000000<0Me>K00<0000007MCV`0000000P1hDi/00`000000jJjB0>V^
TP050>V^TP030000003Y/YX0jK:J00<0jK:J00H000000?CKL@3dfg4000000?STQ000000H0?ooo`80
0000[`3oool2000002H0oooo000F0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0
LP3oool00`000000ESnK0000000205M1V`040000001I@I`0000000000080Fd>L0`00000305i4V`03
0000001OAI/000000080H4JL0P00000406=7V`030000001SB9`0000000D0ITVL00D0000006Y<W01Z
C9`0JTbL0000000206Y<W0030000001_Ci`0000000@0KdnL00@0000006m?W01_Ci`0KdnL0P000000
101dDi`0000007ECW000000207ICW0040000001fDi/0MU>K000000<0Me>K00H0000007MCV`1gDi/0
000007QCV`0000070>V^TP030000003Y/YX0jK:J0080jK:J0P0000020?CKL@030000003hi8@0oooo
01X0oooo0P00002/0?ooo`040000003oool0oooo000002D0oooo000F0?ooo`030000003oool0oooo
07X0oooo00<000000?ooo`3oool0M03oool200000080Ed6K00H0000005U1W0000000FT:L0000001K
@i`3000000<0GTBK00@0000005m5V`1OAI/000000P1PAY`00`000000HdNK06=7V`0306=7V`800000
1P1VBI`010000000JTbL06Y<W000000306Y<W0800000101_Ci`01P000000KdnL06m?W01_Ci`00000
071?V`80000000<0ME>L0000001fDi`00P1fDi`010000000MU>K07ICV`00000207MCV`060000001g
Di/0Me>K0000001hDi/00000203Y[Y8010000000jK:J0>VbVP3Y/YX200000080m=]a0P00000M0?oo
o`<00000[03oool00`000000oooo0?ooo`0S0?ooo`005P3oool00`000000oooo0?ooo`1i0?ooo`03
0000003oool0oooo07D0oooo00X0000005HoV`000000Ed6K0000001I@I`0000005Y2W0000000Fd>L
0P0000001@1NA9/0000005i4V`1NA9/000000080GdFK00@000000616W01PAY`000001@1SAi/00`00
0000HdRL0000000506I9W0030000001ZC9`0000000@0JTbL0P00000406m?W0060000001_Ci`0KdnL
06m?W0000000L4nK0P0000000`1eDi`0000007ICW00207ICW0040000001fDi/0MU>K00000080Me>K
00H0000007MCV`1gDi/0000007QCV`0000080>V^TP040000003Y/YX0jK:J0>VbVP8000000P3dfg42
00000200oooo0P00002Z0?ooo`030000003oool0oooo02<0oooo000E0?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool0MP3oool00`000000ESnK0000000205M1V`040000001I@I`00000
00000080Fd>L00<0000005i4V`0000000`1NA9/01@000000GdFK05m5V`000000H4JL008000001@1S
Ai/2000000D0ITVL00<0000006Y<W0000000101ZC9`2000000<0KdnL00<0000006m?W01_Ci`00P1_
Ci`01P000000L4nK071?V`000000ME>L000000<0MU>L00@0000007ICV`1fDi/000000P1gDi/01P00
0000Me>K07MCV`000000N5>K000000P0jJjB00@000000>VbVP3Y/YX0jK:J0P0000000`3dfg400000
0000000S0?ooo`800000Z03oool00`000000oooo0?ooo`0S0?ooo`005@3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo07P0oooo0P00000205M1V`070000001I@I`0000005Y2W0000000
Fd>L0000000205i4V`040000001NA9/0GTBK00000080GdFK00D000000616W0000000HTJK00000005
06=7V`@000000`1VBI`00`000000JTbL06Y<W00406Y<W0050000001_Ci`0KdnL06m?W00000000`1_
Ci`01@000000L4nK071?V`1`Ci/000000080ME>L00@0000007ICW01fDi`000000P1fDi/010000000
Me>K07MCV`00000207MCV`030000001hDi/0000000P0jJjB00@000000>VbVP3Y/YX0jK:J0P000000
0`3dfg4000000000000U0?ooo`800000YP3oool00`000000oooo0?ooo`0S0?ooo`005@3oool00`00
0000oooo0?ooo`1f0?ooo`800000N`3oool02`000000ESnK0000001G@I/0000005U1W0000000FT:L
0000001K@i`000000080GTBK00D0000005i4V`1NA9/0GTBK0000000205m5V`80000000<0HTJK0000
001SAi/0101SAi/010000000ITVK06I9V`1VBI/4000000H0JTbL00D0000006m?W01_Ci`0KdnL0000
000306m?W0050000001`Ci/0L4nK071?V`0000000P1eDi`010000000MU>L07ICW000000207ICV`04
0000001gDi/0Me>K00000080Me>K00@0000007QCV`1hDi/000001`3Y[Y801`000000jK:J0>VbVP00
0000l=5N0000003dfg400P00000W0?ooo`800000Y@3oool00`000000oooo0?ooo`0R0?ooo`005@3o
ool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo07/0oooo00<0000005HoV`0000000P1G
@I/010000000FD6L0000001J@Y`300000080GTBK00@0000005i4V`1NA9/000000P1OAI/200000080
HTJK00<0000006=7V`1SAi/00P1SAi/00`000000ITVK06I9V`0406I9V`030000001ZC9`0JTbL00@0
JTbL00D0000006m?W01_Ci`0KdnL0000000306m?W0040000001`Ci/0L4nK071?V`80000000D0ME>L
0000001fDi`0MU>L0000000207ICV`040000001gDi/0Me>K00000080Me>K00@0000007QCV`1hDi/0
00001`3Y[Y800`000000jK:J0>VbVP03000000030?CKL@000000oooo02T0oooo0P00002S0?ooo`03
0000003oool0oooo0280oooo000E0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
O03oool00`000000ESnK0000000205M1V`040000001I@I`0000005Y2W0<000000P1NA9/01@000000
GTBK05i4V`1NA9/000000080GdFK0P0000020696V`030000001SAi/0HdNK0080HdNK00<0000006I9
V`1VBI/0101VBI/00`000000JTbL06Y<W00206Y<W0030000001ZC9/000000080KdnL00D0000006m?
W01_Ci`0KdnL00000003071?V`80000000D0ME>L0000001fDi`0MU>L0000000207ICV`040000001g
Di/0Me>K00000080Me>K00@0000007QCV`1hDi/000001`3Y[Y800`000000jK:J0>VbVP0300000003
0?CKL@000000oooo02/0oooo0P00002Q0?ooo`030000003oool0oooo0280oooo000E0?ooo`030000
003oool0oooo07<0oooo00<000000?ooo`3oool0OP3oool020000000ESnK0000001G@I/0000005U1
W0000000FT:L0P0000001@1M@iX0000005i4V`1NA9/000000080GTBK00<0000005m5V`1OAI/00P00
00030696V`050000001SAi/0HdNK06=7V`0000001P1VBI/00`000000JTbL06Y<W00206Y<W0030000
001ZC9/000000080KdnL00D0000006m?W01_Ci`0KdnL00000003071?V`040000001`Ci/000000000
0080MU>L00@0000007ICV`1fDi/000000P1gDi/010000000Me>K07MCV`00000207QCV`030000003Y
[Y80jJjB00D0jJjB00<000000>VbVP3Y/YX00`0000000`3dfg4000000?ooo`0]0?ooo`800000W`3o
ool00`000000oooo0?ooo`0R0?ooo`00503oool00`000000oooo0?ooo`1c0?ooo`030000003oool0
oooo07l0oooo00<0000005HoV`0000000P1G@I/01`000000FD6L0000001J@Y`0000005e3VP000000
0P1NA9/01@000000GTBK05i4V`1NA9/000000080GdFK00D000000696V`1RAY/0HTJK0000000306=7
V`030000001VBI/0ITVK00@0ITVK00<0000006Y<W01ZC9`00P1ZC9`01P000000JTbK06Y<V`000000
KdnL000000<0KdnL00H00000071?V`1`Ci/0L4nK0000001`Ci/200000080MU>L00@0000007ICV`1f
Di/000000P1gDi/010000000Me>K07MCV`00000207QCV`030000003Y[Y80jJjB00D0jJjB00D00000
0>VbVP000000l=5N000000020?CKL@030000003oool0oooo02h0oooo0`00002L0?ooo`030000003o
ool0oooo0280oooo000D0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0P03oool0
0`000000ESnK0000000205M1V`050000001I@I`0000005Y2W00000000P1M@iX010000000GTBK05i4
V`00000205i4V`040000001OAI/0GdFK000000@0HTJK00@0000006=7V`1SAi/000001P1VBI/01@00
0000JTbL06Y<W01ZC9`0000000<0JTbK00<0000006m?W00000000`1_Ci`01@000000L4nK071?V`1`
Ci/000000080L4nK00@0000007ICW01fDi`000000P1fDi/010000000Me>K07MCV`00000207MCV`04
0000001hDi/0N5>K000000L0jJjB00D000000>VbVP000000l=5N000000020?CKLC@0oooo0P00002J
0?ooo`030000003oool0oooo0280oooo000D0?ooo`030000003oool0oooo0740oooo00<000000?oo
o`3oool0PP3oool01@000000ESnK0000001G@I/000000080FD6L0P00000205e3VP040000001NA9/0
GTBK00000080GTBK00<0000005m5V`1OAI/00P0000040696V`030000001SAi/0000000L0ITVK00@0
000006Y<W01ZC9`00000101ZC9/2000000<0KdnL00D00000071?V`1`Ci/0L4nK00000002071?V`04
0000001fDi`0MU>L00000080MU>K00@0000007MCV`1gDi/000000P1gDi/010000000N5>K07QCV`00
00080>V^TP80000000@0l=5N0000003dfg40m=]a=P3oool2000009T0oooo00<000000?ooo`3oool0
8@3oool001@0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`230?ooo`030000001F
?i/000000080Ed6K00<0000005U1W00000000P00000205e3VP040000001NA9/0GTBK00000080GTBK
00@0000005m5V`00000000001@1RAY/2000000L0ITVK00<0000006Y<W00000001@1ZC9/2000000<0
KdnL00@00000071?V`1`Ci/000000`1`Ci/20000000507ICW0000000MU>K07ICV`0000000P1gDi/0
1`000000Me>K07MCV`1gDi/0000007QCV`000000203Y[Y82000000040?3AGP000000m=]a000003P0
oooo0P00002G0?ooo`030000003oool0oooo0240oooo000D0?ooo`030000003oool0oooo06h0oooo
0P0000260?ooo`030000001F?i/000000080Ed6K00<0000005U1W00000000P00000205e3VP040000
001NA9/0GTBK00000080GTBK00D0000005m5V`000000HDFJ000000040696V`030000001SAi/00000
00H0ITVK00<0000006Y<W00000001P1ZC9/01@000000KdnL06m?W01_Ci`000000080L4nK00@00000
071?V`1`Ci/0L4nK0P00000207ICW0030000001fDi/0000000<0Me>K00H0000007MCV`1gDi/00000
07QCV`0000080>V^TP80000000@0l=5N0000003dfg400000>P3oool2000009D0oooo00<000000?oo
o`3oool08@3oool001@0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`270?ooo`03
0000001F?i/000000080Ed6K00D0000005U1W0000000G4:J0000000205e3VP030000001NA9/00000
00<0GTBK0P0000020655VP030000001RAY/0HTJK0080HTJK0P00000606I9V`030000001ZC9`00000
00H0JTbK00D0000006m?W01_Ci`0KdnL00000002071?V`0;0000001`Ci/0L4nK071?V`000000L4nK
0000001fDi`0000007ICV`0000000`1gDi/01P000000Me>K07MCV`000000N5>K000000P0jJjB00D0
00000?3AGP3`dEh000000?CKL@0m0?ooo`800000T`3oool00`000000oooo0?ooo`0Q0?ooo`004`3o
ool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo08P0oooo00<0000005HoV`0000000P1G
@I/01@000000FD6L0000001L@YX000000080GD>J00@0000005i4V`1NA9/000000P1NA9/00`000000
GdFK000000020655VP030000001RAY/0HTJK0080HTJK1000000406I9V`030000001ZC9/0JTbK00D0
JTbK00D0000006m?W01_Ci`0KdnL00000002071?V`0;0000001`Ci/0L4nK071?V`000000L4nK0000
001fDi`0000007ICV`0000000`1gDi/01P000000Me>K07MCV`000000N5>K000000P0jJjB00D00000
0?3AGP3`dEh000000?CKL@0o0?ooo`800000T@3oool00`000000oooo0?ooo`0Q0?ooo`004`3oool0
0`000000oooo0?ooo`1/0?ooo`030000003oool0oooo08T0oooo00<0000005HoV`0000000P1G@I/0
1@000000FD6L0000001L@YX000000080GD>J00@0000005i4V`1NA9/000000`1NA9/200000080HDFJ
00<000000696V`1RAY/00P1RAY/010000000IDRK06E8V`1UB9/5000000H0JTbK00<0000006Y;V`00
00000P1_Ci`010000000L4nK071?V`000003071?V`030000001`Ci/0L4nK0080000000<0MU>K0000
001gDi/00P1gDi/01P000000Me>K07MCV`000000N5>K000000P0jJjB00<000000?3AGP0000000P00
00110?ooo`<00000S`3oool00`000000oooo0?ooo`0P0?ooo`004`3oool00`000000oooo0?ooo`1[
0?ooo`030000003oool0oooo08/0oooo00<0000005HoV`0000000P1G@I/30000000505a2VP000000
GD>J05e3VP0000000P1NA9/00`000000GTBK05i4V`02000000<0HDFJ00D000000696V`1RAY/0HTJK
0000000706E8V`030000001ZC9/0JTbK00@0JTbK00<0000006Y;V`0000000P1_Ci`010000000L4nK
071?V`000003071?V`030000001`Ci/0L4nK0080000000<0MU>K0000001gDi/00P1gDi/01P000000
Me>K07MCV`000000N5>K000000P0jJjB00<000000?3AGP0000000P0000140?ooo`800000S@3oool0
0`000000oooo0?ooo`0P0?ooo`004`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo
08`0oooo00<0000005HoV`0000000P1G@I/30000000505a2VP000000GD>J05e3VP0000000P1NA9/0
1@000000GTBK05i4V`1NA9/0000000@0HDFJ00D000000696V`1RAY/0HTJK0000000606E8V`030000
001ZC9/0JTbK00<0JTbK00H0000006Y;V`1ZBi/0000006m?W0000003071?V`050000001`Ci/0L4nK
071?V`0000000`1`Ci/010000000MU>K07ICV`00000207MCV`040000001gDi/0Me>K00000080N5>K
00<000000>V^TP3Y[Y801@3Y[Y800`000000l=5N00000002000004H0oooo0P00002:0?ooo`800000
8P3oool001<0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`2=0?ooo`030000001F
?i/000000080Ed6K0P000000101K@IT0000005a2VP00000205e3VP040000001NA9/0GTBK00000080
GTBK00<000000655VP1QAIX00`1QAIX010000000HTJK0696V`00000706E8V`030000001ZC9/0JTbK
0080JTbK00H0000006Y;V`1ZBi/0000006m?W0000003071?V`050000001`Ci/0L4nK071?V`000000
0`1`Ci/010000000MU>K07ICV`00000207MCV`040000001gDi/0Me>K00000080N5>K00<000000>V^
TP3Y[Y80103Y[Y82000000030?3AGP000000m=]a04T0oooo0P0000270?ooo`030000003oool00000
0280oooo000C0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0S`3oool00`000000
ESnK0000000205M1V`050000001K@IT0000005a2VP0000000P1M@iX010000000GTBK05i4V`000002
05i4V`800000101QAIX010000000HTJK0696V`00000706E8V`050000001ZC9/0JTbK06Y<V`000000
101ZBi/2000000<0L4nK00D00000071?V`1`Ci/0L4nK00000003071?V`80000000D0MU>K0000001g
Di/0Me>K0000000207MCV`040000001hDi/0N5>K000000H0jJjB0P0000000`3`dEh000000000001;
0?ooo`800000Q`3oool00`000000oooo0?ooo`0P0?ooo`004P3oool00`000000oooo0?ooo`1W0?oo
o`800000TP3oool00`000000ESnK0000000205M1V`030000001K@IT000000080G4:J00@0000005e3
VP1M@iX000000P1NA9/010000000GTBK0000000000050655VP030000001RAY/0000000L0IDRK00D0
000006Y<V`1ZC9/0JTbK0000000406Y;V`8000000`1`Ci/01@000000L4nK071?V`1`Ci/0000000<0
L4nK0P0000001@1fDi/0000007MCV`1gDi/000000080Me>K00@0000007QCV`1hDi/000001P3Y[Y82
000000030?3AGP000000000004d0oooo0P0000250?ooo`030000003oool0oooo0200oooo000B0?oo
o`030000003oool0oooo06H0oooo00<000000?ooo`3oool0TP3oool00`000000ESnK0000000205M1
V`060000001K@IT0Fd6I0000001L@YX000000P1M@iX020000000GTBK05i4V`000000GTBK0000001Q
AIX000001@1QAIX2000000L0IDRK00@0000006Y<V`1ZC9/000001@1ZBi/2000000<0L4nK00D00000
071?V`1`Ci/0L4nK00000003071?V`80000000D0MU>K0000001gDi/0Me>K0000000207MCV`040000
001hDi/0N5>K000000H0jJjB0P0000000`3`dEh000000000001?0?ooo`800000Q03oool00`000000
oooo0?ooo`0O0?ooo`004P3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo09@0oooo
00@0000005HoV`000000Ed6K0P000000101K@IT0000005a2VP00000305e3VP030000001NA9/0GTBK
008000000P1QAIX00`000000HDFJ0655VP030655VP8000001P1UB9/010000000JTbK06Y<V`000006
06Y;V`050000001`Ci/0L4nK071?V`0000000`1`Ci/01P000000L4nK071?V`1`Ci/00000071?VP80
00000P1gDi/010000000Me>K07MCV`00000207QCV`030000003Y[Y80jJjB00@0jJjB00@000000?3A
GP3`dEh00000DP3oool300000840oooo00<000000?ooo`3oool07`3oool00180oooo00<000000?oo
o`3oool0I03oool00`000000oooo0?ooo`2E0?ooo`040000001F?i/0000005M1V`8000000P1K@IT0
0`000000G4:J0000000205e3VP080000001NA9/0GTBK0000001NA9/000000655VP0000050655VP80
00001P1UB9/00`000000JTbK0000000706Y;V`050000001`Ci/0L4nK071?V`0000000`1`Ci/01P00
0000L4nK071?V`1`Ci/00000071?VP8000000P1gDi/01`000000Me>K07MCV`1gDi/0000007QCV`00
00001P3Y[Y8010000000l=5N0?3AGP00001E0?ooo`800000O`3oool00`000000oooo0?ooo`0O0?oo
o`004P3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo09H0oooo00@0000005HoV`00
000000000P1J@9T01@000000Fd6I0000001L@YX0000000<0GD>J00<0000005i4V`1NA9/00P000002
0655VP030000001QAIX0HDFJ00<0HDFJ0P00000606E8V`8000001`1ZBi/01@000000L4nK071?V`1`
Ci/0000000<0L4nK00D00000071?V`1`Ci/0L4nK00000002071?VP040000001gDi/0Me>K000000<0
Me>K00<0000007QCV`0000001@3Y[Y82000000030?3AGP000000000005L0oooo0P00001m0?ooo`03
0000003oool0oooo01l0oooo000B0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0
V03oool00`000000ESnK0000000205Y0V@030000001K@IT000000080G4:J00@0000005e3VP1M@iX0
00000P1NA9/2000000<0HDFJ00<000000655VP1QAIX00P1QAIX00`000000IDNJ0000000300000080
IDRK00<0000006Y;V`1ZBi/01@1ZBi/00`000000JD^K00000002071?V`050000001`Ci/0L4nK071?
V`0000000`1`Ci/010000000L4nJ071?VP00000207MCV`070000001gDi/0Me>K07MCV`000000N5>K
000000050>V^TP80000000<0l=5N000000000000F@3oool2000007/0oooo00<000000?ooo`3oool0
7`3oool00140oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`2I0?ooo`030000001F
?i/000000080FT2I00H0000005]1V@1K@IT0000005a2VP00000205e3VP050000001NA9/0GTBK05i4
V`0000000`1QAIX00`000000HDFJ0655VP020655VP030000001UAiX0IDNJ00<0IDNJ0`00000706Y;
V`050000001YBi/00000071?V`000000101`Ci/01@000000L4nK071?V`1`Ci/000000080L4nJ0P00
000207MCV`060000001gDi/0Me>K0000001hDi/000001@3Y[Y82000000030?3AGP000000oooo05/0
oooo0P00001j0?ooo`030000003oool0oooo00L0oooo0P00000E0?ooo`004@3oool00`000000oooo
0?ooo`1Q0?ooo`030000003oool0oooo09X0oooo00<0000005HoV`0000000`1J@9T01@000000Fd6I
0000001L@YX0000000<0GD>J00@0000005i4V`1NA9/00000101QAIX01@000000HDFJ0655VP1QAIX0
000000L0IDNJ00<0000006Y;V`1ZBi/0101ZBi/01P000000JD^K06U;V`000000L4nK000000<0L4nK
00D00000071?V`1`Ci/0L4nK00000003071?VP8000000P1gDi/01P000000Me>K07MCV`000000N5>K
000000D0jJjB0P0000000`3`dEh000000?ooo`1M0?ooo`800000N03oool00`000000oooo0?ooo`06
0?ooo`040000003oool0oooo000001@0oooo000A0?ooo`030000003oool0oooo05l0oooo0P00002N
0?ooo`<000000P1J@9T01P000000Fd6I05]1V@000000G4:J00000080GD>J00<0000005i4V`1NA9/0
0P0000040655VP040000001QAIX0HDFJ000000P0IDNJ00<0000006Y;V`1ZBi/00`1ZBi/01P000000
JD^K06U;V`000000L4nK000000<0L4nK00D00000071?V`1`Ci/0L4nK00000003071?VP050000001a
CiX0000007MCV`0000000P1gDi/00`000000N5>K000000050>V^TP80000000<0l=5N0000003oool0
G`3oool2000007H0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00000D0?ooo`00
4@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo09h0oooo0`00000305Y0V@050000
001K@IT0000005a2VP0000000`1M@iX010000000GTBK0000000000050655VP030000001QAIX00000
00P0IDNJ00<0000006Y;V`1ZBi/00P1ZBi/00`000000JD^K06U;V`0206U;V`8000000`1`Ci/01@00
0000L4nK071?V`1`Ci/0000000<0L4nJ00D00000075?VP000000Me>K0000000207MCV`040000001h
Di/0N5>K000000<0jJjB00D000000>_7C@000000l=5N0000001R0?ooo`800000M03oool00`000000
oooo0?ooo`060?ooo`<000005@3oool00140oooo00<000000?ooo`3oool0G@3oool00`000000oooo
0?ooo`2O0?ooo`80000000L0FCnI0000001J@9T0FT2I0000001K@IT000000080G4:J00P0000005e3
VP1M@iX0000005i4V`000000H4BJ000000@0HDFJ00@000000655VP1QAIX000001`1UAiX00`000000
JT^K06Y;V`0206Y;V`030000001YBi/0JD^K0080JD^K0P000003071?V`050000001`Ci/0L4nK071?
V`0000000`1`CiX00`000000LDnJ075?VP0200000080Me>K00@0000007QCV`1hDi/000000`3Y[Y80
1@000000jlM=0000003`dEh0000006@0oooo0`00001a0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool05@3oool00140oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`2Q
0?ooo`030000001I?iT000000080FT2I00H0000005]1V@1K@IT0000005a2VP00000305e3VP800000
0P1PA9X00`000000HDFJ0655VP020655VP030000001QAIX0000000L0IDNJ00<0000006Y;V`1ZBi/0
0P1ZBi/00`000000JD^K06U;V`0206U;V`8000000`1`Ci/01@000000L4nK071?V`1`Ci/0000000<0
L4nJ00<00000075?VP1aCiX00P00000207MCV`040000001hDi/0N5>K000000<0jJjB0`0000000`3`
dEh0oooo0?ooo`1V0?ooo`800000K`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
01D0oooo000@0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0XP3oool00`000000
FCnI0000000305Y0V@030000001K@IT000000080G4:J00P0000005e3VP1M@iX0000005i4V`000000
H4BJ000000D0HDFJ0P00000806E7VP040000001ZBi/0JT^K000000H0JD^K00D00000071?V`1`Ci/0
L4nK00000003071?V`050000001`CiX0L4nJ071?VP0000000`1aCiX010000000Me>K07MCV`000002
07QCV`040000003Y[Y80jJjB0>V^TP<0000000<0l=5N0?ooo`3oool0J03oool2000006h0oooo00<0
00000?ooo`3oool01P3oool3000001@0oooo000@0?ooo`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool0X`3oool010000000FCnI05ToV@00000205Y0V@060000001K@IT0Fd6I0000001L@YX0
00000`1M@iX200000080H4BJ00<000000655VP1QAIX00P1QAIX2000000P0IDNJ00@0000006Y;V`1Z
Bi/000001P1YBi/01@000000L4nK071?V`1`Ci/0000000<0L4nK00D00000071?VP1`CiX0L4nJ0000
0003075?VP040000001gDi/0Me>K00000080N5>K00@000000>V^TP3Y[Y80jJjB0`0000000`3`dEh0
oooo0?ooo`1Z0?ooo`800000K03oool00`000000oooo0?ooo`0M0?ooo`00403oool00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo0:D0oooo00<0000005ToV@0000000`1J@9T01@000000Fd6I
0000001L@YX0000000<0GD>J0P0000030614VP030000001QAIX0HDFJ0080HDFJ0P00000706E7VP03
0000001ZBi/0000000L0JD^K00D00000071?V`1`Ci/0L4nK00000003071?V`050000001`CiX0L4nJ
071?VP0000000`1aCiX20000000507MCV`000000N5>K07QCV`0000000`3Y[Y82000000030?3AGP00
0000oooo06d0oooo0P00001Z0?ooo`030000003oool0oooo01d0oooo000@0?ooo`030000003oool0
oooo05T0oooo00<000000?ooo`3oool0YP3oool010000000FCnI05ToV@00000205Y0V@030000001K
@IT000000080G4:J00D0000005e3VP1M@iX0GD>J000000030614VP030000001QAIX0HDFJ0080HDFJ
00<0000006A7VP0000000P00000406E7VP030000001ZBi/0000000H0JD^K00<0000006U:VP000000
0P1`Ci/01@000000L4nK071?V`1`Ci/000000080L4nJ00<00000075?VP1aCiX00P1aCiX200000080
Me>K00<0000007QCV`0000000P3Y[Y801@000000jlM=0000003`dEh000000700oooo0P00001X0?oo
o`030000003oool0oooo01d0oooo000@0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0Z03oool00`000000FCnI0000000205Y0V@060000001K@IT0Fd6I0000001L@YX000000`1M@iX0
0`000000H4BJ0614VP020614VP050000001QAIX0HDFJ0655VP000000101TAiX40000000306E7VP00
0000JD^K00H0JD^K00<0000006U:VP0000000P1`Ci/01@000000L4nK071?V`1`Ci/000000080L4nJ
00<00000075?VP1aCiX00P1aCiX01`000000LDnJ0000001gDi/0000007QCV`0000000P3Y[Y801@00
0000jlM=0000003`dEh000000780oooo0P00001U0?ooo`8000007`3oool00100oooo00<000000?oo
o`3oool0EP3oool200000:/0oooo00@0000005ToV@1I?iT000000P1J@9T00`000000Fd6I00000002
05a2VP030000001M@iX0GD>J00800000101PA9X01@000000HDFJ0655VP1QAIX0000000L0I4NJ0P00
000606U;V`070000001YBYX0JDZJ06U:VP000000L4nK00000003071?V`040000001`CiX0L4nJ0000
00@0LDnJ00L00000075?VP000000Me>K0000001hDi/000000080jJjB00@000000>_7C@000000l=5N
M@3oool300000640oooo00@000000?ooo`3oool000007P3oool000l0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`2[0?ooo`040000001I?iT0FCnI00000080FT2I00H0000005]1V@1K
@IT0000005a2VP00000205e3VP800000101PA9X01@000000HDFJ0655VP1QAIX0000000P0I4NJ00<0
000006U;V`1YBi/0101YBi/01`000000JDZJ06U:VP1YBYX00000071?V`0000000`1`Ci/010000000
L4nJ071?VP000004075?VP030000001aCiX0LDnJ0080000000P0N5>K0000003Y[Y80jJjB0000003[
add000000?3AGWP0oooo0P00001N0?ooo`050000003oool0oooo0?ooo`0000007P3oool000l0oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`2]0?ooo`030000001I?iT0000000<0FT2I
00<0000005]1V@0000000P1L@YX205e3VP030000001O@iT0000000@0H4BJ00@000000655VP1QAIX0
00002@1TAiX00`000000JD^K06U;V`0306U;V`070000001YBYX0JDZJ06U:VP000000L4nK00000003
071?V`040000001`CiX0L4nJ000000@0LDnJ00<00000075?VP1aCiX00P000000201hDi/000000>V^
TP3Y[Y8000000>_7C@000000l=5NNP3oool200000600oooo00<000000?ooo`3oool0703oool000l0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2^0?ooo`040000001I?iT0FCnI0000
0080FT2I00<0000005]1V@0000000P1L@YX00`000000GD>J0000000205m3V@030000001PA9X0H4BJ
0080H4BJ00<000000655VP0000002@1TAiX00`000000JD^K06U;V`0206U;V`030000001YBYX0JDZJ
00<0JDZJ0P000003071?V`040000001`CiX0L4nJ000000@0LDnJ00T00000075?VP1aCiX0LDnJ0000
001hDi/000000>V^TP0000000P3[add2000007`0oooo0P00001N0?ooo`030000003oool0oooo01`0
oooo000?0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0/03oool00`000000FCnI
0000000205Y0V@040000001K@IT0Fd6I00000080G4:J00D0GD>J0000001O@iT0Gd>I000000040614
VP030000001QAIX0000000T0I4NJ00<0000006U;V`1YBi/00P1YBi/00`000000JDZJ06U:VP0306U:
VP8000000`1`Ci/010000000L4nJ071?VP000004075?VP090000001aCiX0LDnJ075?VP000000N5>K
0000003Y[Y8000000080jlM=0P00001n0?ooo`800000G03oool00`000000oooo0?ooo`0L0?ooo`00
3`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0;40oooo00@0000005ToV@1I?iT0
00000P1J@9T00`000000Fd6I0000000205a2VP8000000`1O@iT00`000000H4BJ0614VP020614VP80
00002@1TAiX01@000000JD^K06U;V`1YBi/0000000L0JDZJ00D00000071?V`1`Ci/0L4nK00000002
071?VP030000001aCiX0LDnJ0080LDnJ00@00000075?VP1aCiX0LDnJ0P000000101hDi/000000000
003[add300000800oooo0P00001J0?ooo`030000003oool0oooo01`0oooo000?0?ooo`030000003o
ool0oooo0540oooo00<000000?ooo`3oool0/P3oool010000000FCnI05ToV@00000205Y0V@040000
001K@IT0Fd6I00000080G4:J00<0000005m3V@1O@iT00P1O@iT00`000000H4BJ0614VP020614VP80
00002@1TAiX010000000JD^K06U;V`00000706U:VP050000001`Ci/0L4nK071?V`0000000P1`CiX0
1@000000LDnJ075?VP1aCiX0000000@0LDnJ0P000000101hDi/000000000003[add2000008<0oooo
0P00001I0?ooo`030000003oool0oooo01/0oooo000>0?ooo`030000003oool0oooo0540oooo00<0
00000?ooo`3oool0]03oool00`000000FCnI0000000205Y0V@040000001K@IT0Fd6I00000080G4:J
00<0000005m3V@1O@iT00P1O@iT00`000000H4BJ0614VP020614VP8000002@1TAiX010000000JD^K
06U;V`00000706U:VP050000001`Ci/0L4nK071?V`0000000P1`CiX01@000000LDnJ075?VP1aCiX0
000000@0LDnJ0P000000101hDi/000000000003[add2000008D0oooo0P00001G0?ooo`030000003o
ool0oooo01/0oooo000>0?ooo`030000003oool0oooo04l0oooo0P00002g0?ooo`040000001I?iT0
FCnI00000080FT2I00<0000005]1V@0000000P1L@YX00`000000Gd>I05m3V@0305m3V@030000001P
A9X0H4BJ0080H4BJ0P00000806A7VP030000001YBi/0000000L0JDZJ00D0000006U:VP000000L4nK
00000003071?VP050000001aCiX0LDnJ075?VP000000101aCiX00`000000LDjJ0000000200000003
0>_7C@000000000008L0oooo0`00001D0?ooo`030000003oool0oooo01/0oooo000>0?ooo`030000
003oool0oooo04h0oooo00<000000?ooo`3oool0^03oool00`000000FCnI0000000205Y0V@050000
001K@IT0Fd6I0000001L@YX00P00000405m3V@030000001PA9X0H4BJ0080H4BJ00<0000006A6VP00
00000`00000406A7VP030000001YBi/0000000L0JDZJ00D0000006U:VP000000L4nK00000003071?
VP050000001aCiX0LDnJ075?VP000000101aCiX010000000LDjJ0000000000020>_7C@800000RP3o
ool200000580oooo00<000000?ooo`3oool06`3oool000h0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`2i0?ooo`040000001I?iT0FCnI00000080FT2I00@0000005]1V@000000G4:J
0P00000505m3V@050000001PA9X0H4BJ0614VP0000001@1TAYX40000000306A7VP000000JDZJ00H0
JDZJ00H0000006U:VP1YBYX00000071?V`000003071?VP050000001aCiX0LDnJ075?VP000000101a
CiX010000000LDjJ075>VP0000020>_7C@800000S03oool200000500oooo00<000000?ooo`3oool0
6`3oool000h0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`2j0?ooo`040000001I
?iT0FCnI00000080FT2I00<0000005]1V@1K@IT00P0000000`1N@iT0000005m3V@0405m3V@050000
001PA9X0H4BJ0614VP000000201TAYX2000000L0JDZJ00H0000006U:VP1YBYX00000071?V`000003
071?VP050000001aCiX0LDnJ075?VP0000000`1aCiX01@000000LDjJ075>VP1aCYX000000080jlM=
0P00002>0?ooo`800000C`3oool00`000000oooo0?ooo`0J0?ooo`003P3oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo0;`0oooo00<0000005ToV@0000000P1J@9T00`000000Fd6I05]1
V@0200000080GT>I00<0000005m3V@1O@iT00P1O@iT01@000000H4BJ0614VP1PA9X0000000T0I4JJ
00<0000006U:VP1YBYX0101YBYX00`000000JDZJ06U:VP0206U:VP8000000`1`CiX01@000000LDnJ
075?VP1aCiX0000000<0LDnJ00D00000075>VP1aCYX0LDjJ000000020>_7C@030000003oool0oooo
08l0oooo0P00001=0?ooo`030000003oool0oooo01X0oooo000=0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0_@3oool010000000FCnI05ToV@00000205Y0V@070000001K@IT0Fd6I
05a2VP000000GT>I0000000505m3V@040000001PA9X0H4BJ000000T0I4JJ00<0000006U:VP1YBYX0
101YBYX00`000000JDZJ06U:VP0206U:VP8000000`1`CiX01@000000LDnJ075?VP1aCiX0000000<0
LDnJ00D00000075>VP1aCYX0LDjJ000000020>_7C@030000003oool0oooo0940oooo0P00001;0?oo
o`030000003oool0oooo01X0oooo000=0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool0_`3oool00`000000FCnI0000000205Y0V@030000001K@IT0Fd6I008000000P1N@iT00`000000
Gd>I05m3V@0305m3V@030000001PA9X0000000X0I4JJ00<0000006U:VP1YBYX00P1YBYX00`000000
JDZJ06U:VP0306U:VP8000000`1`CiX01@000000LDnJ075?VP1aCiX0000000<0LDnJ00D00000075>
VP1aCYX0LDjJ000000020>_7C@030000003oool0oooo09<0oooo0P0000190?ooo`030000003oool0
oooo01X0oooo000=0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0`03oool01000
0000FCnI05ToV@00000205Y0V@040000001K@IT0Fd6I000000<0GT>I00<0000005m3V@1O@iT00P1O
@iT00`000000H4BJ0000000:06A6VP030000001YBYX0JDZJ0080JDZJ00<0000006U:VP1YBYX0101Y
BYX01@000000L4nJ071?VP1`CiX0000000<0LDnJ00D00000075?VP1aCiX0LDnJ00000003075>VP04
0000003[add00000000009L0oooo0`0000160?ooo`030000003oool0oooo01X0oooo000=0?ooo`03
0000003oool0oooo04L0oooo0P0000330?ooo`040000001I?iT0FCnI00000080FT2I00@0000005]1
V@1K@IT000000`1N@iT00`000000Gd>I05m3V@0305m3V@8000002P1TAYX01@000000JDZJ06U:VP1Y
BYX0000000L0JDZJ00D00000071?VP1`CiX0L4nJ00000003075?VP050000001aCiX0LDnJ075?VP00
00000`1aCYX010000000jlM=00000000002J0?ooo`800000A03oool00`000000oooo0?ooo`0J0?oo
o`003@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0<@0oooo00H0000005ToV@1I
?iT0000005Y0V@00000205]1V@030000001N@iT0GT>I0080GT>I00<0000005m3V@1O@iT00`1O@iT2
000000T0I4JJ00D0000006U:VP1YBYX0JDZJ0000000706U:VP050000001`CiX0L4nJ071?VP000000
0`1aCiX01@000000LDnJ075?VP1aCiX0000000<0LDjJ00@000000>_7C@0000000000W03oool20000
04<0oooo00<000000?ooo`3oool06@3oool000d0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`350?ooo`040000001I?iT0FCnI00000080FT2I00@0000005]1V@0000000000101N@iT0
0`000000Gd>I05m3V@0205m3V@8000002@1TAYX010000000JDZJ06U:VP00000706U:VP050000001Y
BIT00000071?VP000000101aCiX01@000000LDnJ075?VP1aCiX0000000<0LDjJ00<000000>_7C@00
0000W`3oool200000400oooo0P00000K0?ooo`00303oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo0<L0oooo00<0000005ToV@0000000P1J@9T010000000Fd6I00000000000405i3V@03
0000001O@iT0Gd>I00<0Gd>I0P00000806A6VP040000001YBYX0JDZJ000000L0JDZJ00D0000006U9
V@000000L4nJ00000004075?VP050000001aCiX0LDnJ075?VP0000000`1aCYX00`000000jlM=0000
002Q0?ooo`800000?@3oool00`000000oooo0000000K0?ooo`00303oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo0<P0oooo00@0000005ToV@1I?iT000000P1J@9T20000000305i2V000
0000GT>I00<0GT>I00<0000005m3V@1O@iT00P1O@iT00`000000HdJI00000003000000D0I4JJ0P00
000706U:VP060000001YBIT0JDVI0000001`CiX00000101aCiX01@000000LDnJ075?VP1aCiX00000
00<0LDjJ00<000000>_7C@000000X`3oool2000003d0oooo00<000000?ooo`3oool06@3oool000`0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`390?ooo`040000001I?iT0FCnI0000
0080FT2I0P00000205i2V0050000001N@iT0GT>I05i3V@000000101O@iT00`000000HdJI06=6V@03
06=6V@@0000000<0I4JJ0000000000001`1YBYX01P000000JDVI06U9V@000000L4nJ000000@0LDnJ
00D00000075?VP1aCiX0LDnJ00000003075>VP030000003[add000000:D0oooo0P00000k0?ooo`03
0000003oool0oooo01T0oooo000<0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
b`3oool010000000FCnI05ToV@00000205Y0V@0405]1V@000000GT:H000000@0GT>I00D0000005m3
V@1O@iT0Gd>I0000000906=6V@8000001`1YBYX00`000000JDVI06U9V@0206U9V@800000101aCiX0
1@000000LDnJ075?VP1aCiX0000000<0LDjJ00<000000>_7C@000000Y`3oool3000003T0oooo00<0
00000?ooo`3oool0603oool000`0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3<
0?ooo`040000001I?iT0FCnI00000080FT2I0P00000205i2V0030000001N@iT0GT>I0080GT>I00D0
000005m3V@1O@iT0Gd>I0000000906=6V@030000001YBYX0JDZJ00D0JDZJ00<0000006U9V@1YBIT0
0P1YBIT2000000@0LDnJ00D00000075?VP1aCiX0LDnJ00000003075>VP030000003[add000000:X0
oooo0P00000g0?ooo`030000003oool0oooo01P0oooo000<0?ooo`030000003oool0oooo03l0oooo
0P00003@0?ooo`030000001I?iT0000000<0FT2I00@0000005i2V01N@YP00000101N@iT01@000000
Gd>I05m3V@1O@iT0000000T0HdJI00<0000006U:VP1YBYX0101YBYX00`000000JDVI06U9V@0306U9
V@800000101aCiX01@000000LDnJ075?VP1aCiX000000080LDjJ00@000000>_7C@3[add00000[03o
ool2000003D0oooo00<000000?ooo`3oool0603oool000/0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`3@0?ooo`040000001I?iT0FCnI00000080FT2I00D0000005i2V01N@YP0GT:H
0000000405i3V@040000001O@iT0Gd>I000000X0HdJI00<0000006U:VP1YBYX00`1YBYX00`000000
JDVI06U9V@0306U9V@800000101aCiX01@000000LDnJ075?VP1aCiX000000080LDjJ00@000000>_7
C@3[add00000[P3oool2000003<0oooo00<000000?ooo`3oool0603oool000/0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`3A0?ooo`040000001I?iT0FCnI00000080FT2I00<00000
05i2V01N@YP00P1N@YP00`000000GT>I05i3V@0205i3V@030000001O@iT0000000X0HdJI00<00000
06U:VP1YBYX00`1YBYX00`000000JDVI06U9V@0406U9V@030000001aCiX0LDnJ0080LDnJ00D00000
075?VP1aCiX0LDnJ00000002075>VP030000003[add0jlM=0;40oooo0P00000a0?ooo`030000003o
ool0oooo01P0oooo000;0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0d`3oool0
1@000000FCnI05ToV@000000FT2I008000000`1N@YP00`000000GT>I05i3V@0205i3V@030000001O
@iT0000000X0HdJI00<0000006U:VP1YBYX00P1YBYX00`000000JDVI06U9V@0506U9V@030000001a
CiX0LDnJ0080LDnJ00@00000075?VP1aCiX000000`1aCYX00`000000jlM=0>_7C@2c0?ooo`800000
;`3oool00`000000oooo0?ooo`0H0?ooo`002`3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0=@0oooo00D0000005ToV@1I?iT0000005Y0V@02000000@0GT:H00<0000005i3V@1N@iT0
0P1N@iT2000000X0HdJI00<0000006U:VP1YBYX00P1YBYX00`000000JDVI06U9V@0506U9V@050000
001aCiX0LDnJ075?VP0000000`1aCiX01@000000LDjJ075>VP1aCYX000000080jlM=]@3oool20000
02h0oooo00<000000?ooo`3oool05`3oool000/0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`3F0?ooo`030000001I?iT0FCnI0080000000<0GD6H0000001N@YP00`1N@YP00`000000
GT>I05i3V@0205i3V@8000002P1SAYT010000000JDZJ06U:VP00000706U9V@030000001YBIT00000
0080LDnJ00D00000075?VP1aCiX0LDnJ00000003075>VP030000003[add000000;L0oooo0P00000/
0?ooo`030000003oool0oooo01L0oooo000;0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0e`3oool00`000000FCnI05ToV@020000000305e1V0000000GT:H00<0GT:H00<0000005i3
V@1N@iT00P1N@iT2000000X0HdJI00@0000006U:VP1YBYX000001`1YBIT00`000000JDVI00000002
075?VP050000001aCiX0LDnJ075?VP0000000`1aCYX00`000000jlM=0000002i0?ooo`<00000:@3o
ool00`000000oooo0?ooo`0G0?ooo`002P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo0=P0oooo00P0000005ToV@1I?iT0FCnI05Y0V@000000GD6H000000@0GT:H00<0000005i3V@1N
@iT00P1N@iT2000000T0HdJI00<0000006U:VP0000001`1YBIT010000000JDVI06U9V@000002075?
VP050000001aCiX0LDnJ075?VP0000000`1aCYX00`000000jlM=0000002l0?ooo`8000009`3oool0
0`000000oooo0?ooo`0G0?ooo`002P3oool00`000000oooo0?ooo`0h0?ooo`800000g03oool00`00
0000FCnI05ToV@0200000080GD6H00<0000005i2V01N@YP00P1N@YP01P000000GT>I05i3V@1N@iT0
000006=5V@@000001@1SAYT00`000000JDZJ0000000706U9V@070000001YBIT0JDVI06U9V@000000
LDnJ00000003075?VP070000001aCYX0LDjJ075>VP000000jlM=0000002n0?ooo`8000009@3oool0
0`000000oooo0?ooo`0G0?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0=`0oooo00D0000005ToV@1I?iT0FCnI0000000205e1V0030000001N@YP0GT:H0080GT:H00D00000
05i3V@1N@iT0GT>I0000000506=5V@@000000P1SAYT00`000000JDVI06U9V@0506U9V@030000001Y
BIT0JDVI0080JDVI00<00000075?VP0000000`1aCiX01`000000LDjJ075>VP1aCYX000000>_7C@00
0000`03oool2000002@0oooo00<000000?ooo`3oool05P3oool000X0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`3N0?ooo`040000001I?iT0FCnI000000<0GD6H00<0000005i2V01N
@YP00P1N@YP01@000000GT>I05i3V@1N@iT0000000P0HdFI0`00000706U9V@030000001YBIT0JDVI
00<0JDVI0P000003075?VP070000001aCYX0LDjJ075>VP000000jlM=000000320?ooo`8000008P3o
ool00`000000oooo0?ooo`0F0?ooo`002P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo0=l0oooo00@0000005ToV@1I?iT000000`1M@IP00`000000GT:H05i2V00305i2V0040000001N
@iT0GT>I000000X0HdFI00<0000006U9V@1YBIT01@1YBIT00`000000JDVI06U9V@0306U9V@800000
0`1aCiX01`000000LDjJ075>VP1aCYX000000>_7C@000000a03oool200000200oooo00<000000?oo
o`3oool05P3oool000X0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3P0?ooo`03
0000001I?iT0FCnI008000000`1M@IP00`000000GT:H05i2V00205i2V0040000001N@iT0GT>I0000
00X0HdFI00<0000006U9V@1YBIT0101YBIT00`000000JDVI06U9V@0406U9V@8000000`1aCiX01P00
0000LDjJ075>VP1aCYX000000>_7CLL0oooo0P00000N0?ooo`030000003oool0oooo01H0oooo0009
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0hP3oool010000000FCnI00000000
000405e1V0030000001N@YP0GT:H0080GT:H00<0000005i3V@0000002`1SAIT00`000000JDVI06U9
V@0306U9V@030000001YBIT0JDVI00D0JDVI00D00000075?VP1aCiX0LDnJ00000003075>VP800000
b@3oool3000001/0oooo00<000000?ooo`3oool05P3oool000T0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`3S0?ooo`050000001I?iT0000005e1U`0000000`1M@IP00`000000GT:H
05i2V00205i2V0030000001N@iT0000000/0HdFI00<0000006U9V@1YBIT00P1YBIT00`000000JDVI
06U9V@0606U9V@050000001aCiX0LDnJ075?VP0000000`1aCYX200000<`0oooo0P00000H0?ooo`80
0000603oool000T0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3U0?ooo`800000
00<0GD6G0000001M@IP00`1M@IP00`000000GT:H05i2V00205i2V08000002`1SAIT00`000000JDVI
06U9V@0206U9V@030000001YBIT0JDVI00H0JDVI00D00000075?VP1aCiX0LDnJ00000003075>VP80
0000cP3oool2000001D0oooo00@000000?ooo`3oool000005`3oool000T0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`3V0?ooo`8000000P1M@IL01@000000GD6H05e1V01M@IP00000
00D0GT:H0P00000:06=5V@030000001YBIT0JDVI0080JDVI00<0000006U9V@1YBIT01@1YBIT00`00
0000JDVI00000002075?VP040000001aCYX0LDjJ075>VP800000d03oool2000001H0oooo00<00000
0?ooo`3oool05@3oool000T0oooo00<000000?ooo`3oool0;`3oool200000>T0oooo00D0000005To
V@000000GD6G0000000405e1V0030000001N@YP0GT:H00<0GT:H00<0000006=5V@1SAIT02@1SAIT0
10000000JDVI06U9V@00000806U9V@030000001YBIT000000080LDnJ00@00000075>VP1aCYX0LDjJ
0P00003B0?ooo`800000503oool00`000000oooo0?ooo`0E0?ooo`002@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0>X0oooo0P00000205e1U`030000001M@IP0GD6H0080GD6H00<0
000005i2V01N@YP00P1N@YP2000000X0HdFI00@0000006U9V@1YBIT000001`1YBIT01P000000JDVI
06U9V@000000LDnJ000000@0LDjJ0P00003D0?ooo`8000004P3oool00`000000oooo0?ooo`0E0?oo
o`00203oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0>/0oooo0P00000305e1U`05
0000001M@IP0GD6H05e1V0000000101N@YP00`000000HTFH00000002000000L0HdFI00<0000006U9
V@000000201YBIT01P000000JDVI06U9V@000000LDnJ000000@0LDjJ0P00003F0?ooo`800000403o
ool00`000000oooo0?ooo`0E0?ooo`00203oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo0>d0oooo00D0000005e1U`1M@IL0GD6G0000000405e1V0050000001N@YP0GT:H05i2V0000000
101RAIP4000000<0HdFI00<0000006U9V@0000001`1YBIT00`000000JDVI06U9V@0206U9V@800000
101aCYX200000=P0oooo0P00000?0?ooo`030000003oool0oooo01@0oooo00080?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool0kP3oool00`000000GD6G05e1U`0205e1U`030000001M
@IP0GD6H0080GD6H00@0000005i2V01N@YP00000201RAIP30000000306=5V@000000JDVI00L0JDVI
00<0000006U9V@1YBIT00P1YBIT2000000@0LDjJ0P00003J0?ooo`<00000303oool00`000000oooo
0?ooo`0D0?ooo`00203oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0?00oooo00D0
000005e1U`1M@IL0GD6G0000000405e1V0050000001N@YP0GT:H05i2V00000002P1RAIP2000000P0
JDVI00<0000006U9V@1YBIT00P1YBIT2000000@0LDjJ00<000000?ooo`3oool0g03oool2000000X0
oooo00<000000?ooo`3oool0503oool000P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`3a0?ooo`030000001M@IL0GD6G0080GD6G00<0000005e1V01M@IP00P1M@IP010000000GT:H
05i2V000000;0695V0030000001YBIT0JDVI00D0JDVI00<0000006U9V@1YBIT00`1YBIT2000000@0
LDjJ00<000000?ooo`3oool0gP3oool2000000P0oooo00<000000?ooo`3oool0503oool000P0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3c0?ooo`030000001M@IL0GD6G0080GD6G
00D0000005e1V01M@IP0GD6H0000000205i2V0030000001RAIP0HTFH00T0HTFH00<0000006U9V@1Y
BIT01@1YBIT00`000000JDVI06U9V@0406U9V@030000001aCYX0LDjJ0080LDjJ00<000000?ooo`3o
ool0h03oool2000000H0oooo00<000000?ooo`3oool0503oool000L0oooo00<000000?ooo`3oool0
:03oool200000?H0oooo00<0000005e1U`1M@IL00P1M@IL00`000000GD6H05e1V00205e1V0030000
001N@YP0000000`0HTFH00<0000006U9V@1YBIT00`1YBIT00`000000JDVI06U9V@0506U9V@040000
001aCYX0LDjJ075>VP800000i03oool2000000@0oooo00<000000?ooo`3oool0503oool000L0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`3g0?ooo`030000001M@IL0GD6G0080GD6G
00<0000005e1V01M@IP00P1M@IP2000000`0HTFH00<0000006U9V@1YBIT00`1YBIT00`000000JDVI
06U9V@0506U9V@040000001aCYX0LDjJ075>VP800000iP3oool2000000<0oooo00<000000?ooo`3o
ool04`3oool000L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3h0?ooo`030000
001M@IL0GD6G0080GD6G00<0000005e1V01M@IP00P1M@IP2000000`0HTFH00<0000006U9V@1YBIT0
0P1YBIT00`000000JDVI06U9V@0506U9V@030000001YBIP000000080LDjJ0P00003X0?ooo`800000
00<0oooo0000003oool0503oool000L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`3j0?ooo`030000001M@IL0GD6G0080GD6G00<0000005e1V01M@IP00P1M@IP2000000/0HTFH00<0
000006U9V@1YBIT00P1YBIT00`000000JDVI06U9V@0506U9V@030000001YBIP000000080LDjJ0P00
003Z0?ooo`8000005@3oool000L0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3l
0?ooo`050000001M@IL0GD6G05e1U`0000001@1M@IP00`000000HTFH0695V00:0695V0050000001Y
BIT0JDVI06U9V@0000001P1YBIT010000000JDVH06U9V0000002075>VP800000h`3oool00`000000
oooo0?ooo`030?ooo`8000005P3oool000L0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`3m0?ooo`030000001M@IL0GD6G0080GD6G00<0000005e1V01M@IP00P1M@IP2000000/0HTFH
00@0000006U9V@1YBIT000001`1YBIT01P000000JDVH06U9V01YBIP00000075>VP800000h`3oool0
10000000oooo0?ooo`3oool2000001P0oooo00060?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0o`3oool00`000000GD6G05e1U`0205e1U`060000001M@IP0GD6H05e1V0000000HTBH
0`0000080695V0040000001YBIT0JDVI000000L0JDVI00H0000006U9V01YBIP0JDVH0000001aCYX2
00000>@0oooo0`00000J0?ooo`001P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
0?l0oooo0@3oool00`000000GD6G05e1U`0205e1U`050000001M@IP0GD6H05e1V0000000101RA9P2
000000H0HTFH00<0000006U9V@0000001`1YBIT00`000000JDVH06U9V00206U9V0030000001aCYX0
00000>D0oooo00<000000?ooo`3oool06P3oool000H0oooo00<000000?ooo`3oool0803oool20000
0?l0oooo1@3oool00`000000GD6G05e1U`0205e1U`040000001M@IP0GD6H000000H0HTBH0`000004
0695V08000001`1YBIT00`000000JDVH06U9V00306U9V0800000h`3oool2000001d0oooo00060?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0o`3oool50?ooo`030000001M@IL0GD6G
0080GD6G00D0000005e1V01M@IP0GD6H000000080694V0<0000000<0HTFH0000001YBIT01P1YBIT0
0`000000JDVH06U9V00406U9V0800000h@3oool2000001l0oooo00060?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0o`3oool70?ooo`030000001M@IL0GD6G0080GD6G00@0000005e1
V01M@IP000002`1RA9P2000000L0JDVI00<0000006U9V01YBIP0101YBIP200000=l0oooo0P00000Q
0?ooo`001P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0oooo2@3oool00`00
0000GD6G05e1U`0205e1U`030000001M@IP0000000`0HTBH00<0000006U9V@1YBIT01@1YBIT00`00
0000JDVH06U9V00506U9V0030000003oool0oooo0=/0oooo0P00000S0?ooo`001@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0oooo2P3oool00`000000GD6G05e1U`0205e1U`03
0000001M@IP0000000`0HTBH00<0000006U9V@1YBIT0101YBIT00`000000JDVH06U9V00606U9V003
0000003oool0oooo0=X0oooo00<000000?ooo`3oool08`3oool000D0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`3o0?ooo``0oooo00<0000005e1U`1M@IL00P1M@IL2000000d0HTBH
00<0000006U9V@1YBIT00`1YBIT00`000000JDVH06U9V00606U9V0030000003oool0oooo0=P0oooo
0P00000V0?ooo`001@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?l0oooo3@3o
ool00`000000GD6G05e1U`0205e1U`8000003@1RA9P00`000000JDVI06U9V@0306U9V@030000001Y
BIP0JDVH00D0JDVH00<000000?ooo`3oool0e`3oool2000002P0oooo00050?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0o`3oool?0?ooo`030000001M@IL0GD6G0080GD6G0P00000<
0694V0030000001YBIT0JDVI0080JDVI00<0000006U9V01YBIP01P1YBIP00`000000oooo0?ooo`3E
0?ooo`800000:P3oool000D0oooo00<000000?ooo`3oool0603oool200000?l0oooo4`3oool00`00
0000GD6G05e1U`0205e1U`030000001RA9P0HTBH00X0HTBH00<0000006U9V@1YBIT00P1YBIT00`00
0000JDVH06U9V00506U9V0030000003oool0oooo0=D0oooo00<000000?ooo`3oool0:P3oool000D0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?oooa<0oooo00<0000005e1U`1M
@IL00P1M@IL2000000`0HTBH00@0000006U9V@1YBIT00000201YBIP00`000000oooo0?ooo`3C0?oo
o`800000;@3oool000@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?oooaD0
oooo00H0000005e1U`1M@IL0GD6G0000001RA9P2000000X0HTBH00@0000006U9V@1YBIT00000201Y
BIP00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00<0oooo0P00000_0?ooo`00103oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?l0oooo5P3oool01@000000GD6G05e1U`1M
@IL0000000<0HTBH0`0000070694V0040000001YBIT0JDVI000000L0JDVH00<000000?ooo`3oool0
c03oool010000000oooo0?ooo`3oool200000340oooo00040?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0o`3ooolH0?ooo`040000001M@IL0GD6G000000H0HTBH0P0000050694V003
0000001YBIT0000000P0JDVH00<000000?ooo`3oool0c@3oool00`000000oooo0000000c0?ooo`00
103oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo6@3oool01@000000GD6G
05e1U`1M@IL0000000L0HTBH0`0000030694V08000001`1YBIP00`000000oooo0?ooo`3>0?ooo`80
0000=03oool000@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?oooa/0oooo
00@0000005e1U`1M@IL000002P1RA9P2000000030694V0000000JDVH00L0JDVH00<000000?ooo`3o
ool0c03oool2000003H0oooo00040?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
o`3ooolM0?ooo`030000001M@IL0000000`0HTBH0P00000706U9V0030000003oool0oooo0</0oooo
0P00000h0?ooo`000`3oool00`000000oooo0?ooo`0A0?ooo`800000o`3ooolP0?ooo`030000001M
@IL0000000d0HTBH00<0000006U9V01YBIP01@1YBIP00`000000oooo0?ooo`390?ooo`800000>P3o
ool000<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooob40oooo0P00000=
0694V0030000001YBIP0JDVH00D0JDVH00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0j
0?ooo`000`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo8P3oool20000
00h0HTBH00<0000006U9V01YBIP00`1YBIP00`000000oooo0?ooo`370?ooo`800000?@3oool000<0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooob<0oooo0`00000=0694V003
0000001YBIP0JDVH00<0JDVH00<000000?ooo`3oool0a@3oool2000003l0oooo00030?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`<000003@1RA9P00`000000JDVH
06U9V00206U9V0030000003oool0oooo0<@0oooo0P0000110?ooo`000`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0?l0oooo9@3oool010000000oooo00000000000<0694V0030000
001YBIP0JDVH0080JDVH00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`110?ooo`000P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0oooo9P3oool010000000oooo0?oo
o`3oool2000000/0HTBH00D0000006U9V01YBIP0JDVH0000002j0?ooo`030000003oool0oooo00H0
oooo0P0000140?ooo`000P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo
9`3oool00`000000oooo0?ooo`030?ooo`8000002@1RA9P010000000JDVH06U9V000002k0?ooo`03
0000003oool0oooo00@0oooo0P0000160?ooo`000P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0?l0oooo:03oool00`000000oooo0?ooo`050?ooo`8000001`1RA9P010000000JDVH
06U9V000002k0?ooo`030000003oool0oooo0080oooo0P0000180?ooo`000P3oool00`000000oooo
0?ooo`080?ooo`800000o`3oool[0?ooo`030000003oool0oooo00L0oooo0`0000040694V0030000
001YBIP000000;d0oooo00@000000?ooo`3oool00000BP3oool00080oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`3o0?ooob/0oooo00<000000?ooo`3oool02P3oool2000000<0HTBH
0P00002m0?ooo`<00000B`3oool00080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`3o0?ooob`0oooo00<000000?ooo`3oool0303oool2000000030694V0000000oooo0;`0oooo0P00
001=0?ooo`0000<0oooo0000003oool01`3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<00000
0?ooo`3oool03P3oool200000;/0oooo0P00001?0?ooo`0000<0oooo0000003oool01P3oool00`00
0000oooo0?ooo`3o0?ooobl0oooo00<000000?ooo`3oool0b03oool200000540oooo00000`3oool0
00000?ooo`050?ooo`030000003oool0oooo0?l0oooo<03oool00`000000oooo0?ooo`370?ooo`03
0000003oool0oooo0540oooo00000`3oool000000?ooo`040?ooo`030000003oool0oooo0?l0oooo
<@3oool00`000000oooo0?ooo`350?ooo`800000E03oool000030?ooo`000000oooo00<0oooo00<0
00000?ooo`3oool0o`3ooolb0?ooo`030000003oool0oooo0<<0oooo0P00001F0?ooo`0000@0oooo
0000003oool0oooo0P00003o0?ooocD0oooo00<000000?ooo`3oool0`@3oool2000005P0oooo0000
10000000oooo0?ooo`00003o0?ooocL0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?oo
o`1H0?ooo`0000<000000?ooo`000000o`3ooolh0?ooo`030000003oool0oooo0;h0oooo0P00001K
0?ooo`000P00003o0?ooocT0oooo00<000000?ooo`3oool0_03oool2000005d0oooo0002000000@0
oooo00<000000?ooo`3oool0o`3ooolb0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool00P3oool2000001@0oooo100000170?ooo`000P3oool3000000030?ooo`000000oooo0?l0oooo
<`3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo008000005P3oool00`000000oooo
0?ooo`180?ooo`001@3oool300000?l0oooo<`3oool00`000000oooo0?ooo`2f0?ooo`8000006@3o
ool00`000000oooo0?ooo`170?ooo`001P3oool00`000000oooo0000000200000?l0oooo<03oool0
0`000000oooo0?ooo`2e0?ooo`8000004`3oool4000000@0oooo00<000000?ooo`3oool0AP3oool0
00/0oooo0`00003o0?ooobd0oooo00<000000?ooo`3oool0/`3oool2000001h0oooo00<000000?oo
o`3oool0A@3oool000h0oooo0`00003o0?ooobX0oooo00<000000?ooo`3oool0/@3oool2000001d0
oooo00@000000?ooo`3oool00000A`3oool00140oooo0`00003o0?ooobL0oooo00<000000?ooo`3o
ool0/03oool00`000000oooo0?ooo`0N0?ooo`800000B03oool001@0oooo0`00003o0?ooob@0oooo
00<000000?ooo`3oool0[P3oool2000006/0oooo000G0?ooo`<00000o`3ooolQ0?ooo`030000003o
ool0oooo0:`0oooo0P00001]0?ooo`006P3oool300000?l0oooo7P3oool00`000000oooo0?ooo`2Z
0?ooo`800000K`3oool001d0oooo0`0000030?ooo`030000003oool0oooo0?l0oooo5@3oool00`00
0000oooo0?ooo`2Y0?ooo`030000003oool0oooo06l0oooo000P0?ooo`@00000o`3ooolG0?ooo`03
0000003oool0oooo0:L0oooo0P00001b0?ooo`008`3oool300000?l0oooo5@3oool00`000000oooo
0?ooo`2O0?ooo`030000003oool0oooo00<0oooo0P00001d0?ooo`009P3oool300000?l0oooo4P3o
ool00`000000oooo0?ooo`2O0?ooo`040000003oool0oooo0?ooo`800000MP3oool002T0oooo0`00
003o0?ooo`l0oooo00<000000?ooo`3oool0W`3oool010000000oooo00000000001h0?ooo`00;03o
ool300000?l0oooo303oool00`000000oooo0?ooo`2O0?ooo`800000NP3oool002l0oooo0`00003o
0?ooo`T0oooo00<000000?ooo`3oool0WP3oool2000007/0oooo000b0?ooo`<000002P3oool00`00
0000oooo0?ooo`3h0?ooo`030000003oool0oooo09`0oooo0P00001m0?ooo`00=@3oool3000000L0
oooo00<000000?ooo`3oool0n03oool00`000000oooo0?ooo`2J0?ooo`800000O`3oool003P0oooo
0`0000040?ooo`030000003oool0oooo0?P0oooo00<000000?ooo`3oool0V@3oool00`000000oooo
0?ooo`1o0?ooo`00>`3oool3000000030?ooo`000000oooo0?T0oooo00<000000?ooo`3oool0U`3o
ool200000880oooo000n0?ooo`<00000n@3oool00`000000oooo0?ooo`2E0?ooo`800000Q03oool0
0440oooo0`00003f0?ooo`030000003oool0oooo09<0oooo0P0000260?ooo`00A03oool300000?<0
oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`260?ooo`00A`3oool300000?00oooo
00<000000?ooo`3oool0T03oool2000008T0oooo001:0?ooo`<00000k@3oool00`000000oooo0?oo
o`290?ooo`030000003oool0oooo0080oooo0P00002;0?ooo`00C@3oool200000>/0oooo00<00000
0?ooo`3oool0R@3oool00`000000oooo0?ooo`02000008d0oooo001?0?ooo`<00000j03oool00`00
0000oooo0?ooo`2:0?ooo`800000S`3oool00580oooo0`0000050?ooo`030000003oool0oooo0=d0
oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2?0?ooo`00E@3oool300000080oooo
00<000000?ooo`3oool0g@3oool00`000000oooo0?ooo`270?ooo`800000TP3oool005P0oooo0`00
003O0?ooo`030000003oool0oooo08D0oooo0P00002D0?ooo`00FP3oool400000=`0oooo00<00000
0?ooo`3oool0P`3oool2000009H0oooo001N0?ooo`<00000f@3oool00`000000oooo0?ooo`220?oo
o`030000003oool0oooo09H0oooo000n0?ooo`@000007`3oool300000=H0oooo00<000000?ooo`3o
ool0P03oool2000009T0oooo000n0?ooo`030000003oool0oooo02<0oooo0`00003C0?ooo`030000
003oool0oooo07h0oooo0P00002K0?ooo`00?`3oool00`000000oooo0?ooo`0U0?ooo`<00000d03o
ool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00D0oooo0P00002M0?ooo`00>03oool4
000000@0oooo00<000000?ooo`3oool09`3oool300000<d0oooo00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo09d0oooo00110?ooo`030000003oool0oooo
02T0oooo0`0000050?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0M03oool00`00
0000oooo0?ooo`020?ooo`800000X03oool003h0oooo00@000000?ooo`3oool00000;P3oool30000
0080oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`1d0?ooo`040000003oool00000
00000:80oooo000o0?ooo`800000<P3oool300000<D0oooo00<000000?ooo`3oool0M03oool20000
0:@0oooo001f0?ooo`<00000`P3oool00`000000oooo0?ooo`1b0?ooo`800000YP3oool007T0oooo
0`00002o0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0YP3oool007`0oooo0`00
002l0?ooo`030000003oool0oooo06l0oooo0P00002Y0?ooo`00O`3oool300000;T0oooo00<00000
0?ooo`3oool0K@3oool200000:/0oooo00220?ooo`<00000]P3oool00`000000oooo0?ooo`1[0?oo
o`800000[@3oool008D0oooo0`00002c0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3o
ool0[@3oool008P0oooo0`0000040?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0
J03oool200000;00oooo002;0?ooo`<0000000<0oooo0000003oool0ZP3oool00`000000oooo0?oo
o`1V0?ooo`800000/P3oool008h0oooo0`00002Z0?ooo`030000003oool0oooo05l0oooo00<00000
0?ooo`3oool00P3oool200000;@0oooo002A0?ooo`<00000Y`3oool00`000000oooo0?ooo`1O0?oo
o`050000003oool0oooo0?ooo`000000]P3oool009@0oooo0`00002T0?ooo`030000003oool0oooo
05l0oooo00@000000?ooo`00000000004@3oool200000:@0oooo002G0?ooo`<00000X@3oool00`00
0000oooo0?ooo`1O0?ooo`8000004P3oool010000000oooo0?ooo`00002S0?ooo`00VP3oool30000
00/0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`1M0?ooo`800000503oool01000
0000oooo0?ooo`00002S0?ooo`00W@3oool3000000P0oooo00<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`1K0?ooo`8000005P3oool010000000oooo0?ooo`00002S0?ooo`00X03oool30000
00D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo
01H0oooo00@000000?ooo`3oool00000X`3oool00:<0oooo0`0000020?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool0F03oool2000001T0oooo00@000000?ooo`3oool00000X`3oool0
0:H0oooo0`00002B0?ooo`030000003oool0oooo05H0oooo0P00000L0?ooo`800000Y03oool00:P0
oooo1000002?0?ooo`030000003oool0oooo05@0oooo0P0000340?ooo`00[03oool3000008`0oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`340?ooo`00[`3oool3000008T0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`030?ooo`800000a`3oool00;80oooo0`000026
0?ooo`030000003oool0oooo04/0oooo00@000000?ooo`3oool0oooo0P0000390?ooo`00]@3oool3
000008<0oooo00<000000?ooo`3oool0B`3oool010000000oooo00000000003;0?ooo`00^03oool3
000000H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1;0?ooo`800000c@3oool0
0;/0oooo0`0000030?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0BP3oool20000
0<h0oooo002n0?ooo`@00000N@3oool00`000000oooo0?ooo`180?ooo`800000d03oool00<40oooo
0`00001g0?ooo`030000003oool0oooo04H0oooo0P00003B0?ooo`00a03oool3000007@0oooo00<0
00000?ooo`3oool0A03oool200000=@0oooo00370?ooo`<00000L@3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo0=@0oooo002V0?ooo`8000008P3oool3000006h0oooo00<000000?oo
o`3oool0@@3oool200000=L0oooo002U0?ooo`040000003oool0oooo000002@0oooo0`00001[0?oo
o`030000003oool0oooo03l0oooo0P00003I0?ooo`00Y@3oool010000000oooo0?ooo`00000W0?oo
o`<000001P3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool00P3oool200000=/0oooo002U0?ooo`040000003oool0oooo000002X0oooo0`0000030?oo
o`030000003oool0oooo05l0oooo00<000000?ooo`3oool0>03oool01@000000oooo0?ooo`3oool0
00000=d0oooo002U0?ooo`040000003oool0oooo000002d0oooo1000001Q0?ooo`030000003oool0
oooo03P0oooo00@000000?ooo`0000000000gP3oool00:D0oooo00@000000?ooo`3oool00000<03o
ool3000005l0oooo00<000000?ooo`3oool0>03oool200000>00oooo002V0?ooo`800000=03oool3
000005`0oooo00<000000?ooo`3oool0=P3oool200000>80oooo003O0?ooo`<00000F@3oool00`00
0000oooo0?ooo`0d0?ooo`800000i03oool00>80oooo0`00001F0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0i03oool00>D0oooo0`00001C0?ooo`030000003oool0oooo0340oooo
0P00003W0?ooo`00j03oool3000000H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`0_0?ooo`800000j@3oool00>/0oooo0P0000040?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`040?ooo`800000j`3oool00>d0oooo0`0000000`3o
ool000000?ooo`180?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3[0?ooo`00l03oool3000004P0oooo00<000000?ooo`3oool09P3oool010000000
oooo0?ooo`3oool200000>h0oooo003c0?ooo`<00000A@3oool00`000000oooo0?ooo`0V0?ooo`04
0000003oool0000000000?00oooo003f0?ooo`<00000@P3oool00`000000oooo0?ooo`0V0?ooo`80
0000lP3oool00?T0oooo0`00000<0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`3b0?ooo`00o03oool3000000T0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0R0?ooo`800000m@3oool00?l0oooo0`0000060?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool0803oool200000?L0oooo003o0?ooo`<0oooo0`0000030?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool07P3oool200000?T0oooo003o0?ooo`H0
oooo1000000c0?ooo`030000003oool0oooo01`0oooo0P00003k0?ooo`00o`3oool90?ooo`<00000
<@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0?/0oooo003o0?ooo``0oooo0`00
000^0?ooo`030000003oool0oooo01T0oooo0P00003n0?ooo`00o`3oool?0?ooo`<00000:`3oool0
0`000000oooo0?ooo`0C0?ooo`040000003oool0oooo0?ooo`800000o`3oool10?ooo`00o`3ooolB
0?ooo`<00000:03oool00`000000oooo0?ooo`0C0?ooo`040000003oool00000000005d0oooo1000
002Q0?ooo`00o`3ooolE0?ooo`<000009@3oool00`000000oooo0?ooo`0C0?ooo`800000H03oool0
10000000oooo0?ooo`00002P0?ooo`00o`3ooolH0?ooo`<000001@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo0180oooo0P00000?0?ooo`@00000CP3oool010000000oooo0?ooo`00
002P0?ooo`00o`3ooolK0?ooo`<000000P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo0100oooo0P00000A0?ooo`030000003oool0oooo04l0oooo00@000000?ooo`3oool00000X03o
ool00?l0oooo7P3oool3000001`0oooo00<000000?ooo`3oool03P3oool2000001@0oooo00<00000
0?ooo`3oool0CP3oool300000:40oooo003o0?ooob40oooo0`00000I0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
0:40oooo003o0?ooob@0oooo0`00000F0?ooo`030000003oool0oooo00/0oooo0P00000I0?ooo`03
0000003oool0oooo04/0oooo0P00002S0?ooo`00o`3ooolW0?ooo`<000004`3oool00`000000oooo
0?ooo`090?ooo`800000603oool010000000oooo0?ooo`00003b0?ooo`00o`3oool70?ooo`@00000
7`3oool300000100oooo00D000000?ooo`3oool0oooo000000050?ooo`8000006`3oool200000?<0
oooo003o0?ooo`L0oooo00<000000?ooo`3oool08`3oool3000000H0oooo00<000000?ooo`3oool0
103oool01@000000oooo0?ooo`3oool0000000<0oooo0P00003o0?oooa<0oooo003o0?ooo`P0oooo
00<000000?ooo`3oool09@3oool3000000<0oooo00<000000?ooo`3oool0103oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00o`3oool90?ooo`030000
003oool0oooo02L0oooo100000060?ooo`040000003oool0oooo0?ooo`<00000o`3ooolF0?ooo`00
o`3oool:0?ooo`030000003oool0oooo02T0oooo0`0000040?ooo`030000003oool0oooo00800000
o`3ooolH0?ooo`00o`3oool70?ooo`040000003oool0oooo000002h0oooo0`000000103oool00000
00000000003o0?oooaX0oooo003o0?ooo`P0oooo0P00000b0?ooo`800000o`3ooolL0?ooo`00o`3o
oooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00Y@3oool200000003
0?ooo`000000oooo0?l0oooo[`3oool00:@0oooo00@000000?ooo`3oool00000o`3ooona0?ooo`00
Y@3oool300000?l0oooo/@3oool00:L0oooo00<000000?ooo`3oool0o`3ooon_0?ooo`00Y@3oool2
00000?l0oooo/P3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0oooo
FP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0
ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo0000\
\>"],
  ImageRangeCache->{{{0, 599.625}, {642.75, 0}} -> {0.0771478, -0.00899975, \
0.00150304, 0.00150304}}]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
CellGrouping->Manual,
WindowSize->{1024, 694},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 47, 0, 118, "Title"],

Cell[CellGroupData[{
Cell[1777, 54, 278, 10, 45, "Subsection",
  Evaluatable->False],
Cell[2058, 66, 1221, 23, 251, "Input"],
Cell[3282, 91, 84, 2, 27, "Input"],
Cell[3369, 95, 795, 21, 80, "Input"],

Cell[CellGroupData[{
Cell[4189, 120, 96, 2, 27, "Input"],
Cell[4288, 124, 324, 7, 69, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4661, 137, 210, 7, 29, "Subsection",
  Evaluatable->False],
Cell[4874, 146, 115, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5014, 153, 103, 3, 42, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5142, 160, 76, 2, 27, "Input"],
Cell[5221, 164, 191, 4, 23, "Message"],
Cell[5415, 170, 188, 4, 23, "Message"],
Cell[5606, 176, 187, 4, 23, "Message"],
Cell[5796, 182, 243, 4, 23, "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6088, 192, 53, 1, 42, "Subsubsection"],
Cell[6144, 195, 968, 24, 80, "Input"],

Cell[CellGroupData[{
Cell[7137, 223, 199, 5, 27, "Input"],
Cell[7339, 230, 605, 11, 77, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7993, 247, 53, 1, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[8071, 252, 158, 4, 27, "Input"],
Cell[8232, 258, 367, 7, 119, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8636, 270, 232, 4, 27, "Input"],
Cell[8871, 276, 524, 9, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9432, 290, 167, 4, 31, "Input"],
Cell[9602, 296, 159, 3, 50, "Output"]
}, Open  ]],
Cell[9776, 302, 215, 5, 27, "Input"],
Cell[9994, 309, 126, 3, 27, "Input"],
Cell[10123, 314, 627, 11, 139, "Input"],
Cell[10753, 327, 483, 8, 107, "Input"],

Cell[CellGroupData[{
Cell[11261, 339, 164, 4, 27, "Input"],
Cell[11428, 345, 45629, 1216, 199, 11205, 787, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57094, 1566, 289, 8, 59, "Input"],
Cell[57386, 1576, 52314, 1537, 201, 15437, 1077, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[109737, 3118, 186, 5, 27, "Input"],
Cell[109926, 3125, 62773, 1912, 206, 20591, 1387, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[172736, 5042, 137, 3, 27, "Input"],
Cell[172876, 5047, 36572, 1223, 186, 14518, 946, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[209485, 6275, 190, 5, 40, "Input"],
Cell[209678, 6282, 60647, 1335, 293, 9652, 701, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[270374, 7623, 101, 3, 42, "Subsubsection",
  Evaluatable->False],
Cell[270478, 7628, 135, 3, 27, "Input"],

Cell[CellGroupData[{
Cell[270638, 7635, 658, 12, 123, "Input"],

Cell[CellGroupData[{
Cell[271321, 7651, 16133, 494, 186, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[287457, 8147, 16133, 494, 186, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[303593, 8643, 16129, 494, 186, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[319725, 9139, 16121, 494, 186, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[335849, 9635, 16131, 494, 193, 4244, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[351983, 10131, 16121, 494, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[368107, 10627, 16125, 494, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[384235, 11123, 15955, 492, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[400193, 11617, 15896, 491, 193, 4240, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[416092, 12110, 16048, 493, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[432143, 12605, 16129, 494, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[448275, 13101, 16121, 494, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[464399, 13597, 16131, 494, 193, 4244, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[480533, 14093, 16121, 494, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[496657, 14589, 16125, 494, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[512785, 15085, 16129, 494, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[528917, 15581, 16125, 494, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[545045, 16077, 16129, 494, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[561177, 16573, 16125, 494, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[577305, 17069, 16121, 494, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[593429, 17565, 16131, 494, 193, 4244, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[609563, 18061, 16121, 494, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[625687, 18557, 16129, 494, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[641819, 19053, 16048, 493, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[657870, 19548, 15896, 491, 193, 4240, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[673769, 20041, 15955, 492, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[689727, 20535, 16125, 494, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[705855, 21031, 16121, 494, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[721979, 21527, 16131, 494, 193, 4244, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[738113, 22023, 16121, 494, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[754237, 22519, 16129, 494, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[770369, 23015, 16133, 494, 193, 4246, 341, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[786551, 23515, 693, 13, 123, "Input"],

Cell[CellGroupData[{
Cell[787269, 23532, 23178, 581, 186, 4249, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[810450, 24115, 23179, 581, 186, 4250, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[833632, 24698, 23118, 580, 186, 4250, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[856753, 25280, 23191, 581, 186, 4250, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[879947, 25863, 23195, 581, 186, 4250, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[903145, 26446, 23199, 581, 186, 4250, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[926347, 27029, 22880, 577, 193, 4247, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[949230, 27608, 22625, 574, 193, 4247, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[971858, 28184, 22562, 574, 193, 4240, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[994423, 28760, 22682, 575, 193, 4247, 341, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1017108, 29337, 22876, 577, 193, 4247, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1039987, 29916, 23163, 581, 193, 4250, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1063153, 30499, 23199, 581, 193, 4250, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1086355, 31082, 23199, 581, 193, 4250, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1109557, 31665, 23159, 581, 193, 4250, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1132719, 32248, 23183, 581, 193, 4250, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1155905, 32831, 23190, 581, 193, 4249, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1179098, 33414, 23183, 581, 193, 4250, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1202284, 33997, 23159, 581, 193, 4250, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1225446, 34580, 23199, 581, 193, 4250, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1248648, 35163, 23199, 581, 193, 4250, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1271850, 35746, 23163, 581, 193, 4250, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1295016, 36329, 22876, 577, 193, 4247, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1317895, 36908, 22682, 575, 193, 4247, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1340580, 37485, 22562, 574, 193, 4240, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1363145, 38061, 22625, 574, 193, 4247, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1385773, 38637, 22880, 577, 193, 4247, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1408656, 39216, 23199, 581, 186, 4250, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1431858, 39799, 23195, 581, 186, 4250, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1455056, 40382, 23191, 581, 186, 4250, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1478250, 40965, 23118, 580, 186, 4250, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1501371, 41547, 23179, 581, 186, 4250, 341, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[1524601, 42134, 34, 0, 118, "Title"],

Cell[CellGroupData[{
Cell[1524660, 42138, 190, 6, 45, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[1524875, 42148, 90, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[1524968, 42152, 81, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1525086, 42158, 81, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[1525170, 42162, 63, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1525270, 42168, 31, 0, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[1525326, 42172, 975, 23, 46, "Input"],
Cell[1526304, 42197, 640, 15, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1526981, 42217, 73, 1, 27, "Input"],
Cell[1527057, 42220, 1397, 31, 130, "Output"]
}, Open  ]],
Cell[1528469, 42254, 277, 6, 47, "Input"],

Cell[CellGroupData[{
Cell[1528771, 42264, 104, 2, 27, "Input"],
Cell[1528878, 42268, 894, 23, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1529809, 42296, 64, 1, 27, "Input"],
Cell[1529876, 42299, 443, 12, 45, "Output"]
}, Open  ]],
Cell[1530334, 42314, 273, 6, 62, "Input"],

Cell[CellGroupData[{
Cell[1530632, 42324, 161, 3, 27, "Input"],
Cell[1530796, 42329, 340, 5, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1531173, 42339, 180, 3, 31, "Input"],
Cell[1531356, 42344, 60, 1, 28, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1531465, 42351, 31, 0, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[1531521, 42355, 316, 6, 43, "Input"],
Cell[1531840, 42363, 3709, 113, 176, "Output"]
}, Open  ]],
Cell[1535564, 42479, 382, 6, 99, "Input"],

Cell[CellGroupData[{
Cell[1535971, 42489, 132, 4, 27, "Input"],
Cell[1536106, 42495, 90464, 1982, 425, 17127, 1072, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1626619, 44483, 31, 0, 42, "Subsubsection"],
Cell[1626653, 44485, 468, 8, 123, "Input"],

Cell[CellGroupData[{
Cell[1627146, 44497, 157, 6, 57, "Input"],
Cell[1627306, 44505, 684262, 28622, 544, 497424, 26311, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[2311607, 73132, 45, 0, 118, "Title"],
Cell[2311655, 73134, 39, 0, 60, "Section"],
Cell[2311697, 73136, 39, 0, 60, "Section"],

Cell[CellGroupData[{
Cell[2311761, 73140, 169, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],

Cell[CellGroupData[{
Cell[2311955, 73148, 132, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],

Cell[CellGroupData[{
Cell[2312112, 73156, 114, 3, 27, "Input",
  InitializationCell->False],
Cell[2312229, 73161, 186, 4, 23, "Message"],
Cell[2312418, 73167, 185, 4, 23, "Message"],
Cell[2312606, 73173, 185, 4, 23, "Message"],
Cell[2312794, 73179, 243, 4, 23, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2313074, 73188, 53, 1, 42, "Subsubsection"],
Cell[2313130, 73191, 155, 5, 27, "Input",
  InitializationCell->False],
Cell[2313288, 73198, 384, 11, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2313709, 73214, 53, 1, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[2313787, 73219, 120, 6, 42, "Input",
  InitializationCell->False],
Cell[2313910, 73227, 614, 8, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2314561, 73240, 229, 5, 43, "Input"],
Cell[2314793, 73247, 74835, 1535, 242, 23225, 893, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2389643, 74785, 98, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[2389766, 74791, 99, 2, 27, "Input"],
Cell[2389868, 74795, 83322, 2538, 158, 39679, 1995, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2473239, 77339, 53, 1, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[2473317, 77344, 118, 3, 27, "Input",
  InitializationCell->False],
Cell[2473438, 77349, 513, 9, 61, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2473988, 77363, 359, 10, 44, "Input"],
Cell[2474350, 77375, 210, 3, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2474597, 77383, 201, 4, 27, "Input"],
Cell[2474801, 77389, 72485, 1505, 242, 23061, 890, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[2547337, 78900, 143925, 2387, 498, 23061, 890, "GraphicsData", \
"PostScript", "Graphics"],

Cell[CellGroupData[{
Cell[2691287, 81291, 199, 7, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],

Cell[CellGroupData[{
Cell[2691511, 81302, 141, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],
Cell[2691655, 81308, 178, 6, 42, "Input",
  InitializationCell->False]
}, Open  ]],
Cell[2691848, 81317, 132, 4, 42, "Subsubsection",
  Evaluatable->False,
  InitializationCell->False],

Cell[CellGroupData[{
Cell[2692005, 81325, 114, 3, 27, "Input",
  InitializationCell->False],
Cell[2692122, 81330, 186, 4, 23, "Message"],
Cell[2692311, 81336, 185, 4, 23, "Message"],
Cell[2692499, 81342, 185, 4, 23, "Message"],
Cell[2692687, 81348, 243, 4, 23, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2692967, 81357, 53, 1, 42, "Subsubsection"],
Cell[2693023, 81360, 308, 8, 42, "Input"],
Cell[2693334, 81370, 317, 8, 42, "Input"],
Cell[2693654, 81380, 273, 7, 44, "Input"],

Cell[CellGroupData[{
Cell[2693952, 81391, 80, 2, 27, "Input"],
Cell[2694035, 81395, 217, 3, 47, "Output"]
}, Open  ]],
Cell[2694267, 81401, 189, 5, 31, "Input"],
Cell[2694459, 81408, 148, 4, 27, "Input"],

Cell[CellGroupData[{
Cell[2694632, 81416, 195, 5, 46, "Input"],
Cell[2694830, 81423, 194, 3, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2695061, 81431, 239, 6, 46, "Input"],
Cell[2695303, 81439, 165, 2, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2695505, 81446, 240, 6, 46, "Input"],
Cell[2695748, 81454, 165, 2, 55, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2695962, 81462, 53, 1, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[2696040, 81467, 245, 6, 55, "Input"],
Cell[2696288, 81475, 130, 2, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2696455, 81482, 135, 3, 27, "Input",
  InitializationCell->False],
Cell[2696593, 81487, 220, 3, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2696850, 81495, 131, 3, 27, "Input",
  InitializationCell->False],
Cell[2696984, 81500, 220, 3, 55, "Output"]
}, Open  ]],
Cell[2697219, 81506, 95, 2, 27, "Input"],
Cell[2697317, 81510, 202, 5, 27, "Input"],
Cell[2697522, 81517, 203, 5, 27, "Input"],

Cell[CellGroupData[{
Cell[2697750, 81526, 314, 6, 75, "Input"],
Cell[2698067, 81534, 210383, 7700, 296, 127062, 6667, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2908465, 89237, 180, 4, 27, "Input"],
Cell[2908648, 89243, 236, 5, 43, "Input"],
Cell[2908887, 89250, 220, 5, 43, "Input"],
Cell[2909110, 89257, 255, 7, 31, "Input"],
Cell[2909368, 89266, 130, 3, 27, "Input"],

Cell[CellGroupData[{
Cell[2909523, 89273, 269, 5, 59, "Input"],
Cell[2909795, 89280, 125219, 3172, 292, 41628, 2135, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[3035053, 92457, 453385, 10700, 652, 127062, 6667, "GraphicsData", \
"PostScript", "Graphics"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

